# C:\Users\krgupta\Desktop\xsd-bindings\modifiedbyramittal.py
# -*- coding: utf-8 -*-
# PyXB bindings for NM:0fc19dc0c6315668ca059fd5839cdad268ce84d3
# Generated 2016-05-10 15:07:23.442000 by PyXB version 1.2.4 using Python 2.7.10.final.0
# Namespace AnetApi/xml/v1/schema/AnetApiSchema.xsd

from __future__ import unicode_literals
import pyxb
import pyxb.binding
import pyxb.binding.saxer
import io
import pyxb.utils.utility
import pyxb.utils.domutils
import sys
import pyxb.utils.six as _six

# Unique identifier for bindings created at the same time
_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:9221f480-16fb-11e6-8b8f-340286d38f0f')

# Version of PyXB used to generate the bindings
_PyXBVersion = '1.2.4'
# Generated bindings are not compatible across PyXB versions
if pyxb.__version__ != _PyXBVersion:
    raise pyxb.PyXBVersionError(_PyXBVersion)

# Import bindings for namespaces imported into schema
import pyxb.binding.datatypes

# NOTE: All namespace declarations are reserved within the binding
Namespace = pyxb.namespace.NamespaceForURI('AnetApi/xml/v1/schema/AnetApiSchema.xsd', create_if_missing=True)
Namespace.configureCategories(['typeBinding', 'elementBinding'])

def CreateFromDocument (xml_text, default_namespace=None, location_base=None):
    """Parse the given XML and use the document element to create a
    Python instance.

    @param xml_text An XML document.  This should be data (Python 2
    str or Python 3 bytes), or a text (Python 2 unicode or Python 3
    str) in the L{pyxb._InputEncoding} encoding.

    @keyword default_namespace The L{pyxb.Namespace} instance to use as the
    default namespace where there is no default namespace in scope.
    If unspecified or C{None}, the namespace of the module containing
    this function will be used.

    @keyword location_base: An object to be recorded as the base of all
    L{pyxb.utils.utility.Location} instances associated with events and
    objects handled by the parser.  You might pass the URI from which
    the document was obtained.
    """

    if pyxb.XMLStyle_saxer != pyxb._XMLStyle:
        dom = pyxb.utils.domutils.StringToDOM(xml_text)
        return CreateFromDOM(dom.documentElement, default_namespace=default_namespace)
    if default_namespace is None:
        default_namespace = Namespace.fallbackNamespace()
    saxer = pyxb.binding.saxer.make_parser(fallback_namespace=default_namespace, location_base=location_base)
    handler = saxer.getContentHandler()
    xmld = xml_text
    if isinstance(xmld, _six.text_type):
        xmld = xmld.encode(pyxb._InputEncoding)
    saxer.parse(io.BytesIO(xmld))
    instance = handler.rootObject()
    return instance

def CreateFromDOM (node, default_namespace=None):
    """Create a Python instance from the given DOM node.
    The node tag must correspond to an element declaration in this module.

    @deprecated: Forcing use of DOM interface is unnecessary; use L{CreateFromDocument}."""
    if default_namespace is None:
        default_namespace = Namespace.fallbackNamespace()
    return pyxb.binding.basis.element.AnyCreateFromDOM(node, default_namespace)


# Atomic simple type: {AnetApi/xml/v1/schema/AnetApiSchema.xsd}numericString
class numericString (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'numericString')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 9, 1)
    _Documentation = None
numericString._CF_pattern = pyxb.binding.facets.CF_pattern()
numericString._CF_pattern.addPattern(pattern='[0-9]+')
numericString._InitializeFacetMap(numericString._CF_pattern)
Namespace.addCategoryObject('typeBinding', 'numericString', numericString)

# Atomic simple type: {AnetApi/xml/v1/schema/AnetApiSchema.xsd}bankAccountTypeEnum
class bankAccountTypeEnum (pyxb.binding.datatypes.string, pyxb.binding.basis.enumeration_mixin):

    """An atomic simple type."""

    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'bankAccountTypeEnum')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 85, 1)
    _Documentation = None
bankAccountTypeEnum._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=bankAccountTypeEnum, enum_prefix=None)
bankAccountTypeEnum.checking = bankAccountTypeEnum._CF_enumeration.addEnumeration(unicode_value='checking', tag='checking')
bankAccountTypeEnum.savings = bankAccountTypeEnum._CF_enumeration.addEnumeration(unicode_value='savings', tag='savings')
bankAccountTypeEnum.businessChecking = bankAccountTypeEnum._CF_enumeration.addEnumeration(unicode_value='businessChecking', tag='businessChecking')
bankAccountTypeEnum._InitializeFacetMap(bankAccountTypeEnum._CF_enumeration)
Namespace.addCategoryObject('typeBinding', 'bankAccountTypeEnum', bankAccountTypeEnum)

# Atomic simple type: {AnetApi/xml/v1/schema/AnetApiSchema.xsd}echeckTypeEnum
class echeckTypeEnum (pyxb.binding.datatypes.string, pyxb.binding.basis.enumeration_mixin):

    """An atomic simple type."""

    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'echeckTypeEnum')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 93, 1)
    _Documentation = None
echeckTypeEnum._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=echeckTypeEnum, enum_prefix=None)
echeckTypeEnum.PPD = echeckTypeEnum._CF_enumeration.addEnumeration(unicode_value='PPD', tag='PPD')
echeckTypeEnum.WEB = echeckTypeEnum._CF_enumeration.addEnumeration(unicode_value='WEB', tag='WEB')
echeckTypeEnum.CCD = echeckTypeEnum._CF_enumeration.addEnumeration(unicode_value='CCD', tag='CCD')
echeckTypeEnum.TEL = echeckTypeEnum._CF_enumeration.addEnumeration(unicode_value='TEL', tag='TEL')
echeckTypeEnum.ARC = echeckTypeEnum._CF_enumeration.addEnumeration(unicode_value='ARC', tag='ARC')
echeckTypeEnum.BOC = echeckTypeEnum._CF_enumeration.addEnumeration(unicode_value='BOC', tag='BOC')
echeckTypeEnum._InitializeFacetMap(echeckTypeEnum._CF_enumeration)
Namespace.addCategoryObject('typeBinding', 'echeckTypeEnum', echeckTypeEnum)

# Atomic simple type: {AnetApi/xml/v1/schema/AnetApiSchema.xsd}paymentMethodEnum
class paymentMethodEnum (pyxb.binding.datatypes.string, pyxb.binding.basis.enumeration_mixin):

    """An atomic simple type."""

    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'paymentMethodEnum')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 104, 1)
    _Documentation = None
paymentMethodEnum._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=paymentMethodEnum, enum_prefix=None)
paymentMethodEnum.creditCard = paymentMethodEnum._CF_enumeration.addEnumeration(unicode_value='creditCard', tag='creditCard')
paymentMethodEnum.eCheck = paymentMethodEnum._CF_enumeration.addEnumeration(unicode_value='eCheck', tag='eCheck')
paymentMethodEnum.payPal = paymentMethodEnum._CF_enumeration.addEnumeration(unicode_value='payPal', tag='payPal')
paymentMethodEnum._InitializeFacetMap(paymentMethodEnum._CF_enumeration)
Namespace.addCategoryObject('typeBinding', 'paymentMethodEnum', paymentMethodEnum)

# Atomic simple type: {AnetApi/xml/v1/schema/AnetApiSchema.xsd}cardTypeEnum
class cardTypeEnum (pyxb.binding.datatypes.string, pyxb.binding.basis.enumeration_mixin):

    """An atomic simple type."""

    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'cardTypeEnum')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 112, 1)
    _Documentation = None
cardTypeEnum._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=cardTypeEnum, enum_prefix=None)
cardTypeEnum.Visa = cardTypeEnum._CF_enumeration.addEnumeration(unicode_value='Visa', tag='Visa')
cardTypeEnum.MasterCard = cardTypeEnum._CF_enumeration.addEnumeration(unicode_value='MasterCard', tag='MasterCard')
cardTypeEnum.AmericanExpress = cardTypeEnum._CF_enumeration.addEnumeration(unicode_value='AmericanExpress', tag='AmericanExpress')
cardTypeEnum.Discover = cardTypeEnum._CF_enumeration.addEnumeration(unicode_value='Discover', tag='Discover')
cardTypeEnum.JCB = cardTypeEnum._CF_enumeration.addEnumeration(unicode_value='JCB', tag='JCB')
cardTypeEnum.DinersClub = cardTypeEnum._CF_enumeration.addEnumeration(unicode_value='DinersClub', tag='DinersClub')
cardTypeEnum._InitializeFacetMap(cardTypeEnum._CF_enumeration)
Namespace.addCategoryObject('typeBinding', 'cardTypeEnum', cardTypeEnum)

# Atomic simple type: {AnetApi/xml/v1/schema/AnetApiSchema.xsd}accountTypeEnum
class accountTypeEnum (pyxb.binding.datatypes.string, pyxb.binding.basis.enumeration_mixin):

    """An atomic simple type."""

    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'accountTypeEnum')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 123, 1)
    _Documentation = None
accountTypeEnum._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=accountTypeEnum, enum_prefix=None)
accountTypeEnum.Visa = accountTypeEnum._CF_enumeration.addEnumeration(unicode_value='Visa', tag='Visa')
accountTypeEnum.MasterCard = accountTypeEnum._CF_enumeration.addEnumeration(unicode_value='MasterCard', tag='MasterCard')
accountTypeEnum.AmericanExpress = accountTypeEnum._CF_enumeration.addEnumeration(unicode_value='AmericanExpress', tag='AmericanExpress')
accountTypeEnum.Discover = accountTypeEnum._CF_enumeration.addEnumeration(unicode_value='Discover', tag='Discover')
accountTypeEnum.JCB = accountTypeEnum._CF_enumeration.addEnumeration(unicode_value='JCB', tag='JCB')
accountTypeEnum.DinersClub = accountTypeEnum._CF_enumeration.addEnumeration(unicode_value='DinersClub', tag='DinersClub')
accountTypeEnum.eCheck = accountTypeEnum._CF_enumeration.addEnumeration(unicode_value='eCheck', tag='eCheck')
accountTypeEnum._InitializeFacetMap(accountTypeEnum._CF_enumeration)
Namespace.addCategoryObject('typeBinding', 'accountTypeEnum', accountTypeEnum)

# Atomic simple type: {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerTypeEnum
class customerTypeEnum (pyxb.binding.datatypes.string, pyxb.binding.basis.enumeration_mixin):

    """An atomic simple type."""

    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'customerTypeEnum')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 135, 1)
    _Documentation = None
customerTypeEnum._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=customerTypeEnum, enum_prefix=None)
customerTypeEnum.individual = customerTypeEnum._CF_enumeration.addEnumeration(unicode_value='individual', tag='individual')
customerTypeEnum.business = customerTypeEnum._CF_enumeration.addEnumeration(unicode_value='business', tag='business')
customerTypeEnum._InitializeFacetMap(customerTypeEnum._CF_enumeration)
Namespace.addCategoryObject('typeBinding', 'customerTypeEnum', customerTypeEnum)

# Atomic simple type: {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ARBSubscriptionUnitEnum
class ARBSubscriptionUnitEnum (pyxb.binding.datatypes.string, pyxb.binding.basis.enumeration_mixin):

    """An atomic simple type."""

    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'ARBSubscriptionUnitEnum')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 142, 1)
    _Documentation = None
ARBSubscriptionUnitEnum._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=ARBSubscriptionUnitEnum, enum_prefix=None)
ARBSubscriptionUnitEnum.days = ARBSubscriptionUnitEnum._CF_enumeration.addEnumeration(unicode_value='days', tag='days')
ARBSubscriptionUnitEnum.months = ARBSubscriptionUnitEnum._CF_enumeration.addEnumeration(unicode_value='months', tag='months')
ARBSubscriptionUnitEnum._InitializeFacetMap(ARBSubscriptionUnitEnum._CF_enumeration)
Namespace.addCategoryObject('typeBinding', 'ARBSubscriptionUnitEnum', ARBSubscriptionUnitEnum)

# Atomic simple type: {AnetApi/xml/v1/schema/AnetApiSchema.xsd}validationModeEnum
class validationModeEnum (pyxb.binding.datatypes.string, pyxb.binding.basis.enumeration_mixin):

    """An atomic simple type."""

    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'validationModeEnum')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 149, 1)
    _Documentation = None
validationModeEnum._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=validationModeEnum, enum_prefix=None)
validationModeEnum.none = validationModeEnum._CF_enumeration.addEnumeration(unicode_value='none', tag='none')
validationModeEnum.testMode = validationModeEnum._CF_enumeration.addEnumeration(unicode_value='testMode', tag='testMode')
validationModeEnum.liveMode = validationModeEnum._CF_enumeration.addEnumeration(unicode_value='liveMode', tag='liveMode')
validationModeEnum.oldLiveMode = validationModeEnum._CF_enumeration.addEnumeration(unicode_value='oldLiveMode', tag='oldLiveMode')
validationModeEnum._InitializeFacetMap(validationModeEnum._CF_enumeration)
Namespace.addCategoryObject('typeBinding', 'validationModeEnum', validationModeEnum)

# Atomic simple type: {AnetApi/xml/v1/schema/AnetApiSchema.xsd}splitTenderStatusEnum
class splitTenderStatusEnum (pyxb.binding.datatypes.string, pyxb.binding.basis.enumeration_mixin):

    """An atomic simple type."""

    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'splitTenderStatusEnum')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 158, 1)
    _Documentation = None
splitTenderStatusEnum._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=splitTenderStatusEnum, enum_prefix=None)
splitTenderStatusEnum.completed = splitTenderStatusEnum._CF_enumeration.addEnumeration(unicode_value='completed', tag='completed')
splitTenderStatusEnum.held = splitTenderStatusEnum._CF_enumeration.addEnumeration(unicode_value='held', tag='held')
splitTenderStatusEnum.voided = splitTenderStatusEnum._CF_enumeration.addEnumeration(unicode_value='voided', tag='voided')
splitTenderStatusEnum._InitializeFacetMap(splitTenderStatusEnum._CF_enumeration)
Namespace.addCategoryObject('typeBinding', 'splitTenderStatusEnum', splitTenderStatusEnum)

# Atomic simple type: {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ARBSubscriptionStatusEnum
class ARBSubscriptionStatusEnum (pyxb.binding.datatypes.string, pyxb.binding.basis.enumeration_mixin):

    """An atomic simple type."""

    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'ARBSubscriptionStatusEnum')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 166, 1)
    _Documentation = None
ARBSubscriptionStatusEnum._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=ARBSubscriptionStatusEnum, enum_prefix=None)
ARBSubscriptionStatusEnum.active = ARBSubscriptionStatusEnum._CF_enumeration.addEnumeration(unicode_value='active', tag='active')
ARBSubscriptionStatusEnum.expired = ARBSubscriptionStatusEnum._CF_enumeration.addEnumeration(unicode_value='expired', tag='expired')
ARBSubscriptionStatusEnum.suspended = ARBSubscriptionStatusEnum._CF_enumeration.addEnumeration(unicode_value='suspended', tag='suspended')
ARBSubscriptionStatusEnum.canceled = ARBSubscriptionStatusEnum._CF_enumeration.addEnumeration(unicode_value='canceled', tag='canceled')
ARBSubscriptionStatusEnum.terminated = ARBSubscriptionStatusEnum._CF_enumeration.addEnumeration(unicode_value='terminated', tag='terminated')
ARBSubscriptionStatusEnum._InitializeFacetMap(ARBSubscriptionStatusEnum._CF_enumeration)
Namespace.addCategoryObject('typeBinding', 'ARBSubscriptionStatusEnum', ARBSubscriptionStatusEnum)

# Atomic simple type: {AnetApi/xml/v1/schema/AnetApiSchema.xsd}transactionTypeEnum
class transactionTypeEnum (pyxb.binding.datatypes.string, pyxb.binding.basis.enumeration_mixin):

    """An atomic simple type."""

    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'transactionTypeEnum')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 176, 1)
    _Documentation = None
transactionTypeEnum._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=transactionTypeEnum, enum_prefix=None)
transactionTypeEnum.authOnlyTransaction = transactionTypeEnum._CF_enumeration.addEnumeration(unicode_value='authOnlyTransaction', tag='authOnlyTransaction')
transactionTypeEnum.authCaptureTransaction = transactionTypeEnum._CF_enumeration.addEnumeration(unicode_value='authCaptureTransaction', tag='authCaptureTransaction')
transactionTypeEnum.captureOnlyTransaction = transactionTypeEnum._CF_enumeration.addEnumeration(unicode_value='captureOnlyTransaction', tag='captureOnlyTransaction')
transactionTypeEnum.refundTransaction = transactionTypeEnum._CF_enumeration.addEnumeration(unicode_value='refundTransaction', tag='refundTransaction')
transactionTypeEnum.priorAuthCaptureTransaction = transactionTypeEnum._CF_enumeration.addEnumeration(unicode_value='priorAuthCaptureTransaction', tag='priorAuthCaptureTransaction')
transactionTypeEnum.voidTransaction = transactionTypeEnum._CF_enumeration.addEnumeration(unicode_value='voidTransaction', tag='voidTransaction')
transactionTypeEnum.getDetailsTransaction = transactionTypeEnum._CF_enumeration.addEnumeration(unicode_value='getDetailsTransaction', tag='getDetailsTransaction')
transactionTypeEnum.authOnlyContinueTransaction = transactionTypeEnum._CF_enumeration.addEnumeration(unicode_value='authOnlyContinueTransaction', tag='authOnlyContinueTransaction')
transactionTypeEnum.authCaptureContinueTransaction = transactionTypeEnum._CF_enumeration.addEnumeration(unicode_value='authCaptureContinueTransaction', tag='authCaptureContinueTransaction')
transactionTypeEnum._InitializeFacetMap(transactionTypeEnum._CF_enumeration)
Namespace.addCategoryObject('typeBinding', 'transactionTypeEnum', transactionTypeEnum)

# Atomic simple type: {AnetApi/xml/v1/schema/AnetApiSchema.xsd}transactionStatusEnum
class transactionStatusEnum (pyxb.binding.datatypes.string, pyxb.binding.basis.enumeration_mixin):

    """An atomic simple type."""

    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'transactionStatusEnum')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 190, 1)
    _Documentation = None
transactionStatusEnum._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=transactionStatusEnum, enum_prefix=None)
transactionStatusEnum.authorizedPendingCapture = transactionStatusEnum._CF_enumeration.addEnumeration(unicode_value='authorizedPendingCapture', tag='authorizedPendingCapture')
transactionStatusEnum.capturedPendingSettlement = transactionStatusEnum._CF_enumeration.addEnumeration(unicode_value='capturedPendingSettlement', tag='capturedPendingSettlement')
transactionStatusEnum.communicationError = transactionStatusEnum._CF_enumeration.addEnumeration(unicode_value='communicationError', tag='communicationError')
transactionStatusEnum.refundSettledSuccessfully = transactionStatusEnum._CF_enumeration.addEnumeration(unicode_value='refundSettledSuccessfully', tag='refundSettledSuccessfully')
transactionStatusEnum.refundPendingSettlement = transactionStatusEnum._CF_enumeration.addEnumeration(unicode_value='refundPendingSettlement', tag='refundPendingSettlement')
transactionStatusEnum.approvedReview = transactionStatusEnum._CF_enumeration.addEnumeration(unicode_value='approvedReview', tag='approvedReview')
transactionStatusEnum.declined = transactionStatusEnum._CF_enumeration.addEnumeration(unicode_value='declined', tag='declined')
transactionStatusEnum.couldNotVoid = transactionStatusEnum._CF_enumeration.addEnumeration(unicode_value='couldNotVoid', tag='couldNotVoid')
transactionStatusEnum.expired = transactionStatusEnum._CF_enumeration.addEnumeration(unicode_value='expired', tag='expired')
transactionStatusEnum.generalError = transactionStatusEnum._CF_enumeration.addEnumeration(unicode_value='generalError', tag='generalError')
transactionStatusEnum.pendingFinalSettlement = transactionStatusEnum._CF_enumeration.addEnumeration(unicode_value='pendingFinalSettlement', tag='pendingFinalSettlement')
transactionStatusEnum.pendingSettlement = transactionStatusEnum._CF_enumeration.addEnumeration(unicode_value='pendingSettlement', tag='pendingSettlement')
transactionStatusEnum.failedReview = transactionStatusEnum._CF_enumeration.addEnumeration(unicode_value='failedReview', tag='failedReview')
transactionStatusEnum.settledSuccessfully = transactionStatusEnum._CF_enumeration.addEnumeration(unicode_value='settledSuccessfully', tag='settledSuccessfully')
transactionStatusEnum.settlementError = transactionStatusEnum._CF_enumeration.addEnumeration(unicode_value='settlementError', tag='settlementError')
transactionStatusEnum.underReview = transactionStatusEnum._CF_enumeration.addEnumeration(unicode_value='underReview', tag='underReview')
transactionStatusEnum.updatingSettlement = transactionStatusEnum._CF_enumeration.addEnumeration(unicode_value='updatingSettlement', tag='updatingSettlement')
transactionStatusEnum.voided = transactionStatusEnum._CF_enumeration.addEnumeration(unicode_value='voided', tag='voided')
transactionStatusEnum.FDSPendingReview = transactionStatusEnum._CF_enumeration.addEnumeration(unicode_value='FDSPendingReview', tag='FDSPendingReview')
transactionStatusEnum.FDSAuthorizedPendingReview = transactionStatusEnum._CF_enumeration.addEnumeration(unicode_value='FDSAuthorizedPendingReview', tag='FDSAuthorizedPendingReview')
transactionStatusEnum.returnedItem = transactionStatusEnum._CF_enumeration.addEnumeration(unicode_value='returnedItem', tag='returnedItem')
transactionStatusEnum.chargeback = transactionStatusEnum._CF_enumeration.addEnumeration(unicode_value='chargeback', tag='chargeback')
transactionStatusEnum.chargebackReversal = transactionStatusEnum._CF_enumeration.addEnumeration(unicode_value='chargebackReversal', tag='chargebackReversal')
transactionStatusEnum.authorizedPendingRelease = transactionStatusEnum._CF_enumeration.addEnumeration(unicode_value='authorizedPendingRelease', tag='authorizedPendingRelease')
transactionStatusEnum._InitializeFacetMap(transactionStatusEnum._CF_enumeration)
Namespace.addCategoryObject('typeBinding', 'transactionStatusEnum', transactionStatusEnum)

# Atomic simple type: {AnetApi/xml/v1/schema/AnetApiSchema.xsd}settlementStateEnum
class settlementStateEnum (pyxb.binding.datatypes.string, pyxb.binding.basis.enumeration_mixin):

    """An atomic simple type."""

    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'settlementStateEnum')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 219, 1)
    _Documentation = None
settlementStateEnum._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=settlementStateEnum, enum_prefix=None)
settlementStateEnum.settledSuccessfully = settlementStateEnum._CF_enumeration.addEnumeration(unicode_value='settledSuccessfully', tag='settledSuccessfully')
settlementStateEnum.settlementError = settlementStateEnum._CF_enumeration.addEnumeration(unicode_value='settlementError', tag='settlementError')
settlementStateEnum.pendingSettlement = settlementStateEnum._CF_enumeration.addEnumeration(unicode_value='pendingSettlement', tag='pendingSettlement')
settlementStateEnum._InitializeFacetMap(settlementStateEnum._CF_enumeration)
Namespace.addCategoryObject('typeBinding', 'settlementStateEnum', settlementStateEnum)

# Atomic simple type: {AnetApi/xml/v1/schema/AnetApiSchema.xsd}FDSFilterActionEnum
class FDSFilterActionEnum (pyxb.binding.datatypes.string, pyxb.binding.basis.enumeration_mixin):

    """An atomic simple type."""

    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'FDSFilterActionEnum')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 227, 1)
    _Documentation = None
FDSFilterActionEnum._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=FDSFilterActionEnum, enum_prefix=None)
FDSFilterActionEnum.reject = FDSFilterActionEnum._CF_enumeration.addEnumeration(unicode_value='reject', tag='reject')
FDSFilterActionEnum.decline = FDSFilterActionEnum._CF_enumeration.addEnumeration(unicode_value='decline', tag='decline')
FDSFilterActionEnum.hold = FDSFilterActionEnum._CF_enumeration.addEnumeration(unicode_value='hold', tag='hold')
FDSFilterActionEnum.authAndHold = FDSFilterActionEnum._CF_enumeration.addEnumeration(unicode_value='authAndHold', tag='authAndHold')
FDSFilterActionEnum.report = FDSFilterActionEnum._CF_enumeration.addEnumeration(unicode_value='report', tag='report')
FDSFilterActionEnum._InitializeFacetMap(FDSFilterActionEnum._CF_enumeration)
Namespace.addCategoryObject('typeBinding', 'FDSFilterActionEnum', FDSFilterActionEnum)

# Atomic simple type: {AnetApi/xml/v1/schema/AnetApiSchema.xsd}permissionsEnum
class permissionsEnum (pyxb.binding.datatypes.string, pyxb.binding.basis.enumeration_mixin):

    """An atomic simple type."""

    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'permissionsEnum')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 237, 1)
    _Documentation = None
permissionsEnum._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=permissionsEnum, enum_prefix=None)
permissionsEnum.API_Merchant_BasicReporting = permissionsEnum._CF_enumeration.addEnumeration(unicode_value='API_Merchant_BasicReporting', tag='API_Merchant_BasicReporting')
permissionsEnum.Submit_Charge = permissionsEnum._CF_enumeration.addEnumeration(unicode_value='Submit_Charge', tag='Submit_Charge')
permissionsEnum.Submit_Refund = permissionsEnum._CF_enumeration.addEnumeration(unicode_value='Submit_Refund', tag='Submit_Refund')
permissionsEnum.Submit_Update = permissionsEnum._CF_enumeration.addEnumeration(unicode_value='Submit_Update', tag='Submit_Update')
permissionsEnum.Mobile_Admin = permissionsEnum._CF_enumeration.addEnumeration(unicode_value='Mobile_Admin', tag='Mobile_Admin')
permissionsEnum._InitializeFacetMap(permissionsEnum._CF_enumeration)
Namespace.addCategoryObject('typeBinding', 'permissionsEnum', permissionsEnum)

# Atomic simple type: {AnetApi/xml/v1/schema/AnetApiSchema.xsd}deviceActivationEnum
class deviceActivationEnum (pyxb.binding.datatypes.string, pyxb.binding.basis.enumeration_mixin):

    """An atomic simple type."""

    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'deviceActivationEnum')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 247, 2)
    _Documentation = None
deviceActivationEnum._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=deviceActivationEnum, enum_prefix=None)
deviceActivationEnum.Activate = deviceActivationEnum._CF_enumeration.addEnumeration(unicode_value='Activate', tag='Activate')
deviceActivationEnum.Disable = deviceActivationEnum._CF_enumeration.addEnumeration(unicode_value='Disable', tag='Disable')
deviceActivationEnum._InitializeFacetMap(deviceActivationEnum._CF_enumeration)
Namespace.addCategoryObject('typeBinding', 'deviceActivationEnum', deviceActivationEnum)

# Atomic simple type: [anonymous]
class STD_ANON (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 258, 4)
    _Documentation = None
STD_ANON._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(20))
STD_ANON._CF_minLength = pyxb.binding.facets.CF_minLength(value=pyxb.binding.datatypes.nonNegativeInteger(5))
STD_ANON._InitializeFacetMap(STD_ANON._CF_maxLength,
   STD_ANON._CF_minLength)

# Atomic simple type: [anonymous]
class STD_ANON_ (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 266, 4)
    _Documentation = None
STD_ANON_._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(2))
STD_ANON_._CF_minLength = pyxb.binding.facets.CF_minLength(value=pyxb.binding.datatypes.nonNegativeInteger(2))
STD_ANON_._InitializeFacetMap(STD_ANON_._CF_maxLength,
   STD_ANON_._CF_minLength)

# Atomic simple type: [anonymous]
class STD_ANON_2 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 275, 4)
    _Documentation = None
STD_ANON_2._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(10))
STD_ANON_2._CF_minLength = pyxb.binding.facets.CF_minLength(value=pyxb.binding.datatypes.nonNegativeInteger(8))
STD_ANON_2._InitializeFacetMap(STD_ANON_2._CF_maxLength,
   STD_ANON_2._CF_minLength)

# Atomic simple type: [anonymous]
class STD_ANON_3 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 289, 4)
    _Documentation = None
STD_ANON_3._CF_length = pyxb.binding.facets.CF_length(value=pyxb.binding.datatypes.nonNegativeInteger(8))
STD_ANON_3._InitializeFacetMap(STD_ANON_3._CF_length)

# Atomic simple type: [anonymous]
class STD_ANON_4 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 296, 4)
    _Documentation = None
STD_ANON_4._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(2))
STD_ANON_4._CF_minLength = pyxb.binding.facets.CF_minLength(value=pyxb.binding.datatypes.nonNegativeInteger(2))
STD_ANON_4._InitializeFacetMap(STD_ANON_4._CF_maxLength,
   STD_ANON_4._CF_minLength)

# Atomic simple type: [anonymous]
class STD_ANON_5 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 304, 4)
    _Documentation = None
STD_ANON_5._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(10))
STD_ANON_5._CF_minLength = pyxb.binding.facets.CF_minLength(value=pyxb.binding.datatypes.nonNegativeInteger(8))
STD_ANON_5._InitializeFacetMap(STD_ANON_5._CF_maxLength,
   STD_ANON_5._CF_minLength)

# Atomic simple type: [anonymous]
class STD_ANON_6 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 318, 4)
    _Documentation = None
STD_ANON_6._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(50))
STD_ANON_6._InitializeFacetMap(STD_ANON_6._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_7 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 325, 4)
    _Documentation = None
STD_ANON_7._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(50))
STD_ANON_7._InitializeFacetMap(STD_ANON_7._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_8 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 332, 4)
    _Documentation = None
STD_ANON_8._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(50))
STD_ANON_8._InitializeFacetMap(STD_ANON_8._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_9 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 339, 4)
    _Documentation = None
STD_ANON_9._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(60))
STD_ANON_9._InitializeFacetMap(STD_ANON_9._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_10 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 346, 4)
    _Documentation = None
STD_ANON_10._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(40))
STD_ANON_10._InitializeFacetMap(STD_ANON_10._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_11 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 353, 4)
    _Documentation = None
STD_ANON_11._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(40))
STD_ANON_11._InitializeFacetMap(STD_ANON_11._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_12 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 360, 4)
    _Documentation = None
STD_ANON_12._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(20))
STD_ANON_12._InitializeFacetMap(STD_ANON_12._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_13 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 367, 4)
    _Documentation = None
STD_ANON_13._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(60))
STD_ANON_13._InitializeFacetMap(STD_ANON_13._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_14 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 385, 4)
    _Documentation = None
STD_ANON_14._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(20))
STD_ANON_14._InitializeFacetMap(STD_ANON_14._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_15 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 408, 4)
    _Documentation = None
STD_ANON_15._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(16))
STD_ANON_15._CF_minLength = pyxb.binding.facets.CF_minLength(value=pyxb.binding.datatypes.nonNegativeInteger(4))
STD_ANON_15._InitializeFacetMap(STD_ANON_15._CF_maxLength,
   STD_ANON_15._CF_minLength)

# Atomic simple type: [anonymous]
class STD_ANON_16 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 417, 4)
    _Documentation = None
STD_ANON_16._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(7))
STD_ANON_16._CF_minLength = pyxb.binding.facets.CF_minLength(value=pyxb.binding.datatypes.nonNegativeInteger(4))
STD_ANON_16._InitializeFacetMap(STD_ANON_16._CF_maxLength,
   STD_ANON_16._CF_minLength)

# Atomic simple type: [anonymous]
class STD_ANON_17 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 462, 4)
    _Documentation = None
STD_ANON_17._CF_length = pyxb.binding.facets.CF_length(value=pyxb.binding.datatypes.nonNegativeInteger(8))
STD_ANON_17._InitializeFacetMap(STD_ANON_17._CF_length)

# Atomic simple type: [anonymous]
class STD_ANON_18 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 469, 4)
    _Documentation = None
STD_ANON_18._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(7))
STD_ANON_18._CF_minLength = pyxb.binding.facets.CF_minLength(value=pyxb.binding.datatypes.nonNegativeInteger(4))
STD_ANON_18._InitializeFacetMap(STD_ANON_18._CF_maxLength,
   STD_ANON_18._CF_minLength)

# Atomic simple type: [anonymous]
class STD_ANON_19 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 495, 4)
    _Documentation = None
STD_ANON_19._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(9))
STD_ANON_19._InitializeFacetMap(STD_ANON_19._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_20 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 503, 4)
    _Documentation = None
STD_ANON_20._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(17))
STD_ANON_20._InitializeFacetMap(STD_ANON_20._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_21 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 510, 4)
    _Documentation = None
STD_ANON_21._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(22))
STD_ANON_21._InitializeFacetMap(STD_ANON_21._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_22 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 518, 4)
    _Documentation = None
STD_ANON_22._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(50))
STD_ANON_22._InitializeFacetMap(STD_ANON_22._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_23 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 525, 4)
    _Documentation = None
STD_ANON_23._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(15))
STD_ANON_23._InitializeFacetMap(STD_ANON_23._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_24 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 539, 4)
    _Documentation = None
STD_ANON_24._CF_length = pyxb.binding.facets.CF_length(value=pyxb.binding.datatypes.nonNegativeInteger(8))
STD_ANON_24._InitializeFacetMap(STD_ANON_24._CF_length)

# Atomic simple type: [anonymous]
class STD_ANON_25 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 546, 4)
    _Documentation = None
STD_ANON_25._CF_length = pyxb.binding.facets.CF_length(value=pyxb.binding.datatypes.nonNegativeInteger(8))
STD_ANON_25._InitializeFacetMap(STD_ANON_25._CF_length)

# Atomic simple type: [anonymous]
class STD_ANON_26 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 553, 4)
    _Documentation = None
STD_ANON_26._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(22))
STD_ANON_26._InitializeFacetMap(STD_ANON_26._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_27 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 561, 4)
    _Documentation = None
STD_ANON_27._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(50))
STD_ANON_27._InitializeFacetMap(STD_ANON_27._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_28 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 621, 8)
    _Documentation = None
STD_ANON_28._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(7))
STD_ANON_28._CF_minLength = pyxb.binding.facets.CF_minLength(value=pyxb.binding.datatypes.nonNegativeInteger(4))
STD_ANON_28._InitializeFacetMap(STD_ANON_28._CF_maxLength,
   STD_ANON_28._CF_minLength)

# Atomic simple type: [anonymous]
class STD_ANON_29 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 635, 4)
    _Documentation = None
STD_ANON_29._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(20))
STD_ANON_29._InitializeFacetMap(STD_ANON_29._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_30 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 642, 4)
    _Documentation = None
STD_ANON_30._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(255))
STD_ANON_30._InitializeFacetMap(STD_ANON_30._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_31 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 657, 6)
    _Documentation = None
STD_ANON_31._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(25))
STD_ANON_31._InitializeFacetMap(STD_ANON_31._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_32 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 673, 4)
    _Documentation = None
STD_ANON_32._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(20))
STD_ANON_32._InitializeFacetMap(STD_ANON_32._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_33 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 680, 4)
    _Documentation = None
STD_ANON_33._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(255))
STD_ANON_33._InitializeFacetMap(STD_ANON_33._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_34 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 687, 4)
    _Documentation = None
STD_ANON_34._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(25))
STD_ANON_34._InitializeFacetMap(STD_ANON_34._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_35 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 694, 4)
    _Documentation = None
STD_ANON_35._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(25))
STD_ANON_35._InitializeFacetMap(STD_ANON_35._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_36 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 717, 4)
    _Documentation = None
STD_ANON_36._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(20))
STD_ANON_36._InitializeFacetMap(STD_ANON_36._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_37 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 724, 4)
    _Documentation = None
STD_ANON_37._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(255))
STD_ANON_37._InitializeFacetMap(STD_ANON_37._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_38 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 732, 4)
    _Documentation = None
STD_ANON_38._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(9))
STD_ANON_38._CF_minLength = pyxb.binding.facets.CF_minLength(value=pyxb.binding.datatypes.nonNegativeInteger(8))
STD_ANON_38._InitializeFacetMap(STD_ANON_38._CF_maxLength,
   STD_ANON_38._CF_minLength)

# Atomic simple type: [anonymous]
class STD_ANON_39 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 746, 4)
    _Documentation = None
STD_ANON_39._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(25))
STD_ANON_39._InitializeFacetMap(STD_ANON_39._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_40 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 755, 5)
    _Documentation = None
STD_ANON_40._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(16))
STD_ANON_40._InitializeFacetMap(STD_ANON_40._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_41 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 763, 5)
    _Documentation = None
STD_ANON_41._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(40))
STD_ANON_41._InitializeFacetMap(STD_ANON_41._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_42 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 773, 4)
    _Documentation = None
STD_ANON_42._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(60))
STD_ANON_42._InitializeFacetMap(STD_ANON_42._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_43 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 884, 8)
    _Documentation = None
STD_ANON_43._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(64))
STD_ANON_43._CF_minLength = pyxb.binding.facets.CF_minLength(value=pyxb.binding.datatypes.nonNegativeInteger(1))
STD_ANON_43._InitializeFacetMap(STD_ANON_43._CF_maxLength,
   STD_ANON_43._CF_minLength)

# Atomic simple type: [anonymous]
class STD_ANON_44 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 895, 14)
    _Documentation = None
STD_ANON_44._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(16))
STD_ANON_44._CF_minLength = pyxb.binding.facets.CF_minLength(value=pyxb.binding.datatypes.nonNegativeInteger(4))
STD_ANON_44._InitializeFacetMap(STD_ANON_44._CF_maxLength,
   STD_ANON_44._CF_minLength)

# Atomic simple type: [anonymous]
class STD_ANON_45 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 903, 14)
    _Documentation = None
STD_ANON_45._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(7))
STD_ANON_45._CF_minLength = pyxb.binding.facets.CF_minLength(value=pyxb.binding.datatypes.nonNegativeInteger(4))
STD_ANON_45._InitializeFacetMap(STD_ANON_45._CF_maxLength,
   STD_ANON_45._CF_minLength)

# Atomic simple type: [anonymous]
class STD_ANON_46 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 912, 14)
    _Documentation = None
STD_ANON_46._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(20))
STD_ANON_46._CF_minLength = pyxb.binding.facets.CF_minLength(value=pyxb.binding.datatypes.nonNegativeInteger(1))
STD_ANON_46._InitializeFacetMap(STD_ANON_46._CF_maxLength,
   STD_ANON_46._CF_minLength)

# Atomic simple type: [anonymous]
class STD_ANON_47 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 920, 14)
    _Documentation = None
STD_ANON_47._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(64))
STD_ANON_47._CF_minLength = pyxb.binding.facets.CF_minLength(value=pyxb.binding.datatypes.nonNegativeInteger(1))
STD_ANON_47._InitializeFacetMap(STD_ANON_47._CF_maxLength,
   STD_ANON_47._CF_minLength)

# Atomic simple type: {AnetApi/xml/v1/schema/AnetApiSchema.xsd}webCheckOutTypeEnum
class webCheckOutTypeEnum (pyxb.binding.datatypes.string, pyxb.binding.basis.enumeration_mixin):

    """An atomic simple type."""

    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'webCheckOutTypeEnum')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 943, 2)
    _Documentation = None
webCheckOutTypeEnum._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=webCheckOutTypeEnum, enum_prefix=None)
webCheckOutTypeEnum.PAN = webCheckOutTypeEnum._CF_enumeration.addEnumeration(unicode_value='PAN', tag='PAN')
webCheckOutTypeEnum.TOKEN = webCheckOutTypeEnum._CF_enumeration.addEnumeration(unicode_value='TOKEN', tag='TOKEN')
webCheckOutTypeEnum._InitializeFacetMap(webCheckOutTypeEnum._CF_enumeration)
Namespace.addCategoryObject('typeBinding', 'webCheckOutTypeEnum', webCheckOutTypeEnum)

# Atomic simple type: [anonymous]
class STD_ANON_48 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 955, 8)
    _Documentation = None
STD_ANON_48._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(25))
STD_ANON_48._InitializeFacetMap(STD_ANON_48._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_49 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 962, 8)
    _Documentation = None
STD_ANON_49._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(16))
STD_ANON_49._InitializeFacetMap(STD_ANON_49._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_50 (pyxb.binding.datatypes.short):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 975, 4)
    _Documentation = None
STD_ANON_50._CF_maxInclusive = pyxb.binding.facets.CF_maxInclusive(value_datatype=STD_ANON_50, value=pyxb.binding.datatypes.short(32000))
STD_ANON_50._CF_minInclusive = pyxb.binding.facets.CF_minInclusive(value_datatype=STD_ANON_50, value=pyxb.binding.datatypes.short(1))
STD_ANON_50._InitializeFacetMap(STD_ANON_50._CF_maxInclusive,
   STD_ANON_50._CF_minInclusive)

# Atomic simple type: [anonymous]
class STD_ANON_51 (pyxb.binding.datatypes.short):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 997, 4)
    _Documentation = None
STD_ANON_51._CF_maxInclusive = pyxb.binding.facets.CF_maxInclusive(value_datatype=STD_ANON_51, value=pyxb.binding.datatypes.short(32000))
STD_ANON_51._CF_minInclusive = pyxb.binding.facets.CF_minInclusive(value_datatype=STD_ANON_51, value=pyxb.binding.datatypes.short(1))
STD_ANON_51._InitializeFacetMap(STD_ANON_51._CF_maxInclusive,
   STD_ANON_51._CF_minInclusive)

# Atomic simple type: [anonymous]
class STD_ANON_52 (pyxb.binding.datatypes.short):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1006, 4)
    _Documentation = None
STD_ANON_52._CF_maxInclusive = pyxb.binding.facets.CF_maxInclusive(value_datatype=STD_ANON_52, value=pyxb.binding.datatypes.short(32000))
STD_ANON_52._CF_minInclusive = pyxb.binding.facets.CF_minInclusive(value_datatype=STD_ANON_52, value=pyxb.binding.datatypes.short(0))
STD_ANON_52._InitializeFacetMap(STD_ANON_52._CF_maxInclusive,
   STD_ANON_52._CF_minInclusive)

# Atomic simple type: [anonymous]
class STD_ANON_53 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1020, 4)
    _Documentation = None
STD_ANON_53._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(50))
STD_ANON_53._InitializeFacetMap(STD_ANON_53._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_54 (pyxb.binding.datatypes.decimal):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1029, 4)
    _Documentation = None
STD_ANON_54._CF_minInclusive = pyxb.binding.facets.CF_minInclusive(value_datatype=STD_ANON_54, value=pyxb.binding.datatypes.decimal('0.01'))
STD_ANON_54._CF_fractionDigits = pyxb.binding.facets.CF_fractionDigits(value=pyxb.binding.datatypes.nonNegativeInteger(4))
STD_ANON_54._InitializeFacetMap(STD_ANON_54._CF_minInclusive,
   STD_ANON_54._CF_fractionDigits)

# Atomic simple type: [anonymous]
class STD_ANON_55 (pyxb.binding.datatypes.decimal):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1037, 4)
    _Documentation = None
STD_ANON_55._CF_minInclusive = pyxb.binding.facets.CF_minInclusive(value_datatype=STD_ANON_55, value=pyxb.binding.datatypes.decimal('0.0'))
STD_ANON_55._CF_fractionDigits = pyxb.binding.facets.CF_fractionDigits(value=pyxb.binding.datatypes.nonNegativeInteger(4))
STD_ANON_55._InitializeFacetMap(STD_ANON_55._CF_minInclusive,
   STD_ANON_55._CF_fractionDigits)

# Atomic simple type: [anonymous]
class STD_ANON_56 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1060, 4)
    _Documentation = None
STD_ANON_56._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(50))
STD_ANON_56._InitializeFacetMap(STD_ANON_56._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_57 (pyxb.binding.datatypes.decimal):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1069, 4)
    _Documentation = None
STD_ANON_57._CF_minInclusive = pyxb.binding.facets.CF_minInclusive(value_datatype=STD_ANON_57, value=pyxb.binding.datatypes.decimal('0.01'))
STD_ANON_57._CF_fractionDigits = pyxb.binding.facets.CF_fractionDigits(value=pyxb.binding.datatypes.nonNegativeInteger(4))
STD_ANON_57._InitializeFacetMap(STD_ANON_57._CF_minInclusive,
   STD_ANON_57._CF_fractionDigits)

# Atomic simple type: [anonymous]
class STD_ANON_58 (pyxb.binding.datatypes.decimal):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1077, 4)
    _Documentation = None
STD_ANON_58._CF_minInclusive = pyxb.binding.facets.CF_minInclusive(value_datatype=STD_ANON_58, value=pyxb.binding.datatypes.decimal('0.0'))
STD_ANON_58._CF_fractionDigits = pyxb.binding.facets.CF_fractionDigits(value=pyxb.binding.datatypes.nonNegativeInteger(4))
STD_ANON_58._InitializeFacetMap(STD_ANON_58._CF_minInclusive,
   STD_ANON_58._CF_fractionDigits)

# Atomic simple type: [anonymous]
class STD_ANON_59 (pyxb.binding.datatypes.int):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1110, 8)
    _Documentation = None
STD_ANON_59._CF_minInclusive = pyxb.binding.facets.CF_minInclusive(value_datatype=STD_ANON_59, value=pyxb.binding.datatypes.int(0))
STD_ANON_59._InitializeFacetMap(STD_ANON_59._CF_minInclusive)

# Atomic simple type: [anonymous]
class STD_ANON_60 (pyxb.binding.datatypes.int):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1117, 8)
    _Documentation = None
STD_ANON_60._CF_minInclusive = pyxb.binding.facets.CF_minInclusive(value_datatype=STD_ANON_60, value=pyxb.binding.datatypes.int(0))
STD_ANON_60._InitializeFacetMap(STD_ANON_60._CF_minInclusive)

# Atomic simple type: [anonymous]
class STD_ANON_61 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1130, 4)
    _Documentation = None
STD_ANON_61._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(60))
STD_ANON_61._InitializeFacetMap(STD_ANON_61._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_62 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1137, 4)
    _Documentation = None
STD_ANON_62._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(60))
STD_ANON_62._InitializeFacetMap(STD_ANON_62._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_63 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1144, 4)
    _Documentation = None
STD_ANON_63._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(20))
STD_ANON_63._InitializeFacetMap(STD_ANON_63._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_64 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1151, 8)
    _Documentation = None
STD_ANON_64._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(255))
STD_ANON_64._InitializeFacetMap(STD_ANON_64._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_65 (pyxb.binding.datatypes.boolean):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1186, 4)
    _Documentation = None
STD_ANON_65._InitializeFacetMap()

# Atomic simple type: {AnetApi/xml/v1/schema/AnetApiSchema.xsd}OperationType
class OperationType (pyxb.binding.datatypes.string, pyxb.binding.basis.enumeration_mixin):

    """An atomic simple type."""

    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'OperationType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1253, 3)
    _Documentation = None
OperationType._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=OperationType, enum_prefix=None)
OperationType.DECRYPT = OperationType._CF_enumeration.addEnumeration(unicode_value='DECRYPT', tag='DECRYPT')
OperationType._InitializeFacetMap(OperationType._CF_enumeration)
Namespace.addCategoryObject('typeBinding', 'OperationType', OperationType)

# Atomic simple type: {AnetApi/xml/v1/schema/AnetApiSchema.xsd}EncryptionAlgorithmType
class EncryptionAlgorithmType (pyxb.binding.datatypes.string, pyxb.binding.basis.enumeration_mixin):

    """An atomic simple type."""

    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'EncryptionAlgorithmType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1258, 3)
    _Documentation = None
EncryptionAlgorithmType._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=EncryptionAlgorithmType, enum_prefix=None)
EncryptionAlgorithmType.TDES = EncryptionAlgorithmType._CF_enumeration.addEnumeration(unicode_value='TDES', tag='TDES')
EncryptionAlgorithmType.AES = EncryptionAlgorithmType._CF_enumeration.addEnumeration(unicode_value='AES', tag='AES')
EncryptionAlgorithmType.RSA = EncryptionAlgorithmType._CF_enumeration.addEnumeration(unicode_value='RSA', tag='RSA')
EncryptionAlgorithmType._InitializeFacetMap(EncryptionAlgorithmType._CF_enumeration)
Namespace.addCategoryObject('typeBinding', 'EncryptionAlgorithmType', EncryptionAlgorithmType)

# Atomic simple type: {AnetApi/xml/v1/schema/AnetApiSchema.xsd}EncodingType
class EncodingType (pyxb.binding.datatypes.string, pyxb.binding.basis.enumeration_mixin):

    """An atomic simple type."""

    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'EncodingType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1265, 3)
    _Documentation = None
EncodingType._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=EncodingType, enum_prefix=None)
EncodingType.Base64 = EncodingType._CF_enumeration.addEnumeration(unicode_value='Base64', tag='Base64')
EncodingType.Hex = EncodingType._CF_enumeration.addEnumeration(unicode_value='Hex', tag='Hex')
EncodingType._InitializeFacetMap(EncodingType._CF_enumeration)
Namespace.addCategoryObject('typeBinding', 'EncodingType', EncodingType)

# Atomic simple type: {AnetApi/xml/v1/schema/AnetApiSchema.xsd}settingNameEnum
class settingNameEnum (pyxb.binding.datatypes.string, pyxb.binding.basis.enumeration_mixin):

    """An atomic simple type."""

    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'settingNameEnum')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1307, 1)
    _Documentation = None
settingNameEnum._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=settingNameEnum, enum_prefix=None)
settingNameEnum.emailCustomer = settingNameEnum._CF_enumeration.addEnumeration(unicode_value='emailCustomer', tag='emailCustomer')
settingNameEnum.merchantEmail = settingNameEnum._CF_enumeration.addEnumeration(unicode_value='merchantEmail', tag='merchantEmail')
settingNameEnum.allowPartialAuth = settingNameEnum._CF_enumeration.addEnumeration(unicode_value='allowPartialAuth', tag='allowPartialAuth')
settingNameEnum.headerEmailReceipt = settingNameEnum._CF_enumeration.addEnumeration(unicode_value='headerEmailReceipt', tag='headerEmailReceipt')
settingNameEnum.footerEmailReceipt = settingNameEnum._CF_enumeration.addEnumeration(unicode_value='footerEmailReceipt', tag='footerEmailReceipt')
settingNameEnum.recurringBilling = settingNameEnum._CF_enumeration.addEnumeration(unicode_value='recurringBilling', tag='recurringBilling')
settingNameEnum.duplicateWindow = settingNameEnum._CF_enumeration.addEnumeration(unicode_value='duplicateWindow', tag='duplicateWindow')
settingNameEnum.testRequest = settingNameEnum._CF_enumeration.addEnumeration(unicode_value='testRequest', tag='testRequest')
settingNameEnum.hostedProfileReturnUrl = settingNameEnum._CF_enumeration.addEnumeration(unicode_value='hostedProfileReturnUrl', tag='hostedProfileReturnUrl')
settingNameEnum.hostedProfileReturnUrlText = settingNameEnum._CF_enumeration.addEnumeration(unicode_value='hostedProfileReturnUrlText', tag='hostedProfileReturnUrlText')
settingNameEnum.hostedProfilePageBorderVisible = settingNameEnum._CF_enumeration.addEnumeration(unicode_value='hostedProfilePageBorderVisible', tag='hostedProfilePageBorderVisible')
settingNameEnum.hostedProfileIFrameCommunicatorUrl = settingNameEnum._CF_enumeration.addEnumeration(unicode_value='hostedProfileIFrameCommunicatorUrl', tag='hostedProfileIFrameCommunicatorUrl')
settingNameEnum.hostedProfileHeadingBgColor = settingNameEnum._CF_enumeration.addEnumeration(unicode_value='hostedProfileHeadingBgColor', tag='hostedProfileHeadingBgColor')
settingNameEnum.hostedProfileValidationMode = settingNameEnum._CF_enumeration.addEnumeration(unicode_value='hostedProfileValidationMode', tag='hostedProfileValidationMode')
settingNameEnum.hostedProfileBillingAddressRequired = settingNameEnum._CF_enumeration.addEnumeration(unicode_value='hostedProfileBillingAddressRequired', tag='hostedProfileBillingAddressRequired')
settingNameEnum.hostedProfileCardCodeRequired = settingNameEnum._CF_enumeration.addEnumeration(unicode_value='hostedProfileCardCodeRequired', tag='hostedProfileCardCodeRequired')
settingNameEnum._InitializeFacetMap(settingNameEnum._CF_enumeration)
Namespace.addCategoryObject('typeBinding', 'settingNameEnum', settingNameEnum)

# Atomic simple type: [anonymous]
class STD_ANON_66 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1430, 6)
    _Documentation = None
STD_ANON_66._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(9))
STD_ANON_66._CF_minLength = pyxb.binding.facets.CF_minLength(value=pyxb.binding.datatypes.nonNegativeInteger(8))
STD_ANON_66._InitializeFacetMap(STD_ANON_66._CF_maxLength,
   STD_ANON_66._CF_minLength)

# Atomic simple type: [anonymous]
class STD_ANON_67 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1463, 6)
    _Documentation = None
STD_ANON_67._CF_length = pyxb.binding.facets.CF_length(value=pyxb.binding.datatypes.nonNegativeInteger(8))
STD_ANON_67._InitializeFacetMap(STD_ANON_67._CF_length)

# Atomic simple type: [anonymous]
class STD_ANON_68 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1488, 4)
    _Documentation = None
STD_ANON_68._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(20))
STD_ANON_68._InitializeFacetMap(STD_ANON_68._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_69 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1495, 4)
    _Documentation = None
STD_ANON_69._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(255))
STD_ANON_69._InitializeFacetMap(STD_ANON_69._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_70 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1502, 4)
    _Documentation = None
STD_ANON_70._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(255))
STD_ANON_70._InitializeFacetMap(STD_ANON_70._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_71 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1561, 6)
    _Documentation = None
STD_ANON_71._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(25))
STD_ANON_71._InitializeFacetMap(STD_ANON_71._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_72 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1568, 6)
    _Documentation = None
STD_ANON_72._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(25))
STD_ANON_72._InitializeFacetMap(STD_ANON_72._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_73 (pyxb.binding.datatypes.decimal):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1595, 4)
    _Documentation = None
STD_ANON_73._CF_minInclusive = pyxb.binding.facets.CF_minInclusive(value_datatype=STD_ANON_73, value=pyxb.binding.datatypes.decimal('0.0'))
STD_ANON_73._CF_fractionDigits = pyxb.binding.facets.CF_fractionDigits(value=pyxb.binding.datatypes.nonNegativeInteger(4))
STD_ANON_73._InitializeFacetMap(STD_ANON_73._CF_minInclusive,
   STD_ANON_73._CF_fractionDigits)

# Atomic simple type: [anonymous]
class STD_ANON_74 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1603, 4)
    _Documentation = None
STD_ANON_74._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(31))
STD_ANON_74._InitializeFacetMap(STD_ANON_74._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_75 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1610, 4)
    _Documentation = None
STD_ANON_75._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(255))
STD_ANON_75._InitializeFacetMap(STD_ANON_75._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_76 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1623, 4)
    _Documentation = None
STD_ANON_76._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(31))
STD_ANON_76._CF_minLength = pyxb.binding.facets.CF_minLength(value=pyxb.binding.datatypes.nonNegativeInteger(1))
STD_ANON_76._InitializeFacetMap(STD_ANON_76._CF_maxLength,
   STD_ANON_76._CF_minLength)

# Atomic simple type: [anonymous]
class STD_ANON_77 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1631, 4)
    _Documentation = None
STD_ANON_77._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(31))
STD_ANON_77._CF_minLength = pyxb.binding.facets.CF_minLength(value=pyxb.binding.datatypes.nonNegativeInteger(1))
STD_ANON_77._InitializeFacetMap(STD_ANON_77._CF_maxLength,
   STD_ANON_77._CF_minLength)

# Atomic simple type: [anonymous]
class STD_ANON_78 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1639, 4)
    _Documentation = None
STD_ANON_78._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(255))
STD_ANON_78._InitializeFacetMap(STD_ANON_78._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_79 (pyxb.binding.datatypes.decimal):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1646, 4)
    _Documentation = None
STD_ANON_79._CF_minInclusive = pyxb.binding.facets.CF_minInclusive(value_datatype=STD_ANON_79, value=pyxb.binding.datatypes.decimal('0.0'))
STD_ANON_79._CF_fractionDigits = pyxb.binding.facets.CF_fractionDigits(value=pyxb.binding.datatypes.nonNegativeInteger(4))
STD_ANON_79._InitializeFacetMap(STD_ANON_79._CF_minInclusive,
   STD_ANON_79._CF_fractionDigits)

# Atomic simple type: [anonymous]
class STD_ANON_80 (pyxb.binding.datatypes.decimal):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1654, 4)
    _Documentation = None
STD_ANON_80._CF_minInclusive = pyxb.binding.facets.CF_minInclusive(value_datatype=STD_ANON_80, value=pyxb.binding.datatypes.decimal('0.0'))
STD_ANON_80._CF_fractionDigits = pyxb.binding.facets.CF_fractionDigits(value=pyxb.binding.datatypes.nonNegativeInteger(4))
STD_ANON_80._InitializeFacetMap(STD_ANON_80._CF_minInclusive,
   STD_ANON_80._CF_fractionDigits)

# Atomic simple type: [anonymous]
class STD_ANON_81 (pyxb.binding.datatypes.decimal):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1669, 4)
    _Documentation = None
STD_ANON_81._CF_minInclusive = pyxb.binding.facets.CF_minInclusive(value_datatype=STD_ANON_81, value=pyxb.binding.datatypes.decimal('0.01'))
STD_ANON_81._CF_fractionDigits = pyxb.binding.facets.CF_fractionDigits(value=pyxb.binding.datatypes.nonNegativeInteger(4))
STD_ANON_81._InitializeFacetMap(STD_ANON_81._CF_minInclusive,
   STD_ANON_81._CF_fractionDigits)

# Atomic simple type: [anonymous]
class STD_ANON_82 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1735, 6)
    _Documentation = None
STD_ANON_82._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(6))
STD_ANON_82._InitializeFacetMap(STD_ANON_82._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_83 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1756, 6)
    _Documentation = None
STD_ANON_83._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(8))
STD_ANON_83._CF_minLength = pyxb.binding.facets.CF_minLength(value=pyxb.binding.datatypes.nonNegativeInteger(8))
STD_ANON_83._InitializeFacetMap(STD_ANON_83._CF_maxLength,
   STD_ANON_83._CF_minLength)

# Atomic simple type: [anonymous]
class STD_ANON_84 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1765, 6)
    _Documentation = None
STD_ANON_84._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(8))
STD_ANON_84._CF_minLength = pyxb.binding.facets.CF_minLength(value=pyxb.binding.datatypes.nonNegativeInteger(8))
STD_ANON_84._InitializeFacetMap(STD_ANON_84._CF_maxLength,
   STD_ANON_84._CF_minLength)

# Atomic simple type: [anonymous]
class STD_ANON_85 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1774, 6)
    _Documentation = None
STD_ANON_85._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(8))
STD_ANON_85._CF_minLength = pyxb.binding.facets.CF_minLength(value=pyxb.binding.datatypes.nonNegativeInteger(8))
STD_ANON_85._InitializeFacetMap(STD_ANON_85._CF_maxLength,
   STD_ANON_85._CF_minLength)

# Atomic simple type: [anonymous]
class STD_ANON_86 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1845, 4)
    _Documentation = None
STD_ANON_86._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(6))
STD_ANON_86._InitializeFacetMap(STD_ANON_86._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_87 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1852, 4)
    _Documentation = None
STD_ANON_87._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(1))
STD_ANON_87._InitializeFacetMap(STD_ANON_87._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_88 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1859, 4)
    _Documentation = None
STD_ANON_88._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(1))
STD_ANON_88._InitializeFacetMap(STD_ANON_88._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_89 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1866, 4)
    _Documentation = None
STD_ANON_89._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(1))
STD_ANON_89._InitializeFacetMap(STD_ANON_89._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_90 (pyxb.binding.datatypes.decimal):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1877, 4)
    _Documentation = None
STD_ANON_90._CF_minInclusive = pyxb.binding.facets.CF_minInclusive(value_datatype=STD_ANON_90, value=pyxb.binding.datatypes.decimal('0.0'))
STD_ANON_90._CF_fractionDigits = pyxb.binding.facets.CF_fractionDigits(value=pyxb.binding.datatypes.nonNegativeInteger(4))
STD_ANON_90._InitializeFacetMap(STD_ANON_90._CF_minInclusive,
   STD_ANON_90._CF_fractionDigits)

# Atomic simple type: [anonymous]
class STD_ANON_91 (pyxb.binding.datatypes.decimal):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1885, 4)
    _Documentation = None
STD_ANON_91._CF_minInclusive = pyxb.binding.facets.CF_minInclusive(value_datatype=STD_ANON_91, value=pyxb.binding.datatypes.decimal('0.0'))
STD_ANON_91._CF_fractionDigits = pyxb.binding.facets.CF_fractionDigits(value=pyxb.binding.datatypes.nonNegativeInteger(4))
STD_ANON_91._InitializeFacetMap(STD_ANON_91._CF_minInclusive,
   STD_ANON_91._CF_fractionDigits)

# Atomic simple type: [anonymous]
class STD_ANON_92 (pyxb.binding.datatypes.decimal):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1893, 4)
    _Documentation = None
STD_ANON_92._CF_minInclusive = pyxb.binding.facets.CF_minInclusive(value_datatype=STD_ANON_92, value=pyxb.binding.datatypes.decimal('0.0'))
STD_ANON_92._CF_fractionDigits = pyxb.binding.facets.CF_fractionDigits(value=pyxb.binding.datatypes.nonNegativeInteger(4))
STD_ANON_92._InitializeFacetMap(STD_ANON_92._CF_minInclusive,
   STD_ANON_92._CF_fractionDigits)

# Atomic simple type: [anonymous]
class STD_ANON_93 (pyxb.binding.datatypes.decimal):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1905, 4)
    _Documentation = None
STD_ANON_93._CF_fractionDigits = pyxb.binding.facets.CF_fractionDigits(value=pyxb.binding.datatypes.nonNegativeInteger(4))
STD_ANON_93._InitializeFacetMap(STD_ANON_93._CF_fractionDigits)

# Atomic simple type: [anonymous]
class STD_ANON_94 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2142, 4)
    _Documentation = None
STD_ANON_94._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(20))
STD_ANON_94._InitializeFacetMap(STD_ANON_94._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_95 (pyxb.binding.datatypes.integer):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2159, 10)
    _Documentation = None
STD_ANON_95._InitializeFacetMap()

# Atomic simple type: {AnetApi/xml/v1/schema/AnetApiSchema.xsd}messageTypeEnum
class messageTypeEnum (pyxb.binding.datatypes.string, pyxb.binding.basis.enumeration_mixin):

    """An atomic simple type."""

    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'messageTypeEnum')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2183, 1)
    _Documentation = None
messageTypeEnum._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=messageTypeEnum, enum_prefix=None)
messageTypeEnum.Ok = messageTypeEnum._CF_enumeration.addEnumeration(unicode_value='Ok', tag='Ok')
messageTypeEnum.Error = messageTypeEnum._CF_enumeration.addEnumeration(unicode_value='Error', tag='Error')
messageTypeEnum._InitializeFacetMap(messageTypeEnum._CF_enumeration)
Namespace.addCategoryObject('typeBinding', 'messageTypeEnum', messageTypeEnum)

# Atomic simple type: [anonymous]
class STD_ANON_96 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2244, 5)
    _Documentation = None
STD_ANON_96._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(20))
STD_ANON_96._InitializeFacetMap(STD_ANON_96._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_97 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2543, 7)
    _Documentation = None
STD_ANON_97._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(2048))
STD_ANON_97._InitializeFacetMap(STD_ANON_97._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_98 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2805, 14)
    _Documentation = None
STD_ANON_98._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(2048))
STD_ANON_98._InitializeFacetMap(STD_ANON_98._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_99 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2967, 14)
    _Documentation = None
STD_ANON_99._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(1024))
STD_ANON_99._InitializeFacetMap(STD_ANON_99._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_100 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2992, 14)
    _Documentation = None
STD_ANON_100._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(2048))
STD_ANON_100._InitializeFacetMap(STD_ANON_100._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_101 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3039, 14)
    _Documentation = None
STD_ANON_101._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(2048))
STD_ANON_101._InitializeFacetMap(STD_ANON_101._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_102 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3508, 4)
    _Documentation = None
STD_ANON_102._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(2048))
STD_ANON_102._InitializeFacetMap(STD_ANON_102._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_103 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3515, 4)
    _Documentation = None
STD_ANON_103._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(2048))
STD_ANON_103._InitializeFacetMap(STD_ANON_103._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_104 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3522, 4)
    _Documentation = None
STD_ANON_104._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(2))
STD_ANON_104._InitializeFacetMap(STD_ANON_104._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_105 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3529, 4)
    _Documentation = None
STD_ANON_105._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(127))
STD_ANON_105._InitializeFacetMap(STD_ANON_105._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_106 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3536, 4)
    _Documentation = None
STD_ANON_106._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(6))
STD_ANON_106._InitializeFacetMap(STD_ANON_106._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_107 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3543, 4)
    _Documentation = None
STD_ANON_107._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(255))
STD_ANON_107._InitializeFacetMap(STD_ANON_107._CF_maxLength)

# Atomic simple type: [anonymous]
class STD_ANON_108 (pyxb.binding.datatypes.int):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3569, 16)
    _Documentation = None
STD_ANON_108._CF_maxInclusive = pyxb.binding.facets.CF_maxInclusive(value_datatype=STD_ANON_108, value=pyxb.binding.datatypes.int(1000))
STD_ANON_108._CF_minInclusive = pyxb.binding.facets.CF_minInclusive(value_datatype=STD_ANON_108, value=pyxb.binding.datatypes.int(1))
STD_ANON_108._InitializeFacetMap(STD_ANON_108._CF_maxInclusive,
   STD_ANON_108._CF_minInclusive)

# Atomic simple type: [anonymous]
class STD_ANON_109 (pyxb.binding.datatypes.int):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3577, 16)
    _Documentation = None
STD_ANON_109._CF_maxInclusive = pyxb.binding.facets.CF_maxInclusive(value_datatype=STD_ANON_109, value=pyxb.binding.datatypes.int(100000))
STD_ANON_109._CF_minInclusive = pyxb.binding.facets.CF_minInclusive(value_datatype=STD_ANON_109, value=pyxb.binding.datatypes.int(1))
STD_ANON_109._InitializeFacetMap(STD_ANON_109._CF_maxInclusive,
   STD_ANON_109._CF_minInclusive)

# Atomic simple type: {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ARBGetSubscriptionListSearchTypeEnum
class ARBGetSubscriptionListSearchTypeEnum (pyxb.binding.datatypes.string, pyxb.binding.basis.enumeration_mixin):

    """An atomic simple type."""

    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'ARBGetSubscriptionListSearchTypeEnum')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3594, 1)
    _Documentation = None
ARBGetSubscriptionListSearchTypeEnum._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=ARBGetSubscriptionListSearchTypeEnum, enum_prefix=None)
ARBGetSubscriptionListSearchTypeEnum.cardExpiringThisMonth = ARBGetSubscriptionListSearchTypeEnum._CF_enumeration.addEnumeration(unicode_value='cardExpiringThisMonth', tag='cardExpiringThisMonth')
ARBGetSubscriptionListSearchTypeEnum.subscriptionActive = ARBGetSubscriptionListSearchTypeEnum._CF_enumeration.addEnumeration(unicode_value='subscriptionActive', tag='subscriptionActive')
ARBGetSubscriptionListSearchTypeEnum.subscriptionExpiringThisMonth = ARBGetSubscriptionListSearchTypeEnum._CF_enumeration.addEnumeration(unicode_value='subscriptionExpiringThisMonth', tag='subscriptionExpiringThisMonth')
ARBGetSubscriptionListSearchTypeEnum.subscriptionInactive = ARBGetSubscriptionListSearchTypeEnum._CF_enumeration.addEnumeration(unicode_value='subscriptionInactive', tag='subscriptionInactive')
ARBGetSubscriptionListSearchTypeEnum._InitializeFacetMap(ARBGetSubscriptionListSearchTypeEnum._CF_enumeration)
Namespace.addCategoryObject('typeBinding', 'ARBGetSubscriptionListSearchTypeEnum', ARBGetSubscriptionListSearchTypeEnum)

# Atomic simple type: {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ARBGetSubscriptionListOrderFieldEnum
class ARBGetSubscriptionListOrderFieldEnum (pyxb.binding.datatypes.string, pyxb.binding.basis.enumeration_mixin):

    """An atomic simple type."""

    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'ARBGetSubscriptionListOrderFieldEnum')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3602, 1)
    _Documentation = None
ARBGetSubscriptionListOrderFieldEnum._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=ARBGetSubscriptionListOrderFieldEnum, enum_prefix=None)
ARBGetSubscriptionListOrderFieldEnum.id = ARBGetSubscriptionListOrderFieldEnum._CF_enumeration.addEnumeration(unicode_value='id', tag='id')
ARBGetSubscriptionListOrderFieldEnum.name = ARBGetSubscriptionListOrderFieldEnum._CF_enumeration.addEnumeration(unicode_value='name', tag='name')
ARBGetSubscriptionListOrderFieldEnum.status = ARBGetSubscriptionListOrderFieldEnum._CF_enumeration.addEnumeration(unicode_value='status', tag='status')
ARBGetSubscriptionListOrderFieldEnum.createTimeStampUTC = ARBGetSubscriptionListOrderFieldEnum._CF_enumeration.addEnumeration(unicode_value='createTimeStampUTC', tag='createTimeStampUTC')
ARBGetSubscriptionListOrderFieldEnum.lastName = ARBGetSubscriptionListOrderFieldEnum._CF_enumeration.addEnumeration(unicode_value='lastName', tag='lastName')
ARBGetSubscriptionListOrderFieldEnum.firstName = ARBGetSubscriptionListOrderFieldEnum._CF_enumeration.addEnumeration(unicode_value='firstName', tag='firstName')
ARBGetSubscriptionListOrderFieldEnum.accountNumber = ARBGetSubscriptionListOrderFieldEnum._CF_enumeration.addEnumeration(unicode_value='accountNumber', tag='accountNumber')
ARBGetSubscriptionListOrderFieldEnum.amount = ARBGetSubscriptionListOrderFieldEnum._CF_enumeration.addEnumeration(unicode_value='amount', tag='amount')
ARBGetSubscriptionListOrderFieldEnum.pastOccurrences = ARBGetSubscriptionListOrderFieldEnum._CF_enumeration.addEnumeration(unicode_value='pastOccurrences', tag='pastOccurrences')
ARBGetSubscriptionListOrderFieldEnum._InitializeFacetMap(ARBGetSubscriptionListOrderFieldEnum._CF_enumeration)
Namespace.addCategoryObject('typeBinding', 'ARBGetSubscriptionListOrderFieldEnum', ARBGetSubscriptionListOrderFieldEnum)

# Atomic simple type: [anonymous]
class STD_ANON_110 (pyxb.binding.datatypes.decimal):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3648, 16)
    _Documentation = None
STD_ANON_110._CF_minInclusive = pyxb.binding.facets.CF_minInclusive(value_datatype=STD_ANON_110, value=pyxb.binding.datatypes.decimal('0.0'))
STD_ANON_110._CF_fractionDigits = pyxb.binding.facets.CF_fractionDigits(value=pyxb.binding.datatypes.nonNegativeInteger(4))
STD_ANON_110._InitializeFacetMap(STD_ANON_110._CF_minInclusive,
   STD_ANON_110._CF_fractionDigits)

# Atomic simple type: [anonymous]
class STD_ANON_111 (pyxb.binding.datatypes.string):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3735, 28)
    _Documentation = None
STD_ANON_111._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(7))
STD_ANON_111._CF_minLength = pyxb.binding.facets.CF_minLength(value=pyxb.binding.datatypes.nonNegativeInteger(4))
STD_ANON_111._InitializeFacetMap(STD_ANON_111._CF_maxLength,
   STD_ANON_111._CF_minLength)

# Atomic simple type: {AnetApi/xml/v1/schema/AnetApiSchema.xsd}CustomerPaymentProfileOrderFieldEnum
class CustomerPaymentProfileOrderFieldEnum (pyxb.binding.datatypes.string, pyxb.binding.basis.enumeration_mixin):

    """An atomic simple type."""

    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'CustomerPaymentProfileOrderFieldEnum')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3763, 1)
    _Documentation = None
CustomerPaymentProfileOrderFieldEnum._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=CustomerPaymentProfileOrderFieldEnum, enum_prefix=None)
CustomerPaymentProfileOrderFieldEnum.id = CustomerPaymentProfileOrderFieldEnum._CF_enumeration.addEnumeration(unicode_value='id', tag='id')
CustomerPaymentProfileOrderFieldEnum._InitializeFacetMap(CustomerPaymentProfileOrderFieldEnum._CF_enumeration)
Namespace.addCategoryObject('typeBinding', 'CustomerPaymentProfileOrderFieldEnum', CustomerPaymentProfileOrderFieldEnum)

# Atomic simple type: {AnetApi/xml/v1/schema/AnetApiSchema.xsd}CustomerPaymentProfileSearchTypeEnum
class CustomerPaymentProfileSearchTypeEnum (pyxb.binding.datatypes.string, pyxb.binding.basis.enumeration_mixin):

    """An atomic simple type."""

    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'CustomerPaymentProfileSearchTypeEnum')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3775, 1)
    _Documentation = None
CustomerPaymentProfileSearchTypeEnum._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=CustomerPaymentProfileSearchTypeEnum, enum_prefix=None)
CustomerPaymentProfileSearchTypeEnum.cardsExpiringInMonth = CustomerPaymentProfileSearchTypeEnum._CF_enumeration.addEnumeration(unicode_value='cardsExpiringInMonth', tag='cardsExpiringInMonth')
CustomerPaymentProfileSearchTypeEnum._InitializeFacetMap(CustomerPaymentProfileSearchTypeEnum._CF_enumeration)
Namespace.addCategoryObject('typeBinding', 'CustomerPaymentProfileSearchTypeEnum', CustomerPaymentProfileSearchTypeEnum)

# Atomic simple type: {AnetApi/xml/v1/schema/AnetApiSchema.xsd}cardCode
class cardCode (numericString):

    """An atomic simple type."""

    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'cardCode')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 435, 1)
    _Documentation = None
cardCode._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(4))
cardCode._CF_minLength = pyxb.binding.facets.CF_minLength(value=pyxb.binding.datatypes.nonNegativeInteger(3))
cardCode._InitializeFacetMap(cardCode._CF_maxLength,
   cardCode._CF_minLength)
Namespace.addCategoryObject('typeBinding', 'cardCode', cardCode)

# Atomic simple type: [anonymous]
class STD_ANON_112 (numericString):

    """An atomic simple type."""

    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 702, 4)
    _Documentation = None
STD_ANON_112._CF_maxLength = pyxb.binding.facets.CF_maxLength(value=pyxb.binding.datatypes.nonNegativeInteger(9))
STD_ANON_112._CF_minLength = pyxb.binding.facets.CF_minLength(value=pyxb.binding.datatypes.nonNegativeInteger(9))
STD_ANON_112._InitializeFacetMap(STD_ANON_112._CF_maxLength,
   STD_ANON_112._CF_minLength)

# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ArrayOfLong with content type ELEMENT_ONLY
class ArrayOfLong (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ArrayOfLong with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'ArrayOfLong')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 15, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}long uses Python identifier long
    __long = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'long'), 'long', '__AnetApixmlv1schemaAnetApiSchema_xsd_ArrayOfLong_AnetApixmlv1schemaAnetApiSchema_xsdlong', True, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 17, 3), )

    
    long = property(__long.value, __long.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __long.name() : __long
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'ArrayOfLong', ArrayOfLong)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ArrayOfNumericString with content type ELEMENT_ONLY
class ArrayOfNumericString (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ArrayOfNumericString with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'ArrayOfNumericString')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 22, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}numericString uses Python identifier numericString
    __numericString = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'numericString'), 'numericString', '__AnetApixmlv1schemaAnetApiSchema_xsd_ArrayOfNumericString_AnetApixmlv1schemaAnetApiSchema_xsdnumericString', True, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 24, 3), )

    
    numericString = property(__numericString.value, __numericString.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __numericString.name() : __numericString
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'ArrayOfNumericString', ArrayOfNumericString)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ArrayOfString with content type ELEMENT_ONLY
class ArrayOfString (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ArrayOfString with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'ArrayOfString')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 29, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}string uses Python identifier string
    __string = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'string'), 'string', '__AnetApixmlv1schemaAnetApiSchema_xsd_ArrayOfString_AnetApixmlv1schemaAnetApiSchema_xsdstring', True, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 31, 3), )

    
    string = property(__string.value, __string.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __string.name() : __string
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'ArrayOfString', ArrayOfString)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ArrayOfLineItem with content type ELEMENT_ONLY
class ArrayOfLineItem (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ArrayOfLineItem with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'ArrayOfLineItem')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 36, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}lineItem uses Python identifier lineItem
    __lineItem = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'lineItem'), 'lineItem', '__AnetApixmlv1schemaAnetApiSchema_xsd_ArrayOfLineItem_AnetApixmlv1schemaAnetApiSchema_xsdlineItem', True, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 38, 3), )

    
    lineItem = property(__lineItem.value, __lineItem.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __lineItem.name() : __lineItem
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'ArrayOfLineItem', ArrayOfLineItem)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ArrayOfBatchStatisticType with content type ELEMENT_ONLY
class ArrayOfBatchStatisticType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ArrayOfBatchStatisticType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'ArrayOfBatchStatisticType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 43, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}statistic uses Python identifier statistic
    __statistic = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'statistic'), 'statistic', '__AnetApixmlv1schemaAnetApiSchema_xsd_ArrayOfBatchStatisticType_AnetApixmlv1schemaAnetApiSchema_xsdstatistic', True, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 45, 3), )

    
    statistic = property(__statistic.value, __statistic.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __statistic.name() : __statistic
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'ArrayOfBatchStatisticType', ArrayOfBatchStatisticType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ArrayOfBatchDetailsType with content type ELEMENT_ONLY
class ArrayOfBatchDetailsType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ArrayOfBatchDetailsType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'ArrayOfBatchDetailsType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 50, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}batch uses Python identifier batch
    __batch = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'batch'), 'batch', '__AnetApixmlv1schemaAnetApiSchema_xsd_ArrayOfBatchDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdbatch', True, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 52, 3), )

    
    batch = property(__batch.value, __batch.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __batch.name() : __batch
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'ArrayOfBatchDetailsType', ArrayOfBatchDetailsType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ArrayOfTransactionSummaryType with content type ELEMENT_ONLY
class ArrayOfTransactionSummaryType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ArrayOfTransactionSummaryType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'ArrayOfTransactionSummaryType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 57, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}transaction uses Python identifier transaction
    __transaction = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'transaction'), 'transaction', '__AnetApixmlv1schemaAnetApiSchema_xsd_ArrayOfTransactionSummaryType_AnetApixmlv1schemaAnetApiSchema_xsdtransaction', True, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 59, 3), )

    
    transaction = property(__transaction.value, __transaction.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __transaction.name() : __transaction
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'ArrayOfTransactionSummaryType', ArrayOfTransactionSummaryType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ArrayOfSetting with content type ELEMENT_ONLY
class ArrayOfSetting (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ArrayOfSetting with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'ArrayOfSetting')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 64, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}setting uses Python identifier setting
    __setting = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'setting'), 'setting', '__AnetApixmlv1schemaAnetApiSchema_xsd_ArrayOfSetting_AnetApixmlv1schemaAnetApiSchema_xsdsetting', True, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 66, 3), )

    
    setting = property(__setting.value, __setting.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __setting.name() : __setting
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'ArrayOfSetting', ArrayOfSetting)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ArrayOfFDSFilter with content type ELEMENT_ONLY
class ArrayOfFDSFilter (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ArrayOfFDSFilter with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'ArrayOfFDSFilter')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 71, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}FDSFilter uses Python identifier FDSFilter
    __FDSFilter = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'FDSFilter'), 'FDSFilter', '__AnetApixmlv1schemaAnetApiSchema_xsd_ArrayOfFDSFilter_AnetApixmlv1schemaAnetApiSchema_xsdFDSFilter', True, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 73, 3), )

    
    FDSFilter = property(__FDSFilter.value, __FDSFilter.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __FDSFilter.name() : __FDSFilter
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'ArrayOfFDSFilter', ArrayOfFDSFilter)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ArrayOfPermissionType with content type ELEMENT_ONLY
class ArrayOfPermissionType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ArrayOfPermissionType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'ArrayOfPermissionType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 78, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}permission uses Python identifier permission
    __permission = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'permission'), 'permission', '__AnetApixmlv1schemaAnetApiSchema_xsd_ArrayOfPermissionType_AnetApixmlv1schemaAnetApiSchema_xsdpermission', True, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 80, 3), )

    
    permission = property(__permission.value, __permission.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __permission.name() : __permission
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'ArrayOfPermissionType', ArrayOfPermissionType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}driversLicenseType with content type ELEMENT_ONLY
class driversLicenseType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}driversLicenseType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'driversLicenseType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 254, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}number uses Python identifier number
    __number = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'number'), 'number', '__AnetApixmlv1schemaAnetApiSchema_xsd_driversLicenseType_AnetApixmlv1schemaAnetApiSchema_xsdnumber', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 257, 3), )

    
    number = property(__number.value, __number.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}state uses Python identifier state
    __state = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'state'), 'state', '__AnetApixmlv1schemaAnetApiSchema_xsd_driversLicenseType_AnetApixmlv1schemaAnetApiSchema_xsdstate', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 265, 3), )

    
    state = property(__state.value, __state.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}dateOfBirth uses Python identifier dateOfBirth
    __dateOfBirth = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'dateOfBirth'), 'dateOfBirth', '__AnetApixmlv1schemaAnetApiSchema_xsd_driversLicenseType_AnetApixmlv1schemaAnetApiSchema_xsddateOfBirth', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 274, 3), )

    
    dateOfBirth = property(__dateOfBirth.value, __dateOfBirth.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __number.name() : __number,
        __state.name() : __state,
        __dateOfBirth.name() : __dateOfBirth
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'driversLicenseType', driversLicenseType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}driversLicenseMaskedType with content type ELEMENT_ONLY
class driversLicenseMaskedType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}driversLicenseMaskedType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'driversLicenseMaskedType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 286, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}number uses Python identifier number
    __number = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'number'), 'number', '__AnetApixmlv1schemaAnetApiSchema_xsd_driversLicenseMaskedType_AnetApixmlv1schemaAnetApiSchema_xsdnumber', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 288, 3), )

    
    number = property(__number.value, __number.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}state uses Python identifier state
    __state = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'state'), 'state', '__AnetApixmlv1schemaAnetApiSchema_xsd_driversLicenseMaskedType_AnetApixmlv1schemaAnetApiSchema_xsdstate', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 295, 3), )

    
    state = property(__state.value, __state.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}dateOfBirth uses Python identifier dateOfBirth
    __dateOfBirth = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'dateOfBirth'), 'dateOfBirth', '__AnetApixmlv1schemaAnetApiSchema_xsd_driversLicenseMaskedType_AnetApixmlv1schemaAnetApiSchema_xsddateOfBirth', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 303, 3), )

    
    dateOfBirth = property(__dateOfBirth.value, __dateOfBirth.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __number.name() : __number,
        __state.name() : __state,
        __dateOfBirth.name() : __dateOfBirth
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'driversLicenseMaskedType', driversLicenseMaskedType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}nameAndAddressType with content type ELEMENT_ONLY
class nameAndAddressType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}nameAndAddressType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'nameAndAddressType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 315, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}firstName uses Python identifier firstName
    __firstName = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'firstName'), 'firstName', '__AnetApixmlv1schemaAnetApiSchema_xsd_nameAndAddressType_AnetApixmlv1schemaAnetApiSchema_xsdfirstName', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 317, 3), )

    
    firstName = property(__firstName.value, __firstName.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}lastName uses Python identifier lastName
    __lastName = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'lastName'), 'lastName', '__AnetApixmlv1schemaAnetApiSchema_xsd_nameAndAddressType_AnetApixmlv1schemaAnetApiSchema_xsdlastName', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 324, 3), )

    
    lastName = property(__lastName.value, __lastName.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}company uses Python identifier company
    __company = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'company'), 'company', '__AnetApixmlv1schemaAnetApiSchema_xsd_nameAndAddressType_AnetApixmlv1schemaAnetApiSchema_xsdcompany', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 331, 3), )

    
    company = property(__company.value, __company.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}address uses Python identifier address
    __address = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'address'), 'address', '__AnetApixmlv1schemaAnetApiSchema_xsd_nameAndAddressType_AnetApixmlv1schemaAnetApiSchema_xsdaddress', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 338, 3), )

    
    address = property(__address.value, __address.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}city uses Python identifier city
    __city = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'city'), 'city', '__AnetApixmlv1schemaAnetApiSchema_xsd_nameAndAddressType_AnetApixmlv1schemaAnetApiSchema_xsdcity', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 345, 3), )

    
    city = property(__city.value, __city.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}state uses Python identifier state
    __state = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'state'), 'state', '__AnetApixmlv1schemaAnetApiSchema_xsd_nameAndAddressType_AnetApixmlv1schemaAnetApiSchema_xsdstate', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 352, 3), )

    
    state = property(__state.value, __state.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}zip uses Python identifier zip
    __zip = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'zip'), 'zip', '__AnetApixmlv1schemaAnetApiSchema_xsd_nameAndAddressType_AnetApixmlv1schemaAnetApiSchema_xsdzip', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 359, 3), )

    
    zip = property(__zip.value, __zip.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}country uses Python identifier country
    __country = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'country'), 'country', '__AnetApixmlv1schemaAnetApiSchema_xsd_nameAndAddressType_AnetApixmlv1schemaAnetApiSchema_xsdcountry', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 366, 3), )

    
    country = property(__country.value, __country.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __firstName.name() : __firstName,
        __lastName.name() : __lastName,
        __company.name() : __company,
        __address.name() : __address,
        __city.name() : __city,
        __state.name() : __state,
        __zip.name() : __zip,
        __country.name() : __country
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'nameAndAddressType', nameAndAddressType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantContactType with content type ELEMENT_ONLY
class merchantContactType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantContactType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'merchantContactType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 377, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantName uses Python identifier merchantName
    __merchantName = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'merchantName'), 'merchantName', '__AnetApixmlv1schemaAnetApiSchema_xsd_merchantContactType_AnetApixmlv1schemaAnetApiSchema_xsdmerchantName', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 379, 3), )

    
    merchantName = property(__merchantName.value, __merchantName.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantAddress uses Python identifier merchantAddress
    __merchantAddress = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'merchantAddress'), 'merchantAddress', '__AnetApixmlv1schemaAnetApiSchema_xsd_merchantContactType_AnetApixmlv1schemaAnetApiSchema_xsdmerchantAddress', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 380, 3), )

    
    merchantAddress = property(__merchantAddress.value, __merchantAddress.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantCity uses Python identifier merchantCity
    __merchantCity = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'merchantCity'), 'merchantCity', '__AnetApixmlv1schemaAnetApiSchema_xsd_merchantContactType_AnetApixmlv1schemaAnetApiSchema_xsdmerchantCity', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 381, 3), )

    
    merchantCity = property(__merchantCity.value, __merchantCity.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantState uses Python identifier merchantState
    __merchantState = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'merchantState'), 'merchantState', '__AnetApixmlv1schemaAnetApiSchema_xsd_merchantContactType_AnetApixmlv1schemaAnetApiSchema_xsdmerchantState', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 382, 3), )

    
    merchantState = property(__merchantState.value, __merchantState.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantZip uses Python identifier merchantZip
    __merchantZip = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'merchantZip'), 'merchantZip', '__AnetApixmlv1schemaAnetApiSchema_xsd_merchantContactType_AnetApixmlv1schemaAnetApiSchema_xsdmerchantZip', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 383, 3), )

    
    merchantZip = property(__merchantZip.value, __merchantZip.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantPhone uses Python identifier merchantPhone
    __merchantPhone = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'merchantPhone'), 'merchantPhone', '__AnetApixmlv1schemaAnetApiSchema_xsd_merchantContactType_AnetApixmlv1schemaAnetApiSchema_xsdmerchantPhone', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 384, 3), )

    
    merchantPhone = property(__merchantPhone.value, __merchantPhone.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __merchantName.name() : __merchantName,
        __merchantAddress.name() : __merchantAddress,
        __merchantCity.name() : __merchantCity,
        __merchantState.name() : __merchantState,
        __merchantZip.name() : __merchantZip,
        __merchantPhone.name() : __merchantPhone
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'merchantContactType', merchantContactType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}transRetailInfoType with content type ELEMENT_ONLY
class transRetailInfoType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}transRetailInfoType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'transRetailInfoType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 395, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}marketType uses Python identifier marketType
    __marketType = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'marketType'), 'marketType', '__AnetApixmlv1schemaAnetApiSchema_xsd_transRetailInfoType_AnetApixmlv1schemaAnetApiSchema_xsdmarketType', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 397, 3), )

    
    marketType = property(__marketType.value, __marketType.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}deviceType uses Python identifier deviceType
    __deviceType = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'deviceType'), 'deviceType', '__AnetApixmlv1schemaAnetApiSchema_xsd_transRetailInfoType_AnetApixmlv1schemaAnetApiSchema_xsddeviceType', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 398, 3), )

    
    deviceType = property(__deviceType.value, __deviceType.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerSignature uses Python identifier customerSignature
    __customerSignature = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerSignature'), 'customerSignature', '__AnetApixmlv1schemaAnetApiSchema_xsd_transRetailInfoType_AnetApixmlv1schemaAnetApiSchema_xsdcustomerSignature', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 399, 12), )

    
    customerSignature = property(__customerSignature.value, __customerSignature.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __marketType.name() : __marketType,
        __deviceType.name() : __deviceType,
        __customerSignature.name() : __customerSignature
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'transRetailInfoType', transRetailInfoType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}creditCardSimpleType with content type ELEMENT_ONLY
class creditCardSimpleType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}creditCardSimpleType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'creditCardSimpleType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 404, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}cardNumber uses Python identifier cardNumber
    __cardNumber = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'cardNumber'), 'cardNumber', '__AnetApixmlv1schemaAnetApiSchema_xsd_creditCardSimpleType_AnetApixmlv1schemaAnetApiSchema_xsdcardNumber', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 407, 3), )

    
    cardNumber = property(__cardNumber.value, __cardNumber.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}expirationDate uses Python identifier expirationDate
    __expirationDate = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'expirationDate'), 'expirationDate', '__AnetApixmlv1schemaAnetApiSchema_xsd_creditCardSimpleType_AnetApixmlv1schemaAnetApiSchema_xsdexpirationDate', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 416, 3), )

    
    expirationDate = property(__expirationDate.value, __expirationDate.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __cardNumber.name() : __cardNumber,
        __expirationDate.name() : __expirationDate
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'creditCardSimpleType', creditCardSimpleType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}creditCardTrackType with content type ELEMENT_ONLY
class creditCardTrackType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}creditCardTrackType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'creditCardTrackType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 428, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}track1 uses Python identifier track1
    __track1 = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'track1'), 'track1', '__AnetApixmlv1schemaAnetApiSchema_xsd_creditCardTrackType_AnetApixmlv1schemaAnetApiSchema_xsdtrack1', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 430, 3), )

    
    track1 = property(__track1.value, __track1.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}track2 uses Python identifier track2
    __track2 = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'track2'), 'track2', '__AnetApixmlv1schemaAnetApiSchema_xsd_creditCardTrackType_AnetApixmlv1schemaAnetApiSchema_xsdtrack2', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 431, 3), )

    
    track2 = property(__track2.value, __track2.set, None, None)

    _ElementMap.update({
        __track1.name() : __track1,
        __track2.name() : __track2
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'creditCardTrackType', creditCardTrackType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}creditCardMaskedType with content type ELEMENT_ONLY
class creditCardMaskedType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}creditCardMaskedType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'creditCardMaskedType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 459, 2)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}cardNumber uses Python identifier cardNumber
    __cardNumber = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'cardNumber'), 'cardNumber', '__AnetApixmlv1schemaAnetApiSchema_xsd_creditCardMaskedType_AnetApixmlv1schemaAnetApiSchema_xsdcardNumber', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 461, 3), )

    
    cardNumber = property(__cardNumber.value, __cardNumber.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}expirationDate uses Python identifier expirationDate
    __expirationDate = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'expirationDate'), 'expirationDate', '__AnetApixmlv1schemaAnetApiSchema_xsd_creditCardMaskedType_AnetApixmlv1schemaAnetApiSchema_xsdexpirationDate', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 468, 3), )

    
    expirationDate = property(__expirationDate.value, __expirationDate.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}cardType uses Python identifier cardType
    __cardType = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'cardType'), 'cardType', '__AnetApixmlv1schemaAnetApiSchema_xsd_creditCardMaskedType_AnetApixmlv1schemaAnetApiSchema_xsdcardType', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 476, 3), )

    
    cardType = property(__cardType.value, __cardType.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}cardArt uses Python identifier cardArt
    __cardArt = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'cardArt'), 'cardArt', '__AnetApixmlv1schemaAnetApiSchema_xsd_creditCardMaskedType_AnetApixmlv1schemaAnetApiSchema_xsdcardArt', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 477, 3), )

    
    cardArt = property(__cardArt.value, __cardArt.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __cardNumber.name() : __cardNumber,
        __expirationDate.name() : __expirationDate,
        __cardType.name() : __cardType,
        __cardArt.name() : __cardArt
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'creditCardMaskedType', creditCardMaskedType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ccAuthenticationType with content type ELEMENT_ONLY
class ccAuthenticationType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ccAuthenticationType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'ccAuthenticationType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 482, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}authenticationIndicator uses Python identifier authenticationIndicator
    __authenticationIndicator = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'authenticationIndicator'), 'authenticationIndicator', '__AnetApixmlv1schemaAnetApiSchema_xsd_ccAuthenticationType_AnetApixmlv1schemaAnetApiSchema_xsdauthenticationIndicator', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 484, 3), )

    
    authenticationIndicator = property(__authenticationIndicator.value, __authenticationIndicator.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}cardholderAuthenticationValue uses Python identifier cardholderAuthenticationValue
    __cardholderAuthenticationValue = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'cardholderAuthenticationValue'), 'cardholderAuthenticationValue', '__AnetApixmlv1schemaAnetApiSchema_xsd_ccAuthenticationType_AnetApixmlv1schemaAnetApiSchema_xsdcardholderAuthenticationValue', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 485, 3), )

    
    cardholderAuthenticationValue = property(__cardholderAuthenticationValue.value, __cardholderAuthenticationValue.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __authenticationIndicator.name() : __authenticationIndicator,
        __cardholderAuthenticationValue.name() : __cardholderAuthenticationValue
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'ccAuthenticationType', ccAuthenticationType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}bankAccountType with content type ELEMENT_ONLY
class bankAccountType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}bankAccountType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'bankAccountType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 490, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}accountType uses Python identifier accountType
    __accountType = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'accountType'), 'accountType', '__AnetApixmlv1schemaAnetApiSchema_xsd_bankAccountType_AnetApixmlv1schemaAnetApiSchema_xsdaccountType', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 492, 3), )

    
    accountType = property(__accountType.value, __accountType.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}routingNumber uses Python identifier routingNumber
    __routingNumber = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'routingNumber'), 'routingNumber', '__AnetApixmlv1schemaAnetApiSchema_xsd_bankAccountType_AnetApixmlv1schemaAnetApiSchema_xsdroutingNumber', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 494, 3), )

    
    routingNumber = property(__routingNumber.value, __routingNumber.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}accountNumber uses Python identifier accountNumber
    __accountNumber = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'accountNumber'), 'accountNumber', '__AnetApixmlv1schemaAnetApiSchema_xsd_bankAccountType_AnetApixmlv1schemaAnetApiSchema_xsdaccountNumber', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 502, 3), )

    
    accountNumber = property(__accountNumber.value, __accountNumber.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}nameOnAccount uses Python identifier nameOnAccount
    __nameOnAccount = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'nameOnAccount'), 'nameOnAccount', '__AnetApixmlv1schemaAnetApiSchema_xsd_bankAccountType_AnetApixmlv1schemaAnetApiSchema_xsdnameOnAccount', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 509, 3), )

    
    nameOnAccount = property(__nameOnAccount.value, __nameOnAccount.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}echeckType uses Python identifier echeckType
    __echeckType = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'echeckType'), 'echeckType', '__AnetApixmlv1schemaAnetApiSchema_xsd_bankAccountType_AnetApixmlv1schemaAnetApiSchema_xsdecheckType', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 516, 3), )

    
    echeckType = property(__echeckType.value, __echeckType.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}bankName uses Python identifier bankName
    __bankName = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'bankName'), 'bankName', '__AnetApixmlv1schemaAnetApiSchema_xsd_bankAccountType_AnetApixmlv1schemaAnetApiSchema_xsdbankName', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 517, 3), )

    
    bankName = property(__bankName.value, __bankName.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}checkNumber uses Python identifier checkNumber
    __checkNumber = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'checkNumber'), 'checkNumber', '__AnetApixmlv1schemaAnetApiSchema_xsd_bankAccountType_AnetApixmlv1schemaAnetApiSchema_xsdcheckNumber', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 524, 3), )

    
    checkNumber = property(__checkNumber.value, __checkNumber.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __accountType.name() : __accountType,
        __routingNumber.name() : __routingNumber,
        __accountNumber.name() : __accountNumber,
        __nameOnAccount.name() : __nameOnAccount,
        __echeckType.name() : __echeckType,
        __bankName.name() : __bankName,
        __checkNumber.name() : __checkNumber
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'bankAccountType', bankAccountType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}bankAccountMaskedType with content type ELEMENT_ONLY
class bankAccountMaskedType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}bankAccountMaskedType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'bankAccountMaskedType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 535, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}accountType uses Python identifier accountType
    __accountType = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'accountType'), 'accountType', '__AnetApixmlv1schemaAnetApiSchema_xsd_bankAccountMaskedType_AnetApixmlv1schemaAnetApiSchema_xsdaccountType', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 537, 3), )

    
    accountType = property(__accountType.value, __accountType.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}routingNumber uses Python identifier routingNumber
    __routingNumber = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'routingNumber'), 'routingNumber', '__AnetApixmlv1schemaAnetApiSchema_xsd_bankAccountMaskedType_AnetApixmlv1schemaAnetApiSchema_xsdroutingNumber', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 538, 3), )

    
    routingNumber = property(__routingNumber.value, __routingNumber.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}accountNumber uses Python identifier accountNumber
    __accountNumber = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'accountNumber'), 'accountNumber', '__AnetApixmlv1schemaAnetApiSchema_xsd_bankAccountMaskedType_AnetApixmlv1schemaAnetApiSchema_xsdaccountNumber', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 545, 3), )

    
    accountNumber = property(__accountNumber.value, __accountNumber.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}nameOnAccount uses Python identifier nameOnAccount
    __nameOnAccount = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'nameOnAccount'), 'nameOnAccount', '__AnetApixmlv1schemaAnetApiSchema_xsd_bankAccountMaskedType_AnetApixmlv1schemaAnetApiSchema_xsdnameOnAccount', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 552, 3), )

    
    nameOnAccount = property(__nameOnAccount.value, __nameOnAccount.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}echeckType uses Python identifier echeckType
    __echeckType = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'echeckType'), 'echeckType', '__AnetApixmlv1schemaAnetApiSchema_xsd_bankAccountMaskedType_AnetApixmlv1schemaAnetApiSchema_xsdecheckType', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 559, 3), )

    
    echeckType = property(__echeckType.value, __echeckType.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}bankName uses Python identifier bankName
    __bankName = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'bankName'), 'bankName', '__AnetApixmlv1schemaAnetApiSchema_xsd_bankAccountMaskedType_AnetApixmlv1schemaAnetApiSchema_xsdbankName', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 560, 3), )

    
    bankName = property(__bankName.value, __bankName.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __accountType.name() : __accountType,
        __routingNumber.name() : __routingNumber,
        __accountNumber.name() : __accountNumber,
        __nameOnAccount.name() : __nameOnAccount,
        __echeckType.name() : __echeckType,
        __bankName.name() : __bankName
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'bankAccountMaskedType', bankAccountMaskedType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}opaqueDataType with content type ELEMENT_ONLY
class opaqueDataType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}opaqueDataType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'opaqueDataType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 571, 2)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}dataDescriptor uses Python identifier dataDescriptor
    __dataDescriptor = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'dataDescriptor'), 'dataDescriptor', '__AnetApixmlv1schemaAnetApiSchema_xsd_opaqueDataType_AnetApixmlv1schemaAnetApiSchema_xsddataDescriptor', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 573, 6), )

    
    dataDescriptor = property(__dataDescriptor.value, __dataDescriptor.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}dataValue uses Python identifier dataValue
    __dataValue = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'dataValue'), 'dataValue', '__AnetApixmlv1schemaAnetApiSchema_xsd_opaqueDataType_AnetApixmlv1schemaAnetApiSchema_xsddataValue', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 574, 6), )

    
    dataValue = property(__dataValue.value, __dataValue.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}dataKey uses Python identifier dataKey
    __dataKey = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'dataKey'), 'dataKey', '__AnetApixmlv1schemaAnetApiSchema_xsd_opaqueDataType_AnetApixmlv1schemaAnetApiSchema_xsddataKey', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 575, 6), )

    
    dataKey = property(__dataKey.value, __dataKey.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __dataDescriptor.name() : __dataDescriptor,
        __dataValue.name() : __dataValue,
        __dataKey.name() : __dataKey
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'opaqueDataType', opaqueDataType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}paymentSimpleType with content type ELEMENT_ONLY
class paymentSimpleType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}paymentSimpleType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'paymentSimpleType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 580, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}creditCard uses Python identifier creditCard
    __creditCard = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'creditCard'), 'creditCard', '__AnetApixmlv1schemaAnetApiSchema_xsd_paymentSimpleType_AnetApixmlv1schemaAnetApiSchema_xsdcreditCard', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 583, 4), )

    
    creditCard = property(__creditCard.value, __creditCard.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}bankAccount uses Python identifier bankAccount
    __bankAccount = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'bankAccount'), 'bankAccount', '__AnetApixmlv1schemaAnetApiSchema_xsd_paymentSimpleType_AnetApixmlv1schemaAnetApiSchema_xsdbankAccount', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 584, 4), )

    
    bankAccount = property(__bankAccount.value, __bankAccount.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __creditCard.name() : __creditCard,
        __bankAccount.name() : __bankAccount
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'paymentSimpleType', paymentSimpleType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}paymentType with content type ELEMENT_ONLY
class paymentType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}paymentType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'paymentType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 590, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}creditCard uses Python identifier creditCard
    __creditCard = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'creditCard'), 'creditCard', '__AnetApixmlv1schemaAnetApiSchema_xsd_paymentType_AnetApixmlv1schemaAnetApiSchema_xsdcreditCard', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 593, 4), )

    
    creditCard = property(__creditCard.value, __creditCard.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}bankAccount uses Python identifier bankAccount
    __bankAccount = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'bankAccount'), 'bankAccount', '__AnetApixmlv1schemaAnetApiSchema_xsd_paymentType_AnetApixmlv1schemaAnetApiSchema_xsdbankAccount', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 594, 4), )

    
    bankAccount = property(__bankAccount.value, __bankAccount.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}trackData uses Python identifier trackData
    __trackData = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'trackData'), 'trackData', '__AnetApixmlv1schemaAnetApiSchema_xsd_paymentType_AnetApixmlv1schemaAnetApiSchema_xsdtrackData', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 595, 4), )

    
    trackData = property(__trackData.value, __trackData.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}encryptedTrackData uses Python identifier encryptedTrackData
    __encryptedTrackData = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'encryptedTrackData'), 'encryptedTrackData', '__AnetApixmlv1schemaAnetApiSchema_xsd_paymentType_AnetApixmlv1schemaAnetApiSchema_xsdencryptedTrackData', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 596, 4), )

    
    encryptedTrackData = property(__encryptedTrackData.value, __encryptedTrackData.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}payPal uses Python identifier payPal
    __payPal = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'payPal'), 'payPal', '__AnetApixmlv1schemaAnetApiSchema_xsd_paymentType_AnetApixmlv1schemaAnetApiSchema_xsdpayPal', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 597, 4), )

    
    payPal = property(__payPal.value, __payPal.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}opaqueData uses Python identifier opaqueData
    __opaqueData = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'opaqueData'), 'opaqueData', '__AnetApixmlv1schemaAnetApiSchema_xsd_paymentType_AnetApixmlv1schemaAnetApiSchema_xsdopaqueData', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 598, 8), )

    
    opaqueData = property(__opaqueData.value, __opaqueData.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}emv uses Python identifier emv
    __emv = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'emv'), 'emv', '__AnetApixmlv1schemaAnetApiSchema_xsd_paymentType_AnetApixmlv1schemaAnetApiSchema_xsdemv', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 599, 16), )

    
    emv = property(__emv.value, __emv.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __creditCard.name() : __creditCard,
        __bankAccount.name() : __bankAccount,
        __trackData.name() : __trackData,
        __encryptedTrackData.name() : __encryptedTrackData,
        __payPal.name() : __payPal,
        __opaqueData.name() : __opaqueData,
        __emv.name() : __emv
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'paymentType', paymentType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}paymentMaskedType with content type ELEMENT_ONLY
class paymentMaskedType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}paymentMaskedType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'paymentMaskedType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 605, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}creditCard uses Python identifier creditCard
    __creditCard = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'creditCard'), 'creditCard', '__AnetApixmlv1schemaAnetApiSchema_xsd_paymentMaskedType_AnetApixmlv1schemaAnetApiSchema_xsdcreditCard', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 608, 4), )

    
    creditCard = property(__creditCard.value, __creditCard.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}bankAccount uses Python identifier bankAccount
    __bankAccount = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'bankAccount'), 'bankAccount', '__AnetApixmlv1schemaAnetApiSchema_xsd_paymentMaskedType_AnetApixmlv1schemaAnetApiSchema_xsdbankAccount', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 609, 4), )

    
    bankAccount = property(__bankAccount.value, __bankAccount.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}tokenInformation uses Python identifier tokenInformation
    __tokenInformation = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'tokenInformation'), 'tokenInformation', '__AnetApixmlv1schemaAnetApiSchema_xsd_paymentMaskedType_AnetApixmlv1schemaAnetApiSchema_xsdtokenInformation', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 610, 8), )

    
    tokenInformation = property(__tokenInformation.value, __tokenInformation.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __creditCard.name() : __creditCard,
        __bankAccount.name() : __bankAccount,
        __tokenInformation.name() : __tokenInformation
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'paymentMaskedType', paymentMaskedType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}tokenMaskedType with content type ELEMENT_ONLY
class tokenMaskedType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}tokenMaskedType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'tokenMaskedType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 616, 2)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}tokenSource uses Python identifier tokenSource
    __tokenSource = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'tokenSource'), 'tokenSource', '__AnetApixmlv1schemaAnetApiSchema_xsd_tokenMaskedType_AnetApixmlv1schemaAnetApiSchema_xsdtokenSource', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 618, 6), )

    
    tokenSource = property(__tokenSource.value, __tokenSource.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}tokenNumber uses Python identifier tokenNumber
    __tokenNumber = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'tokenNumber'), 'tokenNumber', '__AnetApixmlv1schemaAnetApiSchema_xsd_tokenMaskedType_AnetApixmlv1schemaAnetApiSchema_xsdtokenNumber', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 619, 6), )

    
    tokenNumber = property(__tokenNumber.value, __tokenNumber.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}expirationDate uses Python identifier expirationDate
    __expirationDate = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'expirationDate'), 'expirationDate', '__AnetApixmlv1schemaAnetApiSchema_xsd_tokenMaskedType_AnetApixmlv1schemaAnetApiSchema_xsdexpirationDate', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 620, 6), )

    
    expirationDate = property(__expirationDate.value, __expirationDate.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __tokenSource.name() : __tokenSource,
        __tokenNumber.name() : __tokenNumber,
        __expirationDate.name() : __expirationDate
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'tokenMaskedType', tokenMaskedType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}orderType with content type ELEMENT_ONLY
class orderType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}orderType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'orderType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 632, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}invoiceNumber uses Python identifier invoiceNumber
    __invoiceNumber = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'invoiceNumber'), 'invoiceNumber', '__AnetApixmlv1schemaAnetApiSchema_xsd_orderType_AnetApixmlv1schemaAnetApiSchema_xsdinvoiceNumber', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 634, 3), )

    
    invoiceNumber = property(__invoiceNumber.value, __invoiceNumber.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}description uses Python identifier description
    __description = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'description'), 'description', '__AnetApixmlv1schemaAnetApiSchema_xsd_orderType_AnetApixmlv1schemaAnetApiSchema_xsddescription', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 641, 3), )

    
    description = property(__description.value, __description.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __invoiceNumber.name() : __invoiceNumber,
        __description.name() : __description
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'orderType', orderType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerType with content type ELEMENT_ONLY
class customerType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'customerType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 669, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}type uses Python identifier type
    __type = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'type'), 'type', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerType_AnetApixmlv1schemaAnetApiSchema_xsdtype', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 671, 3), )

    
    type = property(__type.value, __type.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}id uses Python identifier id
    __id = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'id'), 'id', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerType_AnetApixmlv1schemaAnetApiSchema_xsdid', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 672, 3), )

    
    id = property(__id.value, __id.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}email uses Python identifier email
    __email = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'email'), 'email', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerType_AnetApixmlv1schemaAnetApiSchema_xsdemail', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 679, 3), )

    
    email = property(__email.value, __email.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}phoneNumber uses Python identifier phoneNumber
    __phoneNumber = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'phoneNumber'), 'phoneNumber', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerType_AnetApixmlv1schemaAnetApiSchema_xsdphoneNumber', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 686, 3), )

    
    phoneNumber = property(__phoneNumber.value, __phoneNumber.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}faxNumber uses Python identifier faxNumber
    __faxNumber = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'faxNumber'), 'faxNumber', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerType_AnetApixmlv1schemaAnetApiSchema_xsdfaxNumber', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 693, 3), )

    
    faxNumber = property(__faxNumber.value, __faxNumber.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}driversLicense uses Python identifier driversLicense
    __driversLicense = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'driversLicense'), 'driversLicense', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerType_AnetApixmlv1schemaAnetApiSchema_xsddriversLicense', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 700, 3), )

    
    driversLicense = property(__driversLicense.value, __driversLicense.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}taxId uses Python identifier taxId
    __taxId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'taxId'), 'taxId', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerType_AnetApixmlv1schemaAnetApiSchema_xsdtaxId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 701, 3), )

    
    taxId = property(__taxId.value, __taxId.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __type.name() : __type,
        __id.name() : __id,
        __email.name() : __email,
        __phoneNumber.name() : __phoneNumber,
        __faxNumber.name() : __faxNumber,
        __driversLicense.name() : __driversLicense,
        __taxId.name() : __taxId
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'customerType', customerType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerDataType with content type ELEMENT_ONLY
class customerDataType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerDataType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'customerDataType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 713, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}type uses Python identifier type
    __type = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'type'), 'type', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerDataType_AnetApixmlv1schemaAnetApiSchema_xsdtype', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 715, 3), )

    
    type = property(__type.value, __type.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}id uses Python identifier id
    __id = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'id'), 'id', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerDataType_AnetApixmlv1schemaAnetApiSchema_xsdid', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 716, 3), )

    
    id = property(__id.value, __id.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}email uses Python identifier email
    __email = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'email'), 'email', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerDataType_AnetApixmlv1schemaAnetApiSchema_xsdemail', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 723, 3), )

    
    email = property(__email.value, __email.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}driversLicense uses Python identifier driversLicense
    __driversLicense = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'driversLicense'), 'driversLicense', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerDataType_AnetApixmlv1schemaAnetApiSchema_xsddriversLicense', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 730, 3), )

    
    driversLicense = property(__driversLicense.value, __driversLicense.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}taxId uses Python identifier taxId
    __taxId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'taxId'), 'taxId', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerDataType_AnetApixmlv1schemaAnetApiSchema_xsdtaxId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 731, 3), )

    
    taxId = property(__taxId.value, __taxId.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __type.name() : __type,
        __id.name() : __id,
        __email.name() : __email,
        __driversLicense.name() : __driversLicense,
        __taxId.name() : __taxId
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'customerDataType', customerDataType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantAuthenticationType with content type ELEMENT_ONLY
class merchantAuthenticationType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantAuthenticationType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'merchantAuthenticationType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 743, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}name uses Python identifier name
    __name = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'name'), 'name', '__AnetApixmlv1schemaAnetApiSchema_xsd_merchantAuthenticationType_AnetApixmlv1schemaAnetApiSchema_xsdname', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 745, 3), )

    
    name = property(__name.value, __name.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}transactionKey uses Python identifier transactionKey
    __transactionKey = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'transactionKey'), 'transactionKey', '__AnetApixmlv1schemaAnetApiSchema_xsd_merchantAuthenticationType_AnetApixmlv1schemaAnetApiSchema_xsdtransactionKey', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 754, 4), )

    
    transactionKey = property(__transactionKey.value, __transactionKey.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}sessionToken uses Python identifier sessionToken
    __sessionToken = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'sessionToken'), 'sessionToken', '__AnetApixmlv1schemaAnetApiSchema_xsd_merchantAuthenticationType_AnetApixmlv1schemaAnetApiSchema_xsdsessionToken', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 761, 16), )

    
    sessionToken = property(__sessionToken.value, __sessionToken.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}password uses Python identifier password
    __password = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'password'), 'password', '__AnetApixmlv1schemaAnetApiSchema_xsd_merchantAuthenticationType_AnetApixmlv1schemaAnetApiSchema_xsdpassword', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 762, 4), )

    
    password = property(__password.value, __password.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}impersonationAuthentication uses Python identifier impersonationAuthentication
    __impersonationAuthentication = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'impersonationAuthentication'), 'impersonationAuthentication', '__AnetApixmlv1schemaAnetApiSchema_xsd_merchantAuthenticationType_AnetApixmlv1schemaAnetApiSchema_xsdimpersonationAuthentication', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 769, 8), )

    
    impersonationAuthentication = property(__impersonationAuthentication.value, __impersonationAuthentication.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}fingerPrint uses Python identifier fingerPrint
    __fingerPrint = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'fingerPrint'), 'fingerPrint', '__AnetApixmlv1schemaAnetApiSchema_xsd_merchantAuthenticationType_AnetApixmlv1schemaAnetApiSchema_xsdfingerPrint', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 770, 8), )

    
    fingerPrint = property(__fingerPrint.value, __fingerPrint.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}mobileDeviceId uses Python identifier mobileDeviceId
    __mobileDeviceId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'mobileDeviceId'), 'mobileDeviceId', '__AnetApixmlv1schemaAnetApiSchema_xsd_merchantAuthenticationType_AnetApixmlv1schemaAnetApiSchema_xsdmobileDeviceId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 772, 3), )

    
    mobileDeviceId = property(__mobileDeviceId.value, __mobileDeviceId.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __name.name() : __name,
        __transactionKey.name() : __transactionKey,
        __sessionToken.name() : __sessionToken,
        __password.name() : __password,
        __impersonationAuthentication.name() : __impersonationAuthentication,
        __fingerPrint.name() : __fingerPrint,
        __mobileDeviceId.name() : __mobileDeviceId
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'merchantAuthenticationType', merchantAuthenticationType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}fingerPrintType with content type ELEMENT_ONLY
class fingerPrintType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}fingerPrintType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'fingerPrintType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 783, 2)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}hashValue uses Python identifier hashValue
    __hashValue = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'hashValue'), 'hashValue', '__AnetApixmlv1schemaAnetApiSchema_xsd_fingerPrintType_AnetApixmlv1schemaAnetApiSchema_xsdhashValue', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 785, 6), )

    
    hashValue = property(__hashValue.value, __hashValue.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}sequence uses Python identifier sequence
    __sequence = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'sequence'), 'sequence', '__AnetApixmlv1schemaAnetApiSchema_xsd_fingerPrintType_AnetApixmlv1schemaAnetApiSchema_xsdsequence', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 786, 6), )

    
    sequence = property(__sequence.value, __sequence.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}timestamp uses Python identifier timestamp
    __timestamp = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'timestamp'), 'timestamp', '__AnetApixmlv1schemaAnetApiSchema_xsd_fingerPrintType_AnetApixmlv1schemaAnetApiSchema_xsdtimestamp', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 787, 6), )

    
    timestamp = property(__timestamp.value, __timestamp.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}currencyCode uses Python identifier currencyCode
    __currencyCode = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'currencyCode'), 'currencyCode', '__AnetApixmlv1schemaAnetApiSchema_xsd_fingerPrintType_AnetApixmlv1schemaAnetApiSchema_xsdcurrencyCode', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 788, 6), )

    
    currencyCode = property(__currencyCode.value, __currencyCode.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}amount uses Python identifier amount
    __amount = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'amount'), 'amount', '__AnetApixmlv1schemaAnetApiSchema_xsd_fingerPrintType_AnetApixmlv1schemaAnetApiSchema_xsdamount', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 789, 6), )

    
    amount = property(__amount.value, __amount.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __hashValue.name() : __hashValue,
        __sequence.name() : __sequence,
        __timestamp.name() : __timestamp,
        __currencyCode.name() : __currencyCode,
        __amount.name() : __amount
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'fingerPrintType', fingerPrintType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}cardArt with content type ELEMENT_ONLY
class cardArt (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}cardArt with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'cardArt')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 795, 2)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}cardBrand uses Python identifier cardBrand
    __cardBrand = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'cardBrand'), 'cardBrand', '__AnetApixmlv1schemaAnetApiSchema_xsd_cardArt_AnetApixmlv1schemaAnetApiSchema_xsdcardBrand', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 797, 6), )

    
    cardBrand = property(__cardBrand.value, __cardBrand.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}cardImageHeight uses Python identifier cardImageHeight
    __cardImageHeight = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'cardImageHeight'), 'cardImageHeight', '__AnetApixmlv1schemaAnetApiSchema_xsd_cardArt_AnetApixmlv1schemaAnetApiSchema_xsdcardImageHeight', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 798, 6), )

    
    cardImageHeight = property(__cardImageHeight.value, __cardImageHeight.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}cardImageUrl uses Python identifier cardImageUrl
    __cardImageUrl = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'cardImageUrl'), 'cardImageUrl', '__AnetApixmlv1schemaAnetApiSchema_xsd_cardArt_AnetApixmlv1schemaAnetApiSchema_xsdcardImageUrl', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 799, 6), )

    
    cardImageUrl = property(__cardImageUrl.value, __cardImageUrl.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}cardImageWidth uses Python identifier cardImageWidth
    __cardImageWidth = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'cardImageWidth'), 'cardImageWidth', '__AnetApixmlv1schemaAnetApiSchema_xsd_cardArt_AnetApixmlv1schemaAnetApiSchema_xsdcardImageWidth', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 800, 6), )

    
    cardImageWidth = property(__cardImageWidth.value, __cardImageWidth.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}cardType uses Python identifier cardType
    __cardType = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'cardType'), 'cardType', '__AnetApixmlv1schemaAnetApiSchema_xsd_cardArt_AnetApixmlv1schemaAnetApiSchema_xsdcardType', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 801, 6), )

    
    cardType = property(__cardType.value, __cardType.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __cardBrand.name() : __cardBrand,
        __cardImageHeight.name() : __cardImageHeight,
        __cardImageUrl.name() : __cardImageUrl,
        __cardImageWidth.name() : __cardImageWidth,
        __cardType.name() : __cardType
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'cardArt', cardArt)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}paymentDetails with content type ELEMENT_ONLY
class paymentDetails (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}paymentDetails with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'paymentDetails')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 806, 2)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}currency uses Python identifier currency
    __currency = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'currency'), 'currency', '__AnetApixmlv1schemaAnetApiSchema_xsd_paymentDetails_AnetApixmlv1schemaAnetApiSchema_xsdcurrency', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 808, 6), )

    
    currency = property(__currency.value, __currency.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}promoCode uses Python identifier promoCode
    __promoCode = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'promoCode'), 'promoCode', '__AnetApixmlv1schemaAnetApiSchema_xsd_paymentDetails_AnetApixmlv1schemaAnetApiSchema_xsdpromoCode', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 809, 6), )

    
    promoCode = property(__promoCode.value, __promoCode.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}misc uses Python identifier misc
    __misc = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'misc'), 'misc', '__AnetApixmlv1schemaAnetApiSchema_xsd_paymentDetails_AnetApixmlv1schemaAnetApiSchema_xsdmisc', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 810, 6), )

    
    misc = property(__misc.value, __misc.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}giftWrap uses Python identifier giftWrap
    __giftWrap = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'giftWrap'), 'giftWrap', '__AnetApixmlv1schemaAnetApiSchema_xsd_paymentDetails_AnetApixmlv1schemaAnetApiSchema_xsdgiftWrap', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 811, 6), )

    
    giftWrap = property(__giftWrap.value, __giftWrap.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}discount uses Python identifier discount
    __discount = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'discount'), 'discount', '__AnetApixmlv1schemaAnetApiSchema_xsd_paymentDetails_AnetApixmlv1schemaAnetApiSchema_xsddiscount', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 812, 6), )

    
    discount = property(__discount.value, __discount.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}tax uses Python identifier tax
    __tax = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'tax'), 'tax', '__AnetApixmlv1schemaAnetApiSchema_xsd_paymentDetails_AnetApixmlv1schemaAnetApiSchema_xsdtax', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 813, 6), )

    
    tax = property(__tax.value, __tax.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}shippingHandling uses Python identifier shippingHandling
    __shippingHandling = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'shippingHandling'), 'shippingHandling', '__AnetApixmlv1schemaAnetApiSchema_xsd_paymentDetails_AnetApixmlv1schemaAnetApiSchema_xsdshippingHandling', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 814, 6), )

    
    shippingHandling = property(__shippingHandling.value, __shippingHandling.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}subTotal uses Python identifier subTotal
    __subTotal = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'subTotal'), 'subTotal', '__AnetApixmlv1schemaAnetApiSchema_xsd_paymentDetails_AnetApixmlv1schemaAnetApiSchema_xsdsubTotal', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 815, 6), )

    
    subTotal = property(__subTotal.value, __subTotal.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}orderID uses Python identifier orderID
    __orderID = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'orderID'), 'orderID', '__AnetApixmlv1schemaAnetApiSchema_xsd_paymentDetails_AnetApixmlv1schemaAnetApiSchema_xsdorderID', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 816, 6), )

    
    orderID = property(__orderID.value, __orderID.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}amount uses Python identifier amount
    __amount = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'amount'), 'amount', '__AnetApixmlv1schemaAnetApiSchema_xsd_paymentDetails_AnetApixmlv1schemaAnetApiSchema_xsdamount', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 817, 6), )

    
    amount = property(__amount.value, __amount.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __currency.name() : __currency,
        __promoCode.name() : __promoCode,
        __misc.name() : __misc,
        __giftWrap.name() : __giftWrap,
        __discount.name() : __discount,
        __tax.name() : __tax,
        __shippingHandling.name() : __shippingHandling,
        __subTotal.name() : __subTotal,
        __orderID.name() : __orderID,
        __amount.name() : __amount
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'paymentDetails', paymentDetails)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}webCheckOutDataType with content type ELEMENT_ONLY
class webCheckOutDataType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}webCheckOutDataType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'webCheckOutDataType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 880, 2)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}type uses Python identifier type
    __type = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'type'), 'type', '__AnetApixmlv1schemaAnetApiSchema_xsd_webCheckOutDataType_AnetApixmlv1schemaAnetApiSchema_xsdtype', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 882, 6), )

    
    type = property(__type.value, __type.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}id uses Python identifier id
    __id = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'id'), 'id', '__AnetApixmlv1schemaAnetApiSchema_xsd_webCheckOutDataType_AnetApixmlv1schemaAnetApiSchema_xsdid', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 883, 6), )

    
    id = property(__id.value, __id.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}token uses Python identifier token
    __token = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'token'), 'token', '__AnetApixmlv1schemaAnetApiSchema_xsd_webCheckOutDataType_AnetApixmlv1schemaAnetApiSchema_xsdtoken', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 891, 6), )

    
    token = property(__token.value, __token.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __type.name() : __type,
        __id.name() : __id,
        __token.name() : __token
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'webCheckOutDataType', webCheckOutDataType)


# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON (pyxb.binding.basis.complexTypeDefinition):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 892, 8)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}cardNumber uses Python identifier cardNumber
    __cardNumber = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'cardNumber'), 'cardNumber', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_AnetApixmlv1schemaAnetApiSchema_xsdcardNumber', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 894, 12), )

    
    cardNumber = property(__cardNumber.value, __cardNumber.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}expirationDate uses Python identifier expirationDate
    __expirationDate = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'expirationDate'), 'expirationDate', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_AnetApixmlv1schemaAnetApiSchema_xsdexpirationDate', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 902, 12), )

    
    expirationDate = property(__expirationDate.value, __expirationDate.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}cardCode uses Python identifier cardCode
    __cardCode = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'cardCode'), 'cardCode', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_AnetApixmlv1schemaAnetApiSchema_xsdcardCode', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 910, 12), )

    
    cardCode = property(__cardCode.value, __cardCode.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}zip uses Python identifier zip
    __zip = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'zip'), 'zip', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_AnetApixmlv1schemaAnetApiSchema_xsdzip', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 911, 12), )

    
    zip = property(__zip.value, __zip.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}fullName uses Python identifier fullName
    __fullName = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'fullName'), 'fullName', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_AnetApixmlv1schemaAnetApiSchema_xsdfullName', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 919, 12), )

    
    fullName = property(__fullName.value, __fullName.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __cardNumber.name() : __cardNumber,
        __expirationDate.name() : __expirationDate,
        __cardCode.name() : __cardCode,
        __zip.name() : __zip,
        __fullName.name() : __fullName
    })
    _AttributeMap.update({
        
    })



# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}securePaymentContainerErrorType with content type ELEMENT_ONLY
class securePaymentContainerErrorType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}securePaymentContainerErrorType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'securePaymentContainerErrorType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 935, 2)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}code uses Python identifier code
    __code = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'code'), 'code', '__AnetApixmlv1schemaAnetApiSchema_xsd_securePaymentContainerErrorType_AnetApixmlv1schemaAnetApiSchema_xsdcode', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 937, 6), )

    
    code = property(__code.value, __code.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}description uses Python identifier description
    __description = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'description'), 'description', '__AnetApixmlv1schemaAnetApiSchema_xsd_securePaymentContainerErrorType_AnetApixmlv1schemaAnetApiSchema_xsddescription', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 938, 6), )

    
    description = property(__description.value, __description.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __code.name() : __code,
        __description.name() : __description
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'securePaymentContainerErrorType', securePaymentContainerErrorType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}impersonationAuthenticationType with content type ELEMENT_ONLY
class impersonationAuthenticationType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}impersonationAuthenticationType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'impersonationAuthenticationType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 952, 2)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}partnerLoginId uses Python identifier partnerLoginId
    __partnerLoginId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'partnerLoginId'), 'partnerLoginId', '__AnetApixmlv1schemaAnetApiSchema_xsd_impersonationAuthenticationType_AnetApixmlv1schemaAnetApiSchema_xsdpartnerLoginId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 954, 6), )

    
    partnerLoginId = property(__partnerLoginId.value, __partnerLoginId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}partnerTransactionKey uses Python identifier partnerTransactionKey
    __partnerTransactionKey = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'partnerTransactionKey'), 'partnerTransactionKey', '__AnetApixmlv1schemaAnetApiSchema_xsd_impersonationAuthenticationType_AnetApixmlv1schemaAnetApiSchema_xsdpartnerTransactionKey', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 961, 6), )

    
    partnerTransactionKey = property(__partnerTransactionKey.value, __partnerTransactionKey.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __partnerLoginId.name() : __partnerLoginId,
        __partnerTransactionKey.name() : __partnerTransactionKey
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'impersonationAuthenticationType', impersonationAuthenticationType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}paymentScheduleTypeInterval with content type ELEMENT_ONLY
class paymentScheduleTypeInterval (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}paymentScheduleTypeInterval with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'paymentScheduleTypeInterval')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 972, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}length uses Python identifier length
    __length = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'length'), 'length', '__AnetApixmlv1schemaAnetApiSchema_xsd_paymentScheduleTypeInterval_AnetApixmlv1schemaAnetApiSchema_xsdlength', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 974, 3), )

    
    length = property(__length.value, __length.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}unit uses Python identifier unit
    __unit = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'unit'), 'unit', '__AnetApixmlv1schemaAnetApiSchema_xsd_paymentScheduleTypeInterval_AnetApixmlv1schemaAnetApiSchema_xsdunit', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 982, 3), )

    
    unit = property(__unit.value, __unit.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __length.name() : __length,
        __unit.name() : __unit
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'paymentScheduleTypeInterval', paymentScheduleTypeInterval)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}paymentScheduleType with content type ELEMENT_ONLY
class paymentScheduleType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}paymentScheduleType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'paymentScheduleType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 989, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}interval uses Python identifier interval
    __interval = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'interval'), 'interval', '__AnetApixmlv1schemaAnetApiSchema_xsd_paymentScheduleType_AnetApixmlv1schemaAnetApiSchema_xsdinterval', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 992, 3), )

    
    interval = property(__interval.value, __interval.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}startDate uses Python identifier startDate
    __startDate = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'startDate'), 'startDate', '__AnetApixmlv1schemaAnetApiSchema_xsd_paymentScheduleType_AnetApixmlv1schemaAnetApiSchema_xsdstartDate', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 994, 3), )

    
    startDate = property(__startDate.value, __startDate.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}totalOccurrences uses Python identifier totalOccurrences
    __totalOccurrences = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'totalOccurrences'), 'totalOccurrences', '__AnetApixmlv1schemaAnetApiSchema_xsd_paymentScheduleType_AnetApixmlv1schemaAnetApiSchema_xsdtotalOccurrences', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 996, 3), )

    
    totalOccurrences = property(__totalOccurrences.value, __totalOccurrences.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}trialOccurrences uses Python identifier trialOccurrences
    __trialOccurrences = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'trialOccurrences'), 'trialOccurrences', '__AnetApixmlv1schemaAnetApiSchema_xsd_paymentScheduleType_AnetApixmlv1schemaAnetApiSchema_xsdtrialOccurrences', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1005, 3), )

    
    trialOccurrences = property(__trialOccurrences.value, __trialOccurrences.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __interval.name() : __interval,
        __startDate.name() : __startDate,
        __totalOccurrences.name() : __totalOccurrences,
        __trialOccurrences.name() : __trialOccurrences
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'paymentScheduleType', paymentScheduleType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ARBSubscriptionType with content type ELEMENT_ONLY
class ARBSubscriptionType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ARBSubscriptionType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'ARBSubscriptionType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1017, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}name uses Python identifier name
    __name = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'name'), 'name', '__AnetApixmlv1schemaAnetApiSchema_xsd_ARBSubscriptionType_AnetApixmlv1schemaAnetApiSchema_xsdname', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1019, 3), )

    
    name = property(__name.value, __name.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}paymentSchedule uses Python identifier paymentSchedule
    __paymentSchedule = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'paymentSchedule'), 'paymentSchedule', '__AnetApixmlv1schemaAnetApiSchema_xsd_ARBSubscriptionType_AnetApixmlv1schemaAnetApiSchema_xsdpaymentSchedule', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1027, 3), )

    
    paymentSchedule = property(__paymentSchedule.value, __paymentSchedule.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}amount uses Python identifier amount
    __amount = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'amount'), 'amount', '__AnetApixmlv1schemaAnetApiSchema_xsd_ARBSubscriptionType_AnetApixmlv1schemaAnetApiSchema_xsdamount', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1028, 3), )

    
    amount = property(__amount.value, __amount.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}trialAmount uses Python identifier trialAmount
    __trialAmount = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'trialAmount'), 'trialAmount', '__AnetApixmlv1schemaAnetApiSchema_xsd_ARBSubscriptionType_AnetApixmlv1schemaAnetApiSchema_xsdtrialAmount', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1036, 3), )

    
    trialAmount = property(__trialAmount.value, __trialAmount.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}payment uses Python identifier payment
    __payment = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'payment'), 'payment', '__AnetApixmlv1schemaAnetApiSchema_xsd_ARBSubscriptionType_AnetApixmlv1schemaAnetApiSchema_xsdpayment', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1045, 3), )

    
    payment = property(__payment.value, __payment.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}order uses Python identifier order
    __order = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'order'), 'order', '__AnetApixmlv1schemaAnetApiSchema_xsd_ARBSubscriptionType_AnetApixmlv1schemaAnetApiSchema_xsdorder', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1046, 3), )

    
    order = property(__order.value, __order.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customer uses Python identifier customer
    __customer = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customer'), 'customer', '__AnetApixmlv1schemaAnetApiSchema_xsd_ARBSubscriptionType_AnetApixmlv1schemaAnetApiSchema_xsdcustomer', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1047, 3), )

    
    customer = property(__customer.value, __customer.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}billTo uses Python identifier billTo
    __billTo = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'billTo'), 'billTo', '__AnetApixmlv1schemaAnetApiSchema_xsd_ARBSubscriptionType_AnetApixmlv1schemaAnetApiSchema_xsdbillTo', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1048, 3), )

    
    billTo = property(__billTo.value, __billTo.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}shipTo uses Python identifier shipTo
    __shipTo = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'shipTo'), 'shipTo', '__AnetApixmlv1schemaAnetApiSchema_xsd_ARBSubscriptionType_AnetApixmlv1schemaAnetApiSchema_xsdshipTo', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1049, 3), )

    
    shipTo = property(__shipTo.value, __shipTo.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profile uses Python identifier profile
    __profile = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'profile'), 'profile', '__AnetApixmlv1schemaAnetApiSchema_xsd_ARBSubscriptionType_AnetApixmlv1schemaAnetApiSchema_xsdprofile', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1050, 3), )

    
    profile = property(__profile.value, __profile.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __name.name() : __name,
        __paymentSchedule.name() : __paymentSchedule,
        __amount.name() : __amount,
        __trialAmount.name() : __trialAmount,
        __payment.name() : __payment,
        __order.name() : __order,
        __customer.name() : __customer,
        __billTo.name() : __billTo,
        __shipTo.name() : __shipTo,
        __profile.name() : __profile
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'ARBSubscriptionType', ARBSubscriptionType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ARBSubscriptionMaskedType with content type ELEMENT_ONLY
class ARBSubscriptionMaskedType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ARBSubscriptionMaskedType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'ARBSubscriptionMaskedType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1057, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}name uses Python identifier name
    __name = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'name'), 'name', '__AnetApixmlv1schemaAnetApiSchema_xsd_ARBSubscriptionMaskedType_AnetApixmlv1schemaAnetApiSchema_xsdname', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1059, 6), )

    
    name = property(__name.value, __name.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}paymentSchedule uses Python identifier paymentSchedule
    __paymentSchedule = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'paymentSchedule'), 'paymentSchedule', '__AnetApixmlv1schemaAnetApiSchema_xsd_ARBSubscriptionMaskedType_AnetApixmlv1schemaAnetApiSchema_xsdpaymentSchedule', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1067, 3), )

    
    paymentSchedule = property(__paymentSchedule.value, __paymentSchedule.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}amount uses Python identifier amount
    __amount = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'amount'), 'amount', '__AnetApixmlv1schemaAnetApiSchema_xsd_ARBSubscriptionMaskedType_AnetApixmlv1schemaAnetApiSchema_xsdamount', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1068, 3), )

    
    amount = property(__amount.value, __amount.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}trialAmount uses Python identifier trialAmount
    __trialAmount = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'trialAmount'), 'trialAmount', '__AnetApixmlv1schemaAnetApiSchema_xsd_ARBSubscriptionMaskedType_AnetApixmlv1schemaAnetApiSchema_xsdtrialAmount', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1076, 3), )

    
    trialAmount = property(__trialAmount.value, __trialAmount.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}status uses Python identifier status
    __status = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'status'), 'status', '__AnetApixmlv1schemaAnetApiSchema_xsd_ARBSubscriptionMaskedType_AnetApixmlv1schemaAnetApiSchema_xsdstatus', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1084, 3), )

    
    status = property(__status.value, __status.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profile uses Python identifier profile
    __profile = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'profile'), 'profile', '__AnetApixmlv1schemaAnetApiSchema_xsd_ARBSubscriptionMaskedType_AnetApixmlv1schemaAnetApiSchema_xsdprofile', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1085, 3), )

    
    profile = property(__profile.value, __profile.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}order uses Python identifier order
    __order = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'order'), 'order', '__AnetApixmlv1schemaAnetApiSchema_xsd_ARBSubscriptionMaskedType_AnetApixmlv1schemaAnetApiSchema_xsdorder', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1086, 3), )

    
    order = property(__order.value, __order.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __name.name() : __name,
        __paymentSchedule.name() : __paymentSchedule,
        __amount.name() : __amount,
        __trialAmount.name() : __trialAmount,
        __status.name() : __status,
        __profile.name() : __profile,
        __order.name() : __order
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'ARBSubscriptionMaskedType', ARBSubscriptionMaskedType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}subscriptionPaymentType with content type ELEMENT_ONLY
class subscriptionPaymentType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}subscriptionPaymentType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'subscriptionPaymentType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1107, 2)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}id uses Python identifier id
    __id = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'id'), 'id', '__AnetApixmlv1schemaAnetApiSchema_xsd_subscriptionPaymentType_AnetApixmlv1schemaAnetApiSchema_xsdid', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1109, 6), )

    
    id = property(__id.value, __id.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}payNum uses Python identifier payNum
    __payNum = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'payNum'), 'payNum', '__AnetApixmlv1schemaAnetApiSchema_xsd_subscriptionPaymentType_AnetApixmlv1schemaAnetApiSchema_xsdpayNum', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1116, 6), )

    
    payNum = property(__payNum.value, __payNum.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __id.name() : __id,
        __payNum.name() : __payNum
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'subscriptionPaymentType', subscriptionPaymentType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}mobileDeviceType with content type ELEMENT_ONLY
class mobileDeviceType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}mobileDeviceType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'mobileDeviceType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1127, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}mobileDeviceId uses Python identifier mobileDeviceId
    __mobileDeviceId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'mobileDeviceId'), 'mobileDeviceId', '__AnetApixmlv1schemaAnetApiSchema_xsd_mobileDeviceType_AnetApixmlv1schemaAnetApiSchema_xsdmobileDeviceId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1129, 3), )

    
    mobileDeviceId = property(__mobileDeviceId.value, __mobileDeviceId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}description uses Python identifier description
    __description = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'description'), 'description', '__AnetApixmlv1schemaAnetApiSchema_xsd_mobileDeviceType_AnetApixmlv1schemaAnetApiSchema_xsddescription', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1136, 3), )

    
    description = property(__description.value, __description.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}phoneNumber uses Python identifier phoneNumber
    __phoneNumber = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'phoneNumber'), 'phoneNumber', '__AnetApixmlv1schemaAnetApiSchema_xsd_mobileDeviceType_AnetApixmlv1schemaAnetApiSchema_xsdphoneNumber', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1143, 3), )

    
    phoneNumber = property(__phoneNumber.value, __phoneNumber.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}devicePlatform uses Python identifier devicePlatform
    __devicePlatform = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'devicePlatform'), 'devicePlatform', '__AnetApixmlv1schemaAnetApiSchema_xsd_mobileDeviceType_AnetApixmlv1schemaAnetApiSchema_xsddevicePlatform', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1150, 6), )

    
    devicePlatform = property(__devicePlatform.value, __devicePlatform.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}deviceActivation uses Python identifier deviceActivation
    __deviceActivation = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'deviceActivation'), 'deviceActivation', '__AnetApixmlv1schemaAnetApiSchema_xsd_mobileDeviceType_AnetApixmlv1schemaAnetApiSchema_xsddeviceActivation', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1157, 6), )

    
    deviceActivation = property(__deviceActivation.value, __deviceActivation.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __mobileDeviceId.name() : __mobileDeviceId,
        __description.name() : __description,
        __phoneNumber.name() : __phoneNumber,
        __devicePlatform.name() : __devicePlatform,
        __deviceActivation.name() : __deviceActivation
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'mobileDeviceType', mobileDeviceType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}transactionRequestType with content type ELEMENT_ONLY
class transactionRequestType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}transactionRequestType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'transactionRequestType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1167, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}transactionType uses Python identifier transactionType
    __transactionType = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'transactionType'), 'transactionType', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionRequestType_AnetApixmlv1schemaAnetApiSchema_xsdtransactionType', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1169, 3), )

    
    transactionType = property(__transactionType.value, __transactionType.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}amount uses Python identifier amount
    __amount = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'amount'), 'amount', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionRequestType_AnetApixmlv1schemaAnetApiSchema_xsdamount', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1170, 3), )

    
    amount = property(__amount.value, __amount.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}currencyCode uses Python identifier currencyCode
    __currencyCode = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'currencyCode'), 'currencyCode', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionRequestType_AnetApixmlv1schemaAnetApiSchema_xsdcurrencyCode', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1171, 6), )

    
    currencyCode = property(__currencyCode.value, __currencyCode.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}payment uses Python identifier payment
    __payment = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'payment'), 'payment', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionRequestType_AnetApixmlv1schemaAnetApiSchema_xsdpayment', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1172, 3), )

    
    payment = property(__payment.value, __payment.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profile uses Python identifier profile
    __profile = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'profile'), 'profile', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionRequestType_AnetApixmlv1schemaAnetApiSchema_xsdprofile', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1173, 6), )

    
    profile = property(__profile.value, __profile.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}solution uses Python identifier solution
    __solution = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'solution'), 'solution', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionRequestType_AnetApixmlv1schemaAnetApiSchema_xsdsolution', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1174, 6), )

    
    solution = property(__solution.value, __solution.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}callId uses Python identifier callId
    __callId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'callId'), 'callId', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionRequestType_AnetApixmlv1schemaAnetApiSchema_xsdcallId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1175, 6), )

    
    callId = property(__callId.value, __callId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}terminalNumber uses Python identifier terminalNumber
    __terminalNumber = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'terminalNumber'), 'terminalNumber', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionRequestType_AnetApixmlv1schemaAnetApiSchema_xsdterminalNumber', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1176, 12), )

    
    terminalNumber = property(__terminalNumber.value, __terminalNumber.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}authCode uses Python identifier authCode
    __authCode = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'authCode'), 'authCode', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionRequestType_AnetApixmlv1schemaAnetApiSchema_xsdauthCode', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1177, 3), )

    
    authCode = property(__authCode.value, __authCode.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}refTransId uses Python identifier refTransId
    __refTransId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'refTransId'), 'refTransId', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionRequestType_AnetApixmlv1schemaAnetApiSchema_xsdrefTransId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1178, 3), )

    
    refTransId = property(__refTransId.value, __refTransId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}splitTenderId uses Python identifier splitTenderId
    __splitTenderId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'splitTenderId'), 'splitTenderId', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionRequestType_AnetApixmlv1schemaAnetApiSchema_xsdsplitTenderId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1179, 3), )

    
    splitTenderId = property(__splitTenderId.value, __splitTenderId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}order uses Python identifier order
    __order = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'order'), 'order', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionRequestType_AnetApixmlv1schemaAnetApiSchema_xsdorder', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1180, 3), )

    
    order = property(__order.value, __order.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}lineItems uses Python identifier lineItems
    __lineItems = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'lineItems'), 'lineItems', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionRequestType_AnetApixmlv1schemaAnetApiSchema_xsdlineItems', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1181, 3), )

    
    lineItems = property(__lineItems.value, __lineItems.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}tax uses Python identifier tax
    __tax = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'tax'), 'tax', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionRequestType_AnetApixmlv1schemaAnetApiSchema_xsdtax', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1182, 3), )

    
    tax = property(__tax.value, __tax.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}duty uses Python identifier duty
    __duty = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'duty'), 'duty', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionRequestType_AnetApixmlv1schemaAnetApiSchema_xsdduty', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1183, 3), )

    
    duty = property(__duty.value, __duty.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}shipping uses Python identifier shipping
    __shipping = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'shipping'), 'shipping', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionRequestType_AnetApixmlv1schemaAnetApiSchema_xsdshipping', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1184, 3), )

    
    shipping = property(__shipping.value, __shipping.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}taxExempt uses Python identifier taxExempt
    __taxExempt = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'taxExempt'), 'taxExempt', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionRequestType_AnetApixmlv1schemaAnetApiSchema_xsdtaxExempt', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1185, 3), )

    
    taxExempt = property(__taxExempt.value, __taxExempt.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}poNumber uses Python identifier poNumber
    __poNumber = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'poNumber'), 'poNumber', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionRequestType_AnetApixmlv1schemaAnetApiSchema_xsdpoNumber', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1190, 3), )

    
    poNumber = property(__poNumber.value, __poNumber.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customer uses Python identifier customer
    __customer = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customer'), 'customer', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionRequestType_AnetApixmlv1schemaAnetApiSchema_xsdcustomer', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1191, 3), )

    
    customer = property(__customer.value, __customer.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}billTo uses Python identifier billTo
    __billTo = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'billTo'), 'billTo', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionRequestType_AnetApixmlv1schemaAnetApiSchema_xsdbillTo', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1192, 3), )

    
    billTo = property(__billTo.value, __billTo.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}shipTo uses Python identifier shipTo
    __shipTo = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'shipTo'), 'shipTo', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionRequestType_AnetApixmlv1schemaAnetApiSchema_xsdshipTo', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1193, 3), )

    
    shipTo = property(__shipTo.value, __shipTo.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerIP uses Python identifier customerIP
    __customerIP = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerIP'), 'customerIP', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionRequestType_AnetApixmlv1schemaAnetApiSchema_xsdcustomerIP', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1194, 3), )

    
    customerIP = property(__customerIP.value, __customerIP.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}cardholderAuthentication uses Python identifier cardholderAuthentication
    __cardholderAuthentication = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'cardholderAuthentication'), 'cardholderAuthentication', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionRequestType_AnetApixmlv1schemaAnetApiSchema_xsdcardholderAuthentication', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1195, 3), )

    
    cardholderAuthentication = property(__cardholderAuthentication.value, __cardholderAuthentication.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}retail uses Python identifier retail
    __retail = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'retail'), 'retail', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionRequestType_AnetApixmlv1schemaAnetApiSchema_xsdretail', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1196, 3), )

    
    retail = property(__retail.value, __retail.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}employeeId uses Python identifier employeeId
    __employeeId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'employeeId'), 'employeeId', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionRequestType_AnetApixmlv1schemaAnetApiSchema_xsdemployeeId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1197, 6), )

    
    employeeId = property(__employeeId.value, __employeeId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}transactionSettings uses Python identifier transactionSettings
    __transactionSettings = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'transactionSettings'), 'transactionSettings', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionRequestType_AnetApixmlv1schemaAnetApiSchema_xsdtransactionSettings', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1198, 3), )

    
    transactionSettings = property(__transactionSettings.value, __transactionSettings.set, None, 'Allowed values for settingName are: emailCustomer, merchantEmail, allowPartialAuth, headerEmailReceipt, footerEmailReceipt, recurringBilling, duplicateWindow, testRequest.')

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}userFields uses Python identifier userFields
    __userFields = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'userFields'), 'userFields', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionRequestType_AnetApixmlv1schemaAnetApiSchema_xsduserFields', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1203, 3), )

    
    userFields = property(__userFields.value, __userFields.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __transactionType.name() : __transactionType,
        __amount.name() : __amount,
        __currencyCode.name() : __currencyCode,
        __payment.name() : __payment,
        __profile.name() : __profile,
        __solution.name() : __solution,
        __callId.name() : __callId,
        __terminalNumber.name() : __terminalNumber,
        __authCode.name() : __authCode,
        __refTransId.name() : __refTransId,
        __splitTenderId.name() : __splitTenderId,
        __order.name() : __order,
        __lineItems.name() : __lineItems,
        __tax.name() : __tax,
        __duty.name() : __duty,
        __shipping.name() : __shipping,
        __taxExempt.name() : __taxExempt,
        __poNumber.name() : __poNumber,
        __customer.name() : __customer,
        __billTo.name() : __billTo,
        __shipTo.name() : __shipTo,
        __customerIP.name() : __customerIP,
        __cardholderAuthentication.name() : __cardholderAuthentication,
        __retail.name() : __retail,
        __employeeId.name() : __employeeId,
        __transactionSettings.name() : __transactionSettings,
        __userFields.name() : __userFields
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'transactionRequestType', transactionRequestType)


# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_ (pyxb.binding.basis.complexTypeDefinition):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1204, 4)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}userField uses Python identifier userField
    __userField = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'userField'), 'userField', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON__AnetApixmlv1schemaAnetApiSchema_xsduserField', True, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1206, 6), )

    
    userField = property(__userField.value, __userField.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __userField.name() : __userField
    })
    _AttributeMap.update({
        
    })



# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}KeyManagementScheme with content type ELEMENT_ONLY
class KeyManagementScheme (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}KeyManagementScheme with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'KeyManagementScheme')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1215, 3)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}DUKPT uses Python identifier DUKPT
    __DUKPT = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'DUKPT'), 'DUKPT', '__AnetApixmlv1schemaAnetApiSchema_xsd_KeyManagementScheme_AnetApixmlv1schemaAnetApiSchema_xsdDUKPT', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1217, 7), )

    
    DUKPT = property(__DUKPT.value, __DUKPT.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __DUKPT.name() : __DUKPT
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'KeyManagementScheme', KeyManagementScheme)


# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_2 (pyxb.binding.basis.complexTypeDefinition):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1218, 9)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}Operation uses Python identifier Operation
    __Operation = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'Operation'), 'Operation', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_2_AnetApixmlv1schemaAnetApiSchema_xsdOperation', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1220, 13), )

    
    Operation = property(__Operation.value, __Operation.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}Mode uses Python identifier Mode
    __Mode = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'Mode'), 'Mode', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_2_AnetApixmlv1schemaAnetApiSchema_xsdMode', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1221, 13), )

    
    Mode = property(__Mode.value, __Mode.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}DeviceInfo uses Python identifier DeviceInfo
    __DeviceInfo = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'DeviceInfo'), 'DeviceInfo', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_2_AnetApixmlv1schemaAnetApiSchema_xsdDeviceInfo', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1230, 13), )

    
    DeviceInfo = property(__DeviceInfo.value, __DeviceInfo.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}EncryptedData uses Python identifier EncryptedData
    __EncryptedData = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'EncryptedData'), 'EncryptedData', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_2_AnetApixmlv1schemaAnetApiSchema_xsdEncryptedData', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1238, 13), )

    
    EncryptedData = property(__EncryptedData.value, __EncryptedData.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __Operation.name() : __Operation,
        __Mode.name() : __Mode,
        __DeviceInfo.name() : __DeviceInfo,
        __EncryptedData.name() : __EncryptedData
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_3 (pyxb.binding.basis.complexTypeDefinition):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1222, 15)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}PIN uses Python identifier PIN
    __PIN = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'PIN'), 'PIN', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_3_AnetApixmlv1schemaAnetApiSchema_xsdPIN', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1224, 19), )

    
    PIN = property(__PIN.value, __PIN.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}Data uses Python identifier Data
    __Data = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'Data'), 'Data', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_3_AnetApixmlv1schemaAnetApiSchema_xsdData', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1225, 19), )

    
    Data = property(__Data.value, __Data.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __PIN.name() : __PIN,
        __Data.name() : __Data
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_4 (pyxb.binding.basis.complexTypeDefinition):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1231, 15)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}Description uses Python identifier Description
    __Description = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'Description'), 'Description', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_4_AnetApixmlv1schemaAnetApiSchema_xsdDescription', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1233, 19), )

    
    Description = property(__Description.value, __Description.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __Description.name() : __Description
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_5 (pyxb.binding.basis.complexTypeDefinition):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1239, 15)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}Value uses Python identifier Value
    __Value = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'Value'), 'Value', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_5_AnetApixmlv1schemaAnetApiSchema_xsdValue', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1241, 19), )

    
    Value = property(__Value.value, __Value.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __Value.name() : __Value
    })
    _AttributeMap.update({
        
    })



# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}KeyValue with content type ELEMENT_ONLY
class KeyValue (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}KeyValue with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'KeyValue')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1271, 3)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}Encoding uses Python identifier Encoding
    __Encoding = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'Encoding'), 'Encoding', '__AnetApixmlv1schemaAnetApiSchema_xsd_KeyValue_AnetApixmlv1schemaAnetApiSchema_xsdEncoding', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1273, 7), )

    
    Encoding = property(__Encoding.value, __Encoding.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}EncryptionAlgorithm uses Python identifier EncryptionAlgorithm
    __EncryptionAlgorithm = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'EncryptionAlgorithm'), 'EncryptionAlgorithm', '__AnetApixmlv1schemaAnetApiSchema_xsd_KeyValue_AnetApixmlv1schemaAnetApiSchema_xsdEncryptionAlgorithm', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1274, 7), )

    
    EncryptionAlgorithm = property(__EncryptionAlgorithm.value, __EncryptionAlgorithm.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}Scheme uses Python identifier Scheme
    __Scheme = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'Scheme'), 'Scheme', '__AnetApixmlv1schemaAnetApiSchema_xsd_KeyValue_AnetApixmlv1schemaAnetApiSchema_xsdScheme', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1275, 7), )

    
    Scheme = property(__Scheme.value, __Scheme.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __Encoding.name() : __Encoding,
        __EncryptionAlgorithm.name() : __EncryptionAlgorithm,
        __Scheme.name() : __Scheme
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'KeyValue', KeyValue)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}KeyBlock with content type ELEMENT_ONLY
class KeyBlock (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}KeyBlock with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'KeyBlock')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1279, 3)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}Value uses Python identifier Value
    __Value = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'Value'), 'Value', '__AnetApixmlv1schemaAnetApiSchema_xsd_KeyBlock_AnetApixmlv1schemaAnetApiSchema_xsdValue', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1281, 12), )

    
    Value = property(__Value.value, __Value.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __Value.name() : __Value
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'KeyBlock', KeyBlock)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}encryptedTrackDataType with content type ELEMENT_ONLY
class encryptedTrackDataType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}encryptedTrackDataType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'encryptedTrackDataType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1285, 3)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}FormOfPayment uses Python identifier FormOfPayment
    __FormOfPayment = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'FormOfPayment'), 'FormOfPayment', '__AnetApixmlv1schemaAnetApiSchema_xsd_encryptedTrackDataType_AnetApixmlv1schemaAnetApiSchema_xsdFormOfPayment', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1287, 7), )

    
    FormOfPayment = property(__FormOfPayment.value, __FormOfPayment.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __FormOfPayment.name() : __FormOfPayment
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'encryptedTrackDataType', encryptedTrackDataType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}settingType with content type ELEMENT_ONLY
class settingType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}settingType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'settingType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1292, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}settingName uses Python identifier settingName
    __settingName = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'settingName'), 'settingName', '__AnetApixmlv1schemaAnetApiSchema_xsd_settingType_AnetApixmlv1schemaAnetApiSchema_xsdsettingName', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1294, 3), )

    
    settingName = property(__settingName.value, __settingName.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}settingValue uses Python identifier settingValue
    __settingValue = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'settingValue'), 'settingValue', '__AnetApixmlv1schemaAnetApiSchema_xsd_settingType_AnetApixmlv1schemaAnetApiSchema_xsdsettingValue', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1295, 3), )

    
    settingValue = property(__settingValue.value, __settingValue.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __settingName.name() : __settingName,
        __settingValue.name() : __settingValue
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'settingType', settingType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}permissionType with content type ELEMENT_ONLY
class permissionType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}permissionType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'permissionType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1300, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}permissionName uses Python identifier permissionName
    __permissionName = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'permissionName'), 'permissionName', '__AnetApixmlv1schemaAnetApiSchema_xsd_permissionType_AnetApixmlv1schemaAnetApiSchema_xsdpermissionName', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1302, 3), )

    
    permissionName = property(__permissionName.value, __permissionName.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __permissionName.name() : __permissionName
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'permissionType', permissionType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}userField with content type ELEMENT_ONLY
class userField (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}userField with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'userField')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1397, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}name uses Python identifier name
    __name = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'name'), 'name', '__AnetApixmlv1schemaAnetApiSchema_xsd_userField_AnetApixmlv1schemaAnetApiSchema_xsdname', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1399, 3), )

    
    name = property(__name.value, __name.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}value uses Python identifier value_
    __value = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'value'), 'value_', '__AnetApixmlv1schemaAnetApiSchema_xsd_userField_AnetApixmlv1schemaAnetApiSchema_xsdvalue', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1400, 3), )

    
    value_ = property(__value.value, __value.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __name.name() : __name,
        __value.name() : __value
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'userField', userField)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}emvTag with content type ELEMENT_ONLY
class emvTag (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}emvTag with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'emvTag')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1405, 4)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}name uses Python identifier name
    __name = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'name'), 'name', '__AnetApixmlv1schemaAnetApiSchema_xsd_emvTag_AnetApixmlv1schemaAnetApiSchema_xsdname', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1407, 12), )

    
    name = property(__name.value, __name.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}value uses Python identifier value_
    __value = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'value'), 'value_', '__AnetApixmlv1schemaAnetApiSchema_xsd_emvTag_AnetApixmlv1schemaAnetApiSchema_xsdvalue', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1408, 12), )

    
    value_ = property(__value.value, __value.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}formatted uses Python identifier formatted
    __formatted = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'formatted'), 'formatted', '__AnetApixmlv1schemaAnetApiSchema_xsd_emvTag_AnetApixmlv1schemaAnetApiSchema_xsdformatted', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1409, 12), )

    
    formatted = property(__formatted.value, __formatted.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __name.name() : __name,
        __value.name() : __value,
        __formatted.name() : __formatted
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'emvTag', emvTag)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerPaymentProfileBaseType with content type ELEMENT_ONLY
class customerPaymentProfileBaseType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerPaymentProfileBaseType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileBaseType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1414, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerType uses Python identifier customerType
    __customerType = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerType'), 'customerType', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerPaymentProfileBaseType_AnetApixmlv1schemaAnetApiSchema_xsdcustomerType', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1416, 3), )

    
    customerType = property(__customerType.value, __customerType.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}billTo uses Python identifier billTo
    __billTo = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'billTo'), 'billTo', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerPaymentProfileBaseType_AnetApixmlv1schemaAnetApiSchema_xsdbillTo', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1417, 3), )

    
    billTo = property(__billTo.value, __billTo.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __customerType.name() : __customerType,
        __billTo.name() : __billTo
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'customerPaymentProfileBaseType', customerPaymentProfileBaseType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}SubscriptionIdList with content type ELEMENT_ONLY
class SubscriptionIdList (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}SubscriptionIdList with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'SubscriptionIdList')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1478, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}subscriptionId uses Python identifier subscriptionId
    __subscriptionId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'subscriptionId'), 'subscriptionId', '__AnetApixmlv1schemaAnetApiSchema_xsd_SubscriptionIdList_AnetApixmlv1schemaAnetApiSchema_xsdsubscriptionId', True, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1480, 4), )

    
    subscriptionId = property(__subscriptionId.value, __subscriptionId.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __subscriptionId.name() : __subscriptionId
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'SubscriptionIdList', SubscriptionIdList)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileBaseType with content type ELEMENT_ONLY
class customerProfileBaseType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileBaseType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'customerProfileBaseType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1485, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantCustomerId uses Python identifier merchantCustomerId
    __merchantCustomerId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'merchantCustomerId'), 'merchantCustomerId', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerProfileBaseType_AnetApixmlv1schemaAnetApiSchema_xsdmerchantCustomerId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1487, 3), )

    
    merchantCustomerId = property(__merchantCustomerId.value, __merchantCustomerId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}description uses Python identifier description
    __description = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'description'), 'description', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerProfileBaseType_AnetApixmlv1schemaAnetApiSchema_xsddescription', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1494, 3), )

    
    description = property(__description.value, __description.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}email uses Python identifier email
    __email = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'email'), 'email', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerProfileBaseType_AnetApixmlv1schemaAnetApiSchema_xsdemail', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1501, 3), )

    
    email = property(__email.value, __email.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __merchantCustomerId.name() : __merchantCustomerId,
        __description.name() : __description,
        __email.name() : __email
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'customerProfileBaseType', customerProfileBaseType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}paymentEmvType with content type ELEMENT_ONLY
class paymentEmvType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}paymentEmvType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'paymentEmvType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1524, 4)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}emvData uses Python identifier emvData
    __emvData = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'emvData'), 'emvData', '__AnetApixmlv1schemaAnetApiSchema_xsd_paymentEmvType_AnetApixmlv1schemaAnetApiSchema_xsdemvData', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1526, 12), )

    
    emvData = property(__emvData.value, __emvData.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}emvDescriptor uses Python identifier emvDescriptor
    __emvDescriptor = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'emvDescriptor'), 'emvDescriptor', '__AnetApixmlv1schemaAnetApiSchema_xsd_paymentEmvType_AnetApixmlv1schemaAnetApiSchema_xsdemvDescriptor', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1527, 12), )

    
    emvDescriptor = property(__emvDescriptor.value, __emvDescriptor.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}emvVersion uses Python identifier emvVersion
    __emvVersion = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'emvVersion'), 'emvVersion', '__AnetApixmlv1schemaAnetApiSchema_xsd_paymentEmvType_AnetApixmlv1schemaAnetApiSchema_xsdemvVersion', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1528, 12), )

    
    emvVersion = property(__emvVersion.value, __emvVersion.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __emvData.name() : __emvData,
        __emvDescriptor.name() : __emvDescriptor,
        __emvVersion.name() : __emvVersion
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'paymentEmvType', paymentEmvType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}extendedAmountType with content type ELEMENT_ONLY
class extendedAmountType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}extendedAmountType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'extendedAmountType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1592, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}amount uses Python identifier amount
    __amount = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'amount'), 'amount', '__AnetApixmlv1schemaAnetApiSchema_xsd_extendedAmountType_AnetApixmlv1schemaAnetApiSchema_xsdamount', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1594, 3), )

    
    amount = property(__amount.value, __amount.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}name uses Python identifier name
    __name = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'name'), 'name', '__AnetApixmlv1schemaAnetApiSchema_xsd_extendedAmountType_AnetApixmlv1schemaAnetApiSchema_xsdname', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1602, 3), )

    
    name = property(__name.value, __name.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}description uses Python identifier description
    __description = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'description'), 'description', '__AnetApixmlv1schemaAnetApiSchema_xsd_extendedAmountType_AnetApixmlv1schemaAnetApiSchema_xsddescription', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1609, 3), )

    
    description = property(__description.value, __description.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __amount.name() : __amount,
        __name.name() : __name,
        __description.name() : __description
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'extendedAmountType', extendedAmountType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}lineItemType with content type ELEMENT_ONLY
class lineItemType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}lineItemType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'lineItemType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1620, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}itemId uses Python identifier itemId
    __itemId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'itemId'), 'itemId', '__AnetApixmlv1schemaAnetApiSchema_xsd_lineItemType_AnetApixmlv1schemaAnetApiSchema_xsditemId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1622, 3), )

    
    itemId = property(__itemId.value, __itemId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}name uses Python identifier name
    __name = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'name'), 'name', '__AnetApixmlv1schemaAnetApiSchema_xsd_lineItemType_AnetApixmlv1schemaAnetApiSchema_xsdname', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1630, 3), )

    
    name = property(__name.value, __name.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}description uses Python identifier description
    __description = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'description'), 'description', '__AnetApixmlv1schemaAnetApiSchema_xsd_lineItemType_AnetApixmlv1schemaAnetApiSchema_xsddescription', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1638, 3), )

    
    description = property(__description.value, __description.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}quantity uses Python identifier quantity
    __quantity = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'quantity'), 'quantity', '__AnetApixmlv1schemaAnetApiSchema_xsd_lineItemType_AnetApixmlv1schemaAnetApiSchema_xsdquantity', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1645, 3), )

    
    quantity = property(__quantity.value, __quantity.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}unitPrice uses Python identifier unitPrice
    __unitPrice = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'unitPrice'), 'unitPrice', '__AnetApixmlv1schemaAnetApiSchema_xsd_lineItemType_AnetApixmlv1schemaAnetApiSchema_xsdunitPrice', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1653, 3), )

    
    unitPrice = property(__unitPrice.value, __unitPrice.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}taxable uses Python identifier taxable
    __taxable = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'taxable'), 'taxable', '__AnetApixmlv1schemaAnetApiSchema_xsd_lineItemType_AnetApixmlv1schemaAnetApiSchema_xsdtaxable', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1661, 3), )

    
    taxable = property(__taxable.value, __taxable.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __itemId.name() : __itemId,
        __name.name() : __name,
        __description.name() : __description,
        __quantity.name() : __quantity,
        __unitPrice.name() : __unitPrice,
        __taxable.name() : __taxable
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'lineItemType', lineItemType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransAmountType with content type ELEMENT_ONLY
class profileTransAmountType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransAmountType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'profileTransAmountType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1666, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}amount uses Python identifier amount
    __amount = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'amount'), 'amount', '__AnetApixmlv1schemaAnetApiSchema_xsd_profileTransAmountType_AnetApixmlv1schemaAnetApiSchema_xsdamount', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1668, 3), )

    
    amount = property(__amount.value, __amount.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}tax uses Python identifier tax
    __tax = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'tax'), 'tax', '__AnetApixmlv1schemaAnetApiSchema_xsd_profileTransAmountType_AnetApixmlv1schemaAnetApiSchema_xsdtax', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1676, 3), )

    
    tax = property(__tax.value, __tax.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}shipping uses Python identifier shipping
    __shipping = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'shipping'), 'shipping', '__AnetApixmlv1schemaAnetApiSchema_xsd_profileTransAmountType_AnetApixmlv1schemaAnetApiSchema_xsdshipping', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1677, 3), )

    
    shipping = property(__shipping.value, __shipping.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}duty uses Python identifier duty
    __duty = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'duty'), 'duty', '__AnetApixmlv1schemaAnetApiSchema_xsd_profileTransAmountType_AnetApixmlv1schemaAnetApiSchema_xsdduty', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1678, 3), )

    
    duty = property(__duty.value, __duty.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}lineItems uses Python identifier lineItems
    __lineItems = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'lineItems'), 'lineItems', '__AnetApixmlv1schemaAnetApiSchema_xsd_profileTransAmountType_AnetApixmlv1schemaAnetApiSchema_xsdlineItems', True, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1679, 3), )

    
    lineItems = property(__lineItems.value, __lineItems.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __amount.name() : __amount,
        __tax.name() : __tax,
        __shipping.name() : __shipping,
        __duty.name() : __duty,
        __lineItems.name() : __lineItems
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'profileTransAmountType', profileTransAmountType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransVoidType with content type ELEMENT_ONLY
class profileTransVoidType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransVoidType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'profileTransVoidType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1789, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileId uses Python identifier customerProfileId
    __customerProfileId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), 'customerProfileId', '__AnetApixmlv1schemaAnetApiSchema_xsd_profileTransVoidType_AnetApixmlv1schemaAnetApiSchema_xsdcustomerProfileId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1791, 3), )

    
    customerProfileId = property(__customerProfileId.value, __customerProfileId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerPaymentProfileId uses Python identifier customerPaymentProfileId
    __customerPaymentProfileId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileId'), 'customerPaymentProfileId', '__AnetApixmlv1schemaAnetApiSchema_xsd_profileTransVoidType_AnetApixmlv1schemaAnetApiSchema_xsdcustomerPaymentProfileId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1792, 3), )

    
    customerPaymentProfileId = property(__customerPaymentProfileId.value, __customerPaymentProfileId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerShippingAddressId uses Python identifier customerShippingAddressId
    __customerShippingAddressId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerShippingAddressId'), 'customerShippingAddressId', '__AnetApixmlv1schemaAnetApiSchema_xsd_profileTransVoidType_AnetApixmlv1schemaAnetApiSchema_xsdcustomerShippingAddressId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1793, 3), )

    
    customerShippingAddressId = property(__customerShippingAddressId.value, __customerShippingAddressId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}transId uses Python identifier transId
    __transId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'transId'), 'transId', '__AnetApixmlv1schemaAnetApiSchema_xsd_profileTransVoidType_AnetApixmlv1schemaAnetApiSchema_xsdtransId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1794, 3), )

    
    transId = property(__transId.value, __transId.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __customerProfileId.name() : __customerProfileId,
        __customerPaymentProfileId.name() : __customerPaymentProfileId,
        __customerShippingAddressId.name() : __customerShippingAddressId,
        __transId.name() : __transId
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'profileTransVoidType', profileTransVoidType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransactionType with content type ELEMENT_ONLY
class profileTransactionType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransactionType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'profileTransactionType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1799, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransAuthCapture uses Python identifier profileTransAuthCapture
    __profileTransAuthCapture = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'profileTransAuthCapture'), 'profileTransAuthCapture', '__AnetApixmlv1schemaAnetApiSchema_xsd_profileTransactionType_AnetApixmlv1schemaAnetApiSchema_xsdprofileTransAuthCapture', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1801, 3), )

    
    profileTransAuthCapture = property(__profileTransAuthCapture.value, __profileTransAuthCapture.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransAuthOnly uses Python identifier profileTransAuthOnly
    __profileTransAuthOnly = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'profileTransAuthOnly'), 'profileTransAuthOnly', '__AnetApixmlv1schemaAnetApiSchema_xsd_profileTransactionType_AnetApixmlv1schemaAnetApiSchema_xsdprofileTransAuthOnly', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1802, 3), )

    
    profileTransAuthOnly = property(__profileTransAuthOnly.value, __profileTransAuthOnly.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransPriorAuthCapture uses Python identifier profileTransPriorAuthCapture
    __profileTransPriorAuthCapture = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'profileTransPriorAuthCapture'), 'profileTransPriorAuthCapture', '__AnetApixmlv1schemaAnetApiSchema_xsd_profileTransactionType_AnetApixmlv1schemaAnetApiSchema_xsdprofileTransPriorAuthCapture', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1803, 3), )

    
    profileTransPriorAuthCapture = property(__profileTransPriorAuthCapture.value, __profileTransPriorAuthCapture.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransCaptureOnly uses Python identifier profileTransCaptureOnly
    __profileTransCaptureOnly = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'profileTransCaptureOnly'), 'profileTransCaptureOnly', '__AnetApixmlv1schemaAnetApiSchema_xsd_profileTransactionType_AnetApixmlv1schemaAnetApiSchema_xsdprofileTransCaptureOnly', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1804, 3), )

    
    profileTransCaptureOnly = property(__profileTransCaptureOnly.value, __profileTransCaptureOnly.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransRefund uses Python identifier profileTransRefund
    __profileTransRefund = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'profileTransRefund'), 'profileTransRefund', '__AnetApixmlv1schemaAnetApiSchema_xsd_profileTransactionType_AnetApixmlv1schemaAnetApiSchema_xsdprofileTransRefund', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1805, 3), )

    
    profileTransRefund = property(__profileTransRefund.value, __profileTransRefund.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransVoid uses Python identifier profileTransVoid
    __profileTransVoid = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'profileTransVoid'), 'profileTransVoid', '__AnetApixmlv1schemaAnetApiSchema_xsd_profileTransactionType_AnetApixmlv1schemaAnetApiSchema_xsdprofileTransVoid', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1806, 3), )

    
    profileTransVoid = property(__profileTransVoid.value, __profileTransVoid.set, None, None)

    _ElementMap.update({
        __profileTransAuthCapture.name() : __profileTransAuthCapture,
        __profileTransAuthOnly.name() : __profileTransAuthOnly,
        __profileTransPriorAuthCapture.name() : __profileTransPriorAuthCapture,
        __profileTransCaptureOnly.name() : __profileTransCaptureOnly,
        __profileTransRefund.name() : __profileTransRefund,
        __profileTransVoid.name() : __profileTransVoid
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'profileTransactionType', profileTransactionType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}transactionSummaryType with content type ELEMENT_ONLY
class transactionSummaryType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}transactionSummaryType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'transactionSummaryType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1810, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}transId uses Python identifier transId
    __transId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'transId'), 'transId', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionSummaryType_AnetApixmlv1schemaAnetApiSchema_xsdtransId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1812, 3), )

    
    transId = property(__transId.value, __transId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}submitTimeUTC uses Python identifier submitTimeUTC
    __submitTimeUTC = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'submitTimeUTC'), 'submitTimeUTC', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionSummaryType_AnetApixmlv1schemaAnetApiSchema_xsdsubmitTimeUTC', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1813, 3), )

    
    submitTimeUTC = property(__submitTimeUTC.value, __submitTimeUTC.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}submitTimeLocal uses Python identifier submitTimeLocal
    __submitTimeLocal = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'submitTimeLocal'), 'submitTimeLocal', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionSummaryType_AnetApixmlv1schemaAnetApiSchema_xsdsubmitTimeLocal', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1814, 3), )

    
    submitTimeLocal = property(__submitTimeLocal.value, __submitTimeLocal.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}transactionStatus uses Python identifier transactionStatus
    __transactionStatus = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'transactionStatus'), 'transactionStatus', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionSummaryType_AnetApixmlv1schemaAnetApiSchema_xsdtransactionStatus', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1815, 3), )

    
    transactionStatus = property(__transactionStatus.value, __transactionStatus.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}invoiceNumber uses Python identifier invoiceNumber
    __invoiceNumber = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'invoiceNumber'), 'invoiceNumber', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionSummaryType_AnetApixmlv1schemaAnetApiSchema_xsdinvoiceNumber', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1816, 3), )

    
    invoiceNumber = property(__invoiceNumber.value, __invoiceNumber.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}firstName uses Python identifier firstName
    __firstName = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'firstName'), 'firstName', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionSummaryType_AnetApixmlv1schemaAnetApiSchema_xsdfirstName', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1817, 3), )

    
    firstName = property(__firstName.value, __firstName.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}lastName uses Python identifier lastName
    __lastName = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'lastName'), 'lastName', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionSummaryType_AnetApixmlv1schemaAnetApiSchema_xsdlastName', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1818, 3), )

    
    lastName = property(__lastName.value, __lastName.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}accountType uses Python identifier accountType
    __accountType = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'accountType'), 'accountType', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionSummaryType_AnetApixmlv1schemaAnetApiSchema_xsdaccountType', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1819, 3), )

    
    accountType = property(__accountType.value, __accountType.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}accountNumber uses Python identifier accountNumber
    __accountNumber = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'accountNumber'), 'accountNumber', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionSummaryType_AnetApixmlv1schemaAnetApiSchema_xsdaccountNumber', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1820, 3), )

    
    accountNumber = property(__accountNumber.value, __accountNumber.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}settleAmount uses Python identifier settleAmount
    __settleAmount = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'settleAmount'), 'settleAmount', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionSummaryType_AnetApixmlv1schemaAnetApiSchema_xsdsettleAmount', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1821, 3), )

    
    settleAmount = property(__settleAmount.value, __settleAmount.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}marketType uses Python identifier marketType
    __marketType = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'marketType'), 'marketType', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionSummaryType_AnetApixmlv1schemaAnetApiSchema_xsdmarketType', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1822, 3), )

    
    marketType = property(__marketType.value, __marketType.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}product uses Python identifier product
    __product = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'product'), 'product', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionSummaryType_AnetApixmlv1schemaAnetApiSchema_xsdproduct', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1823, 3), )

    
    product = property(__product.value, __product.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}mobileDeviceId uses Python identifier mobileDeviceId
    __mobileDeviceId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'mobileDeviceId'), 'mobileDeviceId', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionSummaryType_AnetApixmlv1schemaAnetApiSchema_xsdmobileDeviceId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1824, 3), )

    
    mobileDeviceId = property(__mobileDeviceId.value, __mobileDeviceId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}subscription uses Python identifier subscription
    __subscription = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'subscription'), 'subscription', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionSummaryType_AnetApixmlv1schemaAnetApiSchema_xsdsubscription', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1825, 3), )

    
    subscription = property(__subscription.value, __subscription.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}hasReturnedItems uses Python identifier hasReturnedItems
    __hasReturnedItems = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'hasReturnedItems'), 'hasReturnedItems', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionSummaryType_AnetApixmlv1schemaAnetApiSchema_xsdhasReturnedItems', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1826, 9), )

    
    hasReturnedItems = property(__hasReturnedItems.value, __hasReturnedItems.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __transId.name() : __transId,
        __submitTimeUTC.name() : __submitTimeUTC,
        __submitTimeLocal.name() : __submitTimeLocal,
        __transactionStatus.name() : __transactionStatus,
        __invoiceNumber.name() : __invoiceNumber,
        __firstName.name() : __firstName,
        __lastName.name() : __lastName,
        __accountType.name() : __accountType,
        __accountNumber.name() : __accountNumber,
        __settleAmount.name() : __settleAmount,
        __marketType.name() : __marketType,
        __product.name() : __product,
        __mobileDeviceId.name() : __mobileDeviceId,
        __subscription.name() : __subscription,
        __hasReturnedItems.name() : __hasReturnedItems
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'transactionSummaryType', transactionSummaryType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}transactionDetailsType with content type ELEMENT_ONLY
class transactionDetailsType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}transactionDetailsType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'transactionDetailsType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1831, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}transId uses Python identifier transId
    __transId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'transId'), 'transId', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdtransId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1833, 3), )

    
    transId = property(__transId.value, __transId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}refTransId uses Python identifier refTransId
    __refTransId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'refTransId'), 'refTransId', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdrefTransId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1834, 3), )

    
    refTransId = property(__refTransId.value, __refTransId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}splitTenderId uses Python identifier splitTenderId
    __splitTenderId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'splitTenderId'), 'splitTenderId', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdsplitTenderId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1835, 3), )

    
    splitTenderId = property(__splitTenderId.value, __splitTenderId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}submitTimeUTC uses Python identifier submitTimeUTC
    __submitTimeUTC = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'submitTimeUTC'), 'submitTimeUTC', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdsubmitTimeUTC', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1836, 3), )

    
    submitTimeUTC = property(__submitTimeUTC.value, __submitTimeUTC.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}submitTimeLocal uses Python identifier submitTimeLocal
    __submitTimeLocal = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'submitTimeLocal'), 'submitTimeLocal', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdsubmitTimeLocal', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1837, 3), )

    
    submitTimeLocal = property(__submitTimeLocal.value, __submitTimeLocal.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}transactionType uses Python identifier transactionType
    __transactionType = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'transactionType'), 'transactionType', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdtransactionType', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1838, 3), )

    
    transactionType = property(__transactionType.value, __transactionType.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}transactionStatus uses Python identifier transactionStatus
    __transactionStatus = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'transactionStatus'), 'transactionStatus', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdtransactionStatus', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1839, 3), )

    
    transactionStatus = property(__transactionStatus.value, __transactionStatus.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}responseCode uses Python identifier responseCode
    __responseCode = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'responseCode'), 'responseCode', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdresponseCode', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1840, 3), )

    
    responseCode = property(__responseCode.value, __responseCode.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}responseReasonCode uses Python identifier responseReasonCode
    __responseReasonCode = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'responseReasonCode'), 'responseReasonCode', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdresponseReasonCode', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1841, 3), )

    
    responseReasonCode = property(__responseReasonCode.value, __responseReasonCode.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}subscription uses Python identifier subscription
    __subscription = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'subscription'), 'subscription', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdsubscription', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1842, 3), )

    
    subscription = property(__subscription.value, __subscription.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}responseReasonDescription uses Python identifier responseReasonDescription
    __responseReasonDescription = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'responseReasonDescription'), 'responseReasonDescription', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdresponseReasonDescription', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1843, 3), )

    
    responseReasonDescription = property(__responseReasonDescription.value, __responseReasonDescription.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}authCode uses Python identifier authCode
    __authCode = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'authCode'), 'authCode', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdauthCode', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1844, 6), )

    
    authCode = property(__authCode.value, __authCode.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}AVSResponse uses Python identifier AVSResponse
    __AVSResponse = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'AVSResponse'), 'AVSResponse', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdAVSResponse', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1851, 3), )

    
    AVSResponse = property(__AVSResponse.value, __AVSResponse.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}cardCodeResponse uses Python identifier cardCodeResponse
    __cardCodeResponse = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'cardCodeResponse'), 'cardCodeResponse', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdcardCodeResponse', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1858, 3), )

    
    cardCodeResponse = property(__cardCodeResponse.value, __cardCodeResponse.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}CAVVResponse uses Python identifier CAVVResponse
    __CAVVResponse = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'CAVVResponse'), 'CAVVResponse', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdCAVVResponse', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1865, 3), )

    
    CAVVResponse = property(__CAVVResponse.value, __CAVVResponse.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}FDSFilterAction uses Python identifier FDSFilterAction
    __FDSFilterAction = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'FDSFilterAction'), 'FDSFilterAction', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdFDSFilterAction', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1872, 3), )

    
    FDSFilterAction = property(__FDSFilterAction.value, __FDSFilterAction.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}FDSFilters uses Python identifier FDSFilters
    __FDSFilters = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'FDSFilters'), 'FDSFilters', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdFDSFilters', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1873, 3), )

    
    FDSFilters = property(__FDSFilters.value, __FDSFilters.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}batch uses Python identifier batch
    __batch = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'batch'), 'batch', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdbatch', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1874, 3), )

    
    batch = property(__batch.value, __batch.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}order uses Python identifier order
    __order = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'order'), 'order', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdorder', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1875, 3), )

    
    order = property(__order.value, __order.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}requestedAmount uses Python identifier requestedAmount
    __requestedAmount = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'requestedAmount'), 'requestedAmount', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdrequestedAmount', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1876, 3), )

    
    requestedAmount = property(__requestedAmount.value, __requestedAmount.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}authAmount uses Python identifier authAmount
    __authAmount = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'authAmount'), 'authAmount', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdauthAmount', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1884, 3), )

    
    authAmount = property(__authAmount.value, __authAmount.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}settleAmount uses Python identifier settleAmount
    __settleAmount = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'settleAmount'), 'settleAmount', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdsettleAmount', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1892, 3), )

    
    settleAmount = property(__settleAmount.value, __settleAmount.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}tax uses Python identifier tax
    __tax = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'tax'), 'tax', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdtax', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1900, 3), )

    
    tax = property(__tax.value, __tax.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}shipping uses Python identifier shipping
    __shipping = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'shipping'), 'shipping', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdshipping', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1901, 3), )

    
    shipping = property(__shipping.value, __shipping.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}duty uses Python identifier duty
    __duty = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'duty'), 'duty', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdduty', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1902, 3), )

    
    duty = property(__duty.value, __duty.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}lineItems uses Python identifier lineItems
    __lineItems = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'lineItems'), 'lineItems', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdlineItems', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1903, 3), )

    
    lineItems = property(__lineItems.value, __lineItems.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}prepaidBalanceRemaining uses Python identifier prepaidBalanceRemaining
    __prepaidBalanceRemaining = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'prepaidBalanceRemaining'), 'prepaidBalanceRemaining', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdprepaidBalanceRemaining', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1904, 3), )

    
    prepaidBalanceRemaining = property(__prepaidBalanceRemaining.value, __prepaidBalanceRemaining.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}taxExempt uses Python identifier taxExempt
    __taxExempt = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'taxExempt'), 'taxExempt', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdtaxExempt', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1911, 3), )

    
    taxExempt = property(__taxExempt.value, __taxExempt.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}payment uses Python identifier payment
    __payment = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'payment'), 'payment', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdpayment', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1912, 3), )

    
    payment = property(__payment.value, __payment.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customer uses Python identifier customer
    __customer = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customer'), 'customer', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdcustomer', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1913, 3), )

    
    customer = property(__customer.value, __customer.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}billTo uses Python identifier billTo
    __billTo = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'billTo'), 'billTo', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdbillTo', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1914, 3), )

    
    billTo = property(__billTo.value, __billTo.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}shipTo uses Python identifier shipTo
    __shipTo = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'shipTo'), 'shipTo', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdshipTo', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1915, 3), )

    
    shipTo = property(__shipTo.value, __shipTo.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}recurringBilling uses Python identifier recurringBilling
    __recurringBilling = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'recurringBilling'), 'recurringBilling', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdrecurringBilling', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1916, 3), )

    
    recurringBilling = property(__recurringBilling.value, __recurringBilling.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerIP uses Python identifier customerIP
    __customerIP = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerIP'), 'customerIP', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdcustomerIP', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1917, 3), )

    
    customerIP = property(__customerIP.value, __customerIP.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}product uses Python identifier product
    __product = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'product'), 'product', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdproduct', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1918, 3), )

    
    product = property(__product.value, __product.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}entryMethod uses Python identifier entryMethod
    __entryMethod = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'entryMethod'), 'entryMethod', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdentryMethod', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1919, 12), )

    
    entryMethod = property(__entryMethod.value, __entryMethod.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}marketType uses Python identifier marketType
    __marketType = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'marketType'), 'marketType', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdmarketType', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1920, 3), )

    
    marketType = property(__marketType.value, __marketType.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}mobileDeviceId uses Python identifier mobileDeviceId
    __mobileDeviceId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'mobileDeviceId'), 'mobileDeviceId', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdmobileDeviceId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1921, 3), )

    
    mobileDeviceId = property(__mobileDeviceId.value, __mobileDeviceId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerSignature uses Python identifier customerSignature
    __customerSignature = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerSignature'), 'customerSignature', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdcustomerSignature', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1922, 12), )

    
    customerSignature = property(__customerSignature.value, __customerSignature.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}returnedItems uses Python identifier returnedItems
    __returnedItems = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'returnedItems'), 'returnedItems', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdreturnedItems', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1923, 6), )

    
    returnedItems = property(__returnedItems.value, __returnedItems.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}solution uses Python identifier solution
    __solution = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'solution'), 'solution', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdsolution', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1924, 6), )

    
    solution = property(__solution.value, __solution.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}emvDetails uses Python identifier emvDetails
    __emvDetails = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'emvDetails'), 'emvDetails', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdemvDetails', True, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1925, 12), )

    
    emvDetails = property(__emvDetails.value, __emvDetails.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __transId.name() : __transId,
        __refTransId.name() : __refTransId,
        __splitTenderId.name() : __splitTenderId,
        __submitTimeUTC.name() : __submitTimeUTC,
        __submitTimeLocal.name() : __submitTimeLocal,
        __transactionType.name() : __transactionType,
        __transactionStatus.name() : __transactionStatus,
        __responseCode.name() : __responseCode,
        __responseReasonCode.name() : __responseReasonCode,
        __subscription.name() : __subscription,
        __responseReasonDescription.name() : __responseReasonDescription,
        __authCode.name() : __authCode,
        __AVSResponse.name() : __AVSResponse,
        __cardCodeResponse.name() : __cardCodeResponse,
        __CAVVResponse.name() : __CAVVResponse,
        __FDSFilterAction.name() : __FDSFilterAction,
        __FDSFilters.name() : __FDSFilters,
        __batch.name() : __batch,
        __order.name() : __order,
        __requestedAmount.name() : __requestedAmount,
        __authAmount.name() : __authAmount,
        __settleAmount.name() : __settleAmount,
        __tax.name() : __tax,
        __shipping.name() : __shipping,
        __duty.name() : __duty,
        __lineItems.name() : __lineItems,
        __prepaidBalanceRemaining.name() : __prepaidBalanceRemaining,
        __taxExempt.name() : __taxExempt,
        __payment.name() : __payment,
        __customer.name() : __customer,
        __billTo.name() : __billTo,
        __shipTo.name() : __shipTo,
        __recurringBilling.name() : __recurringBilling,
        __customerIP.name() : __customerIP,
        __product.name() : __product,
        __entryMethod.name() : __entryMethod,
        __marketType.name() : __marketType,
        __mobileDeviceId.name() : __mobileDeviceId,
        __customerSignature.name() : __customerSignature,
        __returnedItems.name() : __returnedItems,
        __solution.name() : __solution,
        __emvDetails.name() : __emvDetails
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'transactionDetailsType', transactionDetailsType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}solutionType with content type ELEMENT_ONLY
class solutionType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}solutionType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'solutionType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1930, 2)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}id uses Python identifier id
    __id = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'id'), 'id', '__AnetApixmlv1schemaAnetApiSchema_xsd_solutionType_AnetApixmlv1schemaAnetApiSchema_xsdid', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1932, 6), )

    
    id = property(__id.value, __id.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}name uses Python identifier name
    __name = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'name'), 'name', '__AnetApixmlv1schemaAnetApiSchema_xsd_solutionType_AnetApixmlv1schemaAnetApiSchema_xsdname', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1933, 6), )

    
    name = property(__name.value, __name.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}vendorName uses Python identifier vendorName
    __vendorName = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'vendorName'), 'vendorName', '__AnetApixmlv1schemaAnetApiSchema_xsd_solutionType_AnetApixmlv1schemaAnetApiSchema_xsdvendorName', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1934, 6), )

    
    vendorName = property(__vendorName.value, __vendorName.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __id.name() : __id,
        __name.name() : __name,
        __vendorName.name() : __vendorName
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'solutionType', solutionType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}emvDetailType with content type ELEMENT_ONLY
class emvDetailType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}emvDetailType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'emvDetailType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1939, 4)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}tagId uses Python identifier tagId
    __tagId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'tagId'), 'tagId', '__AnetApixmlv1schemaAnetApiSchema_xsd_emvDetailType_AnetApixmlv1schemaAnetApiSchema_xsdtagId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1941, 12), )

    
    tagId = property(__tagId.value, __tagId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}name uses Python identifier name
    __name = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'name'), 'name', '__AnetApixmlv1schemaAnetApiSchema_xsd_emvDetailType_AnetApixmlv1schemaAnetApiSchema_xsdname', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1942, 12), )

    
    name = property(__name.value, __name.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __tagId.name() : __tagId,
        __name.name() : __name
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'emvDetailType', emvDetailType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ArrayOfEmvDetailType with content type ELEMENT_ONLY
class ArrayOfEmvDetailType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ArrayOfEmvDetailType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'ArrayOfEmvDetailType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1947, 4)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}tags uses Python identifier tags
    __tags = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'tags'), 'tags', '__AnetApixmlv1schemaAnetApiSchema_xsd_ArrayOfEmvDetailType_AnetApixmlv1schemaAnetApiSchema_xsdtags', True, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1949, 12), )

    
    tags = property(__tags.value, __tags.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __tags.name() : __tags
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'ArrayOfEmvDetailType', ArrayOfEmvDetailType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ArrayOfReturnedItem with content type ELEMENT_ONLY
class ArrayOfReturnedItem (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ArrayOfReturnedItem with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'ArrayOfReturnedItem')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1954, 2)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}returnedItem uses Python identifier returnedItem
    __returnedItem = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'returnedItem'), 'returnedItem', '__AnetApixmlv1schemaAnetApiSchema_xsd_ArrayOfReturnedItem_AnetApixmlv1schemaAnetApiSchema_xsdreturnedItem', True, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1956, 6), )

    
    returnedItem = property(__returnedItem.value, __returnedItem.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __returnedItem.name() : __returnedItem
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'ArrayOfReturnedItem', ArrayOfReturnedItem)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}returnedItemType with content type ELEMENT_ONLY
class returnedItemType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}returnedItemType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'returnedItemType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1961, 2)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}id uses Python identifier id
    __id = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'id'), 'id', '__AnetApixmlv1schemaAnetApiSchema_xsd_returnedItemType_AnetApixmlv1schemaAnetApiSchema_xsdid', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1963, 6), )

    
    id = property(__id.value, __id.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}dateUTC uses Python identifier dateUTC
    __dateUTC = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'dateUTC'), 'dateUTC', '__AnetApixmlv1schemaAnetApiSchema_xsd_returnedItemType_AnetApixmlv1schemaAnetApiSchema_xsddateUTC', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1964, 6), )

    
    dateUTC = property(__dateUTC.value, __dateUTC.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}dateLocal uses Python identifier dateLocal
    __dateLocal = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'dateLocal'), 'dateLocal', '__AnetApixmlv1schemaAnetApiSchema_xsd_returnedItemType_AnetApixmlv1schemaAnetApiSchema_xsddateLocal', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1965, 6), )

    
    dateLocal = property(__dateLocal.value, __dateLocal.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}code uses Python identifier code
    __code = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'code'), 'code', '__AnetApixmlv1schemaAnetApiSchema_xsd_returnedItemType_AnetApixmlv1schemaAnetApiSchema_xsdcode', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1966, 6), )

    
    code = property(__code.value, __code.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}description uses Python identifier description
    __description = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'description'), 'description', '__AnetApixmlv1schemaAnetApiSchema_xsd_returnedItemType_AnetApixmlv1schemaAnetApiSchema_xsddescription', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1967, 6), )

    
    description = property(__description.value, __description.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __id.name() : __id,
        __dateUTC.name() : __dateUTC,
        __dateLocal.name() : __dateLocal,
        __code.name() : __code,
        __description.name() : __description
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'returnedItemType', returnedItemType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}FDSFilterType with content type ELEMENT_ONLY
class FDSFilterType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}FDSFilterType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'FDSFilterType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1972, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}name uses Python identifier name
    __name = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'name'), 'name', '__AnetApixmlv1schemaAnetApiSchema_xsd_FDSFilterType_AnetApixmlv1schemaAnetApiSchema_xsdname', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1974, 3), )

    
    name = property(__name.value, __name.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}action uses Python identifier action
    __action = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'action'), 'action', '__AnetApixmlv1schemaAnetApiSchema_xsd_FDSFilterType_AnetApixmlv1schemaAnetApiSchema_xsdaction', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1975, 3), )

    
    action = property(__action.value, __action.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __name.name() : __name,
        __action.name() : __action
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'FDSFilterType', FDSFilterType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}batchDetailsType with content type ELEMENT_ONLY
class batchDetailsType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}batchDetailsType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'batchDetailsType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1980, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}batchId uses Python identifier batchId
    __batchId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'batchId'), 'batchId', '__AnetApixmlv1schemaAnetApiSchema_xsd_batchDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdbatchId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1982, 3), )

    
    batchId = property(__batchId.value, __batchId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}settlementTimeUTC uses Python identifier settlementTimeUTC
    __settlementTimeUTC = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'settlementTimeUTC'), 'settlementTimeUTC', '__AnetApixmlv1schemaAnetApiSchema_xsd_batchDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdsettlementTimeUTC', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1983, 3), )

    
    settlementTimeUTC = property(__settlementTimeUTC.value, __settlementTimeUTC.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}settlementTimeLocal uses Python identifier settlementTimeLocal
    __settlementTimeLocal = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'settlementTimeLocal'), 'settlementTimeLocal', '__AnetApixmlv1schemaAnetApiSchema_xsd_batchDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdsettlementTimeLocal', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1984, 3), )

    
    settlementTimeLocal = property(__settlementTimeLocal.value, __settlementTimeLocal.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}settlementState uses Python identifier settlementState
    __settlementState = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'settlementState'), 'settlementState', '__AnetApixmlv1schemaAnetApiSchema_xsd_batchDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdsettlementState', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1985, 3), )

    
    settlementState = property(__settlementState.value, __settlementState.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}paymentMethod uses Python identifier paymentMethod
    __paymentMethod = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'paymentMethod'), 'paymentMethod', '__AnetApixmlv1schemaAnetApiSchema_xsd_batchDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdpaymentMethod', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1986, 3), )

    
    paymentMethod = property(__paymentMethod.value, __paymentMethod.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}marketType uses Python identifier marketType
    __marketType = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'marketType'), 'marketType', '__AnetApixmlv1schemaAnetApiSchema_xsd_batchDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdmarketType', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1987, 3), )

    
    marketType = property(__marketType.value, __marketType.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}product uses Python identifier product
    __product = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'product'), 'product', '__AnetApixmlv1schemaAnetApiSchema_xsd_batchDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdproduct', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1988, 3), )

    
    product = property(__product.value, __product.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}statistics uses Python identifier statistics
    __statistics = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'statistics'), 'statistics', '__AnetApixmlv1schemaAnetApiSchema_xsd_batchDetailsType_AnetApixmlv1schemaAnetApiSchema_xsdstatistics', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1989, 3), )

    
    statistics = property(__statistics.value, __statistics.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __batchId.name() : __batchId,
        __settlementTimeUTC.name() : __settlementTimeUTC,
        __settlementTimeLocal.name() : __settlementTimeLocal,
        __settlementState.name() : __settlementState,
        __paymentMethod.name() : __paymentMethod,
        __marketType.name() : __marketType,
        __product.name() : __product,
        __statistics.name() : __statistics
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'batchDetailsType', batchDetailsType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}batchStatisticType with content type ELEMENT_ONLY
class batchStatisticType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}batchStatisticType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'batchStatisticType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1994, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}accountType uses Python identifier accountType
    __accountType = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'accountType'), 'accountType', '__AnetApixmlv1schemaAnetApiSchema_xsd_batchStatisticType_AnetApixmlv1schemaAnetApiSchema_xsdaccountType', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1996, 3), )

    
    accountType = property(__accountType.value, __accountType.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}chargeAmount uses Python identifier chargeAmount
    __chargeAmount = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'chargeAmount'), 'chargeAmount', '__AnetApixmlv1schemaAnetApiSchema_xsd_batchStatisticType_AnetApixmlv1schemaAnetApiSchema_xsdchargeAmount', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1997, 3), )

    
    chargeAmount = property(__chargeAmount.value, __chargeAmount.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}chargeCount uses Python identifier chargeCount
    __chargeCount = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'chargeCount'), 'chargeCount', '__AnetApixmlv1schemaAnetApiSchema_xsd_batchStatisticType_AnetApixmlv1schemaAnetApiSchema_xsdchargeCount', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1998, 3), )

    
    chargeCount = property(__chargeCount.value, __chargeCount.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}refundAmount uses Python identifier refundAmount
    __refundAmount = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'refundAmount'), 'refundAmount', '__AnetApixmlv1schemaAnetApiSchema_xsd_batchStatisticType_AnetApixmlv1schemaAnetApiSchema_xsdrefundAmount', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1999, 3), )

    
    refundAmount = property(__refundAmount.value, __refundAmount.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}refundCount uses Python identifier refundCount
    __refundCount = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'refundCount'), 'refundCount', '__AnetApixmlv1schemaAnetApiSchema_xsd_batchStatisticType_AnetApixmlv1schemaAnetApiSchema_xsdrefundCount', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2000, 3), )

    
    refundCount = property(__refundCount.value, __refundCount.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}voidCount uses Python identifier voidCount
    __voidCount = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'voidCount'), 'voidCount', '__AnetApixmlv1schemaAnetApiSchema_xsd_batchStatisticType_AnetApixmlv1schemaAnetApiSchema_xsdvoidCount', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2001, 3), )

    
    voidCount = property(__voidCount.value, __voidCount.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}declineCount uses Python identifier declineCount
    __declineCount = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'declineCount'), 'declineCount', '__AnetApixmlv1schemaAnetApiSchema_xsd_batchStatisticType_AnetApixmlv1schemaAnetApiSchema_xsddeclineCount', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2002, 3), )

    
    declineCount = property(__declineCount.value, __declineCount.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}errorCount uses Python identifier errorCount
    __errorCount = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'errorCount'), 'errorCount', '__AnetApixmlv1schemaAnetApiSchema_xsd_batchStatisticType_AnetApixmlv1schemaAnetApiSchema_xsderrorCount', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2003, 3), )

    
    errorCount = property(__errorCount.value, __errorCount.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}returnedItemAmount uses Python identifier returnedItemAmount
    __returnedItemAmount = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'returnedItemAmount'), 'returnedItemAmount', '__AnetApixmlv1schemaAnetApiSchema_xsd_batchStatisticType_AnetApixmlv1schemaAnetApiSchema_xsdreturnedItemAmount', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2004, 3), )

    
    returnedItemAmount = property(__returnedItemAmount.value, __returnedItemAmount.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}returnedItemCount uses Python identifier returnedItemCount
    __returnedItemCount = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'returnedItemCount'), 'returnedItemCount', '__AnetApixmlv1schemaAnetApiSchema_xsd_batchStatisticType_AnetApixmlv1schemaAnetApiSchema_xsdreturnedItemCount', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2005, 3), )

    
    returnedItemCount = property(__returnedItemCount.value, __returnedItemCount.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}chargebackAmount uses Python identifier chargebackAmount
    __chargebackAmount = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'chargebackAmount'), 'chargebackAmount', '__AnetApixmlv1schemaAnetApiSchema_xsd_batchStatisticType_AnetApixmlv1schemaAnetApiSchema_xsdchargebackAmount', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2006, 3), )

    
    chargebackAmount = property(__chargebackAmount.value, __chargebackAmount.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}chargebackCount uses Python identifier chargebackCount
    __chargebackCount = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'chargebackCount'), 'chargebackCount', '__AnetApixmlv1schemaAnetApiSchema_xsd_batchStatisticType_AnetApixmlv1schemaAnetApiSchema_xsdchargebackCount', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2007, 3), )

    
    chargebackCount = property(__chargebackCount.value, __chargebackCount.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}correctionNoticeCount uses Python identifier correctionNoticeCount
    __correctionNoticeCount = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'correctionNoticeCount'), 'correctionNoticeCount', '__AnetApixmlv1schemaAnetApiSchema_xsd_batchStatisticType_AnetApixmlv1schemaAnetApiSchema_xsdcorrectionNoticeCount', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2008, 3), )

    
    correctionNoticeCount = property(__correctionNoticeCount.value, __correctionNoticeCount.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}chargeChargeBackAmount uses Python identifier chargeChargeBackAmount
    __chargeChargeBackAmount = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'chargeChargeBackAmount'), 'chargeChargeBackAmount', '__AnetApixmlv1schemaAnetApiSchema_xsd_batchStatisticType_AnetApixmlv1schemaAnetApiSchema_xsdchargeChargeBackAmount', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2009, 3), )

    
    chargeChargeBackAmount = property(__chargeChargeBackAmount.value, __chargeChargeBackAmount.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}chargeChargeBackCount uses Python identifier chargeChargeBackCount
    __chargeChargeBackCount = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'chargeChargeBackCount'), 'chargeChargeBackCount', '__AnetApixmlv1schemaAnetApiSchema_xsd_batchStatisticType_AnetApixmlv1schemaAnetApiSchema_xsdchargeChargeBackCount', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2010, 3), )

    
    chargeChargeBackCount = property(__chargeChargeBackCount.value, __chargeChargeBackCount.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}refundChargeBackAmount uses Python identifier refundChargeBackAmount
    __refundChargeBackAmount = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'refundChargeBackAmount'), 'refundChargeBackAmount', '__AnetApixmlv1schemaAnetApiSchema_xsd_batchStatisticType_AnetApixmlv1schemaAnetApiSchema_xsdrefundChargeBackAmount', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2011, 3), )

    
    refundChargeBackAmount = property(__refundChargeBackAmount.value, __refundChargeBackAmount.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}refundChargeBackCount uses Python identifier refundChargeBackCount
    __refundChargeBackCount = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'refundChargeBackCount'), 'refundChargeBackCount', '__AnetApixmlv1schemaAnetApiSchema_xsd_batchStatisticType_AnetApixmlv1schemaAnetApiSchema_xsdrefundChargeBackCount', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2012, 3), )

    
    refundChargeBackCount = property(__refundChargeBackCount.value, __refundChargeBackCount.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}chargeReturnedItemsAmount uses Python identifier chargeReturnedItemsAmount
    __chargeReturnedItemsAmount = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'chargeReturnedItemsAmount'), 'chargeReturnedItemsAmount', '__AnetApixmlv1schemaAnetApiSchema_xsd_batchStatisticType_AnetApixmlv1schemaAnetApiSchema_xsdchargeReturnedItemsAmount', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2013, 3), )

    
    chargeReturnedItemsAmount = property(__chargeReturnedItemsAmount.value, __chargeReturnedItemsAmount.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}chargeReturnedItemsCount uses Python identifier chargeReturnedItemsCount
    __chargeReturnedItemsCount = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'chargeReturnedItemsCount'), 'chargeReturnedItemsCount', '__AnetApixmlv1schemaAnetApiSchema_xsd_batchStatisticType_AnetApixmlv1schemaAnetApiSchema_xsdchargeReturnedItemsCount', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2014, 3), )

    
    chargeReturnedItemsCount = property(__chargeReturnedItemsCount.value, __chargeReturnedItemsCount.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}refundReturnedItemsAmount uses Python identifier refundReturnedItemsAmount
    __refundReturnedItemsAmount = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'refundReturnedItemsAmount'), 'refundReturnedItemsAmount', '__AnetApixmlv1schemaAnetApiSchema_xsd_batchStatisticType_AnetApixmlv1schemaAnetApiSchema_xsdrefundReturnedItemsAmount', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2015, 3), )

    
    refundReturnedItemsAmount = property(__refundReturnedItemsAmount.value, __refundReturnedItemsAmount.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}refundReturnedItemsCount uses Python identifier refundReturnedItemsCount
    __refundReturnedItemsCount = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'refundReturnedItemsCount'), 'refundReturnedItemsCount', '__AnetApixmlv1schemaAnetApiSchema_xsd_batchStatisticType_AnetApixmlv1schemaAnetApiSchema_xsdrefundReturnedItemsCount', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2016, 3), )

    
    refundReturnedItemsCount = property(__refundReturnedItemsCount.value, __refundReturnedItemsCount.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __accountType.name() : __accountType,
        __chargeAmount.name() : __chargeAmount,
        __chargeCount.name() : __chargeCount,
        __refundAmount.name() : __refundAmount,
        __refundCount.name() : __refundCount,
        __voidCount.name() : __voidCount,
        __declineCount.name() : __declineCount,
        __errorCount.name() : __errorCount,
        __returnedItemAmount.name() : __returnedItemAmount,
        __returnedItemCount.name() : __returnedItemCount,
        __chargebackAmount.name() : __chargebackAmount,
        __chargebackCount.name() : __chargebackCount,
        __correctionNoticeCount.name() : __correctionNoticeCount,
        __chargeChargeBackAmount.name() : __chargeChargeBackAmount,
        __chargeChargeBackCount.name() : __chargeChargeBackCount,
        __refundChargeBackAmount.name() : __refundChargeBackAmount,
        __refundChargeBackCount.name() : __refundChargeBackCount,
        __chargeReturnedItemsAmount.name() : __chargeReturnedItemsAmount,
        __chargeReturnedItemsCount.name() : __chargeReturnedItemsCount,
        __refundReturnedItemsAmount.name() : __refundReturnedItemsAmount,
        __refundReturnedItemsCount.name() : __refundReturnedItemsCount
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'batchStatisticType', batchStatisticType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}transactionResponse with content type ELEMENT_ONLY
class transactionResponse (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}transactionResponse with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'transactionResponse')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2021, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}responseCode uses Python identifier responseCode
    __responseCode = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'responseCode'), 'responseCode', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionResponse_AnetApixmlv1schemaAnetApiSchema_xsdresponseCode', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2023, 3), )

    
    responseCode = property(__responseCode.value, __responseCode.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}rawResponseCode uses Python identifier rawResponseCode
    __rawResponseCode = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'rawResponseCode'), 'rawResponseCode', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionResponse_AnetApixmlv1schemaAnetApiSchema_xsdrawResponseCode', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2024, 3), )

    
    rawResponseCode = property(__rawResponseCode.value, __rawResponseCode.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}authCode uses Python identifier authCode
    __authCode = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'authCode'), 'authCode', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionResponse_AnetApixmlv1schemaAnetApiSchema_xsdauthCode', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2025, 3), )

    
    authCode = property(__authCode.value, __authCode.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}avsResultCode uses Python identifier avsResultCode
    __avsResultCode = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'avsResultCode'), 'avsResultCode', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionResponse_AnetApixmlv1schemaAnetApiSchema_xsdavsResultCode', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2026, 3), )

    
    avsResultCode = property(__avsResultCode.value, __avsResultCode.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}cvvResultCode uses Python identifier cvvResultCode
    __cvvResultCode = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'cvvResultCode'), 'cvvResultCode', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionResponse_AnetApixmlv1schemaAnetApiSchema_xsdcvvResultCode', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2027, 3), )

    
    cvvResultCode = property(__cvvResultCode.value, __cvvResultCode.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}cavvResultCode uses Python identifier cavvResultCode
    __cavvResultCode = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'cavvResultCode'), 'cavvResultCode', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionResponse_AnetApixmlv1schemaAnetApiSchema_xsdcavvResultCode', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2028, 3), )

    
    cavvResultCode = property(__cavvResultCode.value, __cavvResultCode.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}transId uses Python identifier transId
    __transId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'transId'), 'transId', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionResponse_AnetApixmlv1schemaAnetApiSchema_xsdtransId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2029, 3), )

    
    transId = property(__transId.value, __transId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}refTransID uses Python identifier refTransID
    __refTransID = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'refTransID'), 'refTransID', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionResponse_AnetApixmlv1schemaAnetApiSchema_xsdrefTransID', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2030, 3), )

    
    refTransID = property(__refTransID.value, __refTransID.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}transHash uses Python identifier transHash
    __transHash = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'transHash'), 'transHash', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionResponse_AnetApixmlv1schemaAnetApiSchema_xsdtransHash', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2031, 3), )

    
    transHash = property(__transHash.value, __transHash.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}testRequest uses Python identifier testRequest
    __testRequest = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'testRequest'), 'testRequest', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionResponse_AnetApixmlv1schemaAnetApiSchema_xsdtestRequest', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2032, 3), )

    
    testRequest = property(__testRequest.value, __testRequest.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}accountNumber uses Python identifier accountNumber
    __accountNumber = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'accountNumber'), 'accountNumber', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionResponse_AnetApixmlv1schemaAnetApiSchema_xsdaccountNumber', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2033, 3), )

    
    accountNumber = property(__accountNumber.value, __accountNumber.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}accountType uses Python identifier accountType
    __accountType = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'accountType'), 'accountType', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionResponse_AnetApixmlv1schemaAnetApiSchema_xsdaccountType', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2034, 3), )

    
    accountType = property(__accountType.value, __accountType.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}entryMode uses Python identifier entryMode
    __entryMode = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'entryMode'), 'entryMode', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionResponse_AnetApixmlv1schemaAnetApiSchema_xsdentryMode', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2035, 12), )

    
    entryMode = property(__entryMode.value, __entryMode.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}splitTenderId uses Python identifier splitTenderId
    __splitTenderId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'splitTenderId'), 'splitTenderId', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionResponse_AnetApixmlv1schemaAnetApiSchema_xsdsplitTenderId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2036, 3), )

    
    splitTenderId = property(__splitTenderId.value, __splitTenderId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}prePaidCard uses Python identifier prePaidCard
    __prePaidCard = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'prePaidCard'), 'prePaidCard', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionResponse_AnetApixmlv1schemaAnetApiSchema_xsdprePaidCard', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2037, 3), )

    
    prePaidCard = property(__prePaidCard.value, __prePaidCard.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}messages uses Python identifier messages
    __messages = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'messages'), 'messages', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionResponse_AnetApixmlv1schemaAnetApiSchema_xsdmessages', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2047, 3), )

    
    messages = property(__messages.value, __messages.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}errors uses Python identifier errors
    __errors = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'errors'), 'errors', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionResponse_AnetApixmlv1schemaAnetApiSchema_xsderrors', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2063, 3), )

    
    errors = property(__errors.value, __errors.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}splitTenderPayments uses Python identifier splitTenderPayments
    __splitTenderPayments = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'splitTenderPayments'), 'splitTenderPayments', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionResponse_AnetApixmlv1schemaAnetApiSchema_xsdsplitTenderPayments', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2079, 3), )

    
    splitTenderPayments = property(__splitTenderPayments.value, __splitTenderPayments.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}userFields uses Python identifier userFields
    __userFields = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'userFields'), 'userFields', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionResponse_AnetApixmlv1schemaAnetApiSchema_xsduserFields', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2102, 3), )

    
    userFields = property(__userFields.value, __userFields.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}shipTo uses Python identifier shipTo
    __shipTo = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'shipTo'), 'shipTo', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionResponse_AnetApixmlv1schemaAnetApiSchema_xsdshipTo', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2110, 6), )

    
    shipTo = property(__shipTo.value, __shipTo.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}secureAcceptance uses Python identifier secureAcceptance
    __secureAcceptance = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'secureAcceptance'), 'secureAcceptance', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionResponse_AnetApixmlv1schemaAnetApiSchema_xsdsecureAcceptance', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2111, 6), )

    
    secureAcceptance = property(__secureAcceptance.value, __secureAcceptance.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}emvResponse uses Python identifier emvResponse
    __emvResponse = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'emvResponse'), 'emvResponse', '__AnetApixmlv1schemaAnetApiSchema_xsd_transactionResponse_AnetApixmlv1schemaAnetApiSchema_xsdemvResponse', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2120, 12), )

    
    emvResponse = property(__emvResponse.value, __emvResponse.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __responseCode.name() : __responseCode,
        __rawResponseCode.name() : __rawResponseCode,
        __authCode.name() : __authCode,
        __avsResultCode.name() : __avsResultCode,
        __cvvResultCode.name() : __cvvResultCode,
        __cavvResultCode.name() : __cavvResultCode,
        __transId.name() : __transId,
        __refTransID.name() : __refTransID,
        __transHash.name() : __transHash,
        __testRequest.name() : __testRequest,
        __accountNumber.name() : __accountNumber,
        __accountType.name() : __accountType,
        __entryMode.name() : __entryMode,
        __splitTenderId.name() : __splitTenderId,
        __prePaidCard.name() : __prePaidCard,
        __messages.name() : __messages,
        __errors.name() : __errors,
        __splitTenderPayments.name() : __splitTenderPayments,
        __userFields.name() : __userFields,
        __shipTo.name() : __shipTo,
        __secureAcceptance.name() : __secureAcceptance,
        __emvResponse.name() : __emvResponse
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'transactionResponse', transactionResponse)


# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_6 (pyxb.binding.basis.complexTypeDefinition):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2038, 4)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}requestedAmount uses Python identifier requestedAmount
    __requestedAmount = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'requestedAmount'), 'requestedAmount', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_6_AnetApixmlv1schemaAnetApiSchema_xsdrequestedAmount', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2040, 6), )

    
    requestedAmount = property(__requestedAmount.value, __requestedAmount.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}approvedAmount uses Python identifier approvedAmount
    __approvedAmount = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'approvedAmount'), 'approvedAmount', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_6_AnetApixmlv1schemaAnetApiSchema_xsdapprovedAmount', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2041, 6), )

    
    approvedAmount = property(__approvedAmount.value, __approvedAmount.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}balanceOnCard uses Python identifier balanceOnCard
    __balanceOnCard = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'balanceOnCard'), 'balanceOnCard', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_6_AnetApixmlv1schemaAnetApiSchema_xsdbalanceOnCard', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2042, 6), )

    
    balanceOnCard = property(__balanceOnCard.value, __balanceOnCard.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __requestedAmount.name() : __requestedAmount,
        __approvedAmount.name() : __approvedAmount,
        __balanceOnCard.name() : __balanceOnCard
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_7 (pyxb.binding.basis.complexTypeDefinition):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2048, 4)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}message uses Python identifier message
    __message = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'message'), 'message', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_7_AnetApixmlv1schemaAnetApiSchema_xsdmessage', True, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2050, 6), )

    
    message = property(__message.value, __message.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __message.name() : __message
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_8 (pyxb.binding.basis.complexTypeDefinition):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2051, 7)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}code uses Python identifier code
    __code = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'code'), 'code', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_8_AnetApixmlv1schemaAnetApiSchema_xsdcode', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2053, 9), )

    
    code = property(__code.value, __code.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}description uses Python identifier description
    __description = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'description'), 'description', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_8_AnetApixmlv1schemaAnetApiSchema_xsddescription', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2054, 9), )

    
    description = property(__description.value, __description.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __code.name() : __code,
        __description.name() : __description
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_9 (pyxb.binding.basis.complexTypeDefinition):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2064, 4)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}error uses Python identifier error
    __error = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'error'), 'error', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_9_AnetApixmlv1schemaAnetApiSchema_xsderror', True, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2066, 6), )

    
    error = property(__error.value, __error.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __error.name() : __error
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_10 (pyxb.binding.basis.complexTypeDefinition):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2067, 7)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}errorCode uses Python identifier errorCode
    __errorCode = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'errorCode'), 'errorCode', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_10_AnetApixmlv1schemaAnetApiSchema_xsderrorCode', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2069, 9), )

    
    errorCode = property(__errorCode.value, __errorCode.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}errorText uses Python identifier errorText
    __errorText = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'errorText'), 'errorText', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_10_AnetApixmlv1schemaAnetApiSchema_xsderrorText', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2070, 9), )

    
    errorText = property(__errorText.value, __errorText.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __errorCode.name() : __errorCode,
        __errorText.name() : __errorText
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_11 (pyxb.binding.basis.complexTypeDefinition):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2080, 4)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}splitTenderPayment uses Python identifier splitTenderPayment
    __splitTenderPayment = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'splitTenderPayment'), 'splitTenderPayment', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_11_AnetApixmlv1schemaAnetApiSchema_xsdsplitTenderPayment', True, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2082, 6), )

    
    splitTenderPayment = property(__splitTenderPayment.value, __splitTenderPayment.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __splitTenderPayment.name() : __splitTenderPayment
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_12 (pyxb.binding.basis.complexTypeDefinition):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2083, 7)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}transId uses Python identifier transId
    __transId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'transId'), 'transId', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_12_AnetApixmlv1schemaAnetApiSchema_xsdtransId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2085, 9), )

    
    transId = property(__transId.value, __transId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}responseCode uses Python identifier responseCode
    __responseCode = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'responseCode'), 'responseCode', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_12_AnetApixmlv1schemaAnetApiSchema_xsdresponseCode', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2086, 9), )

    
    responseCode = property(__responseCode.value, __responseCode.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}responseToCustomer uses Python identifier responseToCustomer
    __responseToCustomer = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'responseToCustomer'), 'responseToCustomer', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_12_AnetApixmlv1schemaAnetApiSchema_xsdresponseToCustomer', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2087, 9), )

    
    responseToCustomer = property(__responseToCustomer.value, __responseToCustomer.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}authCode uses Python identifier authCode
    __authCode = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'authCode'), 'authCode', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_12_AnetApixmlv1schemaAnetApiSchema_xsdauthCode', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2088, 9), )

    
    authCode = property(__authCode.value, __authCode.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}accountNumber uses Python identifier accountNumber
    __accountNumber = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'accountNumber'), 'accountNumber', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_12_AnetApixmlv1schemaAnetApiSchema_xsdaccountNumber', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2089, 9), )

    
    accountNumber = property(__accountNumber.value, __accountNumber.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}accountType uses Python identifier accountType
    __accountType = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'accountType'), 'accountType', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_12_AnetApixmlv1schemaAnetApiSchema_xsdaccountType', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2090, 9), )

    
    accountType = property(__accountType.value, __accountType.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}requestedAmount uses Python identifier requestedAmount
    __requestedAmount = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'requestedAmount'), 'requestedAmount', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_12_AnetApixmlv1schemaAnetApiSchema_xsdrequestedAmount', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2091, 9), )

    
    requestedAmount = property(__requestedAmount.value, __requestedAmount.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}approvedAmount uses Python identifier approvedAmount
    __approvedAmount = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'approvedAmount'), 'approvedAmount', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_12_AnetApixmlv1schemaAnetApiSchema_xsdapprovedAmount', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2092, 9), )

    
    approvedAmount = property(__approvedAmount.value, __approvedAmount.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}balanceOnCard uses Python identifier balanceOnCard
    __balanceOnCard = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'balanceOnCard'), 'balanceOnCard', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_12_AnetApixmlv1schemaAnetApiSchema_xsdbalanceOnCard', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2093, 9), )

    
    balanceOnCard = property(__balanceOnCard.value, __balanceOnCard.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __transId.name() : __transId,
        __responseCode.name() : __responseCode,
        __responseToCustomer.name() : __responseToCustomer,
        __authCode.name() : __authCode,
        __accountNumber.name() : __accountNumber,
        __accountType.name() : __accountType,
        __requestedAmount.name() : __requestedAmount,
        __approvedAmount.name() : __approvedAmount,
        __balanceOnCard.name() : __balanceOnCard
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_13 (pyxb.binding.basis.complexTypeDefinition):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2103, 4)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}userField uses Python identifier userField
    __userField = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'userField'), 'userField', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_13_AnetApixmlv1schemaAnetApiSchema_xsduserField', True, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2105, 6), )

    
    userField = property(__userField.value, __userField.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __userField.name() : __userField
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_14 (pyxb.binding.basis.complexTypeDefinition):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2112, 8)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}SecureAcceptanceUrl uses Python identifier SecureAcceptanceUrl
    __SecureAcceptanceUrl = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'SecureAcceptanceUrl'), 'SecureAcceptanceUrl', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_14_AnetApixmlv1schemaAnetApiSchema_xsdSecureAcceptanceUrl', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2114, 12), )

    
    SecureAcceptanceUrl = property(__SecureAcceptanceUrl.value, __SecureAcceptanceUrl.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}PayerID uses Python identifier PayerID
    __PayerID = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'PayerID'), 'PayerID', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_14_AnetApixmlv1schemaAnetApiSchema_xsdPayerID', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2115, 12), )

    
    PayerID = property(__PayerID.value, __PayerID.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __SecureAcceptanceUrl.name() : __SecureAcceptanceUrl,
        __PayerID.name() : __PayerID
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_15 (pyxb.binding.basis.complexTypeDefinition):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2121, 16)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}tlvData uses Python identifier tlvData
    __tlvData = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'tlvData'), 'tlvData', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_15_AnetApixmlv1schemaAnetApiSchema_xsdtlvData', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2123, 24), )

    
    tlvData = property(__tlvData.value, __tlvData.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}tag uses Python identifier tag
    __tag = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'tag'), 'tag', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_15_AnetApixmlv1schemaAnetApiSchema_xsdtag', True, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2124, 24), )

    
    tag = property(__tag.value, __tag.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __tlvData.name() : __tlvData,
        __tag.name() : __tag
    })
    _AttributeMap.update({
        
    })



# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest with content type ELEMENT_ONLY
class ANetApiRequest (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'ANetApiRequest')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2138, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantAuthentication uses Python identifier merchantAuthentication
    __merchantAuthentication = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'merchantAuthentication'), 'merchantAuthentication', '__AnetApixmlv1schemaAnetApiSchema_xsd_ANetApiRequest_AnetApixmlv1schemaAnetApiSchema_xsdmerchantAuthentication', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2140, 3), )

    
    merchantAuthentication = property(__merchantAuthentication.value, __merchantAuthentication.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId uses Python identifier refId
    __refId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'refId'), 'refId', '__AnetApixmlv1schemaAnetApiSchema_xsd_ANetApiRequest_AnetApixmlv1schemaAnetApiSchema_xsdrefId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3), )

    
    refId = property(__refId.value, __refId.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __merchantAuthentication.name() : __merchantAuthentication,
        __refId.name() : __refId
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'ANetApiRequest', ANetApiRequest)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}messagesType with content type ELEMENT_ONLY
class messagesType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}messagesType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'messagesType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2189, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}resultCode uses Python identifier resultCode
    __resultCode = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'resultCode'), 'resultCode', '__AnetApixmlv1schemaAnetApiSchema_xsd_messagesType_AnetApixmlv1schemaAnetApiSchema_xsdresultCode', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2191, 3), )

    
    resultCode = property(__resultCode.value, __resultCode.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}message uses Python identifier message
    __message = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'message'), 'message', '__AnetApixmlv1schemaAnetApiSchema_xsd_messagesType_AnetApixmlv1schemaAnetApiSchema_xsdmessage', True, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2192, 3), )

    
    message = property(__message.value, __message.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __resultCode.name() : __resultCode,
        __message.name() : __message
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'messagesType', messagesType)


# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_16 (pyxb.binding.basis.complexTypeDefinition):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2193, 4)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}code uses Python identifier code
    __code = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'code'), 'code', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_16_AnetApixmlv1schemaAnetApiSchema_xsdcode', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2195, 6), )

    
    code = property(__code.value, __code.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}text uses Python identifier text
    __text = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'text'), 'text', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_16_AnetApixmlv1schemaAnetApiSchema_xsdtext', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2196, 6), )

    
    text = property(__text.value, __text.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __code.name() : __code,
        __text.name() : __text
    })
    _AttributeMap.update({
        
    })



# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse with content type ELEMENT_ONLY
class ANetApiResponse (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'ANetApiResponse')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2210, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId uses Python identifier refId
    __refId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'refId'), 'refId', '__AnetApixmlv1schemaAnetApiSchema_xsd_ANetApiResponse_AnetApixmlv1schemaAnetApiSchema_xsdrefId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3), )

    
    refId = property(__refId.value, __refId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}messages uses Python identifier messages
    __messages = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'messages'), 'messages', '__AnetApixmlv1schemaAnetApiSchema_xsd_ANetApiResponse_AnetApixmlv1schemaAnetApiSchema_xsdmessages', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2214, 4), )

    
    messages = property(__messages.value, __messages.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}sessionToken uses Python identifier sessionToken
    __sessionToken = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'sessionToken'), 'sessionToken', '__AnetApixmlv1schemaAnetApiSchema_xsd_ANetApiResponse_AnetApixmlv1schemaAnetApiSchema_xsdsessionToken', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3), )

    
    sessionToken = property(__sessionToken.value, __sessionToken.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __refId.name() : __refId,
        __messages.name() : __messages,
        __sessionToken.name() : __sessionToken
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'ANetApiResponse', ANetApiResponse)


# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_17 (pyxb.binding.basis.complexTypeDefinition):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2241, 2)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId uses Python identifier refId
    __refId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'refId'), 'refId', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_17_AnetApixmlv1schemaAnetApiSchema_xsdrefId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2243, 4), )

    
    refId = property(__refId.value, __refId.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __refId.name() : __refId
    })
    _AttributeMap.update({
        
    })



# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}createProfileResponse with content type ELEMENT_ONLY
class createProfileResponse (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}createProfileResponse with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'createProfileResponse')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2494, 4)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}messages uses Python identifier messages
    __messages = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'messages'), 'messages', '__AnetApixmlv1schemaAnetApiSchema_xsd_createProfileResponse_AnetApixmlv1schemaAnetApiSchema_xsdmessages', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2496, 12), )

    
    messages = property(__messages.value, __messages.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileId uses Python identifier customerProfileId
    __customerProfileId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), 'customerProfileId', '__AnetApixmlv1schemaAnetApiSchema_xsd_createProfileResponse_AnetApixmlv1schemaAnetApiSchema_xsdcustomerProfileId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2498, 12), )

    
    customerProfileId = property(__customerProfileId.value, __customerProfileId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerPaymentProfileIdList uses Python identifier customerPaymentProfileIdList
    __customerPaymentProfileIdList = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileIdList'), 'customerPaymentProfileIdList', '__AnetApixmlv1schemaAnetApiSchema_xsd_createProfileResponse_AnetApixmlv1schemaAnetApiSchema_xsdcustomerPaymentProfileIdList', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2499, 12), )

    
    customerPaymentProfileIdList = property(__customerPaymentProfileIdList.value, __customerPaymentProfileIdList.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerShippingAddressIdList uses Python identifier customerShippingAddressIdList
    __customerShippingAddressIdList = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerShippingAddressIdList'), 'customerShippingAddressIdList', '__AnetApixmlv1schemaAnetApiSchema_xsd_createProfileResponse_AnetApixmlv1schemaAnetApiSchema_xsdcustomerShippingAddressIdList', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2500, 12), )

    
    customerShippingAddressIdList = property(__customerShippingAddressIdList.value, __customerShippingAddressIdList.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __messages.name() : __messages,
        __customerProfileId.name() : __customerProfileId,
        __customerPaymentProfileIdList.name() : __customerPaymentProfileIdList,
        __customerShippingAddressIdList.name() : __customerShippingAddressIdList
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'createProfileResponse', createProfileResponse)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}payPalType with content type ELEMENT_ONLY
class payPalType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}payPalType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'payPalType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3505, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}successUrl uses Python identifier successUrl
    __successUrl = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'successUrl'), 'successUrl', '__AnetApixmlv1schemaAnetApiSchema_xsd_payPalType_AnetApixmlv1schemaAnetApiSchema_xsdsuccessUrl', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3507, 3), )

    
    successUrl = property(__successUrl.value, __successUrl.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}cancelUrl uses Python identifier cancelUrl
    __cancelUrl = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'cancelUrl'), 'cancelUrl', '__AnetApixmlv1schemaAnetApiSchema_xsd_payPalType_AnetApixmlv1schemaAnetApiSchema_xsdcancelUrl', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3514, 3), )

    
    cancelUrl = property(__cancelUrl.value, __cancelUrl.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}paypalLc uses Python identifier paypalLc
    __paypalLc = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'paypalLc'), 'paypalLc', '__AnetApixmlv1schemaAnetApiSchema_xsd_payPalType_AnetApixmlv1schemaAnetApiSchema_xsdpaypalLc', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3521, 3), )

    
    paypalLc = property(__paypalLc.value, __paypalLc.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}paypalHdrImg uses Python identifier paypalHdrImg
    __paypalHdrImg = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'paypalHdrImg'), 'paypalHdrImg', '__AnetApixmlv1schemaAnetApiSchema_xsd_payPalType_AnetApixmlv1schemaAnetApiSchema_xsdpaypalHdrImg', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3528, 3), )

    
    paypalHdrImg = property(__paypalHdrImg.value, __paypalHdrImg.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}paypalPayflowcolor uses Python identifier paypalPayflowcolor
    __paypalPayflowcolor = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'paypalPayflowcolor'), 'paypalPayflowcolor', '__AnetApixmlv1schemaAnetApiSchema_xsd_payPalType_AnetApixmlv1schemaAnetApiSchema_xsdpaypalPayflowcolor', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3535, 3), )

    
    paypalPayflowcolor = property(__paypalPayflowcolor.value, __paypalPayflowcolor.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}payerID uses Python identifier payerID
    __payerID = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'payerID'), 'payerID', '__AnetApixmlv1schemaAnetApiSchema_xsd_payPalType_AnetApixmlv1schemaAnetApiSchema_xsdpayerID', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3542, 3), )

    
    payerID = property(__payerID.value, __payerID.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __successUrl.name() : __successUrl,
        __cancelUrl.name() : __cancelUrl,
        __paypalLc.name() : __paypalLc,
        __paypalHdrImg.name() : __paypalHdrImg,
        __paypalPayflowcolor.name() : __paypalPayflowcolor,
        __payerID.name() : __payerID
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'payPalType', payPalType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}Paging with content type ELEMENT_ONLY
class Paging (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}Paging with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'Paging')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3566, 4)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}limit uses Python identifier limit
    __limit = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'limit'), 'limit', '__AnetApixmlv1schemaAnetApiSchema_xsd_Paging_AnetApixmlv1schemaAnetApiSchema_xsdlimit', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3568, 12), )

    
    limit = property(__limit.value, __limit.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}offset uses Python identifier offset
    __offset = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'offset'), 'offset', '__AnetApixmlv1schemaAnetApiSchema_xsd_Paging_AnetApixmlv1schemaAnetApiSchema_xsdoffset', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3576, 12), )

    
    offset = property(__offset.value, __offset.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __limit.name() : __limit,
        __offset.name() : __offset
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'Paging', Paging)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ARBGetSubscriptionListSorting with content type ELEMENT_ONLY
class ARBGetSubscriptionListSorting (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ARBGetSubscriptionListSorting with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'ARBGetSubscriptionListSorting')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3587, 4)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}orderBy uses Python identifier orderBy
    __orderBy = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'orderBy'), 'orderBy', '__AnetApixmlv1schemaAnetApiSchema_xsd_ARBGetSubscriptionListSorting_AnetApixmlv1schemaAnetApiSchema_xsdorderBy', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3589, 12), )

    
    orderBy = property(__orderBy.value, __orderBy.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}orderDescending uses Python identifier orderDescending
    __orderDescending = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'orderDescending'), 'orderDescending', '__AnetApixmlv1schemaAnetApiSchema_xsd_ARBGetSubscriptionListSorting_AnetApixmlv1schemaAnetApiSchema_xsdorderDescending', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3590, 12), )

    
    orderDescending = property(__orderDescending.value, __orderDescending.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __orderBy.name() : __orderBy,
        __orderDescending.name() : __orderDescending
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'ARBGetSubscriptionListSorting', ARBGetSubscriptionListSorting)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ArrayOfSubscription with content type ELEMENT_ONLY
class ArrayOfSubscription (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ArrayOfSubscription with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'ArrayOfSubscription')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3628, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}subscriptionDetail uses Python identifier subscriptionDetail
    __subscriptionDetail = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'subscriptionDetail'), 'subscriptionDetail', '__AnetApixmlv1schemaAnetApiSchema_xsd_ArrayOfSubscription_AnetApixmlv1schemaAnetApiSchema_xsdsubscriptionDetail', True, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3630, 3), )

    
    subscriptionDetail = property(__subscriptionDetail.value, __subscriptionDetail.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __subscriptionDetail.name() : __subscriptionDetail
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'ArrayOfSubscription', ArrayOfSubscription)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}SubscriptionDetail with content type ELEMENT_ONLY
class SubscriptionDetail (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}SubscriptionDetail with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'SubscriptionDetail')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3634, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}id uses Python identifier id
    __id = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'id'), 'id', '__AnetApixmlv1schemaAnetApiSchema_xsd_SubscriptionDetail_AnetApixmlv1schemaAnetApiSchema_xsdid', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3636, 3), )

    
    id = property(__id.value, __id.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}name uses Python identifier name
    __name = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'name'), 'name', '__AnetApixmlv1schemaAnetApiSchema_xsd_SubscriptionDetail_AnetApixmlv1schemaAnetApiSchema_xsdname', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3637, 3), )

    
    name = property(__name.value, __name.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}status uses Python identifier status
    __status = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'status'), 'status', '__AnetApixmlv1schemaAnetApiSchema_xsd_SubscriptionDetail_AnetApixmlv1schemaAnetApiSchema_xsdstatus', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3638, 12), )

    
    status = property(__status.value, __status.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}createTimeStampUTC uses Python identifier createTimeStampUTC
    __createTimeStampUTC = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'createTimeStampUTC'), 'createTimeStampUTC', '__AnetApixmlv1schemaAnetApiSchema_xsd_SubscriptionDetail_AnetApixmlv1schemaAnetApiSchema_xsdcreateTimeStampUTC', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3639, 3), )

    
    createTimeStampUTC = property(__createTimeStampUTC.value, __createTimeStampUTC.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}firstName uses Python identifier firstName
    __firstName = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'firstName'), 'firstName', '__AnetApixmlv1schemaAnetApiSchema_xsd_SubscriptionDetail_AnetApixmlv1schemaAnetApiSchema_xsdfirstName', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3640, 3), )

    
    firstName = property(__firstName.value, __firstName.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}lastName uses Python identifier lastName
    __lastName = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'lastName'), 'lastName', '__AnetApixmlv1schemaAnetApiSchema_xsd_SubscriptionDetail_AnetApixmlv1schemaAnetApiSchema_xsdlastName', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3641, 3), )

    
    lastName = property(__lastName.value, __lastName.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}totalOccurrences uses Python identifier totalOccurrences
    __totalOccurrences = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'totalOccurrences'), 'totalOccurrences', '__AnetApixmlv1schemaAnetApiSchema_xsd_SubscriptionDetail_AnetApixmlv1schemaAnetApiSchema_xsdtotalOccurrences', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3642, 3), )

    
    totalOccurrences = property(__totalOccurrences.value, __totalOccurrences.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}pastOccurrences uses Python identifier pastOccurrences
    __pastOccurrences = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'pastOccurrences'), 'pastOccurrences', '__AnetApixmlv1schemaAnetApiSchema_xsd_SubscriptionDetail_AnetApixmlv1schemaAnetApiSchema_xsdpastOccurrences', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3643, 3), )

    
    pastOccurrences = property(__pastOccurrences.value, __pastOccurrences.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}paymentMethod uses Python identifier paymentMethod
    __paymentMethod = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'paymentMethod'), 'paymentMethod', '__AnetApixmlv1schemaAnetApiSchema_xsd_SubscriptionDetail_AnetApixmlv1schemaAnetApiSchema_xsdpaymentMethod', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3644, 12), )

    
    paymentMethod = property(__paymentMethod.value, __paymentMethod.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}accountNumber uses Python identifier accountNumber
    __accountNumber = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'accountNumber'), 'accountNumber', '__AnetApixmlv1schemaAnetApiSchema_xsd_SubscriptionDetail_AnetApixmlv1schemaAnetApiSchema_xsdaccountNumber', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3645, 12), )

    
    accountNumber = property(__accountNumber.value, __accountNumber.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}invoice uses Python identifier invoice
    __invoice = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'invoice'), 'invoice', '__AnetApixmlv1schemaAnetApiSchema_xsd_SubscriptionDetail_AnetApixmlv1schemaAnetApiSchema_xsdinvoice', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3646, 3), )

    
    invoice = property(__invoice.value, __invoice.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}amount uses Python identifier amount
    __amount = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'amount'), 'amount', '__AnetApixmlv1schemaAnetApiSchema_xsd_SubscriptionDetail_AnetApixmlv1schemaAnetApiSchema_xsdamount', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3647, 3), )

    
    amount = property(__amount.value, __amount.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}currencyCode uses Python identifier currencyCode
    __currencyCode = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'currencyCode'), 'currencyCode', '__AnetApixmlv1schemaAnetApiSchema_xsd_SubscriptionDetail_AnetApixmlv1schemaAnetApiSchema_xsdcurrencyCode', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3655, 3), )

    
    currencyCode = property(__currencyCode.value, __currencyCode.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileId uses Python identifier customerProfileId
    __customerProfileId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), 'customerProfileId', '__AnetApixmlv1schemaAnetApiSchema_xsd_SubscriptionDetail_AnetApixmlv1schemaAnetApiSchema_xsdcustomerProfileId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3656, 3), )

    
    customerProfileId = property(__customerProfileId.value, __customerProfileId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerPaymentProfileId uses Python identifier customerPaymentProfileId
    __customerPaymentProfileId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileId'), 'customerPaymentProfileId', '__AnetApixmlv1schemaAnetApiSchema_xsd_SubscriptionDetail_AnetApixmlv1schemaAnetApiSchema_xsdcustomerPaymentProfileId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3657, 3), )

    
    customerPaymentProfileId = property(__customerPaymentProfileId.value, __customerPaymentProfileId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerShippingProfileId uses Python identifier customerShippingProfileId
    __customerShippingProfileId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerShippingProfileId'), 'customerShippingProfileId', '__AnetApixmlv1schemaAnetApiSchema_xsd_SubscriptionDetail_AnetApixmlv1schemaAnetApiSchema_xsdcustomerShippingProfileId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3658, 3), )

    
    customerShippingProfileId = property(__customerShippingProfileId.value, __customerShippingProfileId.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __id.name() : __id,
        __name.name() : __name,
        __status.name() : __status,
        __createTimeStampUTC.name() : __createTimeStampUTC,
        __firstName.name() : __firstName,
        __lastName.name() : __lastName,
        __totalOccurrences.name() : __totalOccurrences,
        __pastOccurrences.name() : __pastOccurrences,
        __paymentMethod.name() : __paymentMethod,
        __accountNumber.name() : __accountNumber,
        __invoice.name() : __invoice,
        __amount.name() : __amount,
        __currencyCode.name() : __currencyCode,
        __customerProfileId.name() : __customerProfileId,
        __customerPaymentProfileId.name() : __customerPaymentProfileId,
        __customerShippingProfileId.name() : __customerShippingProfileId
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'SubscriptionDetail', SubscriptionDetail)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileSummaryType with content type ELEMENT_ONLY
class customerProfileSummaryType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileSummaryType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'customerProfileSummaryType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3668, 4)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileId uses Python identifier customerProfileId
    __customerProfileId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), 'customerProfileId', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerProfileSummaryType_AnetApixmlv1schemaAnetApiSchema_xsdcustomerProfileId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3670, 8), )

    
    customerProfileId = property(__customerProfileId.value, __customerProfileId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}description uses Python identifier description
    __description = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'description'), 'description', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerProfileSummaryType_AnetApixmlv1schemaAnetApiSchema_xsddescription', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3671, 8), )

    
    description = property(__description.value, __description.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantCustomerId uses Python identifier merchantCustomerId
    __merchantCustomerId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'merchantCustomerId'), 'merchantCustomerId', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerProfileSummaryType_AnetApixmlv1schemaAnetApiSchema_xsdmerchantCustomerId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3672, 8), )

    
    merchantCustomerId = property(__merchantCustomerId.value, __merchantCustomerId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}email uses Python identifier email
    __email = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'email'), 'email', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerProfileSummaryType_AnetApixmlv1schemaAnetApiSchema_xsdemail', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3673, 8), )

    
    email = property(__email.value, __email.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}createdDate uses Python identifier createdDate
    __createdDate = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'createdDate'), 'createdDate', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerProfileSummaryType_AnetApixmlv1schemaAnetApiSchema_xsdcreatedDate', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3674, 8), )

    
    createdDate = property(__createdDate.value, __createdDate.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __customerProfileId.name() : __customerProfileId,
        __description.name() : __description,
        __merchantCustomerId.name() : __merchantCustomerId,
        __email.name() : __email,
        __createdDate.name() : __createdDate
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'customerProfileSummaryType', customerProfileSummaryType)


# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_18 (pyxb.binding.basis.complexTypeDefinition):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3681, 8)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileSummaryType uses Python identifier customerProfileSummaryType
    __customerProfileSummaryType = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerProfileSummaryType'), 'customerProfileSummaryType', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_18_AnetApixmlv1schemaAnetApiSchema_xsdcustomerProfileSummaryType', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3684, 16), )

    
    customerProfileSummaryType = property(__customerProfileSummaryType.value, __customerProfileSummaryType.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}paymentSimpleType uses Python identifier paymentSimpleType
    __paymentSimpleType = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'paymentSimpleType'), 'paymentSimpleType', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_18_AnetApixmlv1schemaAnetApiSchema_xsdpaymentSimpleType', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3685, 16), )

    
    paymentSimpleType = property(__paymentSimpleType.value, __paymentSimpleType.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}accountTypeEnum uses Python identifier accountTypeEnum
    __accountTypeEnum = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'accountTypeEnum'), 'accountTypeEnum', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_18_AnetApixmlv1schemaAnetApiSchema_xsdaccountTypeEnum', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3687, 16), )

    
    accountTypeEnum = property(__accountTypeEnum.value, __accountTypeEnum.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}cardTypeEnum uses Python identifier cardTypeEnum
    __cardTypeEnum = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'cardTypeEnum'), 'cardTypeEnum', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_18_AnetApixmlv1schemaAnetApiSchema_xsdcardTypeEnum', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3688, 16), )

    
    cardTypeEnum = property(__cardTypeEnum.value, __cardTypeEnum.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}FDSFilterActionEnum uses Python identifier FDSFilterActionEnum
    __FDSFilterActionEnum = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'FDSFilterActionEnum'), 'FDSFilterActionEnum', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_18_AnetApixmlv1schemaAnetApiSchema_xsdFDSFilterActionEnum', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3689, 16), )

    
    FDSFilterActionEnum = property(__FDSFilterActionEnum.value, __FDSFilterActionEnum.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}permissionsEnum uses Python identifier permissionsEnum
    __permissionsEnum = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'permissionsEnum'), 'permissionsEnum', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_18_AnetApixmlv1schemaAnetApiSchema_xsdpermissionsEnum', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3690, 16), )

    
    permissionsEnum = property(__permissionsEnum.value, __permissionsEnum.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}settingNameEnum uses Python identifier settingNameEnum
    __settingNameEnum = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'settingNameEnum'), 'settingNameEnum', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_18_AnetApixmlv1schemaAnetApiSchema_xsdsettingNameEnum', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3691, 16), )

    
    settingNameEnum = property(__settingNameEnum.value, __settingNameEnum.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}settlementStateEnum uses Python identifier settlementStateEnum
    __settlementStateEnum = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'settlementStateEnum'), 'settlementStateEnum', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_18_AnetApixmlv1schemaAnetApiSchema_xsdsettlementStateEnum', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3692, 16), )

    
    settlementStateEnum = property(__settlementStateEnum.value, __settlementStateEnum.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}transactionStatusEnum uses Python identifier transactionStatusEnum
    __transactionStatusEnum = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'transactionStatusEnum'), 'transactionStatusEnum', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_18_AnetApixmlv1schemaAnetApiSchema_xsdtransactionStatusEnum', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3693, 16), )

    
    transactionStatusEnum = property(__transactionStatusEnum.value, __transactionStatusEnum.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}transactionTypeEnum uses Python identifier transactionTypeEnum
    __transactionTypeEnum = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'transactionTypeEnum'), 'transactionTypeEnum', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_18_AnetApixmlv1schemaAnetApiSchema_xsdtransactionTypeEnum', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3694, 16), )

    
    transactionTypeEnum = property(__transactionTypeEnum.value, __transactionTypeEnum.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __customerProfileSummaryType.name() : __customerProfileSummaryType,
        __paymentSimpleType.name() : __paymentSimpleType,
        __accountTypeEnum.name() : __accountTypeEnum,
        __cardTypeEnum.name() : __cardTypeEnum,
        __FDSFilterActionEnum.name() : __FDSFilterActionEnum,
        __permissionsEnum.name() : __permissionsEnum,
        __settingNameEnum.name() : __settingNameEnum,
        __settlementStateEnum.name() : __settlementStateEnum,
        __transactionStatusEnum.name() : __transactionStatusEnum,
        __transactionTypeEnum.name() : __transactionTypeEnum
    })
    _AttributeMap.update({
        
    })



# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfilePaymentType with content type ELEMENT_ONLY
class customerProfilePaymentType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfilePaymentType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'customerProfilePaymentType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3704, 2)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}createProfile uses Python identifier createProfile
    __createProfile = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'createProfile'), 'createProfile', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerProfilePaymentType_AnetApixmlv1schemaAnetApiSchema_xsdcreateProfile', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3706, 8), )

    
    createProfile = property(__createProfile.value, __createProfile.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileId uses Python identifier customerProfileId
    __customerProfileId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), 'customerProfileId', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerProfilePaymentType_AnetApixmlv1schemaAnetApiSchema_xsdcustomerProfileId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3707, 8), )

    
    customerProfileId = property(__customerProfileId.value, __customerProfileId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}paymentProfile uses Python identifier paymentProfile
    __paymentProfile = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'paymentProfile'), 'paymentProfile', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerProfilePaymentType_AnetApixmlv1schemaAnetApiSchema_xsdpaymentProfile', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3708, 8), )

    
    paymentProfile = property(__paymentProfile.value, __paymentProfile.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}shippingProfileId uses Python identifier shippingProfileId
    __shippingProfileId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'shippingProfileId'), 'shippingProfileId', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerProfilePaymentType_AnetApixmlv1schemaAnetApiSchema_xsdshippingProfileId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3709, 8), )

    
    shippingProfileId = property(__shippingProfileId.value, __shippingProfileId.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __createProfile.name() : __createProfile,
        __customerProfileId.name() : __customerProfileId,
        __paymentProfile.name() : __paymentProfile,
        __shippingProfileId.name() : __shippingProfileId
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'customerProfilePaymentType', customerProfilePaymentType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}paymentProfile with content type ELEMENT_ONLY
class paymentProfile (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}paymentProfile with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'paymentProfile')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3719, 2)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}paymentProfileId uses Python identifier paymentProfileId
    __paymentProfileId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'paymentProfileId'), 'paymentProfileId', '__AnetApixmlv1schemaAnetApiSchema_xsd_paymentProfile_AnetApixmlv1schemaAnetApiSchema_xsdpaymentProfileId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3721, 6), )

    
    paymentProfileId = property(__paymentProfileId.value, __paymentProfileId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}cardCode uses Python identifier cardCode
    __cardCode = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'cardCode'), 'cardCode', '__AnetApixmlv1schemaAnetApiSchema_xsd_paymentProfile_AnetApixmlv1schemaAnetApiSchema_xsdcardCode', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3722, 6), )

    
    cardCode = property(__cardCode.value, __cardCode.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __paymentProfileId.name() : __paymentProfileId,
        __cardCode.name() : __cardCode
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'paymentProfile', paymentProfile)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}CustomerPaymentProfileSorting with content type ELEMENT_ONLY
class CustomerPaymentProfileSorting (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}CustomerPaymentProfileSorting with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'CustomerPaymentProfileSorting')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3768, 4)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}orderBy uses Python identifier orderBy
    __orderBy = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'orderBy'), 'orderBy', '__AnetApixmlv1schemaAnetApiSchema_xsd_CustomerPaymentProfileSorting_AnetApixmlv1schemaAnetApiSchema_xsdorderBy', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3770, 12), )

    
    orderBy = property(__orderBy.value, __orderBy.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}orderDescending uses Python identifier orderDescending
    __orderDescending = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'orderDescending'), 'orderDescending', '__AnetApixmlv1schemaAnetApiSchema_xsd_CustomerPaymentProfileSorting_AnetApixmlv1schemaAnetApiSchema_xsdorderDescending', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3771, 12), )

    
    orderDescending = property(__orderDescending.value, __orderDescending.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __orderBy.name() : __orderBy,
        __orderDescending.name() : __orderDescending
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'CustomerPaymentProfileSorting', CustomerPaymentProfileSorting)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerPaymentProfileListItemType with content type ELEMENT_ONLY
class customerPaymentProfileListItemType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerPaymentProfileListItemType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileListItemType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3781, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerPaymentProfileId uses Python identifier customerPaymentProfileId
    __customerPaymentProfileId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileId'), 'customerPaymentProfileId', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerPaymentProfileListItemType_AnetApixmlv1schemaAnetApiSchema_xsdcustomerPaymentProfileId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3783, 12), )

    
    customerPaymentProfileId = property(__customerPaymentProfileId.value, __customerPaymentProfileId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileId uses Python identifier customerProfileId
    __customerProfileId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), 'customerProfileId', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerPaymentProfileListItemType_AnetApixmlv1schemaAnetApiSchema_xsdcustomerProfileId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3784, 12), )

    
    customerProfileId = property(__customerProfileId.value, __customerProfileId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}billTo uses Python identifier billTo
    __billTo = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'billTo'), 'billTo', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerPaymentProfileListItemType_AnetApixmlv1schemaAnetApiSchema_xsdbillTo', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3785, 3), )

    
    billTo = property(__billTo.value, __billTo.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}payment uses Python identifier payment
    __payment = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'payment'), 'payment', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerPaymentProfileListItemType_AnetApixmlv1schemaAnetApiSchema_xsdpayment', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3786, 12), )

    
    payment = property(__payment.value, __payment.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __customerPaymentProfileId.name() : __customerPaymentProfileId,
        __customerProfileId.name() : __customerProfileId,
        __billTo.name() : __billTo,
        __payment.name() : __payment
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'customerPaymentProfileListItemType', customerPaymentProfileListItemType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}arrayOfCustomerPaymentProfileListItemType with content type ELEMENT_ONLY
class arrayOfCustomerPaymentProfileListItemType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}arrayOfCustomerPaymentProfileListItemType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'arrayOfCustomerPaymentProfileListItemType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3790, 1)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}paymentProfile uses Python identifier paymentProfile
    __paymentProfile = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'paymentProfile'), 'paymentProfile', '__AnetApixmlv1schemaAnetApiSchema_xsd_arrayOfCustomerPaymentProfileListItemType_AnetApixmlv1schemaAnetApiSchema_xsdpaymentProfile', True, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3792, 3), )

    
    paymentProfile = property(__paymentProfile.value, __paymentProfile.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __paymentProfile.name() : __paymentProfile
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'arrayOfCustomerPaymentProfileListItemType', arrayOfCustomerPaymentProfileListItemType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileIdType with content type ELEMENT_ONLY
class customerProfileIdType (pyxb.binding.basis.complexTypeDefinition):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileIdType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'customerProfileIdType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3839, 2)
    _ElementMap = {}
    _AttributeMap = {}
    # Base type is pyxb.binding.datatypes.anyType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileId uses Python identifier customerProfileId
    __customerProfileId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), 'customerProfileId', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerProfileIdType_AnetApixmlv1schemaAnetApiSchema_xsdcustomerProfileId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3841, 6), )

    
    customerProfileId = property(__customerProfileId.value, __customerProfileId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerPaymentProfileId uses Python identifier customerPaymentProfileId
    __customerPaymentProfileId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileId'), 'customerPaymentProfileId', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerProfileIdType_AnetApixmlv1schemaAnetApiSchema_xsdcustomerPaymentProfileId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3842, 6), )

    
    customerPaymentProfileId = property(__customerPaymentProfileId.value, __customerPaymentProfileId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerAddressId uses Python identifier customerAddressId
    __customerAddressId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerAddressId'), 'customerAddressId', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerProfileIdType_AnetApixmlv1schemaAnetApiSchema_xsdcustomerAddressId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3843, 6), )

    
    customerAddressId = property(__customerAddressId.value, __customerAddressId.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __customerProfileId.name() : __customerProfileId,
        __customerPaymentProfileId.name() : __customerPaymentProfileId,
        __customerAddressId.name() : __customerAddressId
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'customerProfileIdType', customerProfileIdType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}creditCardType with content type ELEMENT_ONLY
class creditCardType (creditCardSimpleType):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}creditCardType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'creditCardType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 443, 1)
    _ElementMap = creditCardSimpleType._ElementMap.copy()
    _AttributeMap = creditCardSimpleType._AttributeMap.copy()
    # Base type is creditCardSimpleType
    
    # Element cardNumber ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}cardNumber) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}creditCardSimpleType
    
    # Element expirationDate ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}expirationDate) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}creditCardSimpleType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}cardCode uses Python identifier cardCode
    __cardCode = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'cardCode'), 'cardCode', '__AnetApixmlv1schemaAnetApiSchema_xsd_creditCardType_AnetApixmlv1schemaAnetApiSchema_xsdcardCode', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 448, 5), )

    
    cardCode = property(__cardCode.value, __cardCode.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}isPaymentToken uses Python identifier isPaymentToken
    __isPaymentToken = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'isPaymentToken'), 'isPaymentToken', '__AnetApixmlv1schemaAnetApiSchema_xsd_creditCardType_AnetApixmlv1schemaAnetApiSchema_xsdisPaymentToken', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 450, 10), )

    
    isPaymentToken = property(__isPaymentToken.value, __isPaymentToken.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}cryptogram uses Python identifier cryptogram
    __cryptogram = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'cryptogram'), 'cryptogram', '__AnetApixmlv1schemaAnetApiSchema_xsd_creditCardType_AnetApixmlv1schemaAnetApiSchema_xsdcryptogram', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 452, 10), )

    
    cryptogram = property(__cryptogram.value, __cryptogram.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __cardCode.name() : __cardCode,
        __isPaymentToken.name() : __isPaymentToken,
        __cryptogram.name() : __cryptogram
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'creditCardType', creditCardType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}orderExType with content type ELEMENT_ONLY
class orderExType (orderType):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}orderExType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'orderExType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 652, 1)
    _ElementMap = orderType._ElementMap.copy()
    _AttributeMap = orderType._AttributeMap.copy()
    # Base type is orderType
    
    # Element invoiceNumber ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}invoiceNumber) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}orderType
    
    # Element description ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}description) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}orderType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}purchaseOrderNumber uses Python identifier purchaseOrderNumber
    __purchaseOrderNumber = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'purchaseOrderNumber'), 'purchaseOrderNumber', '__AnetApixmlv1schemaAnetApiSchema_xsd_orderExType_AnetApixmlv1schemaAnetApiSchema_xsdpurchaseOrderNumber', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 656, 5), )

    
    purchaseOrderNumber = property(__purchaseOrderNumber.value, __purchaseOrderNumber.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __purchaseOrderNumber.name() : __purchaseOrderNumber
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'orderExType', orderExType)


# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_19 (ANetApiRequest):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 823, 4)
    _ElementMap = ANetApiRequest._ElementMap.copy()
    _AttributeMap = ANetApiRequest._AttributeMap.copy()
    # Base type is ANetApiRequest
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}opaqueData uses Python identifier opaqueData
    __opaqueData = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'opaqueData'), 'opaqueData', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_19_AnetApixmlv1schemaAnetApiSchema_xsdopaqueData', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 827, 12), )

    
    opaqueData = property(__opaqueData.value, __opaqueData.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}callId uses Python identifier callId
    __callId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'callId'), 'callId', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_19_AnetApixmlv1schemaAnetApiSchema_xsdcallId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 828, 12), )

    
    callId = property(__callId.value, __callId.set, None, None)

    
    # Element merchantAuthentication ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantAuthentication) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    _HasWildcardElement = True
    _ElementMap.update({
        __opaqueData.name() : __opaqueData,
        __callId.name() : __callId
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_20 (ANetApiResponse):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 837, 4)
    _ElementMap = ANetApiResponse._ElementMap.copy()
    _AttributeMap = ANetApiResponse._AttributeMap.copy()
    # Base type is ANetApiResponse
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}shippingInfo uses Python identifier shippingInfo
    __shippingInfo = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'shippingInfo'), 'shippingInfo', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_20_AnetApixmlv1schemaAnetApiSchema_xsdshippingInfo', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 841, 12), )

    
    shippingInfo = property(__shippingInfo.value, __shippingInfo.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}billingInfo uses Python identifier billingInfo
    __billingInfo = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'billingInfo'), 'billingInfo', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_20_AnetApixmlv1schemaAnetApiSchema_xsdbillingInfo', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 842, 12), )

    
    billingInfo = property(__billingInfo.value, __billingInfo.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}cardInfo uses Python identifier cardInfo
    __cardInfo = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'cardInfo'), 'cardInfo', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_20_AnetApixmlv1schemaAnetApiSchema_xsdcardInfo', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 843, 12), )

    
    cardInfo = property(__cardInfo.value, __cardInfo.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}paymentDetails uses Python identifier paymentDetails
    __paymentDetails = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'paymentDetails'), 'paymentDetails', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_20_AnetApixmlv1schemaAnetApiSchema_xsdpaymentDetails', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 844, 12), )

    
    paymentDetails = property(__paymentDetails.value, __paymentDetails.set, None, None)

    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element messages ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}messages) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element sessionToken ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}sessionToken) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    _HasWildcardElement = True
    _ElementMap.update({
        __shippingInfo.name() : __shippingInfo,
        __billingInfo.name() : __billingInfo,
        __cardInfo.name() : __cardInfo,
        __paymentDetails.name() : __paymentDetails
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_21 (ANetApiRequest):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 855, 4)
    _ElementMap = ANetApiRequest._ElementMap.copy()
    _AttributeMap = ANetApiRequest._AttributeMap.copy()
    # Base type is ANetApiRequest
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}data uses Python identifier data
    __data = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'data'), 'data', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_21_AnetApixmlv1schemaAnetApiSchema_xsddata', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 859, 12), )

    
    data = property(__data.value, __data.set, None, None)

    
    # Element merchantAuthentication ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantAuthentication) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    _HasWildcardElement = True
    _ElementMap.update({
        __data.name() : __data
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_22 (ANetApiResponse):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 868, 4)
    _ElementMap = ANetApiResponse._ElementMap.copy()
    _AttributeMap = ANetApiResponse._AttributeMap.copy()
    # Base type is ANetApiResponse
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}opaqueData uses Python identifier opaqueData
    __opaqueData = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'opaqueData'), 'opaqueData', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_22_AnetApixmlv1schemaAnetApiSchema_xsdopaqueData', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 872, 12), )

    
    opaqueData = property(__opaqueData.value, __opaqueData.set, None, None)

    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element messages ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}messages) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element sessionToken ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}sessionToken) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    _HasWildcardElement = True
    _ElementMap.update({
        __opaqueData.name() : __opaqueData
    })
    _AttributeMap.update({
        
    })



# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerPaymentProfileType with content type ELEMENT_ONLY
class customerPaymentProfileType (customerPaymentProfileBaseType):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerPaymentProfileType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1422, 1)
    _ElementMap = customerPaymentProfileBaseType._ElementMap.copy()
    _AttributeMap = customerPaymentProfileBaseType._AttributeMap.copy()
    # Base type is customerPaymentProfileBaseType
    
    # Element customerType ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerType) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerPaymentProfileBaseType
    
    # Element billTo ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}billTo) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerPaymentProfileBaseType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}payment uses Python identifier payment
    __payment = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'payment'), 'payment', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerPaymentProfileType_AnetApixmlv1schemaAnetApiSchema_xsdpayment', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1426, 5), )

    
    payment = property(__payment.value, __payment.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}driversLicense uses Python identifier driversLicense
    __driversLicense = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'driversLicense'), 'driversLicense', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerPaymentProfileType_AnetApixmlv1schemaAnetApiSchema_xsddriversLicense', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1427, 5), )

    
    driversLicense = property(__driversLicense.value, __driversLicense.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}taxId uses Python identifier taxId
    __taxId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'taxId'), 'taxId', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerPaymentProfileType_AnetApixmlv1schemaAnetApiSchema_xsdtaxId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1429, 5), )

    
    taxId = property(__taxId.value, __taxId.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __payment.name() : __payment,
        __driversLicense.name() : __driversLicense,
        __taxId.name() : __taxId
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'customerPaymentProfileType', customerPaymentProfileType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerPaymentProfileMaskedType with content type ELEMENT_ONLY
class customerPaymentProfileMaskedType (customerPaymentProfileBaseType):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerPaymentProfileMaskedType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileMaskedType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1454, 1)
    _ElementMap = customerPaymentProfileBaseType._ElementMap.copy()
    _AttributeMap = customerPaymentProfileBaseType._AttributeMap.copy()
    # Base type is customerPaymentProfileBaseType
    
    # Element customerType ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerType) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerPaymentProfileBaseType
    
    # Element billTo ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}billTo) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerPaymentProfileBaseType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileId uses Python identifier customerProfileId
    __customerProfileId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), 'customerProfileId', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerPaymentProfileMaskedType_AnetApixmlv1schemaAnetApiSchema_xsdcustomerProfileId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1458, 5), )

    
    customerProfileId = property(__customerProfileId.value, __customerProfileId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerPaymentProfileId uses Python identifier customerPaymentProfileId
    __customerPaymentProfileId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileId'), 'customerPaymentProfileId', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerPaymentProfileMaskedType_AnetApixmlv1schemaAnetApiSchema_xsdcustomerPaymentProfileId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1459, 5), )

    
    customerPaymentProfileId = property(__customerPaymentProfileId.value, __customerPaymentProfileId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}payment uses Python identifier payment
    __payment = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'payment'), 'payment', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerPaymentProfileMaskedType_AnetApixmlv1schemaAnetApiSchema_xsdpayment', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1460, 5), )

    
    payment = property(__payment.value, __payment.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}driversLicense uses Python identifier driversLicense
    __driversLicense = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'driversLicense'), 'driversLicense', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerPaymentProfileMaskedType_AnetApixmlv1schemaAnetApiSchema_xsddriversLicense', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1461, 5), )

    
    driversLicense = property(__driversLicense.value, __driversLicense.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}taxId uses Python identifier taxId
    __taxId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'taxId'), 'taxId', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerPaymentProfileMaskedType_AnetApixmlv1schemaAnetApiSchema_xsdtaxId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1462, 5), )

    
    taxId = property(__taxId.value, __taxId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}subscriptionIds uses Python identifier subscriptionIds
    __subscriptionIds = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'subscriptionIds'), 'subscriptionIds', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerPaymentProfileMaskedType_AnetApixmlv1schemaAnetApiSchema_xsdsubscriptionIds', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1469, 5), )

    
    subscriptionIds = property(__subscriptionIds.value, __subscriptionIds.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __customerProfileId.name() : __customerProfileId,
        __customerPaymentProfileId.name() : __customerPaymentProfileId,
        __payment.name() : __payment,
        __driversLicense.name() : __driversLicense,
        __taxId.name() : __taxId,
        __subscriptionIds.name() : __subscriptionIds
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'customerPaymentProfileMaskedType', customerPaymentProfileMaskedType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileType with content type ELEMENT_ONLY
class customerProfileType (customerProfileBaseType):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'customerProfileType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1512, 1)
    _ElementMap = customerProfileBaseType._ElementMap.copy()
    _AttributeMap = customerProfileBaseType._AttributeMap.copy()
    # Base type is customerProfileBaseType
    
    # Element merchantCustomerId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantCustomerId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileBaseType
    
    # Element description ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}description) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileBaseType
    
    # Element email ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}email) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileBaseType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}paymentProfiles uses Python identifier paymentProfiles
    __paymentProfiles = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'paymentProfiles'), 'paymentProfiles', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerProfileType_AnetApixmlv1schemaAnetApiSchema_xsdpaymentProfiles', True, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1516, 5), )

    
    paymentProfiles = property(__paymentProfiles.value, __paymentProfiles.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}shipToList uses Python identifier shipToList
    __shipToList = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'shipToList'), 'shipToList', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerProfileType_AnetApixmlv1schemaAnetApiSchema_xsdshipToList', True, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1517, 5), )

    
    shipToList = property(__shipToList.value, __shipToList.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __paymentProfiles.name() : __paymentProfiles,
        __shipToList.name() : __shipToList
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'customerProfileType', customerProfileType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileExType with content type ELEMENT_ONLY
class customerProfileExType (customerProfileBaseType):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileExType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'customerProfileExType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1533, 1)
    _ElementMap = customerProfileBaseType._ElementMap.copy()
    _AttributeMap = customerProfileBaseType._AttributeMap.copy()
    # Base type is customerProfileBaseType
    
    # Element merchantCustomerId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantCustomerId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileBaseType
    
    # Element description ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}description) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileBaseType
    
    # Element email ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}email) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileBaseType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileId uses Python identifier customerProfileId
    __customerProfileId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), 'customerProfileId', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerProfileExType_AnetApixmlv1schemaAnetApiSchema_xsdcustomerProfileId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1537, 5), )

    
    customerProfileId = property(__customerProfileId.value, __customerProfileId.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __customerProfileId.name() : __customerProfileId
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'customerProfileExType', customerProfileExType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerAddressType with content type ELEMENT_ONLY
class customerAddressType (nameAndAddressType):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerAddressType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'customerAddressType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1556, 1)
    _ElementMap = nameAndAddressType._ElementMap.copy()
    _AttributeMap = nameAndAddressType._AttributeMap.copy()
    # Base type is nameAndAddressType
    
    # Element firstName ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}firstName) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}nameAndAddressType
    
    # Element lastName ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}lastName) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}nameAndAddressType
    
    # Element company ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}company) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}nameAndAddressType
    
    # Element address ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}address) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}nameAndAddressType
    
    # Element city ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}city) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}nameAndAddressType
    
    # Element state ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}state) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}nameAndAddressType
    
    # Element zip ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}zip) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}nameAndAddressType
    
    # Element country ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}country) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}nameAndAddressType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}phoneNumber uses Python identifier phoneNumber
    __phoneNumber = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'phoneNumber'), 'phoneNumber', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerAddressType_AnetApixmlv1schemaAnetApiSchema_xsdphoneNumber', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1560, 5), )

    
    phoneNumber = property(__phoneNumber.value, __phoneNumber.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}faxNumber uses Python identifier faxNumber
    __faxNumber = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'faxNumber'), 'faxNumber', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerAddressType_AnetApixmlv1schemaAnetApiSchema_xsdfaxNumber', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1567, 5), )

    
    faxNumber = property(__faxNumber.value, __faxNumber.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}email uses Python identifier email
    __email = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'email'), 'email', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerAddressType_AnetApixmlv1schemaAnetApiSchema_xsdemail', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1574, 14), )

    
    email = property(__email.value, __email.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __phoneNumber.name() : __phoneNumber,
        __faxNumber.name() : __faxNumber,
        __email.name() : __email
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'customerAddressType', customerAddressType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransOrderType with content type ELEMENT_ONLY
class profileTransOrderType (profileTransAmountType):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransOrderType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'profileTransOrderType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1684, 1)
    _ElementMap = profileTransAmountType._ElementMap.copy()
    _AttributeMap = profileTransAmountType._AttributeMap.copy()
    # Base type is profileTransAmountType
    
    # Element amount ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}amount) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransAmountType
    
    # Element tax ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}tax) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransAmountType
    
    # Element shipping ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}shipping) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransAmountType
    
    # Element duty ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}duty) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransAmountType
    
    # Element lineItems ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}lineItems) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransAmountType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileId uses Python identifier customerProfileId
    __customerProfileId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), 'customerProfileId', '__AnetApixmlv1schemaAnetApiSchema_xsd_profileTransOrderType_AnetApixmlv1schemaAnetApiSchema_xsdcustomerProfileId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1688, 5), )

    
    customerProfileId = property(__customerProfileId.value, __customerProfileId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerPaymentProfileId uses Python identifier customerPaymentProfileId
    __customerPaymentProfileId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileId'), 'customerPaymentProfileId', '__AnetApixmlv1schemaAnetApiSchema_xsd_profileTransOrderType_AnetApixmlv1schemaAnetApiSchema_xsdcustomerPaymentProfileId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1689, 5), )

    
    customerPaymentProfileId = property(__customerPaymentProfileId.value, __customerPaymentProfileId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerShippingAddressId uses Python identifier customerShippingAddressId
    __customerShippingAddressId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerShippingAddressId'), 'customerShippingAddressId', '__AnetApixmlv1schemaAnetApiSchema_xsd_profileTransOrderType_AnetApixmlv1schemaAnetApiSchema_xsdcustomerShippingAddressId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1690, 5), )

    
    customerShippingAddressId = property(__customerShippingAddressId.value, __customerShippingAddressId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}order uses Python identifier order
    __order = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'order'), 'order', '__AnetApixmlv1schemaAnetApiSchema_xsd_profileTransOrderType_AnetApixmlv1schemaAnetApiSchema_xsdorder', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1691, 5), )

    
    order = property(__order.value, __order.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}taxExempt uses Python identifier taxExempt
    __taxExempt = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'taxExempt'), 'taxExempt', '__AnetApixmlv1schemaAnetApiSchema_xsd_profileTransOrderType_AnetApixmlv1schemaAnetApiSchema_xsdtaxExempt', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1692, 5), )

    
    taxExempt = property(__taxExempt.value, __taxExempt.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}recurringBilling uses Python identifier recurringBilling
    __recurringBilling = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'recurringBilling'), 'recurringBilling', '__AnetApixmlv1schemaAnetApiSchema_xsd_profileTransOrderType_AnetApixmlv1schemaAnetApiSchema_xsdrecurringBilling', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1693, 5), )

    
    recurringBilling = property(__recurringBilling.value, __recurringBilling.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}cardCode uses Python identifier cardCode
    __cardCode = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'cardCode'), 'cardCode', '__AnetApixmlv1schemaAnetApiSchema_xsd_profileTransOrderType_AnetApixmlv1schemaAnetApiSchema_xsdcardCode', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1694, 5), )

    
    cardCode = property(__cardCode.value, __cardCode.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}splitTenderId uses Python identifier splitTenderId
    __splitTenderId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'splitTenderId'), 'splitTenderId', '__AnetApixmlv1schemaAnetApiSchema_xsd_profileTransOrderType_AnetApixmlv1schemaAnetApiSchema_xsdsplitTenderId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1695, 5), )

    
    splitTenderId = property(__splitTenderId.value, __splitTenderId.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __customerProfileId.name() : __customerProfileId,
        __customerPaymentProfileId.name() : __customerPaymentProfileId,
        __customerShippingAddressId.name() : __customerShippingAddressId,
        __order.name() : __order,
        __taxExempt.name() : __taxExempt,
        __recurringBilling.name() : __recurringBilling,
        __cardCode.name() : __cardCode,
        __splitTenderId.name() : __splitTenderId
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'profileTransOrderType', profileTransOrderType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransPriorAuthCaptureType with content type ELEMENT_ONLY
class profileTransPriorAuthCaptureType (profileTransAmountType):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransPriorAuthCaptureType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'profileTransPriorAuthCaptureType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1716, 1)
    _ElementMap = profileTransAmountType._ElementMap.copy()
    _AttributeMap = profileTransAmountType._AttributeMap.copy()
    # Base type is profileTransAmountType
    
    # Element amount ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}amount) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransAmountType
    
    # Element tax ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}tax) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransAmountType
    
    # Element shipping ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}shipping) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransAmountType
    
    # Element duty ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}duty) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransAmountType
    
    # Element lineItems ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}lineItems) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransAmountType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileId uses Python identifier customerProfileId
    __customerProfileId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), 'customerProfileId', '__AnetApixmlv1schemaAnetApiSchema_xsd_profileTransPriorAuthCaptureType_AnetApixmlv1schemaAnetApiSchema_xsdcustomerProfileId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1720, 5), )

    
    customerProfileId = property(__customerProfileId.value, __customerProfileId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerPaymentProfileId uses Python identifier customerPaymentProfileId
    __customerPaymentProfileId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileId'), 'customerPaymentProfileId', '__AnetApixmlv1schemaAnetApiSchema_xsd_profileTransPriorAuthCaptureType_AnetApixmlv1schemaAnetApiSchema_xsdcustomerPaymentProfileId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1721, 5), )

    
    customerPaymentProfileId = property(__customerPaymentProfileId.value, __customerPaymentProfileId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerShippingAddressId uses Python identifier customerShippingAddressId
    __customerShippingAddressId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerShippingAddressId'), 'customerShippingAddressId', '__AnetApixmlv1schemaAnetApiSchema_xsd_profileTransPriorAuthCaptureType_AnetApixmlv1schemaAnetApiSchema_xsdcustomerShippingAddressId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1722, 5), )

    
    customerShippingAddressId = property(__customerShippingAddressId.value, __customerShippingAddressId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}transId uses Python identifier transId
    __transId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'transId'), 'transId', '__AnetApixmlv1schemaAnetApiSchema_xsd_profileTransPriorAuthCaptureType_AnetApixmlv1schemaAnetApiSchema_xsdtransId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1723, 5), )

    
    transId = property(__transId.value, __transId.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __customerProfileId.name() : __customerProfileId,
        __customerPaymentProfileId.name() : __customerPaymentProfileId,
        __customerShippingAddressId.name() : __customerShippingAddressId,
        __transId.name() : __transId
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'profileTransPriorAuthCaptureType', profileTransPriorAuthCaptureType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransRefundType with content type ELEMENT_ONLY
class profileTransRefundType (profileTransAmountType):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransRefundType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'profileTransRefundType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1747, 1)
    _ElementMap = profileTransAmountType._ElementMap.copy()
    _AttributeMap = profileTransAmountType._AttributeMap.copy()
    # Base type is profileTransAmountType
    
    # Element amount ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}amount) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransAmountType
    
    # Element tax ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}tax) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransAmountType
    
    # Element shipping ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}shipping) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransAmountType
    
    # Element duty ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}duty) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransAmountType
    
    # Element lineItems ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}lineItems) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransAmountType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileId uses Python identifier customerProfileId
    __customerProfileId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), 'customerProfileId', '__AnetApixmlv1schemaAnetApiSchema_xsd_profileTransRefundType_AnetApixmlv1schemaAnetApiSchema_xsdcustomerProfileId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1751, 5), )

    
    customerProfileId = property(__customerProfileId.value, __customerProfileId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerPaymentProfileId uses Python identifier customerPaymentProfileId
    __customerPaymentProfileId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileId'), 'customerPaymentProfileId', '__AnetApixmlv1schemaAnetApiSchema_xsd_profileTransRefundType_AnetApixmlv1schemaAnetApiSchema_xsdcustomerPaymentProfileId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1752, 5), )

    
    customerPaymentProfileId = property(__customerPaymentProfileId.value, __customerPaymentProfileId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerShippingAddressId uses Python identifier customerShippingAddressId
    __customerShippingAddressId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerShippingAddressId'), 'customerShippingAddressId', '__AnetApixmlv1schemaAnetApiSchema_xsd_profileTransRefundType_AnetApixmlv1schemaAnetApiSchema_xsdcustomerShippingAddressId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1753, 5), )

    
    customerShippingAddressId = property(__customerShippingAddressId.value, __customerShippingAddressId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}creditCardNumberMasked uses Python identifier creditCardNumberMasked
    __creditCardNumberMasked = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'creditCardNumberMasked'), 'creditCardNumberMasked', '__AnetApixmlv1schemaAnetApiSchema_xsd_profileTransRefundType_AnetApixmlv1schemaAnetApiSchema_xsdcreditCardNumberMasked', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1755, 5), )

    
    creditCardNumberMasked = property(__creditCardNumberMasked.value, __creditCardNumberMasked.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}bankRoutingNumberMasked uses Python identifier bankRoutingNumberMasked
    __bankRoutingNumberMasked = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'bankRoutingNumberMasked'), 'bankRoutingNumberMasked', '__AnetApixmlv1schemaAnetApiSchema_xsd_profileTransRefundType_AnetApixmlv1schemaAnetApiSchema_xsdbankRoutingNumberMasked', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1764, 5), )

    
    bankRoutingNumberMasked = property(__bankRoutingNumberMasked.value, __bankRoutingNumberMasked.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}bankAccountNumberMasked uses Python identifier bankAccountNumberMasked
    __bankAccountNumberMasked = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'bankAccountNumberMasked'), 'bankAccountNumberMasked', '__AnetApixmlv1schemaAnetApiSchema_xsd_profileTransRefundType_AnetApixmlv1schemaAnetApiSchema_xsdbankAccountNumberMasked', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1773, 5), )

    
    bankAccountNumberMasked = property(__bankAccountNumberMasked.value, __bankAccountNumberMasked.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}order uses Python identifier order
    __order = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'order'), 'order', '__AnetApixmlv1schemaAnetApiSchema_xsd_profileTransRefundType_AnetApixmlv1schemaAnetApiSchema_xsdorder', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1781, 5), )

    
    order = property(__order.value, __order.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}transId uses Python identifier transId
    __transId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'transId'), 'transId', '__AnetApixmlv1schemaAnetApiSchema_xsd_profileTransRefundType_AnetApixmlv1schemaAnetApiSchema_xsdtransId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1782, 5), )

    
    transId = property(__transId.value, __transId.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __customerProfileId.name() : __customerProfileId,
        __customerPaymentProfileId.name() : __customerPaymentProfileId,
        __customerShippingAddressId.name() : __customerShippingAddressId,
        __creditCardNumberMasked.name() : __creditCardNumberMasked,
        __bankRoutingNumberMasked.name() : __bankRoutingNumberMasked,
        __bankAccountNumberMasked.name() : __bankAccountNumberMasked,
        __order.name() : __order,
        __transId.name() : __transId
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'profileTransRefundType', profileTransRefundType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}emailSettingsType with content type ELEMENT_ONLY
class emailSettingsType (ArrayOfSetting):
    """Allowed values for settingName are: headerEmailReceipt and footerEmailReceipt"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'emailSettingsType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2152, 2)
    _ElementMap = ArrayOfSetting._ElementMap.copy()
    _AttributeMap = ArrayOfSetting._AttributeMap.copy()
    # Base type is ArrayOfSetting
    
    # Element setting ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}setting) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ArrayOfSetting
    
    # Attribute version uses Python identifier version
    __version = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'version'), 'version', '__AnetApixmlv1schemaAnetApiSchema_xsd_emailSettingsType_version', STD_ANON_95)
    __version._DeclarationLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2158, 8)
    __version._UseLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2158, 8)
    
    version = property(__version.value, __version.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        
    })
    _AttributeMap.update({
        __version.name() : __version
    })
Namespace.addCategoryObject('typeBinding', 'emailSettingsType', emailSettingsType)


# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_23 (ANetApiResponse):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2261, 2)
    _ElementMap = ANetApiResponse._ElementMap.copy()
    _AttributeMap = ANetApiResponse._AttributeMap.copy()
    # Base type is ANetApiResponse
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element messages ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}messages) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element sessionToken ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}sessionToken) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    _HasWildcardElement = True
    _ElementMap.update({
        
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_24 (ANetApiRequest):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2275, 2)
    _ElementMap = ANetApiRequest._ElementMap.copy()
    _AttributeMap = ANetApiRequest._AttributeMap.copy()
    # Base type is ANetApiRequest
    
    # Element merchantAuthentication ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantAuthentication) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    _HasWildcardElement = True
    _ElementMap.update({
        
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_25 (ANetApiResponse):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2289, 2)
    _ElementMap = ANetApiResponse._ElementMap.copy()
    _AttributeMap = ANetApiResponse._AttributeMap.copy()
    # Base type is ANetApiResponse
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element messages ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}messages) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element sessionToken ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}sessionToken) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    _HasWildcardElement = True
    _ElementMap.update({
        
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_26 (ANetApiRequest):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2304, 2)
    _ElementMap = ANetApiRequest._ElementMap.copy()
    _AttributeMap = ANetApiRequest._AttributeMap.copy()
    # Base type is ANetApiRequest
    
    # Element merchantAuthentication ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantAuthentication) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}subscription uses Python identifier subscription
    __subscription = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'subscription'), 'subscription', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_26_AnetApixmlv1schemaAnetApiSchema_xsdsubscription', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2308, 6), )

    
    subscription = property(__subscription.value, __subscription.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __subscription.name() : __subscription
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_27 (ANetApiResponse):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2323, 2)
    _ElementMap = ANetApiResponse._ElementMap.copy()
    _AttributeMap = ANetApiResponse._AttributeMap.copy()
    # Base type is ANetApiResponse
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element messages ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}messages) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element sessionToken ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}sessionToken) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}subscriptionId uses Python identifier subscriptionId
    __subscriptionId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'subscriptionId'), 'subscriptionId', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_27_AnetApixmlv1schemaAnetApiSchema_xsdsubscriptionId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2328, 6), )

    
    subscriptionId = property(__subscriptionId.value, __subscriptionId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profile uses Python identifier profile
    __profile = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'profile'), 'profile', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_27_AnetApixmlv1schemaAnetApiSchema_xsdprofile', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2329, 6), )

    
    profile = property(__profile.value, __profile.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __subscriptionId.name() : __subscriptionId,
        __profile.name() : __profile
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_28 (ANetApiRequest):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2344, 2)
    _ElementMap = ANetApiRequest._ElementMap.copy()
    _AttributeMap = ANetApiRequest._AttributeMap.copy()
    # Base type is ANetApiRequest
    
    # Element merchantAuthentication ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantAuthentication) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}subscriptionId uses Python identifier subscriptionId
    __subscriptionId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'subscriptionId'), 'subscriptionId', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_28_AnetApixmlv1schemaAnetApiSchema_xsdsubscriptionId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2348, 6), )

    
    subscriptionId = property(__subscriptionId.value, __subscriptionId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}subscription uses Python identifier subscription
    __subscription = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'subscription'), 'subscription', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_28_AnetApixmlv1schemaAnetApiSchema_xsdsubscription', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2349, 6), )

    
    subscription = property(__subscription.value, __subscription.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __subscriptionId.name() : __subscriptionId,
        __subscription.name() : __subscription
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_29 (ANetApiResponse):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2363, 2)
    _ElementMap = ANetApiResponse._ElementMap.copy()
    _AttributeMap = ANetApiResponse._AttributeMap.copy()
    # Base type is ANetApiResponse
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element messages ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}messages) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element sessionToken ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}sessionToken) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profile uses Python identifier profile
    __profile = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'profile'), 'profile', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_29_AnetApixmlv1schemaAnetApiSchema_xsdprofile', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2367, 12), )

    
    profile = property(__profile.value, __profile.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __profile.name() : __profile
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_30 (ANetApiRequest):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2382, 2)
    _ElementMap = ANetApiRequest._ElementMap.copy()
    _AttributeMap = ANetApiRequest._AttributeMap.copy()
    # Base type is ANetApiRequest
    
    # Element merchantAuthentication ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantAuthentication) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}subscriptionId uses Python identifier subscriptionId
    __subscriptionId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'subscriptionId'), 'subscriptionId', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_30_AnetApixmlv1schemaAnetApiSchema_xsdsubscriptionId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2386, 6), )

    
    subscriptionId = property(__subscriptionId.value, __subscriptionId.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __subscriptionId.name() : __subscriptionId
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_31 (ANetApiResponse):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2400, 2)
    _ElementMap = ANetApiResponse._ElementMap.copy()
    _AttributeMap = ANetApiResponse._AttributeMap.copy()
    # Base type is ANetApiResponse
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element messages ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}messages) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element sessionToken ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}sessionToken) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    _HasWildcardElement = True
    _ElementMap.update({
        
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_32 (ANetApiRequest):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2415, 2)
    _ElementMap = ANetApiRequest._ElementMap.copy()
    _AttributeMap = ANetApiRequest._AttributeMap.copy()
    # Base type is ANetApiRequest
    
    # Element merchantAuthentication ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantAuthentication) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}subscriptionId uses Python identifier subscriptionId
    __subscriptionId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'subscriptionId'), 'subscriptionId', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_32_AnetApixmlv1schemaAnetApiSchema_xsdsubscriptionId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2419, 6), )

    
    subscriptionId = property(__subscriptionId.value, __subscriptionId.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __subscriptionId.name() : __subscriptionId
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_33 (ANetApiResponse):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2433, 2)
    _ElementMap = ANetApiResponse._ElementMap.copy()
    _AttributeMap = ANetApiResponse._AttributeMap.copy()
    # Base type is ANetApiResponse
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element messages ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}messages) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element sessionToken ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}sessionToken) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}status uses Python identifier status
    __status = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'status'), 'status', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_33_AnetApixmlv1schemaAnetApiSchema_xsdstatus', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2437, 6), )

    
    status = property(__status.value, __status.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __status.name() : __status
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_34 (ANetApiRequest):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2453, 2)
    _ElementMap = ANetApiRequest._ElementMap.copy()
    _AttributeMap = ANetApiRequest._AttributeMap.copy()
    # Base type is ANetApiRequest
    
    # Element merchantAuthentication ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantAuthentication) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profile uses Python identifier profile
    __profile = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'profile'), 'profile', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_34_AnetApixmlv1schemaAnetApiSchema_xsdprofile', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2457, 6), )

    
    profile = property(__profile.value, __profile.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}validationMode uses Python identifier validationMode
    __validationMode = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'validationMode'), 'validationMode', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_34_AnetApixmlv1schemaAnetApiSchema_xsdvalidationMode', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2458, 6), )

    
    validationMode = property(__validationMode.value, __validationMode.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __profile.name() : __profile,
        __validationMode.name() : __validationMode
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_35 (ANetApiResponse):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2472, 2)
    _ElementMap = ANetApiResponse._ElementMap.copy()
    _AttributeMap = ANetApiResponse._AttributeMap.copy()
    # Base type is ANetApiResponse
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element messages ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}messages) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element sessionToken ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}sessionToken) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileId uses Python identifier customerProfileId
    __customerProfileId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), 'customerProfileId', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_35_AnetApixmlv1schemaAnetApiSchema_xsdcustomerProfileId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2477, 6), )

    
    customerProfileId = property(__customerProfileId.value, __customerProfileId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerPaymentProfileIdList uses Python identifier customerPaymentProfileIdList
    __customerPaymentProfileIdList = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileIdList'), 'customerPaymentProfileIdList', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_35_AnetApixmlv1schemaAnetApiSchema_xsdcustomerPaymentProfileIdList', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2478, 6), )

    
    customerPaymentProfileIdList = property(__customerPaymentProfileIdList.value, __customerPaymentProfileIdList.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerShippingAddressIdList uses Python identifier customerShippingAddressIdList
    __customerShippingAddressIdList = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerShippingAddressIdList'), 'customerShippingAddressIdList', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_35_AnetApixmlv1schemaAnetApiSchema_xsdcustomerShippingAddressIdList', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2479, 6), )

    
    customerShippingAddressIdList = property(__customerShippingAddressIdList.value, __customerShippingAddressIdList.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}validationDirectResponseList uses Python identifier validationDirectResponseList
    __validationDirectResponseList = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'validationDirectResponseList'), 'validationDirectResponseList', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_35_AnetApixmlv1schemaAnetApiSchema_xsdvalidationDirectResponseList', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2480, 6), )

    
    validationDirectResponseList = property(__validationDirectResponseList.value, __validationDirectResponseList.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __customerProfileId.name() : __customerProfileId,
        __customerPaymentProfileIdList.name() : __customerPaymentProfileIdList,
        __customerShippingAddressIdList.name() : __customerShippingAddressIdList,
        __validationDirectResponseList.name() : __validationDirectResponseList
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_36 (ANetApiRequest):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2513, 2)
    _ElementMap = ANetApiRequest._ElementMap.copy()
    _AttributeMap = ANetApiRequest._AttributeMap.copy()
    # Base type is ANetApiRequest
    
    # Element merchantAuthentication ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantAuthentication) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileId uses Python identifier customerProfileId
    __customerProfileId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), 'customerProfileId', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_36_AnetApixmlv1schemaAnetApiSchema_xsdcustomerProfileId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2517, 6), )

    
    customerProfileId = property(__customerProfileId.value, __customerProfileId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}paymentProfile uses Python identifier paymentProfile
    __paymentProfile = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'paymentProfile'), 'paymentProfile', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_36_AnetApixmlv1schemaAnetApiSchema_xsdpaymentProfile', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2518, 6), )

    
    paymentProfile = property(__paymentProfile.value, __paymentProfile.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}validationMode uses Python identifier validationMode
    __validationMode = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'validationMode'), 'validationMode', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_36_AnetApixmlv1schemaAnetApiSchema_xsdvalidationMode', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2519, 6), )

    
    validationMode = property(__validationMode.value, __validationMode.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __customerProfileId.name() : __customerProfileId,
        __paymentProfile.name() : __paymentProfile,
        __validationMode.name() : __validationMode
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_37 (ANetApiResponse):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2533, 2)
    _ElementMap = ANetApiResponse._ElementMap.copy()
    _AttributeMap = ANetApiResponse._AttributeMap.copy()
    # Base type is ANetApiResponse
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element messages ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}messages) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element sessionToken ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}sessionToken) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileId uses Python identifier customerProfileId
    __customerProfileId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), 'customerProfileId', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_37_AnetApixmlv1schemaAnetApiSchema_xsdcustomerProfileId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2539, 12), )

    
    customerProfileId = property(__customerProfileId.value, __customerProfileId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerPaymentProfileId uses Python identifier customerPaymentProfileId
    __customerPaymentProfileId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileId'), 'customerPaymentProfileId', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_37_AnetApixmlv1schemaAnetApiSchema_xsdcustomerPaymentProfileId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2540, 12), )

    
    customerPaymentProfileId = property(__customerPaymentProfileId.value, __customerPaymentProfileId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}validationDirectResponse uses Python identifier validationDirectResponse
    __validationDirectResponse = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'validationDirectResponse'), 'validationDirectResponse', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_37_AnetApixmlv1schemaAnetApiSchema_xsdvalidationDirectResponse', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2542, 6), )

    
    validationDirectResponse = property(__validationDirectResponse.value, __validationDirectResponse.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __customerProfileId.name() : __customerProfileId,
        __customerPaymentProfileId.name() : __customerPaymentProfileId,
        __validationDirectResponse.name() : __validationDirectResponse
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_38 (ANetApiRequest):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2563, 2)
    _ElementMap = ANetApiRequest._ElementMap.copy()
    _AttributeMap = ANetApiRequest._AttributeMap.copy()
    # Base type is ANetApiRequest
    
    # Element merchantAuthentication ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantAuthentication) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileId uses Python identifier customerProfileId
    __customerProfileId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), 'customerProfileId', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_38_AnetApixmlv1schemaAnetApiSchema_xsdcustomerProfileId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2567, 6), )

    
    customerProfileId = property(__customerProfileId.value, __customerProfileId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}address uses Python identifier address
    __address = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'address'), 'address', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_38_AnetApixmlv1schemaAnetApiSchema_xsdaddress', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2568, 6), )

    
    address = property(__address.value, __address.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __customerProfileId.name() : __customerProfileId,
        __address.name() : __address
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_39 (ANetApiResponse):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2582, 2)
    _ElementMap = ANetApiResponse._ElementMap.copy()
    _AttributeMap = ANetApiResponse._AttributeMap.copy()
    # Base type is ANetApiResponse
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element messages ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}messages) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element sessionToken ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}sessionToken) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileId uses Python identifier customerProfileId
    __customerProfileId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), 'customerProfileId', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_39_AnetApixmlv1schemaAnetApiSchema_xsdcustomerProfileId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2588, 12), )

    
    customerProfileId = property(__customerProfileId.value, __customerProfileId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerAddressId uses Python identifier customerAddressId
    __customerAddressId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerAddressId'), 'customerAddressId', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_39_AnetApixmlv1schemaAnetApiSchema_xsdcustomerAddressId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2589, 12), )

    
    customerAddressId = property(__customerAddressId.value, __customerAddressId.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __customerProfileId.name() : __customerProfileId,
        __customerAddressId.name() : __customerAddressId
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_40 (ANetApiRequest):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2603, 4)
    _ElementMap = ANetApiRequest._ElementMap.copy()
    _AttributeMap = ANetApiRequest._AttributeMap.copy()
    # Base type is ANetApiRequest
    
    # Element merchantAuthentication ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantAuthentication) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}transId uses Python identifier transId
    __transId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'transId'), 'transId', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_40_AnetApixmlv1schemaAnetApiSchema_xsdtransId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2607, 12), )

    
    transId = property(__transId.value, __transId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customer uses Python identifier customer
    __customer = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customer'), 'customer', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_40_AnetApixmlv1schemaAnetApiSchema_xsdcustomer', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2608, 12), )

    
    customer = property(__customer.value, __customer.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileId uses Python identifier customerProfileId
    __customerProfileId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), 'customerProfileId', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_40_AnetApixmlv1schemaAnetApiSchema_xsdcustomerProfileId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2609, 12), )

    
    customerProfileId = property(__customerProfileId.value, __customerProfileId.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __transId.name() : __transId,
        __customer.name() : __customer,
        __customerProfileId.name() : __customerProfileId
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_41 (ANetApiRequest):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2626, 2)
    _ElementMap = ANetApiRequest._ElementMap.copy()
    _AttributeMap = ANetApiRequest._AttributeMap.copy()
    # Base type is ANetApiRequest
    
    # Element merchantAuthentication ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantAuthentication) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileId uses Python identifier customerProfileId
    __customerProfileId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), 'customerProfileId', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_41_AnetApixmlv1schemaAnetApiSchema_xsdcustomerProfileId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2630, 12), )

    
    customerProfileId = property(__customerProfileId.value, __customerProfileId.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __customerProfileId.name() : __customerProfileId
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_42 (ANetApiResponse):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2644, 4)
    _ElementMap = ANetApiResponse._ElementMap.copy()
    _AttributeMap = ANetApiResponse._AttributeMap.copy()
    # Base type is ANetApiResponse
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element messages ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}messages) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element sessionToken ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}sessionToken) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profile uses Python identifier profile
    __profile = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'profile'), 'profile', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_42_AnetApixmlv1schemaAnetApiSchema_xsdprofile', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2649, 12), )

    
    profile = property(__profile.value, __profile.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}subscriptionIds uses Python identifier subscriptionIds
    __subscriptionIds = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'subscriptionIds'), 'subscriptionIds', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_42_AnetApixmlv1schemaAnetApiSchema_xsdsubscriptionIds', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2650, 12), )

    
    subscriptionIds = property(__subscriptionIds.value, __subscriptionIds.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __profile.name() : __profile,
        __subscriptionIds.name() : __subscriptionIds
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_43 (ANetApiRequest):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2665, 4)
    _ElementMap = ANetApiRequest._ElementMap.copy()
    _AttributeMap = ANetApiRequest._AttributeMap.copy()
    # Base type is ANetApiRequest
    
    # Element merchantAuthentication ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantAuthentication) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileId uses Python identifier customerProfileId
    __customerProfileId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), 'customerProfileId', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_43_AnetApixmlv1schemaAnetApiSchema_xsdcustomerProfileId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2669, 12), )

    
    customerProfileId = property(__customerProfileId.value, __customerProfileId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerPaymentProfileId uses Python identifier customerPaymentProfileId
    __customerPaymentProfileId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileId'), 'customerPaymentProfileId', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_43_AnetApixmlv1schemaAnetApiSchema_xsdcustomerPaymentProfileId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2670, 12), )

    
    customerPaymentProfileId = property(__customerPaymentProfileId.value, __customerPaymentProfileId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}unmaskExpirationDate uses Python identifier unmaskExpirationDate
    __unmaskExpirationDate = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'unmaskExpirationDate'), 'unmaskExpirationDate', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_43_AnetApixmlv1schemaAnetApiSchema_xsdunmaskExpirationDate', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2671, 12), )

    
    unmaskExpirationDate = property(__unmaskExpirationDate.value, __unmaskExpirationDate.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __customerProfileId.name() : __customerProfileId,
        __customerPaymentProfileId.name() : __customerPaymentProfileId,
        __unmaskExpirationDate.name() : __unmaskExpirationDate
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_44 (ANetApiResponse):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2686, 4)
    _ElementMap = ANetApiResponse._ElementMap.copy()
    _AttributeMap = ANetApiResponse._AttributeMap.copy()
    # Base type is ANetApiResponse
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element messages ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}messages) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element sessionToken ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}sessionToken) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}paymentProfile uses Python identifier paymentProfile
    __paymentProfile = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'paymentProfile'), 'paymentProfile', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_44_AnetApixmlv1schemaAnetApiSchema_xsdpaymentProfile', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2691, 12), )

    
    paymentProfile = property(__paymentProfile.value, __paymentProfile.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __paymentProfile.name() : __paymentProfile
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_45 (ANetApiRequest):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2706, 4)
    _ElementMap = ANetApiRequest._ElementMap.copy()
    _AttributeMap = ANetApiRequest._AttributeMap.copy()
    # Base type is ANetApiRequest
    
    # Element merchantAuthentication ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantAuthentication) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileId uses Python identifier customerProfileId
    __customerProfileId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), 'customerProfileId', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_45_AnetApixmlv1schemaAnetApiSchema_xsdcustomerProfileId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2710, 12), )

    
    customerProfileId = property(__customerProfileId.value, __customerProfileId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerAddressId uses Python identifier customerAddressId
    __customerAddressId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerAddressId'), 'customerAddressId', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_45_AnetApixmlv1schemaAnetApiSchema_xsdcustomerAddressId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2711, 12), )

    
    customerAddressId = property(__customerAddressId.value, __customerAddressId.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __customerProfileId.name() : __customerProfileId,
        __customerAddressId.name() : __customerAddressId
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_46 (ANetApiResponse):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2725, 4)
    _ElementMap = ANetApiResponse._ElementMap.copy()
    _AttributeMap = ANetApiResponse._AttributeMap.copy()
    # Base type is ANetApiResponse
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element messages ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}messages) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element sessionToken ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}sessionToken) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}address uses Python identifier address
    __address = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'address'), 'address', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_46_AnetApixmlv1schemaAnetApiSchema_xsdaddress', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2730, 12), )

    
    address = property(__address.value, __address.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}subscriptionIds uses Python identifier subscriptionIds
    __subscriptionIds = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'subscriptionIds'), 'subscriptionIds', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_46_AnetApixmlv1schemaAnetApiSchema_xsdsubscriptionIds', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2731, 12), )

    
    subscriptionIds = property(__subscriptionIds.value, __subscriptionIds.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __address.name() : __address,
        __subscriptionIds.name() : __subscriptionIds
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_47 (ANetApiRequest):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2746, 4)
    _ElementMap = ANetApiRequest._ElementMap.copy()
    _AttributeMap = ANetApiRequest._AttributeMap.copy()
    # Base type is ANetApiRequest
    
    # Element merchantAuthentication ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantAuthentication) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profile uses Python identifier profile
    __profile = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'profile'), 'profile', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_47_AnetApixmlv1schemaAnetApiSchema_xsdprofile', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2750, 12), )

    
    profile = property(__profile.value, __profile.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __profile.name() : __profile
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_48 (ANetApiResponse):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2764, 4)
    _ElementMap = ANetApiResponse._ElementMap.copy()
    _AttributeMap = ANetApiResponse._AttributeMap.copy()
    # Base type is ANetApiResponse
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element messages ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}messages) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element sessionToken ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}sessionToken) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    _HasWildcardElement = True
    _ElementMap.update({
        
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_49 (ANetApiRequest):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2779, 4)
    _ElementMap = ANetApiRequest._ElementMap.copy()
    _AttributeMap = ANetApiRequest._AttributeMap.copy()
    # Base type is ANetApiRequest
    
    # Element merchantAuthentication ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantAuthentication) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileId uses Python identifier customerProfileId
    __customerProfileId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), 'customerProfileId', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_49_AnetApixmlv1schemaAnetApiSchema_xsdcustomerProfileId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2783, 12), )

    
    customerProfileId = property(__customerProfileId.value, __customerProfileId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}paymentProfile uses Python identifier paymentProfile
    __paymentProfile = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'paymentProfile'), 'paymentProfile', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_49_AnetApixmlv1schemaAnetApiSchema_xsdpaymentProfile', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2784, 12), )

    
    paymentProfile = property(__paymentProfile.value, __paymentProfile.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}validationMode uses Python identifier validationMode
    __validationMode = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'validationMode'), 'validationMode', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_49_AnetApixmlv1schemaAnetApiSchema_xsdvalidationMode', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2785, 12), )

    
    validationMode = property(__validationMode.value, __validationMode.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __customerProfileId.name() : __customerProfileId,
        __paymentProfile.name() : __paymentProfile,
        __validationMode.name() : __validationMode
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_50 (ANetApiResponse):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2799, 4)
    _ElementMap = ANetApiResponse._ElementMap.copy()
    _AttributeMap = ANetApiResponse._AttributeMap.copy()
    # Base type is ANetApiResponse
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element messages ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}messages) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element sessionToken ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}sessionToken) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}validationDirectResponse uses Python identifier validationDirectResponse
    __validationDirectResponse = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'validationDirectResponse'), 'validationDirectResponse', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_50_AnetApixmlv1schemaAnetApiSchema_xsdvalidationDirectResponse', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2804, 12), )

    
    validationDirectResponse = property(__validationDirectResponse.value, __validationDirectResponse.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __validationDirectResponse.name() : __validationDirectResponse
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_51 (ANetApiRequest):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2825, 4)
    _ElementMap = ANetApiRequest._ElementMap.copy()
    _AttributeMap = ANetApiRequest._AttributeMap.copy()
    # Base type is ANetApiRequest
    
    # Element merchantAuthentication ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantAuthentication) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileId uses Python identifier customerProfileId
    __customerProfileId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), 'customerProfileId', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_51_AnetApixmlv1schemaAnetApiSchema_xsdcustomerProfileId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2829, 12), )

    
    customerProfileId = property(__customerProfileId.value, __customerProfileId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}address uses Python identifier address
    __address = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'address'), 'address', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_51_AnetApixmlv1schemaAnetApiSchema_xsdaddress', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2830, 12), )

    
    address = property(__address.value, __address.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __customerProfileId.name() : __customerProfileId,
        __address.name() : __address
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_52 (ANetApiResponse):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2844, 4)
    _ElementMap = ANetApiResponse._ElementMap.copy()
    _AttributeMap = ANetApiResponse._AttributeMap.copy()
    # Base type is ANetApiResponse
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element messages ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}messages) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element sessionToken ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}sessionToken) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    _HasWildcardElement = True
    _ElementMap.update({
        
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_53 (ANetApiRequest):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2860, 4)
    _ElementMap = ANetApiRequest._ElementMap.copy()
    _AttributeMap = ANetApiRequest._AttributeMap.copy()
    # Base type is ANetApiRequest
    
    # Element merchantAuthentication ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantAuthentication) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileId uses Python identifier customerProfileId
    __customerProfileId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), 'customerProfileId', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_53_AnetApixmlv1schemaAnetApiSchema_xsdcustomerProfileId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2864, 12), )

    
    customerProfileId = property(__customerProfileId.value, __customerProfileId.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __customerProfileId.name() : __customerProfileId
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_54 (ANetApiResponse):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2878, 4)
    _ElementMap = ANetApiResponse._ElementMap.copy()
    _AttributeMap = ANetApiResponse._AttributeMap.copy()
    # Base type is ANetApiResponse
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element messages ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}messages) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element sessionToken ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}sessionToken) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    _HasWildcardElement = True
    _ElementMap.update({
        
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_55 (ANetApiRequest):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2893, 4)
    _ElementMap = ANetApiRequest._ElementMap.copy()
    _AttributeMap = ANetApiRequest._AttributeMap.copy()
    # Base type is ANetApiRequest
    
    # Element merchantAuthentication ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantAuthentication) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileId uses Python identifier customerProfileId
    __customerProfileId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), 'customerProfileId', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_55_AnetApixmlv1schemaAnetApiSchema_xsdcustomerProfileId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2897, 12), )

    
    customerProfileId = property(__customerProfileId.value, __customerProfileId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerPaymentProfileId uses Python identifier customerPaymentProfileId
    __customerPaymentProfileId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileId'), 'customerPaymentProfileId', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_55_AnetApixmlv1schemaAnetApiSchema_xsdcustomerPaymentProfileId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2898, 12), )

    
    customerPaymentProfileId = property(__customerPaymentProfileId.value, __customerPaymentProfileId.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __customerProfileId.name() : __customerProfileId,
        __customerPaymentProfileId.name() : __customerPaymentProfileId
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_56 (ANetApiResponse):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2912, 4)
    _ElementMap = ANetApiResponse._ElementMap.copy()
    _AttributeMap = ANetApiResponse._AttributeMap.copy()
    # Base type is ANetApiResponse
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element messages ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}messages) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element sessionToken ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}sessionToken) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    _HasWildcardElement = True
    _ElementMap.update({
        
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_57 (ANetApiRequest):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2927, 4)
    _ElementMap = ANetApiRequest._ElementMap.copy()
    _AttributeMap = ANetApiRequest._AttributeMap.copy()
    # Base type is ANetApiRequest
    
    # Element merchantAuthentication ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantAuthentication) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileId uses Python identifier customerProfileId
    __customerProfileId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), 'customerProfileId', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_57_AnetApixmlv1schemaAnetApiSchema_xsdcustomerProfileId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2931, 12), )

    
    customerProfileId = property(__customerProfileId.value, __customerProfileId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerAddressId uses Python identifier customerAddressId
    __customerAddressId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerAddressId'), 'customerAddressId', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_57_AnetApixmlv1schemaAnetApiSchema_xsdcustomerAddressId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2932, 12), )

    
    customerAddressId = property(__customerAddressId.value, __customerAddressId.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __customerProfileId.name() : __customerProfileId,
        __customerAddressId.name() : __customerAddressId
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_58 (ANetApiResponse):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2946, 4)
    _ElementMap = ANetApiResponse._ElementMap.copy()
    _AttributeMap = ANetApiResponse._AttributeMap.copy()
    # Base type is ANetApiResponse
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element messages ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}messages) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element sessionToken ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}sessionToken) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    _HasWildcardElement = True
    _ElementMap.update({
        
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_59 (ANetApiRequest):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2961, 4)
    _ElementMap = ANetApiRequest._ElementMap.copy()
    _AttributeMap = ANetApiRequest._AttributeMap.copy()
    # Base type is ANetApiRequest
    
    # Element merchantAuthentication ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantAuthentication) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}transaction uses Python identifier transaction
    __transaction = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'transaction'), 'transaction', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_59_AnetApixmlv1schemaAnetApiSchema_xsdtransaction', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2965, 12), )

    
    transaction = property(__transaction.value, __transaction.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}extraOptions uses Python identifier extraOptions
    __extraOptions = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'extraOptions'), 'extraOptions', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_59_AnetApixmlv1schemaAnetApiSchema_xsdextraOptions', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2966, 12), )

    
    extraOptions = property(__extraOptions.value, __extraOptions.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __transaction.name() : __transaction,
        __extraOptions.name() : __extraOptions
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_60 (ANetApiResponse):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2986, 4)
    _ElementMap = ANetApiResponse._ElementMap.copy()
    _AttributeMap = ANetApiResponse._AttributeMap.copy()
    # Base type is ANetApiResponse
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element messages ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}messages) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element sessionToken ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}sessionToken) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}transactionResponse uses Python identifier transactionResponse
    __transactionResponse = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'transactionResponse'), 'transactionResponse', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_60_AnetApixmlv1schemaAnetApiSchema_xsdtransactionResponse', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2990, 48), )

    
    transactionResponse = property(__transactionResponse.value, __transactionResponse.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}directResponse uses Python identifier directResponse
    __directResponse = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'directResponse'), 'directResponse', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_60_AnetApixmlv1schemaAnetApiSchema_xsddirectResponse', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2991, 12), )

    
    directResponse = property(__directResponse.value, __directResponse.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __transactionResponse.name() : __transactionResponse,
        __directResponse.name() : __directResponse
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_61 (ANetApiRequest):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3012, 4)
    _ElementMap = ANetApiRequest._ElementMap.copy()
    _AttributeMap = ANetApiRequest._AttributeMap.copy()
    # Base type is ANetApiRequest
    
    # Element merchantAuthentication ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantAuthentication) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileId uses Python identifier customerProfileId
    __customerProfileId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), 'customerProfileId', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_61_AnetApixmlv1schemaAnetApiSchema_xsdcustomerProfileId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3016, 12), )

    
    customerProfileId = property(__customerProfileId.value, __customerProfileId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerPaymentProfileId uses Python identifier customerPaymentProfileId
    __customerPaymentProfileId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileId'), 'customerPaymentProfileId', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_61_AnetApixmlv1schemaAnetApiSchema_xsdcustomerPaymentProfileId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3017, 12), )

    
    customerPaymentProfileId = property(__customerPaymentProfileId.value, __customerPaymentProfileId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerShippingAddressId uses Python identifier customerShippingAddressId
    __customerShippingAddressId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerShippingAddressId'), 'customerShippingAddressId', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_61_AnetApixmlv1schemaAnetApiSchema_xsdcustomerShippingAddressId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3018, 12), )

    
    customerShippingAddressId = property(__customerShippingAddressId.value, __customerShippingAddressId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}cardCode uses Python identifier cardCode
    __cardCode = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'cardCode'), 'cardCode', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_61_AnetApixmlv1schemaAnetApiSchema_xsdcardCode', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3019, 12), )

    
    cardCode = property(__cardCode.value, __cardCode.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}validationMode uses Python identifier validationMode
    __validationMode = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'validationMode'), 'validationMode', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_61_AnetApixmlv1schemaAnetApiSchema_xsdvalidationMode', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3020, 12), )

    
    validationMode = property(__validationMode.value, __validationMode.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __customerProfileId.name() : __customerProfileId,
        __customerPaymentProfileId.name() : __customerPaymentProfileId,
        __customerShippingAddressId.name() : __customerShippingAddressId,
        __cardCode.name() : __cardCode,
        __validationMode.name() : __validationMode
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_62 (ANetApiResponse):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3034, 4)
    _ElementMap = ANetApiResponse._ElementMap.copy()
    _AttributeMap = ANetApiResponse._AttributeMap.copy()
    # Base type is ANetApiResponse
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element messages ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}messages) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element sessionToken ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}sessionToken) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}directResponse uses Python identifier directResponse
    __directResponse = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'directResponse'), 'directResponse', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_62_AnetApixmlv1schemaAnetApiSchema_xsddirectResponse', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3038, 12), )

    
    directResponse = property(__directResponse.value, __directResponse.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __directResponse.name() : __directResponse
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_63 (ANetApiRequest):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3059, 4)
    _ElementMap = ANetApiRequest._ElementMap.copy()
    _AttributeMap = ANetApiRequest._AttributeMap.copy()
    # Base type is ANetApiRequest
    
    # Element merchantAuthentication ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantAuthentication) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    _HasWildcardElement = True
    _ElementMap.update({
        
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_64 (ANetApiResponse):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3073, 4)
    _ElementMap = ANetApiResponse._ElementMap.copy()
    _AttributeMap = ANetApiResponse._AttributeMap.copy()
    # Base type is ANetApiResponse
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element messages ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}messages) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element sessionToken ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}sessionToken) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ids uses Python identifier ids
    __ids = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'ids'), 'ids', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_64_AnetApixmlv1schemaAnetApiSchema_xsdids', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3077, 12), )

    
    ids = property(__ids.value, __ids.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __ids.name() : __ids
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_65 (ANetApiRequest):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3091, 4)
    _ElementMap = ANetApiRequest._ElementMap.copy()
    _AttributeMap = ANetApiRequest._AttributeMap.copy()
    # Base type is ANetApiRequest
    
    # Element merchantAuthentication ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantAuthentication) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}splitTenderId uses Python identifier splitTenderId
    __splitTenderId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'splitTenderId'), 'splitTenderId', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_65_AnetApixmlv1schemaAnetApiSchema_xsdsplitTenderId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3095, 12), )

    
    splitTenderId = property(__splitTenderId.value, __splitTenderId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}splitTenderStatus uses Python identifier splitTenderStatus
    __splitTenderStatus = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'splitTenderStatus'), 'splitTenderStatus', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_65_AnetApixmlv1schemaAnetApiSchema_xsdsplitTenderStatus', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3096, 12), )

    
    splitTenderStatus = property(__splitTenderStatus.value, __splitTenderStatus.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __splitTenderId.name() : __splitTenderId,
        __splitTenderStatus.name() : __splitTenderStatus
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_66 (ANetApiResponse):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3110, 4)
    _ElementMap = ANetApiResponse._ElementMap.copy()
    _AttributeMap = ANetApiResponse._AttributeMap.copy()
    # Base type is ANetApiResponse
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element messages ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}messages) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element sessionToken ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}sessionToken) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    _HasWildcardElement = True
    _ElementMap.update({
        
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_67 (ANetApiRequest):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3124, 4)
    _ElementMap = ANetApiRequest._ElementMap.copy()
    _AttributeMap = ANetApiRequest._AttributeMap.copy()
    # Base type is ANetApiRequest
    
    # Element merchantAuthentication ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantAuthentication) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}transId uses Python identifier transId
    __transId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'transId'), 'transId', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_67_AnetApixmlv1schemaAnetApiSchema_xsdtransId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3128, 12), )

    
    transId = property(__transId.value, __transId.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __transId.name() : __transId
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_68 (ANetApiResponse):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3142, 2)
    _ElementMap = ANetApiResponse._ElementMap.copy()
    _AttributeMap = ANetApiResponse._AttributeMap.copy()
    # Base type is ANetApiResponse
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element messages ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}messages) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element sessionToken ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}sessionToken) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}transaction uses Python identifier transaction
    __transaction = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'transaction'), 'transaction', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_68_AnetApixmlv1schemaAnetApiSchema_xsdtransaction', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3146, 6), )

    
    transaction = property(__transaction.value, __transaction.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __transaction.name() : __transaction
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_69 (ANetApiRequest):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3161, 2)
    _ElementMap = ANetApiRequest._ElementMap.copy()
    _AttributeMap = ANetApiRequest._AttributeMap.copy()
    # Base type is ANetApiRequest
    
    # Element merchantAuthentication ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantAuthentication) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}transactionRequest uses Python identifier transactionRequest
    __transactionRequest = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'transactionRequest'), 'transactionRequest', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_69_AnetApixmlv1schemaAnetApiSchema_xsdtransactionRequest', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3165, 6), )

    
    transactionRequest = property(__transactionRequest.value, __transactionRequest.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __transactionRequest.name() : __transactionRequest
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_70 (ANetApiResponse):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3180, 2)
    _ElementMap = ANetApiResponse._ElementMap.copy()
    _AttributeMap = ANetApiResponse._AttributeMap.copy()
    # Base type is ANetApiResponse
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element messages ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}messages) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element sessionToken ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}sessionToken) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}transactionResponse uses Python identifier transactionResponse
    __transactionResponse = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'transactionResponse'), 'transactionResponse', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_70_AnetApixmlv1schemaAnetApiSchema_xsdtransactionResponse', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3184, 6), )

    
    transactionResponse = property(__transactionResponse.value, __transactionResponse.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileResponse uses Python identifier profileResponse
    __profileResponse = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'profileResponse'), 'profileResponse', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_70_AnetApixmlv1schemaAnetApiSchema_xsdprofileResponse', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3185, 12), )

    
    profileResponse = property(__profileResponse.value, __profileResponse.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __transactionResponse.name() : __transactionResponse,
        __profileResponse.name() : __profileResponse
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_71 (ANetApiRequest):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3199, 2)
    _ElementMap = ANetApiRequest._ElementMap.copy()
    _AttributeMap = ANetApiRequest._AttributeMap.copy()
    # Base type is ANetApiRequest
    
    # Element merchantAuthentication ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantAuthentication) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}batchId uses Python identifier batchId
    __batchId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'batchId'), 'batchId', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_71_AnetApixmlv1schemaAnetApiSchema_xsdbatchId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3203, 6), )

    
    batchId = property(__batchId.value, __batchId.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __batchId.name() : __batchId
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_72 (ANetApiResponse):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3217, 2)
    _ElementMap = ANetApiResponse._ElementMap.copy()
    _AttributeMap = ANetApiResponse._AttributeMap.copy()
    # Base type is ANetApiResponse
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element messages ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}messages) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element sessionToken ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}sessionToken) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}batch uses Python identifier batch
    __batch = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'batch'), 'batch', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_72_AnetApixmlv1schemaAnetApiSchema_xsdbatch', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3221, 6), )

    
    batch = property(__batch.value, __batch.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __batch.name() : __batch
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_73 (ANetApiRequest):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3235, 2)
    _ElementMap = ANetApiRequest._ElementMap.copy()
    _AttributeMap = ANetApiRequest._AttributeMap.copy()
    # Base type is ANetApiRequest
    
    # Element merchantAuthentication ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantAuthentication) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}includeStatistics uses Python identifier includeStatistics
    __includeStatistics = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'includeStatistics'), 'includeStatistics', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_73_AnetApixmlv1schemaAnetApiSchema_xsdincludeStatistics', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3239, 6), )

    
    includeStatistics = property(__includeStatistics.value, __includeStatistics.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}firstSettlementDate uses Python identifier firstSettlementDate
    __firstSettlementDate = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'firstSettlementDate'), 'firstSettlementDate', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_73_AnetApixmlv1schemaAnetApiSchema_xsdfirstSettlementDate', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3240, 6), )

    
    firstSettlementDate = property(__firstSettlementDate.value, __firstSettlementDate.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}lastSettlementDate uses Python identifier lastSettlementDate
    __lastSettlementDate = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'lastSettlementDate'), 'lastSettlementDate', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_73_AnetApixmlv1schemaAnetApiSchema_xsdlastSettlementDate', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3241, 6), )

    
    lastSettlementDate = property(__lastSettlementDate.value, __lastSettlementDate.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __includeStatistics.name() : __includeStatistics,
        __firstSettlementDate.name() : __firstSettlementDate,
        __lastSettlementDate.name() : __lastSettlementDate
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_74 (ANetApiResponse):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3255, 2)
    _ElementMap = ANetApiResponse._ElementMap.copy()
    _AttributeMap = ANetApiResponse._AttributeMap.copy()
    # Base type is ANetApiResponse
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element messages ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}messages) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element sessionToken ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}sessionToken) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}batchList uses Python identifier batchList
    __batchList = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'batchList'), 'batchList', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_74_AnetApixmlv1schemaAnetApiSchema_xsdbatchList', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3259, 6), )

    
    batchList = property(__batchList.value, __batchList.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __batchList.name() : __batchList
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_75 (ANetApiRequest):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3273, 2)
    _ElementMap = ANetApiRequest._ElementMap.copy()
    _AttributeMap = ANetApiRequest._AttributeMap.copy()
    # Base type is ANetApiRequest
    
    # Element merchantAuthentication ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantAuthentication) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}batchId uses Python identifier batchId
    __batchId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'batchId'), 'batchId', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_75_AnetApixmlv1schemaAnetApiSchema_xsdbatchId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3277, 6), )

    
    batchId = property(__batchId.value, __batchId.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __batchId.name() : __batchId
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_76 (ANetApiResponse):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3291, 2)
    _ElementMap = ANetApiResponse._ElementMap.copy()
    _AttributeMap = ANetApiResponse._AttributeMap.copy()
    # Base type is ANetApiResponse
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element messages ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}messages) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element sessionToken ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}sessionToken) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}transactions uses Python identifier transactions
    __transactions = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'transactions'), 'transactions', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_76_AnetApixmlv1schemaAnetApiSchema_xsdtransactions', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3295, 6), )

    
    transactions = property(__transactions.value, __transactions.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __transactions.name() : __transactions
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_77 (ANetApiRequest):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3310, 2)
    _ElementMap = ANetApiRequest._ElementMap.copy()
    _AttributeMap = ANetApiRequest._AttributeMap.copy()
    # Base type is ANetApiRequest
    
    # Element merchantAuthentication ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantAuthentication) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileId uses Python identifier customerProfileId
    __customerProfileId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), 'customerProfileId', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_77_AnetApixmlv1schemaAnetApiSchema_xsdcustomerProfileId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3314, 6), )

    
    customerProfileId = property(__customerProfileId.value, __customerProfileId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}hostedProfileSettings uses Python identifier hostedProfileSettings
    __hostedProfileSettings = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'hostedProfileSettings'), 'hostedProfileSettings', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_77_AnetApixmlv1schemaAnetApiSchema_xsdhostedProfileSettings', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3315, 6), )

    
    hostedProfileSettings = property(__hostedProfileSettings.value, __hostedProfileSettings.set, None, 'Allowed values for settingName are: hostedProfileReturnUrl, hostedProfileReturnUrlText, hostedProfilePageBorderVisible, hostedProfileIFrameCommunicatorUrl, hostedProfileHeadingBgColor, hostedProfileBillingAddressRequired, hostedProfileCardCodeRequired.')

    _HasWildcardElement = True
    _ElementMap.update({
        __customerProfileId.name() : __customerProfileId,
        __hostedProfileSettings.name() : __hostedProfileSettings
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_78 (ANetApiResponse):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3333, 2)
    _ElementMap = ANetApiResponse._ElementMap.copy()
    _AttributeMap = ANetApiResponse._AttributeMap.copy()
    # Base type is ANetApiResponse
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element messages ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}messages) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element sessionToken ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}sessionToken) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}token uses Python identifier token
    __token = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'token'), 'token', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_78_AnetApixmlv1schemaAnetApiSchema_xsdtoken', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3337, 6), )

    
    token = property(__token.value, __token.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __token.name() : __token
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_79 (ANetApiRequest):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3351, 2)
    _ElementMap = ANetApiRequest._ElementMap.copy()
    _AttributeMap = ANetApiRequest._AttributeMap.copy()
    # Base type is ANetApiRequest
    
    # Element merchantAuthentication ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantAuthentication) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    _HasWildcardElement = True
    _ElementMap.update({
        
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_80 (ANetApiResponse):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3365, 2)
    _ElementMap = ANetApiResponse._ElementMap.copy()
    _AttributeMap = ANetApiResponse._AttributeMap.copy()
    # Base type is ANetApiResponse
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element messages ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}messages) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element sessionToken ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}sessionToken) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}transactions uses Python identifier transactions
    __transactions = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'transactions'), 'transactions', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_80_AnetApixmlv1schemaAnetApiSchema_xsdtransactions', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3369, 6), )

    
    transactions = property(__transactions.value, __transactions.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __transactions.name() : __transactions
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_81 (ANetApiRequest):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3384, 2)
    _ElementMap = ANetApiRequest._ElementMap.copy()
    _AttributeMap = ANetApiRequest._AttributeMap.copy()
    # Base type is ANetApiRequest
    
    # Element merchantAuthentication ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantAuthentication) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}mobileDevice uses Python identifier mobileDevice
    __mobileDevice = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'mobileDevice'), 'mobileDevice', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_81_AnetApixmlv1schemaAnetApiSchema_xsdmobileDevice', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3388, 6), )

    
    mobileDevice = property(__mobileDevice.value, __mobileDevice.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __mobileDevice.name() : __mobileDevice
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_82 (ANetApiResponse):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3402, 2)
    _ElementMap = ANetApiResponse._ElementMap.copy()
    _AttributeMap = ANetApiResponse._AttributeMap.copy()
    # Base type is ANetApiResponse
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element messages ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}messages) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element sessionToken ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}sessionToken) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    _HasWildcardElement = True
    _ElementMap.update({
        
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_83 (ANetApiRequest):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3415, 2)
    _ElementMap = ANetApiRequest._ElementMap.copy()
    _AttributeMap = ANetApiRequest._AttributeMap.copy()
    # Base type is ANetApiRequest
    
    # Element merchantAuthentication ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantAuthentication) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    _HasWildcardElement = True
    _ElementMap.update({
        
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_84 (ANetApiResponse):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3428, 2)
    _ElementMap = ANetApiResponse._ElementMap.copy()
    _AttributeMap = ANetApiResponse._AttributeMap.copy()
    # Base type is ANetApiResponse
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element messages ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}messages) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element sessionToken ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}sessionToken) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantContact uses Python identifier merchantContact
    __merchantContact = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'merchantContact'), 'merchantContact', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_84_AnetApixmlv1schemaAnetApiSchema_xsdmerchantContact', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3432, 6), )

    
    merchantContact = property(__merchantContact.value, __merchantContact.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}userPermissions uses Python identifier userPermissions
    __userPermissions = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'userPermissions'), 'userPermissions', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_84_AnetApixmlv1schemaAnetApiSchema_xsduserPermissions', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3433, 6), )

    
    userPermissions = property(__userPermissions.value, __userPermissions.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantAccount uses Python identifier merchantAccount
    __merchantAccount = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'merchantAccount'), 'merchantAccount', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_84_AnetApixmlv1schemaAnetApiSchema_xsdmerchantAccount', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3434, 24), )

    
    merchantAccount = property(__merchantAccount.value, __merchantAccount.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __merchantContact.name() : __merchantContact,
        __userPermissions.name() : __userPermissions,
        __merchantAccount.name() : __merchantAccount
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_85 (ANetApiRequest):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3448, 2)
    _ElementMap = ANetApiRequest._ElementMap.copy()
    _AttributeMap = ANetApiRequest._AttributeMap.copy()
    # Base type is ANetApiRequest
    
    # Element merchantAuthentication ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantAuthentication) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    _HasWildcardElement = True
    _ElementMap.update({
        
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_86 (ANetApiResponse):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3461, 2)
    _ElementMap = ANetApiResponse._ElementMap.copy()
    _AttributeMap = ANetApiResponse._AttributeMap.copy()
    # Base type is ANetApiResponse
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element messages ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}messages) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element sessionToken ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}sessionToken) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    _HasWildcardElement = True
    _ElementMap.update({
        
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_87 (ANetApiRequest):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3474, 2)
    _ElementMap = ANetApiRequest._ElementMap.copy()
    _AttributeMap = ANetApiRequest._AttributeMap.copy()
    # Base type is ANetApiRequest
    
    # Element merchantAuthentication ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantAuthentication) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}transId uses Python identifier transId
    __transId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'transId'), 'transId', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_87_AnetApixmlv1schemaAnetApiSchema_xsdtransId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3478, 6), )

    
    transId = property(__transId.value, __transId.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerEmail uses Python identifier customerEmail
    __customerEmail = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerEmail'), 'customerEmail', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_87_AnetApixmlv1schemaAnetApiSchema_xsdcustomerEmail', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3479, 6), )

    
    customerEmail = property(__customerEmail.value, __customerEmail.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}emailSettings uses Python identifier emailSettings
    __emailSettings = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'emailSettings'), 'emailSettings', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_87_AnetApixmlv1schemaAnetApiSchema_xsdemailSettings', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3480, 6), )

    
    emailSettings = property(__emailSettings.value, __emailSettings.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __transId.name() : __transId,
        __customerEmail.name() : __customerEmail,
        __emailSettings.name() : __emailSettings
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_88 (ANetApiResponse):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3494, 2)
    _ElementMap = ANetApiResponse._ElementMap.copy()
    _AttributeMap = ANetApiResponse._AttributeMap.copy()
    # Base type is ANetApiResponse
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element messages ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}messages) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element sessionToken ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}sessionToken) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    _HasWildcardElement = True
    _ElementMap.update({
        
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_89 (ANetApiRequest):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3553, 2)
    _ElementMap = ANetApiRequest._ElementMap.copy()
    _AttributeMap = ANetApiRequest._AttributeMap.copy()
    # Base type is ANetApiRequest
    
    # Element merchantAuthentication ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantAuthentication) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}searchType uses Python identifier searchType
    __searchType = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'searchType'), 'searchType', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_89_AnetApixmlv1schemaAnetApiSchema_xsdsearchType', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3557, 6), )

    
    searchType = property(__searchType.value, __searchType.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}sorting uses Python identifier sorting
    __sorting = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'sorting'), 'sorting', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_89_AnetApixmlv1schemaAnetApiSchema_xsdsorting', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3558, 6), )

    
    sorting = property(__sorting.value, __sorting.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}paging uses Python identifier paging
    __paging = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'paging'), 'paging', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_89_AnetApixmlv1schemaAnetApiSchema_xsdpaging', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3559, 6), )

    
    paging = property(__paging.value, __paging.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __searchType.name() : __searchType,
        __sorting.name() : __sorting,
        __paging.name() : __paging
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_90 (ANetApiResponse):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3616, 2)
    _ElementMap = ANetApiResponse._ElementMap.copy()
    _AttributeMap = ANetApiResponse._AttributeMap.copy()
    # Base type is ANetApiResponse
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element messages ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}messages) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element sessionToken ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}sessionToken) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}totalNumInResultSet uses Python identifier totalNumInResultSet
    __totalNumInResultSet = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'totalNumInResultSet'), 'totalNumInResultSet', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_90_AnetApixmlv1schemaAnetApiSchema_xsdtotalNumInResultSet', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3620, 6), )

    
    totalNumInResultSet = property(__totalNumInResultSet.value, __totalNumInResultSet.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}subscriptionDetails uses Python identifier subscriptionDetails
    __subscriptionDetails = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'subscriptionDetails'), 'subscriptionDetails', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_90_AnetApixmlv1schemaAnetApiSchema_xsdsubscriptionDetails', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3621, 6), )

    
    subscriptionDetails = property(__subscriptionDetails.value, __subscriptionDetails.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __totalNumInResultSet.name() : __totalNumInResultSet,
        __subscriptionDetails.name() : __subscriptionDetails
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_91 (ANetApiRequest):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3729, 2)
    _ElementMap = ANetApiRequest._ElementMap.copy()
    _AttributeMap = ANetApiRequest._AttributeMap.copy()
    # Base type is ANetApiRequest
    
    # Element merchantAuthentication ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantAuthentication) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}searchType uses Python identifier searchType
    __searchType = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'searchType'), 'searchType', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_91_AnetApixmlv1schemaAnetApiSchema_xsdsearchType', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3733, 6), )

    
    searchType = property(__searchType.value, __searchType.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}month uses Python identifier month
    __month = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'month'), 'month', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_91_AnetApixmlv1schemaAnetApiSchema_xsdmonth', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3734, 24), )

    
    month = property(__month.value, __month.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}sorting uses Python identifier sorting
    __sorting = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'sorting'), 'sorting', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_91_AnetApixmlv1schemaAnetApiSchema_xsdsorting', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3742, 6), )

    
    sorting = property(__sorting.value, __sorting.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}paging uses Python identifier paging
    __paging = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'paging'), 'paging', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_91_AnetApixmlv1schemaAnetApiSchema_xsdpaging', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3743, 6), )

    
    paging = property(__paging.value, __paging.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __searchType.name() : __searchType,
        __month.name() : __month,
        __sorting.name() : __sorting,
        __paging.name() : __paging
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_92 (ANetApiResponse):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3751, 2)
    _ElementMap = ANetApiResponse._ElementMap.copy()
    _AttributeMap = ANetApiResponse._AttributeMap.copy()
    # Base type is ANetApiResponse
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element messages ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}messages) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element sessionToken ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}sessionToken) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}totalNumInResultSet uses Python identifier totalNumInResultSet
    __totalNumInResultSet = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'totalNumInResultSet'), 'totalNumInResultSet', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_92_AnetApixmlv1schemaAnetApiSchema_xsdtotalNumInResultSet', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3755, 6), )

    
    totalNumInResultSet = property(__totalNumInResultSet.value, __totalNumInResultSet.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}paymentProfiles uses Python identifier paymentProfiles
    __paymentProfiles = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'paymentProfiles'), 'paymentProfiles', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_92_AnetApixmlv1schemaAnetApiSchema_xsdpaymentProfiles', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3756, 6), )

    
    paymentProfiles = property(__paymentProfiles.value, __paymentProfiles.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __totalNumInResultSet.name() : __totalNumInResultSet,
        __paymentProfiles.name() : __paymentProfiles
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_93 (ANetApiRequest):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3805, 2)
    _ElementMap = ANetApiRequest._ElementMap.copy()
    _AttributeMap = ANetApiRequest._AttributeMap.copy()
    # Base type is ANetApiRequest
    
    # Element merchantAuthentication ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantAuthentication) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiRequest
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}subscriptionId uses Python identifier subscriptionId
    __subscriptionId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'subscriptionId'), 'subscriptionId', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_93_AnetApixmlv1schemaAnetApiSchema_xsdsubscriptionId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3809, 6), )

    
    subscriptionId = property(__subscriptionId.value, __subscriptionId.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __subscriptionId.name() : __subscriptionId
    })
    _AttributeMap.update({
        
    })



# Complex type [anonymous] with content type ELEMENT_ONLY
class CTD_ANON_94 (ANetApiResponse):
    """Complex type [anonymous] with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = None
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3823, 2)
    _ElementMap = ANetApiResponse._ElementMap.copy()
    _AttributeMap = ANetApiResponse._AttributeMap.copy()
    # Base type is ANetApiResponse
    
    # Element refId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}refId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element messages ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}messages) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element sessionToken ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}sessionToken) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}ANetApiResponse
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}subscription uses Python identifier subscription
    __subscription = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'subscription'), 'subscription', '__AnetApixmlv1schemaAnetApiSchema_xsd_CTD_ANON_94_AnetApixmlv1schemaAnetApiSchema_xsdsubscription', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3827, 4), )

    
    subscription = property(__subscription.value, __subscription.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __subscription.name() : __subscription
    })
    _AttributeMap.update({
        
    })



# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}subscriptionCustomerProfileType with content type ELEMENT_ONLY
class subscriptionCustomerProfileType (customerProfileExType):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}subscriptionCustomerProfileType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'subscriptionCustomerProfileType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1092, 3)
    _ElementMap = customerProfileExType._ElementMap.copy()
    _AttributeMap = customerProfileExType._AttributeMap.copy()
    # Base type is customerProfileExType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}paymentProfile uses Python identifier paymentProfile
    __paymentProfile = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'paymentProfile'), 'paymentProfile', '__AnetApixmlv1schemaAnetApiSchema_xsd_subscriptionCustomerProfileType_AnetApixmlv1schemaAnetApiSchema_xsdpaymentProfile', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1096, 16), )

    
    paymentProfile = property(__paymentProfile.value, __paymentProfile.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}shippingProfile uses Python identifier shippingProfile
    __shippingProfile = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'shippingProfile'), 'shippingProfile', '__AnetApixmlv1schemaAnetApiSchema_xsd_subscriptionCustomerProfileType_AnetApixmlv1schemaAnetApiSchema_xsdshippingProfile', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1097, 16), )

    
    shippingProfile = property(__shippingProfile.value, __shippingProfile.set, None, None)

    
    # Element merchantCustomerId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantCustomerId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileBaseType
    
    # Element description ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}description) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileBaseType
    
    # Element email ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}email) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileBaseType
    
    # Element customerProfileId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileExType
    _HasWildcardElement = True
    _ElementMap.update({
        __paymentProfile.name() : __paymentProfile,
        __shippingProfile.name() : __shippingProfile
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'subscriptionCustomerProfileType', subscriptionCustomerProfileType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerPaymentProfileExType with content type ELEMENT_ONLY
class customerPaymentProfileExType (customerPaymentProfileType):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerPaymentProfileExType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileExType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1443, 1)
    _ElementMap = customerPaymentProfileType._ElementMap.copy()
    _AttributeMap = customerPaymentProfileType._AttributeMap.copy()
    # Base type is customerPaymentProfileType
    
    # Element customerType ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerType) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerPaymentProfileBaseType
    
    # Element billTo ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}billTo) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerPaymentProfileBaseType
    
    # Element payment ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}payment) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerPaymentProfileType
    
    # Element driversLicense ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}driversLicense) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerPaymentProfileType
    
    # Element taxId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}taxId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerPaymentProfileType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerPaymentProfileId uses Python identifier customerPaymentProfileId
    __customerPaymentProfileId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileId'), 'customerPaymentProfileId', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerPaymentProfileExType_AnetApixmlv1schemaAnetApiSchema_xsdcustomerPaymentProfileId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1447, 5), )

    
    customerPaymentProfileId = property(__customerPaymentProfileId.value, __customerPaymentProfileId.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __customerPaymentProfileId.name() : __customerPaymentProfileId
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'customerPaymentProfileExType', customerPaymentProfileExType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileMaskedType with content type ELEMENT_ONLY
class customerProfileMaskedType (customerProfileExType):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileMaskedType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'customerProfileMaskedType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1544, 1)
    _ElementMap = customerProfileExType._ElementMap.copy()
    _AttributeMap = customerProfileExType._AttributeMap.copy()
    # Base type is customerProfileExType
    
    # Element merchantCustomerId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}merchantCustomerId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileBaseType
    
    # Element description ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}description) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileBaseType
    
    # Element email ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}email) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileBaseType
    
    # Element customerProfileId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileExType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}paymentProfiles uses Python identifier paymentProfiles
    __paymentProfiles = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'paymentProfiles'), 'paymentProfiles', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerProfileMaskedType_AnetApixmlv1schemaAnetApiSchema_xsdpaymentProfiles', True, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1548, 5), )

    
    paymentProfiles = property(__paymentProfiles.value, __paymentProfiles.set, None, None)

    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}shipToList uses Python identifier shipToList
    __shipToList = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'shipToList'), 'shipToList', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerProfileMaskedType_AnetApixmlv1schemaAnetApiSchema_xsdshipToList', True, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1549, 5), )

    
    shipToList = property(__shipToList.value, __shipToList.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __paymentProfiles.name() : __paymentProfiles,
        __shipToList.name() : __shipToList
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'customerProfileMaskedType', customerProfileMaskedType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerAddressExType with content type ELEMENT_ONLY
class customerAddressExType (customerAddressType):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerAddressExType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'customerAddressExType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1581, 1)
    _ElementMap = customerAddressType._ElementMap.copy()
    _AttributeMap = customerAddressType._AttributeMap.copy()
    # Base type is customerAddressType
    
    # Element firstName ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}firstName) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}nameAndAddressType
    
    # Element lastName ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}lastName) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}nameAndAddressType
    
    # Element company ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}company) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}nameAndAddressType
    
    # Element address ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}address) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}nameAndAddressType
    
    # Element city ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}city) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}nameAndAddressType
    
    # Element state ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}state) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}nameAndAddressType
    
    # Element zip ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}zip) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}nameAndAddressType
    
    # Element country ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}country) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}nameAndAddressType
    
    # Element phoneNumber ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}phoneNumber) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerAddressType
    
    # Element faxNumber ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}faxNumber) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerAddressType
    
    # Element email ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}email) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerAddressType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerAddressId uses Python identifier customerAddressId
    __customerAddressId = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'customerAddressId'), 'customerAddressId', '__AnetApixmlv1schemaAnetApiSchema_xsd_customerAddressExType_AnetApixmlv1schemaAnetApiSchema_xsdcustomerAddressId', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1585, 5), )

    
    customerAddressId = property(__customerAddressId.value, __customerAddressId.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __customerAddressId.name() : __customerAddressId
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'customerAddressExType', customerAddressExType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransAuthCaptureType with content type ELEMENT_ONLY
class profileTransAuthCaptureType (profileTransOrderType):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransAuthCaptureType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'profileTransAuthCaptureType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1702, 1)
    _ElementMap = profileTransOrderType._ElementMap.copy()
    _AttributeMap = profileTransOrderType._AttributeMap.copy()
    # Base type is profileTransOrderType
    
    # Element amount ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}amount) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransAmountType
    
    # Element tax ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}tax) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransAmountType
    
    # Element shipping ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}shipping) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransAmountType
    
    # Element duty ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}duty) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransAmountType
    
    # Element lineItems ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}lineItems) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransAmountType
    
    # Element customerProfileId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransOrderType
    
    # Element customerPaymentProfileId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerPaymentProfileId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransOrderType
    
    # Element customerShippingAddressId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerShippingAddressId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransOrderType
    
    # Element order ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}order) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransOrderType
    
    # Element taxExempt ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}taxExempt) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransOrderType
    
    # Element recurringBilling ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}recurringBilling) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransOrderType
    
    # Element cardCode ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}cardCode) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransOrderType
    
    # Element splitTenderId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}splitTenderId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransOrderType
    _HasWildcardElement = True
    _ElementMap.update({
        
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'profileTransAuthCaptureType', profileTransAuthCaptureType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransAuthOnlyType with content type ELEMENT_ONLY
class profileTransAuthOnlyType (profileTransOrderType):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransAuthOnlyType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'profileTransAuthOnlyType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1709, 1)
    _ElementMap = profileTransOrderType._ElementMap.copy()
    _AttributeMap = profileTransOrderType._AttributeMap.copy()
    # Base type is profileTransOrderType
    
    # Element amount ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}amount) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransAmountType
    
    # Element tax ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}tax) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransAmountType
    
    # Element shipping ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}shipping) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransAmountType
    
    # Element duty ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}duty) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransAmountType
    
    # Element lineItems ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}lineItems) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransAmountType
    
    # Element customerProfileId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransOrderType
    
    # Element customerPaymentProfileId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerPaymentProfileId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransOrderType
    
    # Element customerShippingAddressId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerShippingAddressId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransOrderType
    
    # Element order ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}order) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransOrderType
    
    # Element taxExempt ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}taxExempt) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransOrderType
    
    # Element recurringBilling ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}recurringBilling) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransOrderType
    
    # Element cardCode ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}cardCode) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransOrderType
    
    # Element splitTenderId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}splitTenderId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransOrderType
    _HasWildcardElement = True
    _ElementMap.update({
        
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'profileTransAuthOnlyType', profileTransAuthOnlyType)


# Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransCaptureOnlyType with content type ELEMENT_ONLY
class profileTransCaptureOnlyType (profileTransOrderType):
    """Complex type {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransCaptureOnlyType with content type ELEMENT_ONLY"""
    _TypeDefinition = None
    _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
    _Abstract = False
    _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'profileTransCaptureOnlyType')
    _XSDLocation = pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1730, 1)
    _ElementMap = profileTransOrderType._ElementMap.copy()
    _AttributeMap = profileTransOrderType._AttributeMap.copy()
    # Base type is profileTransOrderType
    
    # Element amount ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}amount) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransAmountType
    
    # Element tax ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}tax) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransAmountType
    
    # Element shipping ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}shipping) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransAmountType
    
    # Element duty ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}duty) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransAmountType
    
    # Element lineItems ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}lineItems) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransAmountType
    
    # Element customerProfileId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerProfileId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransOrderType
    
    # Element customerPaymentProfileId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerPaymentProfileId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransOrderType
    
    # Element customerShippingAddressId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}customerShippingAddressId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransOrderType
    
    # Element order ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}order) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransOrderType
    
    # Element taxExempt ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}taxExempt) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransOrderType
    
    # Element recurringBilling ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}recurringBilling) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransOrderType
    
    # Element cardCode ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}cardCode) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransOrderType
    
    # Element splitTenderId ({AnetApi/xml/v1/schema/AnetApiSchema.xsd}splitTenderId) inherited from {AnetApi/xml/v1/schema/AnetApiSchema.xsd}profileTransOrderType
    
    # Element {AnetApi/xml/v1/schema/AnetApiSchema.xsd}approvalCode uses Python identifier approvalCode
    __approvalCode = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'approvalCode'), 'approvalCode', '__AnetApixmlv1schemaAnetApiSchema_xsd_profileTransCaptureOnlyType_AnetApixmlv1schemaAnetApiSchema_xsdapprovalCode', False, pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1734, 5), )

    
    approvalCode = property(__approvalCode.value, __approvalCode.set, None, None)

    _HasWildcardElement = True
    _ElementMap.update({
        __approvalCode.name() : __approvalCode
    })
    _AttributeMap.update({
        
    })
Namespace.addCategoryObject('typeBinding', 'profileTransCaptureOnlyType', profileTransCaptureOnlyType)


ErrorResponse = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'ErrorResponse'), ANetApiResponse, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2233, 1))
Namespace.addCategoryObject('elementBinding', ErrorResponse.name().localName(), ErrorResponse)

isAliveRequest = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'isAliveRequest'), CTD_ANON_17, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2240, 1))
Namespace.addCategoryObject('elementBinding', isAliveRequest.name().localName(), isAliveRequest)

EnumCollection = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'EnumCollection'), CTD_ANON_18, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3680, 4))
Namespace.addCategoryObject('elementBinding', EnumCollection.name().localName(), EnumCollection)

decryptPaymentDataRequest = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'decryptPaymentDataRequest'), CTD_ANON_19, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 822, 2))
Namespace.addCategoryObject('elementBinding', decryptPaymentDataRequest.name().localName(), decryptPaymentDataRequest)

decryptPaymentDataResponse = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'decryptPaymentDataResponse'), CTD_ANON_20, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 836, 2))
Namespace.addCategoryObject('elementBinding', decryptPaymentDataResponse.name().localName(), decryptPaymentDataResponse)

securePaymentContainerRequest = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'securePaymentContainerRequest'), CTD_ANON_21, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 854, 2))
Namespace.addCategoryObject('elementBinding', securePaymentContainerRequest.name().localName(), securePaymentContainerRequest)

securePaymentContainerResponse = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'securePaymentContainerResponse'), CTD_ANON_22, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 867, 2))
Namespace.addCategoryObject('elementBinding', securePaymentContainerResponse.name().localName(), securePaymentContainerResponse)

isAliveResponse = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'isAliveResponse'), CTD_ANON_23, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2260, 1))
Namespace.addCategoryObject('elementBinding', isAliveResponse.name().localName(), isAliveResponse)

authenticateTestRequest = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'authenticateTestRequest'), CTD_ANON_24, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2274, 1))
Namespace.addCategoryObject('elementBinding', authenticateTestRequest.name().localName(), authenticateTestRequest)

authenticateTestResponse = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'authenticateTestResponse'), CTD_ANON_25, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2288, 1))
Namespace.addCategoryObject('elementBinding', authenticateTestResponse.name().localName(), authenticateTestResponse)

ARBCreateSubscriptionRequest = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'ARBCreateSubscriptionRequest'), CTD_ANON_26, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2303, 1))
Namespace.addCategoryObject('elementBinding', ARBCreateSubscriptionRequest.name().localName(), ARBCreateSubscriptionRequest)

ARBCreateSubscriptionResponse = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'ARBCreateSubscriptionResponse'), CTD_ANON_27, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2322, 1))
Namespace.addCategoryObject('elementBinding', ARBCreateSubscriptionResponse.name().localName(), ARBCreateSubscriptionResponse)

ARBUpdateSubscriptionRequest = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'ARBUpdateSubscriptionRequest'), CTD_ANON_28, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2343, 1))
Namespace.addCategoryObject('elementBinding', ARBUpdateSubscriptionRequest.name().localName(), ARBUpdateSubscriptionRequest)

ARBUpdateSubscriptionResponse = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'ARBUpdateSubscriptionResponse'), CTD_ANON_29, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2362, 1))
Namespace.addCategoryObject('elementBinding', ARBUpdateSubscriptionResponse.name().localName(), ARBUpdateSubscriptionResponse)

ARBCancelSubscriptionRequest = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'ARBCancelSubscriptionRequest'), CTD_ANON_30, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2381, 1))
Namespace.addCategoryObject('elementBinding', ARBCancelSubscriptionRequest.name().localName(), ARBCancelSubscriptionRequest)

ARBCancelSubscriptionResponse = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'ARBCancelSubscriptionResponse'), CTD_ANON_31, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2399, 1))
Namespace.addCategoryObject('elementBinding', ARBCancelSubscriptionResponse.name().localName(), ARBCancelSubscriptionResponse)

ARBGetSubscriptionStatusRequest = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'ARBGetSubscriptionStatusRequest'), CTD_ANON_32, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2414, 1))
Namespace.addCategoryObject('elementBinding', ARBGetSubscriptionStatusRequest.name().localName(), ARBGetSubscriptionStatusRequest)

ARBGetSubscriptionStatusResponse = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'ARBGetSubscriptionStatusResponse'), CTD_ANON_33, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2432, 1))
Namespace.addCategoryObject('elementBinding', ARBGetSubscriptionStatusResponse.name().localName(), ARBGetSubscriptionStatusResponse)

createCustomerProfileRequest = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'createCustomerProfileRequest'), CTD_ANON_34, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2452, 1))
Namespace.addCategoryObject('elementBinding', createCustomerProfileRequest.name().localName(), createCustomerProfileRequest)

createCustomerProfileResponse = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'createCustomerProfileResponse'), CTD_ANON_35, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2471, 1))
Namespace.addCategoryObject('elementBinding', createCustomerProfileResponse.name().localName(), createCustomerProfileResponse)

createCustomerPaymentProfileRequest = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'createCustomerPaymentProfileRequest'), CTD_ANON_36, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2512, 1))
Namespace.addCategoryObject('elementBinding', createCustomerPaymentProfileRequest.name().localName(), createCustomerPaymentProfileRequest)

createCustomerPaymentProfileResponse = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'createCustomerPaymentProfileResponse'), CTD_ANON_37, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2532, 1))
Namespace.addCategoryObject('elementBinding', createCustomerPaymentProfileResponse.name().localName(), createCustomerPaymentProfileResponse)

createCustomerShippingAddressRequest = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'createCustomerShippingAddressRequest'), CTD_ANON_38, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2562, 1))
Namespace.addCategoryObject('elementBinding', createCustomerShippingAddressRequest.name().localName(), createCustomerShippingAddressRequest)

createCustomerShippingAddressResponse = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'createCustomerShippingAddressResponse'), CTD_ANON_39, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2581, 1))
Namespace.addCategoryObject('elementBinding', createCustomerShippingAddressResponse.name().localName(), createCustomerShippingAddressResponse)

createCustomerProfileFromTransactionRequest = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'createCustomerProfileFromTransactionRequest'), CTD_ANON_40, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2602, 2))
Namespace.addCategoryObject('elementBinding', createCustomerProfileFromTransactionRequest.name().localName(), createCustomerProfileFromTransactionRequest)

getCustomerProfileRequest = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'getCustomerProfileRequest'), CTD_ANON_41, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2625, 1))
Namespace.addCategoryObject('elementBinding', getCustomerProfileRequest.name().localName(), getCustomerProfileRequest)

getCustomerProfileResponse = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'getCustomerProfileResponse'), CTD_ANON_42, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2643, 2))
Namespace.addCategoryObject('elementBinding', getCustomerProfileResponse.name().localName(), getCustomerProfileResponse)

getCustomerPaymentProfileRequest = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'getCustomerPaymentProfileRequest'), CTD_ANON_43, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2664, 2))
Namespace.addCategoryObject('elementBinding', getCustomerPaymentProfileRequest.name().localName(), getCustomerPaymentProfileRequest)

getCustomerPaymentProfileResponse = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'getCustomerPaymentProfileResponse'), CTD_ANON_44, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2685, 2))
Namespace.addCategoryObject('elementBinding', getCustomerPaymentProfileResponse.name().localName(), getCustomerPaymentProfileResponse)

getCustomerShippingAddressRequest = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'getCustomerShippingAddressRequest'), CTD_ANON_45, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2705, 2))
Namespace.addCategoryObject('elementBinding', getCustomerShippingAddressRequest.name().localName(), getCustomerShippingAddressRequest)

getCustomerShippingAddressResponse = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'getCustomerShippingAddressResponse'), CTD_ANON_46, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2724, 2))
Namespace.addCategoryObject('elementBinding', getCustomerShippingAddressResponse.name().localName(), getCustomerShippingAddressResponse)

updateCustomerProfileRequest = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'updateCustomerProfileRequest'), CTD_ANON_47, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2745, 2))
Namespace.addCategoryObject('elementBinding', updateCustomerProfileRequest.name().localName(), updateCustomerProfileRequest)

updateCustomerProfileResponse = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'updateCustomerProfileResponse'), CTD_ANON_48, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2763, 2))
Namespace.addCategoryObject('elementBinding', updateCustomerProfileResponse.name().localName(), updateCustomerProfileResponse)

updateCustomerPaymentProfileRequest = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'updateCustomerPaymentProfileRequest'), CTD_ANON_49, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2778, 2))
Namespace.addCategoryObject('elementBinding', updateCustomerPaymentProfileRequest.name().localName(), updateCustomerPaymentProfileRequest)

updateCustomerPaymentProfileResponse = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'updateCustomerPaymentProfileResponse'), CTD_ANON_50, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2798, 2))
Namespace.addCategoryObject('elementBinding', updateCustomerPaymentProfileResponse.name().localName(), updateCustomerPaymentProfileResponse)

updateCustomerShippingAddressRequest = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'updateCustomerShippingAddressRequest'), CTD_ANON_51, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2824, 2))
Namespace.addCategoryObject('elementBinding', updateCustomerShippingAddressRequest.name().localName(), updateCustomerShippingAddressRequest)

updateCustomerShippingAddressResponse = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'updateCustomerShippingAddressResponse'), CTD_ANON_52, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2843, 2))
Namespace.addCategoryObject('elementBinding', updateCustomerShippingAddressResponse.name().localName(), updateCustomerShippingAddressResponse)

deleteCustomerProfileRequest = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'deleteCustomerProfileRequest'), CTD_ANON_53, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2859, 2))
Namespace.addCategoryObject('elementBinding', deleteCustomerProfileRequest.name().localName(), deleteCustomerProfileRequest)

deleteCustomerProfileResponse = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'deleteCustomerProfileResponse'), CTD_ANON_54, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2877, 2))
Namespace.addCategoryObject('elementBinding', deleteCustomerProfileResponse.name().localName(), deleteCustomerProfileResponse)

deleteCustomerPaymentProfileRequest = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'deleteCustomerPaymentProfileRequest'), CTD_ANON_55, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2892, 2))
Namespace.addCategoryObject('elementBinding', deleteCustomerPaymentProfileRequest.name().localName(), deleteCustomerPaymentProfileRequest)

deleteCustomerPaymentProfileResponse = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'deleteCustomerPaymentProfileResponse'), CTD_ANON_56, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2911, 2))
Namespace.addCategoryObject('elementBinding', deleteCustomerPaymentProfileResponse.name().localName(), deleteCustomerPaymentProfileResponse)

deleteCustomerShippingAddressRequest = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'deleteCustomerShippingAddressRequest'), CTD_ANON_57, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2926, 2))
Namespace.addCategoryObject('elementBinding', deleteCustomerShippingAddressRequest.name().localName(), deleteCustomerShippingAddressRequest)

deleteCustomerShippingAddressResponse = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'deleteCustomerShippingAddressResponse'), CTD_ANON_58, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2945, 2))
Namespace.addCategoryObject('elementBinding', deleteCustomerShippingAddressResponse.name().localName(), deleteCustomerShippingAddressResponse)

createCustomerProfileTransactionRequest = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'createCustomerProfileTransactionRequest'), CTD_ANON_59, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2960, 2))
Namespace.addCategoryObject('elementBinding', createCustomerProfileTransactionRequest.name().localName(), createCustomerProfileTransactionRequest)

createCustomerProfileTransactionResponse = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'createCustomerProfileTransactionResponse'), CTD_ANON_60, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2985, 2))
Namespace.addCategoryObject('elementBinding', createCustomerProfileTransactionResponse.name().localName(), createCustomerProfileTransactionResponse)

validateCustomerPaymentProfileRequest = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'validateCustomerPaymentProfileRequest'), CTD_ANON_61, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3011, 2))
Namespace.addCategoryObject('elementBinding', validateCustomerPaymentProfileRequest.name().localName(), validateCustomerPaymentProfileRequest)

validateCustomerPaymentProfileResponse = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'validateCustomerPaymentProfileResponse'), CTD_ANON_62, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3033, 2))
Namespace.addCategoryObject('elementBinding', validateCustomerPaymentProfileResponse.name().localName(), validateCustomerPaymentProfileResponse)

getCustomerProfileIdsRequest = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'getCustomerProfileIdsRequest'), CTD_ANON_63, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3058, 2))
Namespace.addCategoryObject('elementBinding', getCustomerProfileIdsRequest.name().localName(), getCustomerProfileIdsRequest)

getCustomerProfileIdsResponse = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'getCustomerProfileIdsResponse'), CTD_ANON_64, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3072, 2))
Namespace.addCategoryObject('elementBinding', getCustomerProfileIdsResponse.name().localName(), getCustomerProfileIdsResponse)

updateSplitTenderGroupRequest = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'updateSplitTenderGroupRequest'), CTD_ANON_65, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3090, 2))
Namespace.addCategoryObject('elementBinding', updateSplitTenderGroupRequest.name().localName(), updateSplitTenderGroupRequest)

updateSplitTenderGroupResponse = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'updateSplitTenderGroupResponse'), CTD_ANON_66, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3109, 2))
Namespace.addCategoryObject('elementBinding', updateSplitTenderGroupResponse.name().localName(), updateSplitTenderGroupResponse)

getTransactionDetailsRequest = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'getTransactionDetailsRequest'), CTD_ANON_67, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3123, 2))
Namespace.addCategoryObject('elementBinding', getTransactionDetailsRequest.name().localName(), getTransactionDetailsRequest)

getTransactionDetailsResponse = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'getTransactionDetailsResponse'), CTD_ANON_68, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3141, 1))
Namespace.addCategoryObject('elementBinding', getTransactionDetailsResponse.name().localName(), getTransactionDetailsResponse)

createTransactionRequest = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'createTransactionRequest'), CTD_ANON_69, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3160, 1))
Namespace.addCategoryObject('elementBinding', createTransactionRequest.name().localName(), createTransactionRequest)

createTransactionResponse = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'createTransactionResponse'), CTD_ANON_70, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3179, 1))
Namespace.addCategoryObject('elementBinding', createTransactionResponse.name().localName(), createTransactionResponse)

getBatchStatisticsRequest = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'getBatchStatisticsRequest'), CTD_ANON_71, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3198, 1))
Namespace.addCategoryObject('elementBinding', getBatchStatisticsRequest.name().localName(), getBatchStatisticsRequest)

getBatchStatisticsResponse = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'getBatchStatisticsResponse'), CTD_ANON_72, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3216, 1))
Namespace.addCategoryObject('elementBinding', getBatchStatisticsResponse.name().localName(), getBatchStatisticsResponse)

getSettledBatchListRequest = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'getSettledBatchListRequest'), CTD_ANON_73, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3234, 1))
Namespace.addCategoryObject('elementBinding', getSettledBatchListRequest.name().localName(), getSettledBatchListRequest)

getSettledBatchListResponse = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'getSettledBatchListResponse'), CTD_ANON_74, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3254, 1))
Namespace.addCategoryObject('elementBinding', getSettledBatchListResponse.name().localName(), getSettledBatchListResponse)

getTransactionListRequest = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'getTransactionListRequest'), CTD_ANON_75, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3272, 1))
Namespace.addCategoryObject('elementBinding', getTransactionListRequest.name().localName(), getTransactionListRequest)

getTransactionListResponse = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'getTransactionListResponse'), CTD_ANON_76, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3290, 1))
Namespace.addCategoryObject('elementBinding', getTransactionListResponse.name().localName(), getTransactionListResponse)

getHostedProfilePageRequest = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'getHostedProfilePageRequest'), CTD_ANON_77, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3309, 1))
Namespace.addCategoryObject('elementBinding', getHostedProfilePageRequest.name().localName(), getHostedProfilePageRequest)

getHostedProfilePageResponse = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'getHostedProfilePageResponse'), CTD_ANON_78, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3332, 1))
Namespace.addCategoryObject('elementBinding', getHostedProfilePageResponse.name().localName(), getHostedProfilePageResponse)

getUnsettledTransactionListRequest = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'getUnsettledTransactionListRequest'), CTD_ANON_79, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3350, 1))
Namespace.addCategoryObject('elementBinding', getUnsettledTransactionListRequest.name().localName(), getUnsettledTransactionListRequest)

getUnsettledTransactionListResponse = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'getUnsettledTransactionListResponse'), CTD_ANON_80, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3364, 1))
Namespace.addCategoryObject('elementBinding', getUnsettledTransactionListResponse.name().localName(), getUnsettledTransactionListResponse)

mobileDeviceRegistrationRequest = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'mobileDeviceRegistrationRequest'), CTD_ANON_81, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3383, 1))
Namespace.addCategoryObject('elementBinding', mobileDeviceRegistrationRequest.name().localName(), mobileDeviceRegistrationRequest)

mobileDeviceRegistrationResponse = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'mobileDeviceRegistrationResponse'), CTD_ANON_82, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3401, 1))
Namespace.addCategoryObject('elementBinding', mobileDeviceRegistrationResponse.name().localName(), mobileDeviceRegistrationResponse)

mobileDeviceLoginRequest = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'mobileDeviceLoginRequest'), CTD_ANON_83, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3414, 1))
Namespace.addCategoryObject('elementBinding', mobileDeviceLoginRequest.name().localName(), mobileDeviceLoginRequest)

mobileDeviceLoginResponse = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'mobileDeviceLoginResponse'), CTD_ANON_84, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3427, 1))
Namespace.addCategoryObject('elementBinding', mobileDeviceLoginResponse.name().localName(), mobileDeviceLoginResponse)

logoutRequest = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'logoutRequest'), CTD_ANON_85, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3447, 1))
Namespace.addCategoryObject('elementBinding', logoutRequest.name().localName(), logoutRequest)

logoutResponse = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'logoutResponse'), CTD_ANON_86, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3460, 1))
Namespace.addCategoryObject('elementBinding', logoutResponse.name().localName(), logoutResponse)

sendCustomerTransactionReceiptRequest = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'sendCustomerTransactionReceiptRequest'), CTD_ANON_87, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3473, 1))
Namespace.addCategoryObject('elementBinding', sendCustomerTransactionReceiptRequest.name().localName(), sendCustomerTransactionReceiptRequest)

sendCustomerTransactionReceiptResponse = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'sendCustomerTransactionReceiptResponse'), CTD_ANON_88, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3493, 1))
Namespace.addCategoryObject('elementBinding', sendCustomerTransactionReceiptResponse.name().localName(), sendCustomerTransactionReceiptResponse)

ARBGetSubscriptionListRequest = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'ARBGetSubscriptionListRequest'), CTD_ANON_89, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3552, 1))
Namespace.addCategoryObject('elementBinding', ARBGetSubscriptionListRequest.name().localName(), ARBGetSubscriptionListRequest)

ARBGetSubscriptionListResponse = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'ARBGetSubscriptionListResponse'), CTD_ANON_90, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3615, 1))
Namespace.addCategoryObject('elementBinding', ARBGetSubscriptionListResponse.name().localName(), ARBGetSubscriptionListResponse)

getCustomerPaymentProfileListRequest = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'getCustomerPaymentProfileListRequest'), CTD_ANON_91, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3728, 1))
Namespace.addCategoryObject('elementBinding', getCustomerPaymentProfileListRequest.name().localName(), getCustomerPaymentProfileListRequest)

getCustomerPaymentProfileListResponse = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'getCustomerPaymentProfileListResponse'), CTD_ANON_92, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3750, 1))
Namespace.addCategoryObject('elementBinding', getCustomerPaymentProfileListResponse.name().localName(), getCustomerPaymentProfileListResponse)

ARBGetSubscriptionRequest = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'ARBGetSubscriptionRequest'), CTD_ANON_93, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3804, 1))
Namespace.addCategoryObject('elementBinding', ARBGetSubscriptionRequest.name().localName(), ARBGetSubscriptionRequest)

ARBGetSubscriptionResponse = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'ARBGetSubscriptionResponse'), CTD_ANON_94, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3822, 2))
Namespace.addCategoryObject('elementBinding', ARBGetSubscriptionResponse.name().localName(), ARBGetSubscriptionResponse)



ArrayOfLong._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'long'), pyxb.binding.datatypes.long, scope=ArrayOfLong, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 17, 3)))

def _BuildAutomaton ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton
    del _BuildAutomaton
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 17, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 18, 3))
    counters.add(cc_1)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(ArrayOfLong._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'long')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 17, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 18, 3))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    st_1._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
ArrayOfLong._Automaton = _BuildAutomaton()




ArrayOfNumericString._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'numericString'), numericString, scope=ArrayOfNumericString, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 24, 3)))

def _BuildAutomaton_ ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_
    del _BuildAutomaton_
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 24, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 25, 3))
    counters.add(cc_1)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(ArrayOfNumericString._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'numericString')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 24, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 25, 3))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    st_1._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
ArrayOfNumericString._Automaton = _BuildAutomaton_()




ArrayOfString._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'string'), pyxb.binding.datatypes.string, scope=ArrayOfString, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 31, 3)))

def _BuildAutomaton_2 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_2
    del _BuildAutomaton_2
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 31, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 32, 3))
    counters.add(cc_1)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(ArrayOfString._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'string')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 31, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 32, 3))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    st_1._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
ArrayOfString._Automaton = _BuildAutomaton_2()




ArrayOfLineItem._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'lineItem'), lineItemType, scope=ArrayOfLineItem, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 38, 3)))

def _BuildAutomaton_3 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_3
    del _BuildAutomaton_3
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 38, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 39, 3))
    counters.add(cc_1)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(ArrayOfLineItem._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'lineItem')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 38, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 39, 3))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    st_1._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
ArrayOfLineItem._Automaton = _BuildAutomaton_3()




ArrayOfBatchStatisticType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'statistic'), batchStatisticType, scope=ArrayOfBatchStatisticType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 45, 3)))

def _BuildAutomaton_4 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_4
    del _BuildAutomaton_4
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 45, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 46, 3))
    counters.add(cc_1)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(ArrayOfBatchStatisticType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'statistic')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 45, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 46, 3))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    st_1._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
ArrayOfBatchStatisticType._Automaton = _BuildAutomaton_4()




ArrayOfBatchDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'batch'), batchDetailsType, scope=ArrayOfBatchDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 52, 3)))

def _BuildAutomaton_5 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_5
    del _BuildAutomaton_5
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 52, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 53, 3))
    counters.add(cc_1)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(ArrayOfBatchDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'batch')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 52, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 53, 3))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    st_1._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
ArrayOfBatchDetailsType._Automaton = _BuildAutomaton_5()




ArrayOfTransactionSummaryType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'transaction'), transactionSummaryType, scope=ArrayOfTransactionSummaryType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 59, 3)))

def _BuildAutomaton_6 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_6
    del _BuildAutomaton_6
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 59, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 60, 3))
    counters.add(cc_1)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(ArrayOfTransactionSummaryType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'transaction')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 59, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 60, 3))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    st_1._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
ArrayOfTransactionSummaryType._Automaton = _BuildAutomaton_6()




ArrayOfSetting._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'setting'), settingType, scope=ArrayOfSetting, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 66, 3)))

def _BuildAutomaton_7 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_7
    del _BuildAutomaton_7
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 66, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 67, 3))
    counters.add(cc_1)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(ArrayOfSetting._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'setting')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 66, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 67, 3))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    st_1._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
ArrayOfSetting._Automaton = _BuildAutomaton_7()




ArrayOfFDSFilter._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'FDSFilter'), FDSFilterType, scope=ArrayOfFDSFilter, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 73, 3)))

def _BuildAutomaton_8 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_8
    del _BuildAutomaton_8
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 73, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 74, 3))
    counters.add(cc_1)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(ArrayOfFDSFilter._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'FDSFilter')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 73, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 74, 3))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    st_1._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
ArrayOfFDSFilter._Automaton = _BuildAutomaton_8()




ArrayOfPermissionType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'permission'), permissionType, scope=ArrayOfPermissionType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 80, 3)))

def _BuildAutomaton_9 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_9
    del _BuildAutomaton_9
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 80, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 81, 3))
    counters.add(cc_1)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(ArrayOfPermissionType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'permission')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 80, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 81, 3))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    st_1._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
ArrayOfPermissionType._Automaton = _BuildAutomaton_9()




driversLicenseType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'number'), STD_ANON, scope=driversLicenseType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 257, 3)))

driversLicenseType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'state'), STD_ANON_, scope=driversLicenseType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 265, 3)))

driversLicenseType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'dateOfBirth'), STD_ANON_2, scope=driversLicenseType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 274, 3)))

def _BuildAutomaton_10 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_10
    del _BuildAutomaton_10
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 282, 3))
    counters.add(cc_0)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(driversLicenseType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'number')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 257, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(driversLicenseType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'state')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 265, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(driversLicenseType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'dateOfBirth')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 274, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 282, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
         ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, True) ]))
    st_3._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
driversLicenseType._Automaton = _BuildAutomaton_10()




driversLicenseMaskedType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'number'), STD_ANON_3, scope=driversLicenseMaskedType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 288, 3)))

driversLicenseMaskedType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'state'), STD_ANON_4, scope=driversLicenseMaskedType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 295, 3)))

driversLicenseMaskedType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'dateOfBirth'), STD_ANON_5, scope=driversLicenseMaskedType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 303, 3)))

def _BuildAutomaton_11 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_11
    del _BuildAutomaton_11
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 311, 3))
    counters.add(cc_0)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(driversLicenseMaskedType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'number')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 288, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(driversLicenseMaskedType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'state')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 295, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(driversLicenseMaskedType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'dateOfBirth')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 303, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 311, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
         ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, True) ]))
    st_3._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
driversLicenseMaskedType._Automaton = _BuildAutomaton_11()




nameAndAddressType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'firstName'), STD_ANON_6, scope=nameAndAddressType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 317, 3)))

nameAndAddressType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'lastName'), STD_ANON_7, scope=nameAndAddressType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 324, 3)))

nameAndAddressType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'company'), STD_ANON_8, scope=nameAndAddressType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 331, 3)))

nameAndAddressType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'address'), STD_ANON_9, scope=nameAndAddressType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 338, 3)))

nameAndAddressType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'city'), STD_ANON_10, scope=nameAndAddressType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 345, 3)))

nameAndAddressType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'state'), STD_ANON_11, scope=nameAndAddressType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 352, 3)))

nameAndAddressType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'zip'), STD_ANON_12, scope=nameAndAddressType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 359, 3)))

nameAndAddressType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'country'), STD_ANON_13, scope=nameAndAddressType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 366, 3)))

def _BuildAutomaton_12 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_12
    del _BuildAutomaton_12
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 317, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 324, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 331, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 338, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 345, 3))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 352, 3))
    counters.add(cc_5)
    cc_6 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 359, 3))
    counters.add(cc_6)
    cc_7 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 366, 3))
    counters.add(cc_7)
    cc_8 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 373, 3))
    counters.add(cc_8)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(nameAndAddressType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'firstName')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 317, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(nameAndAddressType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'lastName')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 324, 3))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(nameAndAddressType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'company')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 331, 3))
    st_2 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.ElementUse(nameAndAddressType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'address')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 338, 3))
    st_3 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.ElementUse(nameAndAddressType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'city')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 345, 3))
    st_4 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.ElementUse(nameAndAddressType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'state')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 352, 3))
    st_5 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_6, False))
    symbol = pyxb.binding.content.ElementUse(nameAndAddressType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'zip')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 359, 3))
    st_6 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_7, False))
    symbol = pyxb.binding.content.ElementUse(nameAndAddressType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'country')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 366, 3))
    st_7 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_7)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_8, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 373, 3))
    st_8 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_8)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_5, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_5, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_6, True) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_6, False) ]))
    st_6._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_7, True) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_7, False) ]))
    st_7._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_8, True) ]))
    st_8._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
nameAndAddressType._Automaton = _BuildAutomaton_12()




merchantContactType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'merchantName'), pyxb.binding.datatypes.string, scope=merchantContactType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 379, 3)))

merchantContactType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'merchantAddress'), pyxb.binding.datatypes.string, scope=merchantContactType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 380, 3)))

merchantContactType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'merchantCity'), pyxb.binding.datatypes.string, scope=merchantContactType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 381, 3)))

merchantContactType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'merchantState'), pyxb.binding.datatypes.string, scope=merchantContactType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 382, 3)))

merchantContactType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'merchantZip'), pyxb.binding.datatypes.string, scope=merchantContactType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 383, 3)))

merchantContactType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'merchantPhone'), STD_ANON_14, scope=merchantContactType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 384, 3)))

def _BuildAutomaton_13 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_13
    del _BuildAutomaton_13
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 379, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 380, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 381, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 382, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 383, 3))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 384, 3))
    counters.add(cc_5)
    cc_6 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 391, 3))
    counters.add(cc_6)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(merchantContactType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantName')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 379, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(merchantContactType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantAddress')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 380, 3))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(merchantContactType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantCity')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 381, 3))
    st_2 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.ElementUse(merchantContactType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantState')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 382, 3))
    st_3 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.ElementUse(merchantContactType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantZip')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 383, 3))
    st_4 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.ElementUse(merchantContactType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantPhone')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 384, 3))
    st_5 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_6, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 391, 3))
    st_6 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_5, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_5, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_6, True) ]))
    st_6._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
merchantContactType._Automaton = _BuildAutomaton_13()




transRetailInfoType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'marketType'), pyxb.binding.datatypes.string, scope=transRetailInfoType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 397, 3), unicode_default='2'))

transRetailInfoType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'deviceType'), pyxb.binding.datatypes.string, scope=transRetailInfoType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 398, 3)))

transRetailInfoType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerSignature'), pyxb.binding.datatypes.string, scope=transRetailInfoType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 399, 12)))

def _BuildAutomaton_14 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_14
    del _BuildAutomaton_14
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 397, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 398, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 399, 12))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 400, 3))
    counters.add(cc_3)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(transRetailInfoType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'marketType')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 397, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(transRetailInfoType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'deviceType')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 398, 3))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(transRetailInfoType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerSignature')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 399, 12))
    st_2 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 400, 3))
    st_3 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_3, True) ]))
    st_3._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
transRetailInfoType._Automaton = _BuildAutomaton_14()




creditCardSimpleType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'cardNumber'), STD_ANON_15, scope=creditCardSimpleType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 407, 3)))

creditCardSimpleType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'expirationDate'), STD_ANON_16, scope=creditCardSimpleType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 416, 3)))

def _BuildAutomaton_15 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_15
    del _BuildAutomaton_15
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 424, 3))
    counters.add(cc_0)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(creditCardSimpleType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'cardNumber')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 407, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(creditCardSimpleType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'expirationDate')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 416, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 424, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, True) ]))
    st_2._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
creditCardSimpleType._Automaton = _BuildAutomaton_15()




creditCardTrackType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'track1'), pyxb.binding.datatypes.string, scope=creditCardTrackType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 430, 3)))

creditCardTrackType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'track2'), pyxb.binding.datatypes.string, scope=creditCardTrackType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 431, 3)))

def _BuildAutomaton_16 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_16
    del _BuildAutomaton_16
    import pyxb.utils.fac as fac

    counters = set()
    states = []
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(creditCardTrackType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'track1')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 430, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(creditCardTrackType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'track2')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 431, 3))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    transitions = []
    st_0._set_transitionSet(transitions)
    transitions = []
    st_1._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
creditCardTrackType._Automaton = _BuildAutomaton_16()




creditCardMaskedType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'cardNumber'), STD_ANON_17, scope=creditCardMaskedType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 461, 3)))

creditCardMaskedType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'expirationDate'), STD_ANON_18, scope=creditCardMaskedType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 468, 3)))

creditCardMaskedType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'cardType'), pyxb.binding.datatypes.string, scope=creditCardMaskedType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 476, 3)))

creditCardMaskedType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'cardArt'), cardArt, scope=creditCardMaskedType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 477, 3)))

def _BuildAutomaton_17 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_17
    del _BuildAutomaton_17
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 476, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 477, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 478, 5))
    counters.add(cc_2)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(creditCardMaskedType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'cardNumber')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 461, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(creditCardMaskedType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'expirationDate')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 468, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(creditCardMaskedType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'cardType')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 476, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(creditCardMaskedType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'cardArt')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 477, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 478, 5))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, True) ]))
    st_4._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
creditCardMaskedType._Automaton = _BuildAutomaton_17()




ccAuthenticationType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'authenticationIndicator'), pyxb.binding.datatypes.string, scope=ccAuthenticationType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 484, 3)))

ccAuthenticationType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'cardholderAuthenticationValue'), pyxb.binding.datatypes.string, scope=ccAuthenticationType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 485, 3)))

def _BuildAutomaton_18 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_18
    del _BuildAutomaton_18
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 486, 3))
    counters.add(cc_0)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(ccAuthenticationType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'authenticationIndicator')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 484, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(ccAuthenticationType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'cardholderAuthenticationValue')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 485, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 486, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, True) ]))
    st_2._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
ccAuthenticationType._Automaton = _BuildAutomaton_18()




bankAccountType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'accountType'), bankAccountTypeEnum, scope=bankAccountType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 492, 3)))

bankAccountType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'routingNumber'), STD_ANON_19, scope=bankAccountType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 494, 3)))

bankAccountType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'accountNumber'), STD_ANON_20, scope=bankAccountType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 502, 3)))

bankAccountType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'nameOnAccount'), STD_ANON_21, scope=bankAccountType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 509, 3)))

bankAccountType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'echeckType'), echeckTypeEnum, scope=bankAccountType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 516, 3)))

bankAccountType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'bankName'), STD_ANON_22, scope=bankAccountType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 517, 3)))

bankAccountType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'checkNumber'), STD_ANON_23, scope=bankAccountType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 524, 3)))

def _BuildAutomaton_19 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_19
    del _BuildAutomaton_19
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 492, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 516, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 517, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 524, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 531, 3))
    counters.add(cc_4)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(bankAccountType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'accountType')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 492, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(bankAccountType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'routingNumber')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 494, 3))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(bankAccountType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'accountNumber')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 502, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(bankAccountType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'nameOnAccount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 509, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(bankAccountType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'echeckType')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 516, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(bankAccountType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'bankName')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 517, 3))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.ElementUse(bankAccountType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'checkNumber')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 524, 3))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 531, 3))
    st_7 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_7)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
         ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
         ]))
    transitions.append(fac.Transition(st_5, [
         ]))
    transitions.append(fac.Transition(st_6, [
         ]))
    transitions.append(fac.Transition(st_7, [
         ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_6._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_4, True) ]))
    st_7._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
bankAccountType._Automaton = _BuildAutomaton_19()




bankAccountMaskedType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'accountType'), bankAccountTypeEnum, scope=bankAccountMaskedType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 537, 3)))

bankAccountMaskedType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'routingNumber'), STD_ANON_24, scope=bankAccountMaskedType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 538, 3)))

bankAccountMaskedType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'accountNumber'), STD_ANON_25, scope=bankAccountMaskedType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 545, 3)))

bankAccountMaskedType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'nameOnAccount'), STD_ANON_26, scope=bankAccountMaskedType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 552, 3)))

bankAccountMaskedType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'echeckType'), echeckTypeEnum, scope=bankAccountMaskedType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 559, 3)))

bankAccountMaskedType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'bankName'), STD_ANON_27, scope=bankAccountMaskedType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 560, 3)))

def _BuildAutomaton_20 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_20
    del _BuildAutomaton_20
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 537, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 559, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 560, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 567, 3))
    counters.add(cc_3)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(bankAccountMaskedType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'accountType')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 537, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(bankAccountMaskedType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'routingNumber')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 538, 3))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(bankAccountMaskedType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'accountNumber')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 545, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(bankAccountMaskedType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'nameOnAccount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 552, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(bankAccountMaskedType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'echeckType')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 559, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(bankAccountMaskedType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'bankName')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 560, 3))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 567, 3))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
         ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
         ]))
    transitions.append(fac.Transition(st_5, [
         ]))
    transitions.append(fac.Transition(st_6, [
         ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, True) ]))
    st_6._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
bankAccountMaskedType._Automaton = _BuildAutomaton_20()




opaqueDataType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'dataDescriptor'), pyxb.binding.datatypes.string, scope=opaqueDataType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 573, 6)))

opaqueDataType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'dataValue'), pyxb.binding.datatypes.string, scope=opaqueDataType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 574, 6)))

opaqueDataType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'dataKey'), pyxb.binding.datatypes.string, scope=opaqueDataType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 575, 6)))

def _BuildAutomaton_21 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_21
    del _BuildAutomaton_21
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 575, 6))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 576, 5))
    counters.add(cc_1)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(opaqueDataType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'dataDescriptor')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 573, 6))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(opaqueDataType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'dataValue')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 574, 6))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(opaqueDataType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'dataKey')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 575, 6))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 576, 5))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, True) ]))
    st_3._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
opaqueDataType._Automaton = _BuildAutomaton_21()




paymentSimpleType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'creditCard'), creditCardSimpleType, scope=paymentSimpleType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 583, 4)))

paymentSimpleType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'bankAccount'), bankAccountType, scope=paymentSimpleType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 584, 4)))

def _BuildAutomaton_22 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_22
    del _BuildAutomaton_22
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 586, 3))
    counters.add(cc_0)
    states = []
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(paymentSimpleType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'creditCard')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 583, 4))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(paymentSimpleType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'bankAccount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 584, 4))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 586, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, True) ]))
    st_2._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
paymentSimpleType._Automaton = _BuildAutomaton_22()




paymentType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'creditCard'), creditCardType, scope=paymentType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 593, 4)))

paymentType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'bankAccount'), bankAccountType, scope=paymentType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 594, 4)))

paymentType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'trackData'), creditCardTrackType, scope=paymentType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 595, 4)))

paymentType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'encryptedTrackData'), encryptedTrackDataType, scope=paymentType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 596, 4)))

paymentType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'payPal'), payPalType, scope=paymentType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 597, 4)))

paymentType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'opaqueData'), opaqueDataType, scope=paymentType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 598, 8)))

paymentType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'emv'), paymentEmvType, scope=paymentType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 599, 16)))

def _BuildAutomaton_23 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_23
    del _BuildAutomaton_23
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 601, 3))
    counters.add(cc_0)
    states = []
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(paymentType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'creditCard')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 593, 4))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(paymentType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'bankAccount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 594, 4))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(paymentType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'trackData')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 595, 4))
    st_2 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(paymentType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'encryptedTrackData')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 596, 4))
    st_3 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(paymentType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'payPal')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 597, 4))
    st_4 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(paymentType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'opaqueData')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 598, 8))
    st_5 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(paymentType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'emv')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 599, 16))
    st_6 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 601, 3))
    st_7 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_7)
    transitions = []
    transitions.append(fac.Transition(st_7, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_7, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_7, [
         ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_7, [
         ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_7, [
         ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_7, [
         ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_7, [
         ]))
    st_6._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_0, True) ]))
    st_7._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
paymentType._Automaton = _BuildAutomaton_23()




paymentMaskedType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'creditCard'), creditCardMaskedType, scope=paymentMaskedType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 608, 4)))

paymentMaskedType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'bankAccount'), bankAccountMaskedType, scope=paymentMaskedType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 609, 4)))

paymentMaskedType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'tokenInformation'), tokenMaskedType, scope=paymentMaskedType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 610, 8)))

def _BuildAutomaton_24 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_24
    del _BuildAutomaton_24
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 612, 3))
    counters.add(cc_0)
    states = []
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(paymentMaskedType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'creditCard')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 608, 4))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(paymentMaskedType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'bankAccount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 609, 4))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(paymentMaskedType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'tokenInformation')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 610, 8))
    st_2 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 612, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    transitions = []
    transitions.append(fac.Transition(st_3, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
         ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, True) ]))
    st_3._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
paymentMaskedType._Automaton = _BuildAutomaton_24()




tokenMaskedType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'tokenSource'), pyxb.binding.datatypes.string, scope=tokenMaskedType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 618, 6)))

tokenMaskedType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'tokenNumber'), pyxb.binding.datatypes.string, scope=tokenMaskedType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 619, 6)))

tokenMaskedType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'expirationDate'), STD_ANON_28, scope=tokenMaskedType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 620, 6)))

def _BuildAutomaton_25 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_25
    del _BuildAutomaton_25
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 618, 6))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 628, 5))
    counters.add(cc_1)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(tokenMaskedType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'tokenSource')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 618, 6))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(tokenMaskedType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'tokenNumber')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 619, 6))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(tokenMaskedType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'expirationDate')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 620, 6))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 628, 5))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
         ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, True) ]))
    st_3._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
tokenMaskedType._Automaton = _BuildAutomaton_25()




orderType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'invoiceNumber'), STD_ANON_29, scope=orderType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 634, 3)))

orderType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'description'), STD_ANON_30, scope=orderType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 641, 3)))

def _BuildAutomaton_26 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_26
    del _BuildAutomaton_26
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 634, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 641, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 648, 3))
    counters.add(cc_2)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(orderType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'invoiceNumber')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 634, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(orderType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'description')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 641, 3))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 648, 3))
    st_2 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_2, True) ]))
    st_2._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
orderType._Automaton = _BuildAutomaton_26()




customerType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'type'), customerTypeEnum, scope=customerType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 671, 3)))

customerType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'id'), STD_ANON_32, scope=customerType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 672, 3)))

customerType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'email'), STD_ANON_33, scope=customerType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 679, 3)))

customerType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'phoneNumber'), STD_ANON_34, scope=customerType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 686, 3)))

customerType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'faxNumber'), STD_ANON_35, scope=customerType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 693, 3)))

customerType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'driversLicense'), driversLicenseType, scope=customerType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 700, 3)))

customerType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'taxId'), STD_ANON_112, scope=customerType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 701, 3)))

def _BuildAutomaton_27 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_27
    del _BuildAutomaton_27
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 671, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 672, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 679, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 686, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 693, 3))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 700, 3))
    counters.add(cc_5)
    cc_6 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 701, 3))
    counters.add(cc_6)
    cc_7 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 709, 3))
    counters.add(cc_7)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(customerType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'type')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 671, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(customerType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'id')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 672, 3))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(customerType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'email')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 679, 3))
    st_2 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.ElementUse(customerType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'phoneNumber')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 686, 3))
    st_3 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.ElementUse(customerType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'faxNumber')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 693, 3))
    st_4 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.ElementUse(customerType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'driversLicense')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 700, 3))
    st_5 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_6, False))
    symbol = pyxb.binding.content.ElementUse(customerType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'taxId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 701, 3))
    st_6 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_7, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 709, 3))
    st_7 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_7)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_5, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_5, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_6, True) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_6, False) ]))
    st_6._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_7, True) ]))
    st_7._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
customerType._Automaton = _BuildAutomaton_27()




customerDataType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'type'), customerTypeEnum, scope=customerDataType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 715, 3)))

customerDataType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'id'), STD_ANON_36, scope=customerDataType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 716, 3)))

customerDataType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'email'), STD_ANON_37, scope=customerDataType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 723, 3)))

customerDataType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'driversLicense'), driversLicenseType, scope=customerDataType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 730, 3)))

customerDataType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'taxId'), STD_ANON_38, scope=customerDataType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 731, 3)))

def _BuildAutomaton_28 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_28
    del _BuildAutomaton_28
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 715, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 716, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 723, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 730, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 731, 3))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 739, 3))
    counters.add(cc_5)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(customerDataType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'type')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 715, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(customerDataType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'id')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 716, 3))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(customerDataType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'email')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 723, 3))
    st_2 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.ElementUse(customerDataType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'driversLicense')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 730, 3))
    st_3 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.ElementUse(customerDataType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'taxId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 731, 3))
    st_4 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 739, 3))
    st_5 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_5, True) ]))
    st_5._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
customerDataType._Automaton = _BuildAutomaton_28()




merchantAuthenticationType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'name'), STD_ANON_39, scope=merchantAuthenticationType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 745, 3)))

merchantAuthenticationType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'transactionKey'), STD_ANON_40, scope=merchantAuthenticationType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 754, 4)))

merchantAuthenticationType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'sessionToken'), pyxb.binding.datatypes.string, scope=merchantAuthenticationType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 761, 16)))

merchantAuthenticationType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'password'), STD_ANON_41, scope=merchantAuthenticationType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 762, 4)))

merchantAuthenticationType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'impersonationAuthentication'), impersonationAuthenticationType, scope=merchantAuthenticationType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 769, 8)))

merchantAuthenticationType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'fingerPrint'), fingerPrintType, scope=merchantAuthenticationType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 770, 8)))

merchantAuthenticationType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'mobileDeviceId'), STD_ANON_42, scope=merchantAuthenticationType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 772, 3)))

def _BuildAutomaton_29 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_29
    del _BuildAutomaton_29
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 745, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 761, 16))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 769, 8))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 770, 8))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 772, 3))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 779, 3))
    counters.add(cc_5)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(merchantAuthenticationType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'name')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 745, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(merchantAuthenticationType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'transactionKey')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 754, 4))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(merchantAuthenticationType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'sessionToken')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 761, 16))
    st_2 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(merchantAuthenticationType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'password')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 762, 4))
    st_3 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(merchantAuthenticationType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'impersonationAuthentication')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 769, 8))
    st_4 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.ElementUse(merchantAuthenticationType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'fingerPrint')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 770, 8))
    st_5 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.ElementUse(merchantAuthenticationType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'mobileDeviceId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 772, 3))
    st_6 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 779, 3))
    st_7 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_7)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
         ]))
    transitions.append(fac.Transition(st_7, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
         ]))
    transitions.append(fac.Transition(st_7, [
         ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_6._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_5, True) ]))
    st_7._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
merchantAuthenticationType._Automaton = _BuildAutomaton_29()




fingerPrintType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'hashValue'), pyxb.binding.datatypes.string, scope=fingerPrintType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 785, 6)))

fingerPrintType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'sequence'), pyxb.binding.datatypes.string, scope=fingerPrintType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 786, 6)))

fingerPrintType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'timestamp'), pyxb.binding.datatypes.string, scope=fingerPrintType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 787, 6)))

fingerPrintType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'currencyCode'), pyxb.binding.datatypes.string, scope=fingerPrintType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 788, 6)))

fingerPrintType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'amount'), pyxb.binding.datatypes.string, scope=fingerPrintType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 789, 6)))

def _BuildAutomaton_30 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_30
    del _BuildAutomaton_30
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 786, 6))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 788, 6))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 789, 6))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 790, 5))
    counters.add(cc_3)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(fingerPrintType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'hashValue')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 785, 6))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(fingerPrintType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'sequence')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 786, 6))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(fingerPrintType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'timestamp')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 787, 6))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(fingerPrintType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'currencyCode')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 788, 6))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(fingerPrintType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'amount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 789, 6))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 790, 5))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    transitions.append(fac.Transition(st_5, [
         ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, True) ]))
    st_5._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
fingerPrintType._Automaton = _BuildAutomaton_30()




cardArt._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'cardBrand'), pyxb.binding.datatypes.string, scope=cardArt, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 797, 6)))

cardArt._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'cardImageHeight'), pyxb.binding.datatypes.string, scope=cardArt, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 798, 6)))

cardArt._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'cardImageUrl'), pyxb.binding.datatypes.string, scope=cardArt, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 799, 6)))

cardArt._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'cardImageWidth'), pyxb.binding.datatypes.string, scope=cardArt, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 800, 6)))

cardArt._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'cardType'), pyxb.binding.datatypes.string, scope=cardArt, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 801, 6)))

def _BuildAutomaton_31 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_31
    del _BuildAutomaton_31
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 797, 6))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 798, 6))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 799, 6))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 800, 6))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 801, 6))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 802, 5))
    counters.add(cc_5)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(cardArt._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'cardBrand')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 797, 6))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(cardArt._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'cardImageHeight')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 798, 6))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(cardArt._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'cardImageUrl')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 799, 6))
    st_2 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.ElementUse(cardArt._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'cardImageWidth')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 800, 6))
    st_3 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.ElementUse(cardArt._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'cardType')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 801, 6))
    st_4 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 802, 5))
    st_5 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_5, True) ]))
    st_5._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
cardArt._Automaton = _BuildAutomaton_31()




paymentDetails._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'currency'), pyxb.binding.datatypes.string, scope=paymentDetails, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 808, 6)))

paymentDetails._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'promoCode'), pyxb.binding.datatypes.string, scope=paymentDetails, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 809, 6)))

paymentDetails._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'misc'), pyxb.binding.datatypes.string, scope=paymentDetails, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 810, 6)))

paymentDetails._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'giftWrap'), pyxb.binding.datatypes.string, scope=paymentDetails, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 811, 6)))

paymentDetails._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'discount'), pyxb.binding.datatypes.string, scope=paymentDetails, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 812, 6)))

paymentDetails._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'tax'), pyxb.binding.datatypes.string, scope=paymentDetails, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 813, 6)))

paymentDetails._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'shippingHandling'), pyxb.binding.datatypes.string, scope=paymentDetails, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 814, 6)))

paymentDetails._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'subTotal'), pyxb.binding.datatypes.string, scope=paymentDetails, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 815, 6)))

paymentDetails._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'orderID'), pyxb.binding.datatypes.string, scope=paymentDetails, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 816, 6)))

paymentDetails._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'amount'), pyxb.binding.datatypes.string, scope=paymentDetails, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 817, 6)))

def _BuildAutomaton_32 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_32
    del _BuildAutomaton_32
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 808, 6))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 809, 6))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 810, 6))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 811, 6))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 812, 6))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 813, 6))
    counters.add(cc_5)
    cc_6 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 814, 6))
    counters.add(cc_6)
    cc_7 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 815, 6))
    counters.add(cc_7)
    cc_8 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 816, 6))
    counters.add(cc_8)
    cc_9 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 817, 6))
    counters.add(cc_9)
    cc_10 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 818, 5))
    counters.add(cc_10)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(paymentDetails._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'currency')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 808, 6))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(paymentDetails._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'promoCode')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 809, 6))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(paymentDetails._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'misc')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 810, 6))
    st_2 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.ElementUse(paymentDetails._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'giftWrap')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 811, 6))
    st_3 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.ElementUse(paymentDetails._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'discount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 812, 6))
    st_4 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.ElementUse(paymentDetails._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'tax')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 813, 6))
    st_5 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_6, False))
    symbol = pyxb.binding.content.ElementUse(paymentDetails._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'shippingHandling')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 814, 6))
    st_6 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_7, False))
    symbol = pyxb.binding.content.ElementUse(paymentDetails._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'subTotal')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 815, 6))
    st_7 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_7)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_8, False))
    symbol = pyxb.binding.content.ElementUse(paymentDetails._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'orderID')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 816, 6))
    st_8 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_8)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_9, False))
    symbol = pyxb.binding.content.ElementUse(paymentDetails._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'amount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 817, 6))
    st_9 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_9)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_10, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 818, 5))
    st_10 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_10)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_5, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_5, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_6, True) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_6, False) ]))
    st_6._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_7, True) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_7, False) ]))
    st_7._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_8, True) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_8, False) ]))
    st_8._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_9, True) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_9, False) ]))
    st_9._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_10, True) ]))
    st_10._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
paymentDetails._Automaton = _BuildAutomaton_32()




webCheckOutDataType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'type'), webCheckOutTypeEnum, scope=webCheckOutDataType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 882, 6)))

webCheckOutDataType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'id'), STD_ANON_43, scope=webCheckOutDataType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 883, 6)))

webCheckOutDataType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'token'), CTD_ANON, scope=webCheckOutDataType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 891, 6)))

def _BuildAutomaton_33 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_33
    del _BuildAutomaton_33
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 931, 5))
    counters.add(cc_0)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(webCheckOutDataType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'type')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 882, 6))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(webCheckOutDataType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'id')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 883, 6))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(webCheckOutDataType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'token')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 891, 6))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 931, 5))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
         ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, True) ]))
    st_3._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
webCheckOutDataType._Automaton = _BuildAutomaton_33()




CTD_ANON._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'cardNumber'), STD_ANON_44, scope=CTD_ANON, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 894, 12)))

CTD_ANON._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'expirationDate'), STD_ANON_45, scope=CTD_ANON, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 902, 12)))

CTD_ANON._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'cardCode'), cardCode, scope=CTD_ANON, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 910, 12)))

CTD_ANON._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'zip'), STD_ANON_46, scope=CTD_ANON, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 911, 12)))

CTD_ANON._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'fullName'), STD_ANON_47, scope=CTD_ANON, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 919, 12)))

def _BuildAutomaton_34 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_34
    del _BuildAutomaton_34
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 910, 12))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 911, 12))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 919, 12))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 927, 11))
    counters.add(cc_3)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'cardNumber')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 894, 12))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'expirationDate')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 902, 12))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'cardCode')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 910, 12))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'zip')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 911, 12))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'fullName')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 919, 12))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 927, 11))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    transitions.append(fac.Transition(st_5, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, True) ]))
    st_5._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON._Automaton = _BuildAutomaton_34()




securePaymentContainerErrorType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'code'), pyxb.binding.datatypes.string, scope=securePaymentContainerErrorType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 937, 6)))

securePaymentContainerErrorType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'description'), pyxb.binding.datatypes.string, scope=securePaymentContainerErrorType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 938, 6)))

def _BuildAutomaton_35 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_35
    del _BuildAutomaton_35
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 939, 5))
    counters.add(cc_0)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(securePaymentContainerErrorType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'code')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 937, 6))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(securePaymentContainerErrorType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'description')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 938, 6))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 939, 5))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, True) ]))
    st_2._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
securePaymentContainerErrorType._Automaton = _BuildAutomaton_35()




impersonationAuthenticationType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'partnerLoginId'), STD_ANON_48, scope=impersonationAuthenticationType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 954, 6)))

impersonationAuthenticationType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'partnerTransactionKey'), STD_ANON_49, scope=impersonationAuthenticationType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 961, 6)))

def _BuildAutomaton_36 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_36
    del _BuildAutomaton_36
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 968, 5))
    counters.add(cc_0)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(impersonationAuthenticationType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'partnerLoginId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 954, 6))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(impersonationAuthenticationType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'partnerTransactionKey')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 961, 6))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 968, 5))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, True) ]))
    st_2._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
impersonationAuthenticationType._Automaton = _BuildAutomaton_36()




paymentScheduleTypeInterval._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'length'), STD_ANON_50, scope=paymentScheduleTypeInterval, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 974, 3)))

paymentScheduleTypeInterval._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'unit'), ARBSubscriptionUnitEnum, scope=paymentScheduleTypeInterval, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 982, 3)))

def _BuildAutomaton_37 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_37
    del _BuildAutomaton_37
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 983, 3))
    counters.add(cc_0)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(paymentScheduleTypeInterval._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'length')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 974, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(paymentScheduleTypeInterval._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'unit')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 982, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 983, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, True) ]))
    st_2._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
paymentScheduleTypeInterval._Automaton = _BuildAutomaton_37()




paymentScheduleType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'interval'), paymentScheduleTypeInterval, scope=paymentScheduleType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 992, 3)))

paymentScheduleType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'startDate'), pyxb.binding.datatypes.date, scope=paymentScheduleType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 994, 3)))

paymentScheduleType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'totalOccurrences'), STD_ANON_51, scope=paymentScheduleType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 996, 3)))

paymentScheduleType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'trialOccurrences'), STD_ANON_52, scope=paymentScheduleType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1005, 3)))

def _BuildAutomaton_38 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_38
    del _BuildAutomaton_38
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 992, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 994, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 996, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1005, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1013, 3))
    counters.add(cc_4)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(paymentScheduleType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'interval')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 992, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(paymentScheduleType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'startDate')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 994, 3))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(paymentScheduleType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'totalOccurrences')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 996, 3))
    st_2 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.ElementUse(paymentScheduleType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'trialOccurrences')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1005, 3))
    st_3 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1013, 3))
    st_4 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_4, True) ]))
    st_4._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
paymentScheduleType._Automaton = _BuildAutomaton_38()




ARBSubscriptionType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'name'), STD_ANON_53, scope=ARBSubscriptionType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1019, 3)))

ARBSubscriptionType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'paymentSchedule'), paymentScheduleType, scope=ARBSubscriptionType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1027, 3)))

ARBSubscriptionType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'amount'), STD_ANON_54, scope=ARBSubscriptionType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1028, 3)))

ARBSubscriptionType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'trialAmount'), STD_ANON_55, scope=ARBSubscriptionType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1036, 3)))

ARBSubscriptionType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'payment'), paymentType, scope=ARBSubscriptionType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1045, 3)))

ARBSubscriptionType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'order'), orderType, scope=ARBSubscriptionType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1046, 3)))

ARBSubscriptionType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customer'), customerType, scope=ARBSubscriptionType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1047, 3)))

ARBSubscriptionType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'billTo'), nameAndAddressType, scope=ARBSubscriptionType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1048, 3)))

ARBSubscriptionType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'shipTo'), nameAndAddressType, scope=ARBSubscriptionType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1049, 3)))

ARBSubscriptionType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'profile'), customerProfileIdType, scope=ARBSubscriptionType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1050, 3)))

def _BuildAutomaton_39 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_39
    del _BuildAutomaton_39
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1019, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1027, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1028, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1036, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1045, 3))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1046, 3))
    counters.add(cc_5)
    cc_6 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1047, 3))
    counters.add(cc_6)
    cc_7 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1048, 3))
    counters.add(cc_7)
    cc_8 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1049, 3))
    counters.add(cc_8)
    cc_9 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1050, 3))
    counters.add(cc_9)
    cc_10 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1051, 3))
    counters.add(cc_10)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(ARBSubscriptionType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'name')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1019, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(ARBSubscriptionType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'paymentSchedule')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1027, 3))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(ARBSubscriptionType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'amount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1028, 3))
    st_2 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.ElementUse(ARBSubscriptionType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'trialAmount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1036, 3))
    st_3 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.ElementUse(ARBSubscriptionType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'payment')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1045, 3))
    st_4 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.ElementUse(ARBSubscriptionType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'order')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1046, 3))
    st_5 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_6, False))
    symbol = pyxb.binding.content.ElementUse(ARBSubscriptionType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customer')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1047, 3))
    st_6 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_7, False))
    symbol = pyxb.binding.content.ElementUse(ARBSubscriptionType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'billTo')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1048, 3))
    st_7 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_7)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_8, False))
    symbol = pyxb.binding.content.ElementUse(ARBSubscriptionType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'shipTo')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1049, 3))
    st_8 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_8)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_9, False))
    symbol = pyxb.binding.content.ElementUse(ARBSubscriptionType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'profile')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1050, 3))
    st_9 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_9)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_10, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1051, 3))
    st_10 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_10)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_5, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_5, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_6, True) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_6, False) ]))
    st_6._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_7, True) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_7, False) ]))
    st_7._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_8, True) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_8, False) ]))
    st_8._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_9, True) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_9, False) ]))
    st_9._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_10, True) ]))
    st_10._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
ARBSubscriptionType._Automaton = _BuildAutomaton_39()




ARBSubscriptionMaskedType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'name'), STD_ANON_56, scope=ARBSubscriptionMaskedType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1059, 6)))

ARBSubscriptionMaskedType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'paymentSchedule'), paymentScheduleType, scope=ARBSubscriptionMaskedType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1067, 3)))

ARBSubscriptionMaskedType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'amount'), STD_ANON_57, scope=ARBSubscriptionMaskedType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1068, 3)))

ARBSubscriptionMaskedType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'trialAmount'), STD_ANON_58, scope=ARBSubscriptionMaskedType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1076, 3)))

ARBSubscriptionMaskedType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'status'), ARBSubscriptionStatusEnum, scope=ARBSubscriptionMaskedType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1084, 3)))

ARBSubscriptionMaskedType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'profile'), subscriptionCustomerProfileType, scope=ARBSubscriptionMaskedType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1085, 3)))

ARBSubscriptionMaskedType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'order'), orderType, scope=ARBSubscriptionMaskedType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1086, 3)))

def _BuildAutomaton_40 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_40
    del _BuildAutomaton_40
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1059, 6))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1067, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1068, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1076, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1084, 3))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1085, 3))
    counters.add(cc_5)
    cc_6 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1086, 3))
    counters.add(cc_6)
    cc_7 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1087, 9))
    counters.add(cc_7)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(ARBSubscriptionMaskedType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'name')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1059, 6))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(ARBSubscriptionMaskedType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'paymentSchedule')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1067, 3))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(ARBSubscriptionMaskedType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'amount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1068, 3))
    st_2 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.ElementUse(ARBSubscriptionMaskedType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'trialAmount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1076, 3))
    st_3 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.ElementUse(ARBSubscriptionMaskedType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'status')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1084, 3))
    st_4 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.ElementUse(ARBSubscriptionMaskedType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'profile')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1085, 3))
    st_5 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_6, False))
    symbol = pyxb.binding.content.ElementUse(ARBSubscriptionMaskedType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'order')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1086, 3))
    st_6 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_7, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1087, 9))
    st_7 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_7)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_5, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_5, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_6, True) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_6, False) ]))
    st_6._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_7, True) ]))
    st_7._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
ARBSubscriptionMaskedType._Automaton = _BuildAutomaton_40()




subscriptionPaymentType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'id'), STD_ANON_59, scope=subscriptionPaymentType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1109, 6)))

subscriptionPaymentType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'payNum'), STD_ANON_60, scope=subscriptionPaymentType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1116, 6)))

def _BuildAutomaton_41 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_41
    del _BuildAutomaton_41
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1123, 5))
    counters.add(cc_0)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(subscriptionPaymentType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'id')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1109, 6))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(subscriptionPaymentType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'payNum')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1116, 6))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1123, 5))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, True) ]))
    st_2._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
subscriptionPaymentType._Automaton = _BuildAutomaton_41()




mobileDeviceType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'mobileDeviceId'), STD_ANON_61, scope=mobileDeviceType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1129, 3)))

mobileDeviceType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'description'), STD_ANON_62, scope=mobileDeviceType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1136, 3)))

mobileDeviceType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'phoneNumber'), STD_ANON_63, scope=mobileDeviceType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1143, 3)))

mobileDeviceType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'devicePlatform'), STD_ANON_64, scope=mobileDeviceType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1150, 6)))

mobileDeviceType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'deviceActivation'), deviceActivationEnum, scope=mobileDeviceType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1157, 6)))

def _BuildAutomaton_42 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_42
    del _BuildAutomaton_42
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1136, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1143, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1150, 6))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1157, 6))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1158, 5))
    counters.add(cc_4)
    states = []
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(mobileDeviceType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'mobileDeviceId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1129, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(mobileDeviceType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'description')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1136, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(mobileDeviceType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'phoneNumber')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1143, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(mobileDeviceType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'devicePlatform')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1150, 6))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.ElementUse(mobileDeviceType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'deviceActivation')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1157, 6))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1158, 5))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    transitions.append(fac.Transition(st_5, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_4, True) ]))
    st_5._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
mobileDeviceType._Automaton = _BuildAutomaton_42()




transactionRequestType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'transactionType'), pyxb.binding.datatypes.string, scope=transactionRequestType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1169, 3)))

transactionRequestType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'amount'), pyxb.binding.datatypes.decimal, scope=transactionRequestType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1170, 3)))

transactionRequestType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'currencyCode'), pyxb.binding.datatypes.string, scope=transactionRequestType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1171, 6)))

transactionRequestType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'payment'), paymentType, scope=transactionRequestType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1172, 3)))

transactionRequestType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'profile'), customerProfilePaymentType, scope=transactionRequestType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1173, 6)))

transactionRequestType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'solution'), solutionType, scope=transactionRequestType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1174, 6)))

transactionRequestType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'callId'), pyxb.binding.datatypes.string, scope=transactionRequestType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1175, 6)))

transactionRequestType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'terminalNumber'), pyxb.binding.datatypes.string, scope=transactionRequestType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1176, 12)))

transactionRequestType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'authCode'), pyxb.binding.datatypes.string, scope=transactionRequestType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1177, 3)))

transactionRequestType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'refTransId'), pyxb.binding.datatypes.string, scope=transactionRequestType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1178, 3)))

transactionRequestType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'splitTenderId'), pyxb.binding.datatypes.string, scope=transactionRequestType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1179, 3)))

transactionRequestType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'order'), orderType, scope=transactionRequestType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1180, 3)))

transactionRequestType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'lineItems'), ArrayOfLineItem, scope=transactionRequestType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1181, 3)))

transactionRequestType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'tax'), extendedAmountType, scope=transactionRequestType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1182, 3)))

transactionRequestType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'duty'), extendedAmountType, scope=transactionRequestType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1183, 3)))

transactionRequestType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'shipping'), extendedAmountType, scope=transactionRequestType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1184, 3)))

transactionRequestType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'taxExempt'), STD_ANON_65, scope=transactionRequestType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1185, 3)))

transactionRequestType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'poNumber'), pyxb.binding.datatypes.string, scope=transactionRequestType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1190, 3)))

transactionRequestType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customer'), customerDataType, scope=transactionRequestType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1191, 3)))

transactionRequestType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'billTo'), customerAddressType, scope=transactionRequestType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1192, 3)))

transactionRequestType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'shipTo'), nameAndAddressType, scope=transactionRequestType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1193, 3)))

transactionRequestType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerIP'), pyxb.binding.datatypes.string, scope=transactionRequestType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1194, 3)))

transactionRequestType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'cardholderAuthentication'), ccAuthenticationType, scope=transactionRequestType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1195, 3)))

transactionRequestType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'retail'), transRetailInfoType, scope=transactionRequestType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1196, 3)))

transactionRequestType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'employeeId'), pyxb.binding.datatypes.string, scope=transactionRequestType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1197, 6)))

transactionRequestType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'transactionSettings'), ArrayOfSetting, scope=transactionRequestType, documentation='Allowed values for settingName are: emailCustomer, merchantEmail, allowPartialAuth, headerEmailReceipt, footerEmailReceipt, recurringBilling, duplicateWindow, testRequest.', location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1198, 3)))

transactionRequestType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'userFields'), CTD_ANON_, scope=transactionRequestType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1203, 3)))

def _BuildAutomaton_43 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_43
    del _BuildAutomaton_43
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1170, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1171, 6))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1172, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1173, 6))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1174, 6))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1175, 6))
    counters.add(cc_5)
    cc_6 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1176, 12))
    counters.add(cc_6)
    cc_7 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1177, 3))
    counters.add(cc_7)
    cc_8 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1178, 3))
    counters.add(cc_8)
    cc_9 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1179, 3))
    counters.add(cc_9)
    cc_10 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1180, 3))
    counters.add(cc_10)
    cc_11 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1181, 3))
    counters.add(cc_11)
    cc_12 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1182, 3))
    counters.add(cc_12)
    cc_13 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1183, 3))
    counters.add(cc_13)
    cc_14 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1184, 3))
    counters.add(cc_14)
    cc_15 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1185, 3))
    counters.add(cc_15)
    cc_16 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1190, 3))
    counters.add(cc_16)
    cc_17 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1191, 3))
    counters.add(cc_17)
    cc_18 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1192, 3))
    counters.add(cc_18)
    cc_19 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1193, 3))
    counters.add(cc_19)
    cc_20 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1194, 3))
    counters.add(cc_20)
    cc_21 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1195, 3))
    counters.add(cc_21)
    cc_22 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1196, 3))
    counters.add(cc_22)
    cc_23 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1197, 6))
    counters.add(cc_23)
    cc_24 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1198, 3))
    counters.add(cc_24)
    cc_25 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1203, 3))
    counters.add(cc_25)
    cc_26 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1211, 3))
    counters.add(cc_26)
    states = []
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(transactionRequestType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'transactionType')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1169, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(transactionRequestType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'amount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1170, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(transactionRequestType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'currencyCode')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1171, 6))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(transactionRequestType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'payment')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1172, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.ElementUse(transactionRequestType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'profile')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1173, 6))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.ElementUse(transactionRequestType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'solution')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1174, 6))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.ElementUse(transactionRequestType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'callId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1175, 6))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_6, False))
    symbol = pyxb.binding.content.ElementUse(transactionRequestType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'terminalNumber')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1176, 12))
    st_7 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_7)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_7, False))
    symbol = pyxb.binding.content.ElementUse(transactionRequestType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'authCode')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1177, 3))
    st_8 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_8)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_8, False))
    symbol = pyxb.binding.content.ElementUse(transactionRequestType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refTransId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1178, 3))
    st_9 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_9)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_9, False))
    symbol = pyxb.binding.content.ElementUse(transactionRequestType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'splitTenderId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1179, 3))
    st_10 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_10)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_10, False))
    symbol = pyxb.binding.content.ElementUse(transactionRequestType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'order')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1180, 3))
    st_11 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_11)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_11, False))
    symbol = pyxb.binding.content.ElementUse(transactionRequestType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'lineItems')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1181, 3))
    st_12 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_12)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_12, False))
    symbol = pyxb.binding.content.ElementUse(transactionRequestType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'tax')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1182, 3))
    st_13 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_13)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_13, False))
    symbol = pyxb.binding.content.ElementUse(transactionRequestType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'duty')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1183, 3))
    st_14 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_14)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_14, False))
    symbol = pyxb.binding.content.ElementUse(transactionRequestType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'shipping')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1184, 3))
    st_15 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_15)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_15, False))
    symbol = pyxb.binding.content.ElementUse(transactionRequestType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'taxExempt')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1185, 3))
    st_16 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_16)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_16, False))
    symbol = pyxb.binding.content.ElementUse(transactionRequestType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'poNumber')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1190, 3))
    st_17 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_17)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_17, False))
    symbol = pyxb.binding.content.ElementUse(transactionRequestType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customer')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1191, 3))
    st_18 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_18)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_18, False))
    symbol = pyxb.binding.content.ElementUse(transactionRequestType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'billTo')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1192, 3))
    st_19 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_19)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_19, False))
    symbol = pyxb.binding.content.ElementUse(transactionRequestType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'shipTo')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1193, 3))
    st_20 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_20)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_20, False))
    symbol = pyxb.binding.content.ElementUse(transactionRequestType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerIP')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1194, 3))
    st_21 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_21)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_21, False))
    symbol = pyxb.binding.content.ElementUse(transactionRequestType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'cardholderAuthentication')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1195, 3))
    st_22 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_22)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_22, False))
    symbol = pyxb.binding.content.ElementUse(transactionRequestType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'retail')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1196, 3))
    st_23 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_23)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_23, False))
    symbol = pyxb.binding.content.ElementUse(transactionRequestType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'employeeId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1197, 6))
    st_24 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_24)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_24, False))
    symbol = pyxb.binding.content.ElementUse(transactionRequestType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'transactionSettings')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1198, 3))
    st_25 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_25)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_25, False))
    symbol = pyxb.binding.content.ElementUse(transactionRequestType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'userFields')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1203, 3))
    st_26 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_26)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_26, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1211, 3))
    st_27 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_27)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    transitions.append(fac.Transition(st_5, [
         ]))
    transitions.append(fac.Transition(st_6, [
         ]))
    transitions.append(fac.Transition(st_7, [
         ]))
    transitions.append(fac.Transition(st_8, [
         ]))
    transitions.append(fac.Transition(st_9, [
         ]))
    transitions.append(fac.Transition(st_10, [
         ]))
    transitions.append(fac.Transition(st_11, [
         ]))
    transitions.append(fac.Transition(st_12, [
         ]))
    transitions.append(fac.Transition(st_13, [
         ]))
    transitions.append(fac.Transition(st_14, [
         ]))
    transitions.append(fac.Transition(st_15, [
         ]))
    transitions.append(fac.Transition(st_16, [
         ]))
    transitions.append(fac.Transition(st_17, [
         ]))
    transitions.append(fac.Transition(st_18, [
         ]))
    transitions.append(fac.Transition(st_19, [
         ]))
    transitions.append(fac.Transition(st_20, [
         ]))
    transitions.append(fac.Transition(st_21, [
         ]))
    transitions.append(fac.Transition(st_22, [
         ]))
    transitions.append(fac.Transition(st_23, [
         ]))
    transitions.append(fac.Transition(st_24, [
         ]))
    transitions.append(fac.Transition(st_25, [
         ]))
    transitions.append(fac.Transition(st_26, [
         ]))
    transitions.append(fac.Transition(st_27, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_22, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_23, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_24, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_25, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_26, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_27, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_22, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_23, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_24, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_25, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_26, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_27, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_22, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_23, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_24, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_25, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_26, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_27, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_22, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_23, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_24, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_25, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_26, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_27, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_22, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_23, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_24, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_25, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_26, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_27, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_5, True) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_22, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_23, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_24, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_25, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_26, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_27, [
        fac.UpdateInstruction(cc_5, False) ]))
    st_6._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_6, True) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_22, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_23, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_24, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_25, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_26, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_27, [
        fac.UpdateInstruction(cc_6, False) ]))
    st_7._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_7, True) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_22, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_23, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_24, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_25, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_26, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_27, [
        fac.UpdateInstruction(cc_7, False) ]))
    st_8._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_8, True) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_22, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_23, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_24, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_25, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_26, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_27, [
        fac.UpdateInstruction(cc_8, False) ]))
    st_9._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_9, True) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_9, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_9, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_9, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_9, False) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_9, False) ]))
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_9, False) ]))
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_9, False) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_9, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_9, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_9, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_9, False) ]))
    transitions.append(fac.Transition(st_22, [
        fac.UpdateInstruction(cc_9, False) ]))
    transitions.append(fac.Transition(st_23, [
        fac.UpdateInstruction(cc_9, False) ]))
    transitions.append(fac.Transition(st_24, [
        fac.UpdateInstruction(cc_9, False) ]))
    transitions.append(fac.Transition(st_25, [
        fac.UpdateInstruction(cc_9, False) ]))
    transitions.append(fac.Transition(st_26, [
        fac.UpdateInstruction(cc_9, False) ]))
    transitions.append(fac.Transition(st_27, [
        fac.UpdateInstruction(cc_9, False) ]))
    st_10._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_10, True) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_10, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_10, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_10, False) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_10, False) ]))
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_10, False) ]))
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_10, False) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_10, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_10, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_10, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_10, False) ]))
    transitions.append(fac.Transition(st_22, [
        fac.UpdateInstruction(cc_10, False) ]))
    transitions.append(fac.Transition(st_23, [
        fac.UpdateInstruction(cc_10, False) ]))
    transitions.append(fac.Transition(st_24, [
        fac.UpdateInstruction(cc_10, False) ]))
    transitions.append(fac.Transition(st_25, [
        fac.UpdateInstruction(cc_10, False) ]))
    transitions.append(fac.Transition(st_26, [
        fac.UpdateInstruction(cc_10, False) ]))
    transitions.append(fac.Transition(st_27, [
        fac.UpdateInstruction(cc_10, False) ]))
    st_11._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_11, True) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_11, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_11, False) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_11, False) ]))
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_11, False) ]))
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_11, False) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_11, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_11, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_11, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_11, False) ]))
    transitions.append(fac.Transition(st_22, [
        fac.UpdateInstruction(cc_11, False) ]))
    transitions.append(fac.Transition(st_23, [
        fac.UpdateInstruction(cc_11, False) ]))
    transitions.append(fac.Transition(st_24, [
        fac.UpdateInstruction(cc_11, False) ]))
    transitions.append(fac.Transition(st_25, [
        fac.UpdateInstruction(cc_11, False) ]))
    transitions.append(fac.Transition(st_26, [
        fac.UpdateInstruction(cc_11, False) ]))
    transitions.append(fac.Transition(st_27, [
        fac.UpdateInstruction(cc_11, False) ]))
    st_12._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_12, True) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_12, False) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_12, False) ]))
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_12, False) ]))
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_12, False) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_12, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_12, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_12, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_12, False) ]))
    transitions.append(fac.Transition(st_22, [
        fac.UpdateInstruction(cc_12, False) ]))
    transitions.append(fac.Transition(st_23, [
        fac.UpdateInstruction(cc_12, False) ]))
    transitions.append(fac.Transition(st_24, [
        fac.UpdateInstruction(cc_12, False) ]))
    transitions.append(fac.Transition(st_25, [
        fac.UpdateInstruction(cc_12, False) ]))
    transitions.append(fac.Transition(st_26, [
        fac.UpdateInstruction(cc_12, False) ]))
    transitions.append(fac.Transition(st_27, [
        fac.UpdateInstruction(cc_12, False) ]))
    st_13._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_13, True) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_13, False) ]))
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_13, False) ]))
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_13, False) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_13, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_13, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_13, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_13, False) ]))
    transitions.append(fac.Transition(st_22, [
        fac.UpdateInstruction(cc_13, False) ]))
    transitions.append(fac.Transition(st_23, [
        fac.UpdateInstruction(cc_13, False) ]))
    transitions.append(fac.Transition(st_24, [
        fac.UpdateInstruction(cc_13, False) ]))
    transitions.append(fac.Transition(st_25, [
        fac.UpdateInstruction(cc_13, False) ]))
    transitions.append(fac.Transition(st_26, [
        fac.UpdateInstruction(cc_13, False) ]))
    transitions.append(fac.Transition(st_27, [
        fac.UpdateInstruction(cc_13, False) ]))
    st_14._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_14, True) ]))
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_14, False) ]))
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_14, False) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_14, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_14, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_14, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_14, False) ]))
    transitions.append(fac.Transition(st_22, [
        fac.UpdateInstruction(cc_14, False) ]))
    transitions.append(fac.Transition(st_23, [
        fac.UpdateInstruction(cc_14, False) ]))
    transitions.append(fac.Transition(st_24, [
        fac.UpdateInstruction(cc_14, False) ]))
    transitions.append(fac.Transition(st_25, [
        fac.UpdateInstruction(cc_14, False) ]))
    transitions.append(fac.Transition(st_26, [
        fac.UpdateInstruction(cc_14, False) ]))
    transitions.append(fac.Transition(st_27, [
        fac.UpdateInstruction(cc_14, False) ]))
    st_15._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_15, True) ]))
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_15, False) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_15, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_15, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_15, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_15, False) ]))
    transitions.append(fac.Transition(st_22, [
        fac.UpdateInstruction(cc_15, False) ]))
    transitions.append(fac.Transition(st_23, [
        fac.UpdateInstruction(cc_15, False) ]))
    transitions.append(fac.Transition(st_24, [
        fac.UpdateInstruction(cc_15, False) ]))
    transitions.append(fac.Transition(st_25, [
        fac.UpdateInstruction(cc_15, False) ]))
    transitions.append(fac.Transition(st_26, [
        fac.UpdateInstruction(cc_15, False) ]))
    transitions.append(fac.Transition(st_27, [
        fac.UpdateInstruction(cc_15, False) ]))
    st_16._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_16, True) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_16, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_16, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_16, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_16, False) ]))
    transitions.append(fac.Transition(st_22, [
        fac.UpdateInstruction(cc_16, False) ]))
    transitions.append(fac.Transition(st_23, [
        fac.UpdateInstruction(cc_16, False) ]))
    transitions.append(fac.Transition(st_24, [
        fac.UpdateInstruction(cc_16, False) ]))
    transitions.append(fac.Transition(st_25, [
        fac.UpdateInstruction(cc_16, False) ]))
    transitions.append(fac.Transition(st_26, [
        fac.UpdateInstruction(cc_16, False) ]))
    transitions.append(fac.Transition(st_27, [
        fac.UpdateInstruction(cc_16, False) ]))
    st_17._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_17, True) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_17, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_17, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_17, False) ]))
    transitions.append(fac.Transition(st_22, [
        fac.UpdateInstruction(cc_17, False) ]))
    transitions.append(fac.Transition(st_23, [
        fac.UpdateInstruction(cc_17, False) ]))
    transitions.append(fac.Transition(st_24, [
        fac.UpdateInstruction(cc_17, False) ]))
    transitions.append(fac.Transition(st_25, [
        fac.UpdateInstruction(cc_17, False) ]))
    transitions.append(fac.Transition(st_26, [
        fac.UpdateInstruction(cc_17, False) ]))
    transitions.append(fac.Transition(st_27, [
        fac.UpdateInstruction(cc_17, False) ]))
    st_18._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_18, True) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_18, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_18, False) ]))
    transitions.append(fac.Transition(st_22, [
        fac.UpdateInstruction(cc_18, False) ]))
    transitions.append(fac.Transition(st_23, [
        fac.UpdateInstruction(cc_18, False) ]))
    transitions.append(fac.Transition(st_24, [
        fac.UpdateInstruction(cc_18, False) ]))
    transitions.append(fac.Transition(st_25, [
        fac.UpdateInstruction(cc_18, False) ]))
    transitions.append(fac.Transition(st_26, [
        fac.UpdateInstruction(cc_18, False) ]))
    transitions.append(fac.Transition(st_27, [
        fac.UpdateInstruction(cc_18, False) ]))
    st_19._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_19, True) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_19, False) ]))
    transitions.append(fac.Transition(st_22, [
        fac.UpdateInstruction(cc_19, False) ]))
    transitions.append(fac.Transition(st_23, [
        fac.UpdateInstruction(cc_19, False) ]))
    transitions.append(fac.Transition(st_24, [
        fac.UpdateInstruction(cc_19, False) ]))
    transitions.append(fac.Transition(st_25, [
        fac.UpdateInstruction(cc_19, False) ]))
    transitions.append(fac.Transition(st_26, [
        fac.UpdateInstruction(cc_19, False) ]))
    transitions.append(fac.Transition(st_27, [
        fac.UpdateInstruction(cc_19, False) ]))
    st_20._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_20, True) ]))
    transitions.append(fac.Transition(st_22, [
        fac.UpdateInstruction(cc_20, False) ]))
    transitions.append(fac.Transition(st_23, [
        fac.UpdateInstruction(cc_20, False) ]))
    transitions.append(fac.Transition(st_24, [
        fac.UpdateInstruction(cc_20, False) ]))
    transitions.append(fac.Transition(st_25, [
        fac.UpdateInstruction(cc_20, False) ]))
    transitions.append(fac.Transition(st_26, [
        fac.UpdateInstruction(cc_20, False) ]))
    transitions.append(fac.Transition(st_27, [
        fac.UpdateInstruction(cc_20, False) ]))
    st_21._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_22, [
        fac.UpdateInstruction(cc_21, True) ]))
    transitions.append(fac.Transition(st_23, [
        fac.UpdateInstruction(cc_21, False) ]))
    transitions.append(fac.Transition(st_24, [
        fac.UpdateInstruction(cc_21, False) ]))
    transitions.append(fac.Transition(st_25, [
        fac.UpdateInstruction(cc_21, False) ]))
    transitions.append(fac.Transition(st_26, [
        fac.UpdateInstruction(cc_21, False) ]))
    transitions.append(fac.Transition(st_27, [
        fac.UpdateInstruction(cc_21, False) ]))
    st_22._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_23, [
        fac.UpdateInstruction(cc_22, True) ]))
    transitions.append(fac.Transition(st_24, [
        fac.UpdateInstruction(cc_22, False) ]))
    transitions.append(fac.Transition(st_25, [
        fac.UpdateInstruction(cc_22, False) ]))
    transitions.append(fac.Transition(st_26, [
        fac.UpdateInstruction(cc_22, False) ]))
    transitions.append(fac.Transition(st_27, [
        fac.UpdateInstruction(cc_22, False) ]))
    st_23._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_24, [
        fac.UpdateInstruction(cc_23, True) ]))
    transitions.append(fac.Transition(st_25, [
        fac.UpdateInstruction(cc_23, False) ]))
    transitions.append(fac.Transition(st_26, [
        fac.UpdateInstruction(cc_23, False) ]))
    transitions.append(fac.Transition(st_27, [
        fac.UpdateInstruction(cc_23, False) ]))
    st_24._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_25, [
        fac.UpdateInstruction(cc_24, True) ]))
    transitions.append(fac.Transition(st_26, [
        fac.UpdateInstruction(cc_24, False) ]))
    transitions.append(fac.Transition(st_27, [
        fac.UpdateInstruction(cc_24, False) ]))
    st_25._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_26, [
        fac.UpdateInstruction(cc_25, True) ]))
    transitions.append(fac.Transition(st_27, [
        fac.UpdateInstruction(cc_25, False) ]))
    st_26._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_27, [
        fac.UpdateInstruction(cc_26, True) ]))
    st_27._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
transactionRequestType._Automaton = _BuildAutomaton_43()




CTD_ANON_._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'userField'), userField, scope=CTD_ANON_, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1206, 6)))

def _BuildAutomaton_44 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_44
    del _BuildAutomaton_44
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=20, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1206, 6))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1207, 6))
    counters.add(cc_1)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'userField')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1206, 6))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1207, 6))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    st_1._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
CTD_ANON_._Automaton = _BuildAutomaton_44()




KeyManagementScheme._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'DUKPT'), CTD_ANON_2, scope=KeyManagementScheme, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1217, 7)))

def _BuildAutomaton_45 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_45
    del _BuildAutomaton_45
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1250, 6))
    counters.add(cc_0)
    states = []
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(KeyManagementScheme._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'DUKPT')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1217, 7))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1250, 6))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    st_1._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
KeyManagementScheme._Automaton = _BuildAutomaton_45()




CTD_ANON_2._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'Operation'), OperationType, scope=CTD_ANON_2, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1220, 13)))

CTD_ANON_2._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'Mode'), CTD_ANON_3, scope=CTD_ANON_2, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1221, 13)))

CTD_ANON_2._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'DeviceInfo'), CTD_ANON_4, scope=CTD_ANON_2, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1230, 13)))

CTD_ANON_2._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'EncryptedData'), CTD_ANON_5, scope=CTD_ANON_2, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1238, 13)))

def _BuildAutomaton_46 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_46
    del _BuildAutomaton_46
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1246, 12))
    counters.add(cc_0)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_2._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'Operation')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1220, 13))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_2._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'Mode')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1221, 13))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_2._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'DeviceInfo')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1230, 13))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_2._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'EncryptedData')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1238, 13))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1246, 12))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
         ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
         ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_0, True) ]))
    st_4._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_2._Automaton = _BuildAutomaton_46()




CTD_ANON_3._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'PIN'), pyxb.binding.datatypes.string, scope=CTD_ANON_3, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1224, 19)))

CTD_ANON_3._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'Data'), pyxb.binding.datatypes.string, scope=CTD_ANON_3, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1225, 19)))

def _BuildAutomaton_47 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_47
    del _BuildAutomaton_47
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1224, 19))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1225, 19))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1226, 18))
    counters.add(cc_2)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_3._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'PIN')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1224, 19))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_3._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'Data')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1225, 19))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1226, 18))
    st_2 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_2, True) ]))
    st_2._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
CTD_ANON_3._Automaton = _BuildAutomaton_47()




CTD_ANON_4._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'Description'), pyxb.binding.datatypes.string, scope=CTD_ANON_4, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1233, 19)))

def _BuildAutomaton_48 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_48
    del _BuildAutomaton_48
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1234, 18))
    counters.add(cc_0)
    states = []
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_4._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'Description')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1233, 19))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1234, 18))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    st_1._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_4._Automaton = _BuildAutomaton_48()




CTD_ANON_5._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'Value'), pyxb.binding.datatypes.string, scope=CTD_ANON_5, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1241, 19)))

def _BuildAutomaton_49 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_49
    del _BuildAutomaton_49
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1242, 18))
    counters.add(cc_0)
    states = []
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_5._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'Value')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1241, 19))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1242, 18))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    st_1._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_5._Automaton = _BuildAutomaton_49()




KeyValue._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'Encoding'), EncodingType, scope=KeyValue, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1273, 7)))

KeyValue._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'EncryptionAlgorithm'), EncryptionAlgorithmType, scope=KeyValue, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1274, 7)))

KeyValue._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'Scheme'), KeyManagementScheme, scope=KeyValue, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1275, 7)))

def _BuildAutomaton_50 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_50
    del _BuildAutomaton_50
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1276, 6))
    counters.add(cc_0)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(KeyValue._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'Encoding')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1273, 7))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(KeyValue._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'EncryptionAlgorithm')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1274, 7))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(KeyValue._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'Scheme')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1275, 7))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1276, 6))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
         ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, True) ]))
    st_3._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
KeyValue._Automaton = _BuildAutomaton_50()




KeyBlock._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'Value'), KeyValue, scope=KeyBlock, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1281, 12)))

def _BuildAutomaton_51 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_51
    del _BuildAutomaton_51
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1282, 6))
    counters.add(cc_0)
    states = []
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(KeyBlock._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'Value')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1281, 12))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1282, 6))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    st_1._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
KeyBlock._Automaton = _BuildAutomaton_51()




encryptedTrackDataType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'FormOfPayment'), KeyBlock, scope=encryptedTrackDataType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1287, 7)))

def _BuildAutomaton_52 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_52
    del _BuildAutomaton_52
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1288, 6))
    counters.add(cc_0)
    states = []
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(encryptedTrackDataType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'FormOfPayment')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1287, 7))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1288, 6))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    st_1._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
encryptedTrackDataType._Automaton = _BuildAutomaton_52()




settingType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'settingName'), pyxb.binding.datatypes.string, scope=settingType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1294, 3)))

settingType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'settingValue'), pyxb.binding.datatypes.string, scope=settingType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1295, 3)))

def _BuildAutomaton_53 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_53
    del _BuildAutomaton_53
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1294, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1295, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1296, 3))
    counters.add(cc_2)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(settingType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'settingName')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1294, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(settingType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'settingValue')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1295, 3))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1296, 3))
    st_2 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_2, True) ]))
    st_2._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
settingType._Automaton = _BuildAutomaton_53()




permissionType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'permissionName'), pyxb.binding.datatypes.string, scope=permissionType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1302, 3)))

def _BuildAutomaton_54 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_54
    del _BuildAutomaton_54
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1302, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1303, 3))
    counters.add(cc_1)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(permissionType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'permissionName')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1302, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1303, 3))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    st_1._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
permissionType._Automaton = _BuildAutomaton_54()




userField._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'name'), pyxb.binding.datatypes.string, scope=userField, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1399, 3)))

userField._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'value'), pyxb.binding.datatypes.string, scope=userField, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1400, 3)))

def _BuildAutomaton_55 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_55
    del _BuildAutomaton_55
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1399, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1400, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1401, 3))
    counters.add(cc_2)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(userField._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'name')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1399, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(userField._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'value')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1400, 3))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1401, 3))
    st_2 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_2, True) ]))
    st_2._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
userField._Automaton = _BuildAutomaton_55()




emvTag._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'name'), pyxb.binding.datatypes.string, scope=emvTag, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1407, 12)))

emvTag._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'value'), pyxb.binding.datatypes.string, scope=emvTag, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1408, 12)))

emvTag._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'formatted'), pyxb.binding.datatypes.string, scope=emvTag, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1409, 12)))

def _BuildAutomaton_56 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_56
    del _BuildAutomaton_56
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1407, 12))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1408, 12))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1409, 12))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1410, 9))
    counters.add(cc_3)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(emvTag._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'name')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1407, 12))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(emvTag._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'value')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1408, 12))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(emvTag._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'formatted')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1409, 12))
    st_2 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1410, 9))
    st_3 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_3, True) ]))
    st_3._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
emvTag._Automaton = _BuildAutomaton_56()




customerPaymentProfileBaseType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerType'), customerTypeEnum, scope=customerPaymentProfileBaseType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1416, 3)))

customerPaymentProfileBaseType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'billTo'), customerAddressType, scope=customerPaymentProfileBaseType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1417, 3)))

def _BuildAutomaton_57 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_57
    del _BuildAutomaton_57
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1416, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1417, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1418, 3))
    counters.add(cc_2)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(customerPaymentProfileBaseType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerType')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1416, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(customerPaymentProfileBaseType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'billTo')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1417, 3))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1418, 3))
    st_2 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_2, True) ]))
    st_2._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
customerPaymentProfileBaseType._Automaton = _BuildAutomaton_57()




SubscriptionIdList._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'subscriptionId'), numericString, scope=SubscriptionIdList, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1480, 4)))

def _BuildAutomaton_58 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_58
    del _BuildAutomaton_58
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1480, 4))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1481, 4))
    counters.add(cc_1)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(SubscriptionIdList._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'subscriptionId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1480, 4))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1481, 4))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    st_1._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
SubscriptionIdList._Automaton = _BuildAutomaton_58()




customerProfileBaseType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'merchantCustomerId'), STD_ANON_68, scope=customerProfileBaseType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1487, 3)))

customerProfileBaseType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'description'), STD_ANON_69, scope=customerProfileBaseType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1494, 3)))

customerProfileBaseType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'email'), STD_ANON_70, scope=customerProfileBaseType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1501, 3)))

def _BuildAutomaton_59 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_59
    del _BuildAutomaton_59
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1487, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1494, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1501, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1508, 3))
    counters.add(cc_3)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(customerProfileBaseType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantCustomerId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1487, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(customerProfileBaseType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'description')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1494, 3))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(customerProfileBaseType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'email')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1501, 3))
    st_2 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1508, 3))
    st_3 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_3, True) ]))
    st_3._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
customerProfileBaseType._Automaton = _BuildAutomaton_59()




paymentEmvType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'emvData'), pyxb.binding.datatypes.anyType, scope=paymentEmvType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1526, 12)))

paymentEmvType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'emvDescriptor'), pyxb.binding.datatypes.anyType, scope=paymentEmvType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1527, 12)))

paymentEmvType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'emvVersion'), pyxb.binding.datatypes.anyType, scope=paymentEmvType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1528, 12)))

def _BuildAutomaton_60 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_60
    del _BuildAutomaton_60
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1529, 9))
    counters.add(cc_0)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(paymentEmvType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'emvData')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1526, 12))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(paymentEmvType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'emvDescriptor')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1527, 12))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(paymentEmvType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'emvVersion')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1528, 12))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1529, 9))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
         ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, True) ]))
    st_3._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
paymentEmvType._Automaton = _BuildAutomaton_60()




extendedAmountType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'amount'), STD_ANON_73, scope=extendedAmountType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1594, 3)))

extendedAmountType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'name'), STD_ANON_74, scope=extendedAmountType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1602, 3)))

extendedAmountType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'description'), STD_ANON_75, scope=extendedAmountType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1609, 3)))

def _BuildAutomaton_61 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_61
    del _BuildAutomaton_61
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1602, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1609, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1616, 3))
    counters.add(cc_2)
    states = []
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(extendedAmountType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'amount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1594, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(extendedAmountType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'name')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1602, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(extendedAmountType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'description')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1609, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1616, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    st_3._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
extendedAmountType._Automaton = _BuildAutomaton_61()




lineItemType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'itemId'), STD_ANON_76, scope=lineItemType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1622, 3)))

lineItemType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'name'), STD_ANON_77, scope=lineItemType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1630, 3)))

lineItemType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'description'), STD_ANON_78, scope=lineItemType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1638, 3)))

lineItemType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'quantity'), STD_ANON_79, scope=lineItemType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1645, 3)))

lineItemType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'unitPrice'), STD_ANON_80, scope=lineItemType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1653, 3)))

lineItemType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'taxable'), pyxb.binding.datatypes.boolean, scope=lineItemType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1661, 3)))

def _BuildAutomaton_62 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_62
    del _BuildAutomaton_62
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1638, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1661, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1662, 3))
    counters.add(cc_2)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(lineItemType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'itemId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1622, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(lineItemType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'name')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1630, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(lineItemType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'description')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1638, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(lineItemType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'quantity')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1645, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(lineItemType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'unitPrice')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1653, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(lineItemType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'taxable')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1661, 3))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1662, 3))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
         ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
         ]))
    transitions.append(fac.Transition(st_6, [
         ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, True) ]))
    st_6._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
lineItemType._Automaton = _BuildAutomaton_62()




profileTransAmountType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'amount'), STD_ANON_81, scope=profileTransAmountType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1668, 3)))

profileTransAmountType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'tax'), extendedAmountType, scope=profileTransAmountType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1676, 3)))

profileTransAmountType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'shipping'), extendedAmountType, scope=profileTransAmountType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1677, 3)))

profileTransAmountType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'duty'), extendedAmountType, scope=profileTransAmountType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1678, 3)))

profileTransAmountType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'lineItems'), lineItemType, scope=profileTransAmountType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1679, 3)))

def _BuildAutomaton_63 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_63
    del _BuildAutomaton_63
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1676, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1677, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1678, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=30, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1679, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1680, 3))
    counters.add(cc_4)
    states = []
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(profileTransAmountType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'amount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1668, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(profileTransAmountType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'tax')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1676, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(profileTransAmountType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'shipping')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1677, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(profileTransAmountType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'duty')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1678, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.ElementUse(profileTransAmountType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'lineItems')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1679, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1680, 3))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    transitions.append(fac.Transition(st_5, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_4, True) ]))
    st_5._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
profileTransAmountType._Automaton = _BuildAutomaton_63()




profileTransVoidType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), numericString, scope=profileTransVoidType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1791, 3)))

profileTransVoidType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileId'), numericString, scope=profileTransVoidType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1792, 3)))

profileTransVoidType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerShippingAddressId'), numericString, scope=profileTransVoidType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1793, 3)))

profileTransVoidType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'transId'), numericString, scope=profileTransVoidType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1794, 3)))

def _BuildAutomaton_64 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_64
    del _BuildAutomaton_64
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1791, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1792, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1793, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1795, 3))
    counters.add(cc_3)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(profileTransVoidType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1791, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(profileTransVoidType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1792, 3))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(profileTransVoidType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerShippingAddressId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1793, 3))
    st_2 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(profileTransVoidType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'transId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1794, 3))
    st_3 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1795, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
         ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    st_4._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
profileTransVoidType._Automaton = _BuildAutomaton_64()




profileTransactionType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'profileTransAuthCapture'), profileTransAuthCaptureType, scope=profileTransactionType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1801, 3)))

profileTransactionType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'profileTransAuthOnly'), profileTransAuthOnlyType, scope=profileTransactionType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1802, 3)))

profileTransactionType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'profileTransPriorAuthCapture'), profileTransPriorAuthCaptureType, scope=profileTransactionType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1803, 3)))

profileTransactionType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'profileTransCaptureOnly'), profileTransCaptureOnlyType, scope=profileTransactionType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1804, 3)))

profileTransactionType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'profileTransRefund'), profileTransRefundType, scope=profileTransactionType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1805, 3)))

profileTransactionType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'profileTransVoid'), profileTransVoidType, scope=profileTransactionType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1806, 3)))

def _BuildAutomaton_65 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_65
    del _BuildAutomaton_65
    import pyxb.utils.fac as fac

    counters = set()
    states = []
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(profileTransactionType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'profileTransAuthCapture')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1801, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(profileTransactionType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'profileTransAuthOnly')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1802, 3))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(profileTransactionType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'profileTransPriorAuthCapture')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1803, 3))
    st_2 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(profileTransactionType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'profileTransCaptureOnly')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1804, 3))
    st_3 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(profileTransactionType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'profileTransRefund')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1805, 3))
    st_4 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(profileTransactionType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'profileTransVoid')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1806, 3))
    st_5 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    transitions = []
    st_0._set_transitionSet(transitions)
    transitions = []
    st_1._set_transitionSet(transitions)
    transitions = []
    st_2._set_transitionSet(transitions)
    transitions = []
    st_3._set_transitionSet(transitions)
    transitions = []
    st_4._set_transitionSet(transitions)
    transitions = []
    st_5._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
profileTransactionType._Automaton = _BuildAutomaton_65()




transactionSummaryType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'transId'), numericString, scope=transactionSummaryType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1812, 3)))

transactionSummaryType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'submitTimeUTC'), pyxb.binding.datatypes.dateTime, scope=transactionSummaryType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1813, 3)))

transactionSummaryType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'submitTimeLocal'), pyxb.binding.datatypes.dateTime, scope=transactionSummaryType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1814, 3)))

transactionSummaryType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'transactionStatus'), pyxb.binding.datatypes.string, scope=transactionSummaryType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1815, 3)))

transactionSummaryType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'invoiceNumber'), pyxb.binding.datatypes.string, scope=transactionSummaryType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1816, 3)))

transactionSummaryType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'firstName'), pyxb.binding.datatypes.string, scope=transactionSummaryType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1817, 3)))

transactionSummaryType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'lastName'), pyxb.binding.datatypes.string, scope=transactionSummaryType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1818, 3)))

transactionSummaryType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'accountType'), pyxb.binding.datatypes.string, scope=transactionSummaryType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1819, 3)))

transactionSummaryType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'accountNumber'), pyxb.binding.datatypes.string, scope=transactionSummaryType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1820, 3)))

transactionSummaryType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'settleAmount'), pyxb.binding.datatypes.decimal, scope=transactionSummaryType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1821, 3)))

transactionSummaryType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'marketType'), pyxb.binding.datatypes.string, scope=transactionSummaryType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1822, 3)))

transactionSummaryType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'product'), pyxb.binding.datatypes.string, scope=transactionSummaryType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1823, 3)))

transactionSummaryType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'mobileDeviceId'), pyxb.binding.datatypes.string, scope=transactionSummaryType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1824, 3)))

transactionSummaryType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'subscription'), subscriptionPaymentType, scope=transactionSummaryType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1825, 3)))

transactionSummaryType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'hasReturnedItems'), pyxb.binding.datatypes.boolean, scope=transactionSummaryType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1826, 9)))

def _BuildAutomaton_66 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_66
    del _BuildAutomaton_66
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1816, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1817, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1818, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1822, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1823, 3))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1824, 3))
    counters.add(cc_5)
    cc_6 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1825, 3))
    counters.add(cc_6)
    cc_7 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1826, 9))
    counters.add(cc_7)
    cc_8 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1827, 3))
    counters.add(cc_8)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(transactionSummaryType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'transId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1812, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(transactionSummaryType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'submitTimeUTC')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1813, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(transactionSummaryType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'submitTimeLocal')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1814, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(transactionSummaryType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'transactionStatus')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1815, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(transactionSummaryType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'invoiceNumber')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1816, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(transactionSummaryType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'firstName')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1817, 3))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(transactionSummaryType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'lastName')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1818, 3))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(transactionSummaryType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'accountType')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1819, 3))
    st_7 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_7)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(transactionSummaryType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'accountNumber')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1820, 3))
    st_8 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_8)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(transactionSummaryType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'settleAmount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1821, 3))
    st_9 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_9)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.ElementUse(transactionSummaryType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'marketType')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1822, 3))
    st_10 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_10)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.ElementUse(transactionSummaryType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'product')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1823, 3))
    st_11 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_11)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.ElementUse(transactionSummaryType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'mobileDeviceId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1824, 3))
    st_12 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_12)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_6, False))
    symbol = pyxb.binding.content.ElementUse(transactionSummaryType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'subscription')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1825, 3))
    st_13 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_13)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_7, False))
    symbol = pyxb.binding.content.ElementUse(transactionSummaryType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'hasReturnedItems')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1826, 9))
    st_14 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_14)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_8, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1827, 3))
    st_15 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_15)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
         ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
         ]))
    transitions.append(fac.Transition(st_5, [
         ]))
    transitions.append(fac.Transition(st_6, [
         ]))
    transitions.append(fac.Transition(st_7, [
         ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_6._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_8, [
         ]))
    st_7._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_9, [
         ]))
    st_8._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_10, [
         ]))
    transitions.append(fac.Transition(st_11, [
         ]))
    transitions.append(fac.Transition(st_12, [
         ]))
    transitions.append(fac.Transition(st_13, [
         ]))
    transitions.append(fac.Transition(st_14, [
         ]))
    transitions.append(fac.Transition(st_15, [
         ]))
    st_9._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_10._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_11._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_5, True) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_5, False) ]))
    st_12._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_6, True) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_6, False) ]))
    st_13._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_7, True) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_7, False) ]))
    st_14._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_8, True) ]))
    st_15._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
transactionSummaryType._Automaton = _BuildAutomaton_66()




transactionDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'transId'), numericString, scope=transactionDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1833, 3)))

transactionDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'refTransId'), numericString, scope=transactionDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1834, 3)))

transactionDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'splitTenderId'), numericString, scope=transactionDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1835, 3)))

transactionDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'submitTimeUTC'), pyxb.binding.datatypes.dateTime, scope=transactionDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1836, 3)))

transactionDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'submitTimeLocal'), pyxb.binding.datatypes.dateTime, scope=transactionDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1837, 3)))

transactionDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'transactionType'), pyxb.binding.datatypes.string, scope=transactionDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1838, 3)))

transactionDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'transactionStatus'), pyxb.binding.datatypes.string, scope=transactionDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1839, 3)))

transactionDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'responseCode'), pyxb.binding.datatypes.int, scope=transactionDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1840, 3)))

transactionDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'responseReasonCode'), pyxb.binding.datatypes.int, scope=transactionDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1841, 3)))

transactionDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'subscription'), subscriptionPaymentType, scope=transactionDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1842, 3)))

transactionDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'responseReasonDescription'), pyxb.binding.datatypes.string, scope=transactionDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1843, 3)))

transactionDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'authCode'), STD_ANON_86, scope=transactionDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1844, 6)))

transactionDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'AVSResponse'), STD_ANON_87, scope=transactionDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1851, 3)))

transactionDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'cardCodeResponse'), STD_ANON_88, scope=transactionDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1858, 3)))

transactionDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'CAVVResponse'), STD_ANON_89, scope=transactionDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1865, 3)))

transactionDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'FDSFilterAction'), pyxb.binding.datatypes.string, scope=transactionDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1872, 3)))

transactionDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'FDSFilters'), ArrayOfFDSFilter, scope=transactionDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1873, 3)))

transactionDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'batch'), batchDetailsType, scope=transactionDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1874, 3)))

transactionDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'order'), orderExType, scope=transactionDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1875, 3)))

transactionDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'requestedAmount'), STD_ANON_90, scope=transactionDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1876, 3)))

transactionDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'authAmount'), STD_ANON_91, scope=transactionDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1884, 3)))

transactionDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'settleAmount'), STD_ANON_92, scope=transactionDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1892, 3)))

transactionDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'tax'), extendedAmountType, scope=transactionDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1900, 3)))

transactionDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'shipping'), extendedAmountType, scope=transactionDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1901, 3)))

transactionDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'duty'), extendedAmountType, scope=transactionDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1902, 3)))

transactionDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'lineItems'), ArrayOfLineItem, scope=transactionDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1903, 3)))

transactionDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'prepaidBalanceRemaining'), STD_ANON_93, scope=transactionDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1904, 3)))

transactionDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'taxExempt'), pyxb.binding.datatypes.boolean, scope=transactionDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1911, 3)))

transactionDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'payment'), paymentMaskedType, scope=transactionDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1912, 3)))

transactionDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customer'), customerDataType, scope=transactionDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1913, 3)))

transactionDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'billTo'), customerAddressType, scope=transactionDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1914, 3)))

transactionDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'shipTo'), nameAndAddressType, scope=transactionDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1915, 3)))

transactionDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'recurringBilling'), pyxb.binding.datatypes.boolean, scope=transactionDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1916, 3)))

transactionDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerIP'), pyxb.binding.datatypes.string, scope=transactionDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1917, 3)))

transactionDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'product'), pyxb.binding.datatypes.string, scope=transactionDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1918, 3)))

transactionDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'entryMethod'), pyxb.binding.datatypes.string, scope=transactionDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1919, 12)))

transactionDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'marketType'), pyxb.binding.datatypes.string, scope=transactionDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1920, 3)))

transactionDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'mobileDeviceId'), pyxb.binding.datatypes.string, scope=transactionDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1921, 3)))

transactionDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerSignature'), pyxb.binding.datatypes.string, scope=transactionDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1922, 12)))

transactionDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'returnedItems'), ArrayOfReturnedItem, scope=transactionDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1923, 6)))

transactionDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'solution'), solutionType, scope=transactionDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1924, 6)))

transactionDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'emvDetails'), ArrayOfEmvDetailType, scope=transactionDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1925, 12)))

def _BuildAutomaton_67 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_67
    del _BuildAutomaton_67
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1834, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1835, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1842, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1844, 6))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1851, 3))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1858, 3))
    counters.add(cc_5)
    cc_6 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1865, 3))
    counters.add(cc_6)
    cc_7 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1872, 3))
    counters.add(cc_7)
    cc_8 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1873, 3))
    counters.add(cc_8)
    cc_9 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1874, 3))
    counters.add(cc_9)
    cc_10 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1875, 3))
    counters.add(cc_10)
    cc_11 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1876, 3))
    counters.add(cc_11)
    cc_12 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1900, 3))
    counters.add(cc_12)
    cc_13 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1901, 3))
    counters.add(cc_13)
    cc_14 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1902, 3))
    counters.add(cc_14)
    cc_15 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1903, 3))
    counters.add(cc_15)
    cc_16 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1904, 3))
    counters.add(cc_16)
    cc_17 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1911, 3))
    counters.add(cc_17)
    cc_18 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1913, 3))
    counters.add(cc_18)
    cc_19 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1914, 3))
    counters.add(cc_19)
    cc_20 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1915, 3))
    counters.add(cc_20)
    cc_21 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1916, 3))
    counters.add(cc_21)
    cc_22 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1917, 3))
    counters.add(cc_22)
    cc_23 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1918, 3))
    counters.add(cc_23)
    cc_24 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1919, 12))
    counters.add(cc_24)
    cc_25 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1920, 3))
    counters.add(cc_25)
    cc_26 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1921, 3))
    counters.add(cc_26)
    cc_27 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1922, 12))
    counters.add(cc_27)
    cc_28 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1923, 6))
    counters.add(cc_28)
    cc_29 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1924, 6))
    counters.add(cc_29)
    cc_30 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1925, 12))
    counters.add(cc_30)
    cc_31 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1926, 3))
    counters.add(cc_31)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(transactionDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'transId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1833, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(transactionDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refTransId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1834, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(transactionDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'splitTenderId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1835, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(transactionDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'submitTimeUTC')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1836, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(transactionDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'submitTimeLocal')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1837, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(transactionDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'transactionType')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1838, 3))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(transactionDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'transactionStatus')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1839, 3))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(transactionDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'responseCode')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1840, 3))
    st_7 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_7)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(transactionDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'responseReasonCode')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1841, 3))
    st_8 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_8)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(transactionDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'subscription')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1842, 3))
    st_9 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_9)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(transactionDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'responseReasonDescription')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1843, 3))
    st_10 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_10)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(transactionDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'authCode')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1844, 6))
    st_11 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_11)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(transactionDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'AVSResponse')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1851, 3))
    st_12 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_12)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(transactionDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'cardCodeResponse')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1858, 3))
    st_13 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_13)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(transactionDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'CAVVResponse')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1865, 3))
    st_14 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_14)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(transactionDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'FDSFilterAction')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1872, 3))
    st_15 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_15)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(transactionDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'FDSFilters')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1873, 3))
    st_16 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_16)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(transactionDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'batch')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1874, 3))
    st_17 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_17)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(transactionDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'order')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1875, 3))
    st_18 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_18)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(transactionDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'requestedAmount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1876, 3))
    st_19 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_19)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(transactionDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'authAmount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1884, 3))
    st_20 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_20)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(transactionDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'settleAmount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1892, 3))
    st_21 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_21)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(transactionDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'tax')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1900, 3))
    st_22 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_22)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(transactionDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'shipping')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1901, 3))
    st_23 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_23)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(transactionDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'duty')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1902, 3))
    st_24 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_24)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(transactionDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'lineItems')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1903, 3))
    st_25 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_25)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(transactionDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'prepaidBalanceRemaining')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1904, 3))
    st_26 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_26)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(transactionDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'taxExempt')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1911, 3))
    st_27 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_27)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(transactionDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'payment')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1912, 3))
    st_28 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_28)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_18, False))
    symbol = pyxb.binding.content.ElementUse(transactionDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customer')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1913, 3))
    st_29 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_29)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_19, False))
    symbol = pyxb.binding.content.ElementUse(transactionDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'billTo')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1914, 3))
    st_30 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_30)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_20, False))
    symbol = pyxb.binding.content.ElementUse(transactionDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'shipTo')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1915, 3))
    st_31 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_31)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_21, False))
    symbol = pyxb.binding.content.ElementUse(transactionDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'recurringBilling')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1916, 3))
    st_32 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_32)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_22, False))
    symbol = pyxb.binding.content.ElementUse(transactionDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerIP')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1917, 3))
    st_33 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_33)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_23, False))
    symbol = pyxb.binding.content.ElementUse(transactionDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'product')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1918, 3))
    st_34 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_34)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_24, False))
    symbol = pyxb.binding.content.ElementUse(transactionDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'entryMethod')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1919, 12))
    st_35 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_35)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_25, False))
    symbol = pyxb.binding.content.ElementUse(transactionDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'marketType')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1920, 3))
    st_36 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_36)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_26, False))
    symbol = pyxb.binding.content.ElementUse(transactionDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'mobileDeviceId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1921, 3))
    st_37 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_37)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_27, False))
    symbol = pyxb.binding.content.ElementUse(transactionDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerSignature')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1922, 12))
    st_38 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_38)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_28, False))
    symbol = pyxb.binding.content.ElementUse(transactionDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'returnedItems')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1923, 6))
    st_39 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_39)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_29, False))
    symbol = pyxb.binding.content.ElementUse(transactionDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'solution')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1924, 6))
    st_40 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_40)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_30, False))
    symbol = pyxb.binding.content.ElementUse(transactionDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'emvDetails')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1925, 12))
    st_41 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_41)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_31, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1926, 3))
    st_42 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_42)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
         ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
         ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
         ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_7, [
         ]))
    st_6._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_8, [
         ]))
    st_7._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_9, [
         ]))
    transitions.append(fac.Transition(st_10, [
         ]))
    st_8._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_9._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_11, [
         ]))
    transitions.append(fac.Transition(st_12, [
         ]))
    transitions.append(fac.Transition(st_13, [
         ]))
    transitions.append(fac.Transition(st_14, [
         ]))
    transitions.append(fac.Transition(st_15, [
         ]))
    transitions.append(fac.Transition(st_16, [
         ]))
    transitions.append(fac.Transition(st_17, [
         ]))
    transitions.append(fac.Transition(st_18, [
         ]))
    transitions.append(fac.Transition(st_19, [
         ]))
    transitions.append(fac.Transition(st_20, [
         ]))
    st_10._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_11._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_12._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_5, True) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_5, False) ]))
    st_13._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_6, True) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_6, False) ]))
    st_14._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_7, True) ]))
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_7, False) ]))
    st_15._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_8, True) ]))
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_8, False) ]))
    st_16._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_9, True) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_9, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_9, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_9, False) ]))
    st_17._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_10, True) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_10, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_10, False) ]))
    st_18._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_11, True) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_11, False) ]))
    st_19._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_21, [
         ]))
    st_20._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_22, [
         ]))
    transitions.append(fac.Transition(st_23, [
         ]))
    transitions.append(fac.Transition(st_24, [
         ]))
    transitions.append(fac.Transition(st_25, [
         ]))
    transitions.append(fac.Transition(st_26, [
         ]))
    transitions.append(fac.Transition(st_27, [
         ]))
    transitions.append(fac.Transition(st_28, [
         ]))
    st_21._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_22, [
        fac.UpdateInstruction(cc_12, True) ]))
    transitions.append(fac.Transition(st_23, [
        fac.UpdateInstruction(cc_12, False) ]))
    transitions.append(fac.Transition(st_24, [
        fac.UpdateInstruction(cc_12, False) ]))
    transitions.append(fac.Transition(st_25, [
        fac.UpdateInstruction(cc_12, False) ]))
    transitions.append(fac.Transition(st_26, [
        fac.UpdateInstruction(cc_12, False) ]))
    transitions.append(fac.Transition(st_27, [
        fac.UpdateInstruction(cc_12, False) ]))
    transitions.append(fac.Transition(st_28, [
        fac.UpdateInstruction(cc_12, False) ]))
    st_22._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_23, [
        fac.UpdateInstruction(cc_13, True) ]))
    transitions.append(fac.Transition(st_24, [
        fac.UpdateInstruction(cc_13, False) ]))
    transitions.append(fac.Transition(st_25, [
        fac.UpdateInstruction(cc_13, False) ]))
    transitions.append(fac.Transition(st_26, [
        fac.UpdateInstruction(cc_13, False) ]))
    transitions.append(fac.Transition(st_27, [
        fac.UpdateInstruction(cc_13, False) ]))
    transitions.append(fac.Transition(st_28, [
        fac.UpdateInstruction(cc_13, False) ]))
    st_23._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_24, [
        fac.UpdateInstruction(cc_14, True) ]))
    transitions.append(fac.Transition(st_25, [
        fac.UpdateInstruction(cc_14, False) ]))
    transitions.append(fac.Transition(st_26, [
        fac.UpdateInstruction(cc_14, False) ]))
    transitions.append(fac.Transition(st_27, [
        fac.UpdateInstruction(cc_14, False) ]))
    transitions.append(fac.Transition(st_28, [
        fac.UpdateInstruction(cc_14, False) ]))
    st_24._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_25, [
        fac.UpdateInstruction(cc_15, True) ]))
    transitions.append(fac.Transition(st_26, [
        fac.UpdateInstruction(cc_15, False) ]))
    transitions.append(fac.Transition(st_27, [
        fac.UpdateInstruction(cc_15, False) ]))
    transitions.append(fac.Transition(st_28, [
        fac.UpdateInstruction(cc_15, False) ]))
    st_25._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_26, [
        fac.UpdateInstruction(cc_16, True) ]))
    transitions.append(fac.Transition(st_27, [
        fac.UpdateInstruction(cc_16, False) ]))
    transitions.append(fac.Transition(st_28, [
        fac.UpdateInstruction(cc_16, False) ]))
    st_26._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_27, [
        fac.UpdateInstruction(cc_17, True) ]))
    transitions.append(fac.Transition(st_28, [
        fac.UpdateInstruction(cc_17, False) ]))
    st_27._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_29, [
         ]))
    transitions.append(fac.Transition(st_30, [
         ]))
    transitions.append(fac.Transition(st_31, [
         ]))
    transitions.append(fac.Transition(st_32, [
         ]))
    transitions.append(fac.Transition(st_33, [
         ]))
    transitions.append(fac.Transition(st_34, [
         ]))
    transitions.append(fac.Transition(st_35, [
         ]))
    transitions.append(fac.Transition(st_36, [
         ]))
    transitions.append(fac.Transition(st_37, [
         ]))
    transitions.append(fac.Transition(st_38, [
         ]))
    transitions.append(fac.Transition(st_39, [
         ]))
    transitions.append(fac.Transition(st_40, [
         ]))
    transitions.append(fac.Transition(st_41, [
         ]))
    transitions.append(fac.Transition(st_42, [
         ]))
    st_28._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_29, [
        fac.UpdateInstruction(cc_18, True) ]))
    transitions.append(fac.Transition(st_30, [
        fac.UpdateInstruction(cc_18, False) ]))
    transitions.append(fac.Transition(st_31, [
        fac.UpdateInstruction(cc_18, False) ]))
    transitions.append(fac.Transition(st_32, [
        fac.UpdateInstruction(cc_18, False) ]))
    transitions.append(fac.Transition(st_33, [
        fac.UpdateInstruction(cc_18, False) ]))
    transitions.append(fac.Transition(st_34, [
        fac.UpdateInstruction(cc_18, False) ]))
    transitions.append(fac.Transition(st_35, [
        fac.UpdateInstruction(cc_18, False) ]))
    transitions.append(fac.Transition(st_36, [
        fac.UpdateInstruction(cc_18, False) ]))
    transitions.append(fac.Transition(st_37, [
        fac.UpdateInstruction(cc_18, False) ]))
    transitions.append(fac.Transition(st_38, [
        fac.UpdateInstruction(cc_18, False) ]))
    transitions.append(fac.Transition(st_39, [
        fac.UpdateInstruction(cc_18, False) ]))
    transitions.append(fac.Transition(st_40, [
        fac.UpdateInstruction(cc_18, False) ]))
    transitions.append(fac.Transition(st_41, [
        fac.UpdateInstruction(cc_18, False) ]))
    transitions.append(fac.Transition(st_42, [
        fac.UpdateInstruction(cc_18, False) ]))
    st_29._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_30, [
        fac.UpdateInstruction(cc_19, True) ]))
    transitions.append(fac.Transition(st_31, [
        fac.UpdateInstruction(cc_19, False) ]))
    transitions.append(fac.Transition(st_32, [
        fac.UpdateInstruction(cc_19, False) ]))
    transitions.append(fac.Transition(st_33, [
        fac.UpdateInstruction(cc_19, False) ]))
    transitions.append(fac.Transition(st_34, [
        fac.UpdateInstruction(cc_19, False) ]))
    transitions.append(fac.Transition(st_35, [
        fac.UpdateInstruction(cc_19, False) ]))
    transitions.append(fac.Transition(st_36, [
        fac.UpdateInstruction(cc_19, False) ]))
    transitions.append(fac.Transition(st_37, [
        fac.UpdateInstruction(cc_19, False) ]))
    transitions.append(fac.Transition(st_38, [
        fac.UpdateInstruction(cc_19, False) ]))
    transitions.append(fac.Transition(st_39, [
        fac.UpdateInstruction(cc_19, False) ]))
    transitions.append(fac.Transition(st_40, [
        fac.UpdateInstruction(cc_19, False) ]))
    transitions.append(fac.Transition(st_41, [
        fac.UpdateInstruction(cc_19, False) ]))
    transitions.append(fac.Transition(st_42, [
        fac.UpdateInstruction(cc_19, False) ]))
    st_30._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_31, [
        fac.UpdateInstruction(cc_20, True) ]))
    transitions.append(fac.Transition(st_32, [
        fac.UpdateInstruction(cc_20, False) ]))
    transitions.append(fac.Transition(st_33, [
        fac.UpdateInstruction(cc_20, False) ]))
    transitions.append(fac.Transition(st_34, [
        fac.UpdateInstruction(cc_20, False) ]))
    transitions.append(fac.Transition(st_35, [
        fac.UpdateInstruction(cc_20, False) ]))
    transitions.append(fac.Transition(st_36, [
        fac.UpdateInstruction(cc_20, False) ]))
    transitions.append(fac.Transition(st_37, [
        fac.UpdateInstruction(cc_20, False) ]))
    transitions.append(fac.Transition(st_38, [
        fac.UpdateInstruction(cc_20, False) ]))
    transitions.append(fac.Transition(st_39, [
        fac.UpdateInstruction(cc_20, False) ]))
    transitions.append(fac.Transition(st_40, [
        fac.UpdateInstruction(cc_20, False) ]))
    transitions.append(fac.Transition(st_41, [
        fac.UpdateInstruction(cc_20, False) ]))
    transitions.append(fac.Transition(st_42, [
        fac.UpdateInstruction(cc_20, False) ]))
    st_31._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_32, [
        fac.UpdateInstruction(cc_21, True) ]))
    transitions.append(fac.Transition(st_33, [
        fac.UpdateInstruction(cc_21, False) ]))
    transitions.append(fac.Transition(st_34, [
        fac.UpdateInstruction(cc_21, False) ]))
    transitions.append(fac.Transition(st_35, [
        fac.UpdateInstruction(cc_21, False) ]))
    transitions.append(fac.Transition(st_36, [
        fac.UpdateInstruction(cc_21, False) ]))
    transitions.append(fac.Transition(st_37, [
        fac.UpdateInstruction(cc_21, False) ]))
    transitions.append(fac.Transition(st_38, [
        fac.UpdateInstruction(cc_21, False) ]))
    transitions.append(fac.Transition(st_39, [
        fac.UpdateInstruction(cc_21, False) ]))
    transitions.append(fac.Transition(st_40, [
        fac.UpdateInstruction(cc_21, False) ]))
    transitions.append(fac.Transition(st_41, [
        fac.UpdateInstruction(cc_21, False) ]))
    transitions.append(fac.Transition(st_42, [
        fac.UpdateInstruction(cc_21, False) ]))
    st_32._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_33, [
        fac.UpdateInstruction(cc_22, True) ]))
    transitions.append(fac.Transition(st_34, [
        fac.UpdateInstruction(cc_22, False) ]))
    transitions.append(fac.Transition(st_35, [
        fac.UpdateInstruction(cc_22, False) ]))
    transitions.append(fac.Transition(st_36, [
        fac.UpdateInstruction(cc_22, False) ]))
    transitions.append(fac.Transition(st_37, [
        fac.UpdateInstruction(cc_22, False) ]))
    transitions.append(fac.Transition(st_38, [
        fac.UpdateInstruction(cc_22, False) ]))
    transitions.append(fac.Transition(st_39, [
        fac.UpdateInstruction(cc_22, False) ]))
    transitions.append(fac.Transition(st_40, [
        fac.UpdateInstruction(cc_22, False) ]))
    transitions.append(fac.Transition(st_41, [
        fac.UpdateInstruction(cc_22, False) ]))
    transitions.append(fac.Transition(st_42, [
        fac.UpdateInstruction(cc_22, False) ]))
    st_33._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_34, [
        fac.UpdateInstruction(cc_23, True) ]))
    transitions.append(fac.Transition(st_35, [
        fac.UpdateInstruction(cc_23, False) ]))
    transitions.append(fac.Transition(st_36, [
        fac.UpdateInstruction(cc_23, False) ]))
    transitions.append(fac.Transition(st_37, [
        fac.UpdateInstruction(cc_23, False) ]))
    transitions.append(fac.Transition(st_38, [
        fac.UpdateInstruction(cc_23, False) ]))
    transitions.append(fac.Transition(st_39, [
        fac.UpdateInstruction(cc_23, False) ]))
    transitions.append(fac.Transition(st_40, [
        fac.UpdateInstruction(cc_23, False) ]))
    transitions.append(fac.Transition(st_41, [
        fac.UpdateInstruction(cc_23, False) ]))
    transitions.append(fac.Transition(st_42, [
        fac.UpdateInstruction(cc_23, False) ]))
    st_34._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_35, [
        fac.UpdateInstruction(cc_24, True) ]))
    transitions.append(fac.Transition(st_36, [
        fac.UpdateInstruction(cc_24, False) ]))
    transitions.append(fac.Transition(st_37, [
        fac.UpdateInstruction(cc_24, False) ]))
    transitions.append(fac.Transition(st_38, [
        fac.UpdateInstruction(cc_24, False) ]))
    transitions.append(fac.Transition(st_39, [
        fac.UpdateInstruction(cc_24, False) ]))
    transitions.append(fac.Transition(st_40, [
        fac.UpdateInstruction(cc_24, False) ]))
    transitions.append(fac.Transition(st_41, [
        fac.UpdateInstruction(cc_24, False) ]))
    transitions.append(fac.Transition(st_42, [
        fac.UpdateInstruction(cc_24, False) ]))
    st_35._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_36, [
        fac.UpdateInstruction(cc_25, True) ]))
    transitions.append(fac.Transition(st_37, [
        fac.UpdateInstruction(cc_25, False) ]))
    transitions.append(fac.Transition(st_38, [
        fac.UpdateInstruction(cc_25, False) ]))
    transitions.append(fac.Transition(st_39, [
        fac.UpdateInstruction(cc_25, False) ]))
    transitions.append(fac.Transition(st_40, [
        fac.UpdateInstruction(cc_25, False) ]))
    transitions.append(fac.Transition(st_41, [
        fac.UpdateInstruction(cc_25, False) ]))
    transitions.append(fac.Transition(st_42, [
        fac.UpdateInstruction(cc_25, False) ]))
    st_36._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_37, [
        fac.UpdateInstruction(cc_26, True) ]))
    transitions.append(fac.Transition(st_38, [
        fac.UpdateInstruction(cc_26, False) ]))
    transitions.append(fac.Transition(st_39, [
        fac.UpdateInstruction(cc_26, False) ]))
    transitions.append(fac.Transition(st_40, [
        fac.UpdateInstruction(cc_26, False) ]))
    transitions.append(fac.Transition(st_41, [
        fac.UpdateInstruction(cc_26, False) ]))
    transitions.append(fac.Transition(st_42, [
        fac.UpdateInstruction(cc_26, False) ]))
    st_37._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_38, [
        fac.UpdateInstruction(cc_27, True) ]))
    transitions.append(fac.Transition(st_39, [
        fac.UpdateInstruction(cc_27, False) ]))
    transitions.append(fac.Transition(st_40, [
        fac.UpdateInstruction(cc_27, False) ]))
    transitions.append(fac.Transition(st_41, [
        fac.UpdateInstruction(cc_27, False) ]))
    transitions.append(fac.Transition(st_42, [
        fac.UpdateInstruction(cc_27, False) ]))
    st_38._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_39, [
        fac.UpdateInstruction(cc_28, True) ]))
    transitions.append(fac.Transition(st_40, [
        fac.UpdateInstruction(cc_28, False) ]))
    transitions.append(fac.Transition(st_41, [
        fac.UpdateInstruction(cc_28, False) ]))
    transitions.append(fac.Transition(st_42, [
        fac.UpdateInstruction(cc_28, False) ]))
    st_39._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_40, [
        fac.UpdateInstruction(cc_29, True) ]))
    transitions.append(fac.Transition(st_41, [
        fac.UpdateInstruction(cc_29, False) ]))
    transitions.append(fac.Transition(st_42, [
        fac.UpdateInstruction(cc_29, False) ]))
    st_40._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_41, [
        fac.UpdateInstruction(cc_30, True) ]))
    transitions.append(fac.Transition(st_42, [
        fac.UpdateInstruction(cc_30, False) ]))
    st_41._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_42, [
        fac.UpdateInstruction(cc_31, True) ]))
    st_42._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
transactionDetailsType._Automaton = _BuildAutomaton_67()




solutionType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'id'), pyxb.binding.datatypes.string, scope=solutionType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1932, 6)))

solutionType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'name'), pyxb.binding.datatypes.string, scope=solutionType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1933, 6)))

solutionType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'vendorName'), pyxb.binding.datatypes.string, scope=solutionType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1934, 6)))

def _BuildAutomaton_68 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_68
    del _BuildAutomaton_68
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1933, 6))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1934, 6))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1935, 5))
    counters.add(cc_2)
    states = []
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(solutionType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'id')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1932, 6))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(solutionType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'name')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1933, 6))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(solutionType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'vendorName')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1934, 6))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1935, 5))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    st_3._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
solutionType._Automaton = _BuildAutomaton_68()




emvDetailType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'tagId'), pyxb.binding.datatypes.string, scope=emvDetailType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1941, 12)))

emvDetailType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'name'), pyxb.binding.datatypes.string, scope=emvDetailType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1942, 12)))

def _BuildAutomaton_69 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_69
    del _BuildAutomaton_69
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1943, 9))
    counters.add(cc_0)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(emvDetailType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'tagId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1941, 12))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(emvDetailType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'name')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1942, 12))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1943, 9))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, True) ]))
    st_2._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
emvDetailType._Automaton = _BuildAutomaton_69()




ArrayOfEmvDetailType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'tags'), emvDetailType, scope=ArrayOfEmvDetailType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1949, 12)))

def _BuildAutomaton_70 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_70
    del _BuildAutomaton_70
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1949, 12))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1950, 9))
    counters.add(cc_1)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(ArrayOfEmvDetailType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'tags')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1949, 12))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1950, 9))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    st_1._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
ArrayOfEmvDetailType._Automaton = _BuildAutomaton_70()




ArrayOfReturnedItem._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'returnedItem'), returnedItemType, scope=ArrayOfReturnedItem, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1956, 6)))

def _BuildAutomaton_71 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_71
    del _BuildAutomaton_71
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1956, 6))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1957, 5))
    counters.add(cc_1)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(ArrayOfReturnedItem._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'returnedItem')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1956, 6))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1957, 5))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    st_1._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
ArrayOfReturnedItem._Automaton = _BuildAutomaton_71()




returnedItemType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'id'), numericString, scope=returnedItemType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1963, 6)))

returnedItemType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'dateUTC'), pyxb.binding.datatypes.dateTime, scope=returnedItemType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1964, 6)))

returnedItemType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'dateLocal'), pyxb.binding.datatypes.dateTime, scope=returnedItemType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1965, 6)))

returnedItemType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'code'), pyxb.binding.datatypes.string, scope=returnedItemType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1966, 6)))

returnedItemType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'description'), pyxb.binding.datatypes.string, scope=returnedItemType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1967, 6)))

def _BuildAutomaton_72 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_72
    del _BuildAutomaton_72
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1968, 5))
    counters.add(cc_0)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(returnedItemType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'id')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1963, 6))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(returnedItemType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'dateUTC')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1964, 6))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(returnedItemType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'dateLocal')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1965, 6))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(returnedItemType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'code')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1966, 6))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(returnedItemType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'description')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1967, 6))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1968, 5))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
         ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
         ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
         ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_0, True) ]))
    st_5._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
returnedItemType._Automaton = _BuildAutomaton_72()




FDSFilterType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'name'), pyxb.binding.datatypes.string, scope=FDSFilterType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1974, 3)))

FDSFilterType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'action'), pyxb.binding.datatypes.string, scope=FDSFilterType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1975, 3)))

def _BuildAutomaton_73 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_73
    del _BuildAutomaton_73
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1976, 3))
    counters.add(cc_0)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(FDSFilterType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'name')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1974, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(FDSFilterType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'action')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1975, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1976, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, True) ]))
    st_2._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
FDSFilterType._Automaton = _BuildAutomaton_73()




batchDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'batchId'), numericString, scope=batchDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1982, 3)))

batchDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'settlementTimeUTC'), pyxb.binding.datatypes.dateTime, scope=batchDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1983, 3)))

batchDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'settlementTimeLocal'), pyxb.binding.datatypes.dateTime, scope=batchDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1984, 3)))

batchDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'settlementState'), pyxb.binding.datatypes.string, scope=batchDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1985, 3)))

batchDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'paymentMethod'), pyxb.binding.datatypes.string, scope=batchDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1986, 3)))

batchDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'marketType'), pyxb.binding.datatypes.string, scope=batchDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1987, 3)))

batchDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'product'), pyxb.binding.datatypes.string, scope=batchDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1988, 3)))

batchDetailsType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'statistics'), ArrayOfBatchStatisticType, scope=batchDetailsType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1989, 3)))

def _BuildAutomaton_74 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_74
    del _BuildAutomaton_74
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1983, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1984, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1986, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1987, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1988, 3))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1989, 3))
    counters.add(cc_5)
    cc_6 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1990, 3))
    counters.add(cc_6)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(batchDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'batchId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1982, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(batchDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'settlementTimeUTC')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1983, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(batchDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'settlementTimeLocal')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1984, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(batchDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'settlementState')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1985, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(batchDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'paymentMethod')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1986, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.ElementUse(batchDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'marketType')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1987, 3))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.ElementUse(batchDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'product')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1988, 3))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.ElementUse(batchDetailsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'statistics')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1989, 3))
    st_7 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_7)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_6, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1990, 3))
    st_8 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_8)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
         ]))
    transitions.append(fac.Transition(st_5, [
         ]))
    transitions.append(fac.Transition(st_6, [
         ]))
    transitions.append(fac.Transition(st_7, [
         ]))
    transitions.append(fac.Transition(st_8, [
         ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_6._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_5, True) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_5, False) ]))
    st_7._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_6, True) ]))
    st_8._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
batchDetailsType._Automaton = _BuildAutomaton_74()




batchStatisticType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'accountType'), pyxb.binding.datatypes.string, scope=batchStatisticType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1996, 3)))

batchStatisticType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'chargeAmount'), pyxb.binding.datatypes.decimal, scope=batchStatisticType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1997, 3)))

batchStatisticType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'chargeCount'), pyxb.binding.datatypes.int, scope=batchStatisticType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1998, 3)))

batchStatisticType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'refundAmount'), pyxb.binding.datatypes.decimal, scope=batchStatisticType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1999, 3)))

batchStatisticType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'refundCount'), pyxb.binding.datatypes.int, scope=batchStatisticType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2000, 3)))

batchStatisticType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'voidCount'), pyxb.binding.datatypes.int, scope=batchStatisticType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2001, 3)))

batchStatisticType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'declineCount'), pyxb.binding.datatypes.int, scope=batchStatisticType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2002, 3)))

batchStatisticType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'errorCount'), pyxb.binding.datatypes.int, scope=batchStatisticType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2003, 3)))

batchStatisticType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'returnedItemAmount'), pyxb.binding.datatypes.decimal, scope=batchStatisticType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2004, 3)))

batchStatisticType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'returnedItemCount'), pyxb.binding.datatypes.int, scope=batchStatisticType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2005, 3)))

batchStatisticType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'chargebackAmount'), pyxb.binding.datatypes.decimal, scope=batchStatisticType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2006, 3)))

batchStatisticType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'chargebackCount'), pyxb.binding.datatypes.int, scope=batchStatisticType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2007, 3)))

batchStatisticType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'correctionNoticeCount'), pyxb.binding.datatypes.int, scope=batchStatisticType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2008, 3)))

batchStatisticType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'chargeChargeBackAmount'), pyxb.binding.datatypes.decimal, scope=batchStatisticType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2009, 3)))

batchStatisticType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'chargeChargeBackCount'), pyxb.binding.datatypes.int, scope=batchStatisticType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2010, 3)))

batchStatisticType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'refundChargeBackAmount'), pyxb.binding.datatypes.decimal, scope=batchStatisticType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2011, 3)))

batchStatisticType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'refundChargeBackCount'), pyxb.binding.datatypes.int, scope=batchStatisticType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2012, 3)))

batchStatisticType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'chargeReturnedItemsAmount'), pyxb.binding.datatypes.decimal, scope=batchStatisticType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2013, 3)))

batchStatisticType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'chargeReturnedItemsCount'), pyxb.binding.datatypes.int, scope=batchStatisticType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2014, 3)))

batchStatisticType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'refundReturnedItemsAmount'), pyxb.binding.datatypes.decimal, scope=batchStatisticType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2015, 3)))

batchStatisticType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'refundReturnedItemsCount'), pyxb.binding.datatypes.int, scope=batchStatisticType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2016, 3)))

def _BuildAutomaton_75 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_75
    del _BuildAutomaton_75
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2004, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2005, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2006, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2007, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2008, 3))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2009, 3))
    counters.add(cc_5)
    cc_6 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2010, 3))
    counters.add(cc_6)
    cc_7 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2011, 3))
    counters.add(cc_7)
    cc_8 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2012, 3))
    counters.add(cc_8)
    cc_9 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2013, 3))
    counters.add(cc_9)
    cc_10 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2014, 3))
    counters.add(cc_10)
    cc_11 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2015, 3))
    counters.add(cc_11)
    cc_12 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2016, 3))
    counters.add(cc_12)
    cc_13 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2017, 3))
    counters.add(cc_13)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(batchStatisticType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'accountType')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1996, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(batchStatisticType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'chargeAmount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1997, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(batchStatisticType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'chargeCount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1998, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(batchStatisticType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refundAmount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1999, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(batchStatisticType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refundCount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2000, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(batchStatisticType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'voidCount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2001, 3))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(batchStatisticType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'declineCount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2002, 3))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(batchStatisticType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'errorCount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2003, 3))
    st_7 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_7)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(batchStatisticType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'returnedItemAmount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2004, 3))
    st_8 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_8)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(batchStatisticType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'returnedItemCount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2005, 3))
    st_9 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_9)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(batchStatisticType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'chargebackAmount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2006, 3))
    st_10 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_10)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.ElementUse(batchStatisticType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'chargebackCount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2007, 3))
    st_11 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_11)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.ElementUse(batchStatisticType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'correctionNoticeCount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2008, 3))
    st_12 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_12)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.ElementUse(batchStatisticType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'chargeChargeBackAmount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2009, 3))
    st_13 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_13)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_6, False))
    symbol = pyxb.binding.content.ElementUse(batchStatisticType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'chargeChargeBackCount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2010, 3))
    st_14 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_14)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_7, False))
    symbol = pyxb.binding.content.ElementUse(batchStatisticType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refundChargeBackAmount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2011, 3))
    st_15 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_15)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_8, False))
    symbol = pyxb.binding.content.ElementUse(batchStatisticType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refundChargeBackCount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2012, 3))
    st_16 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_16)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_9, False))
    symbol = pyxb.binding.content.ElementUse(batchStatisticType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'chargeReturnedItemsAmount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2013, 3))
    st_17 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_17)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_10, False))
    symbol = pyxb.binding.content.ElementUse(batchStatisticType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'chargeReturnedItemsCount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2014, 3))
    st_18 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_18)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_11, False))
    symbol = pyxb.binding.content.ElementUse(batchStatisticType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refundReturnedItemsAmount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2015, 3))
    st_19 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_19)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_12, False))
    symbol = pyxb.binding.content.ElementUse(batchStatisticType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refundReturnedItemsCount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2016, 3))
    st_20 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_20)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_13, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2017, 3))
    st_21 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_21)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
         ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
         ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
         ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
         ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_7, [
         ]))
    st_6._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_8, [
         ]))
    transitions.append(fac.Transition(st_9, [
         ]))
    transitions.append(fac.Transition(st_10, [
         ]))
    transitions.append(fac.Transition(st_11, [
         ]))
    transitions.append(fac.Transition(st_12, [
         ]))
    transitions.append(fac.Transition(st_13, [
         ]))
    transitions.append(fac.Transition(st_14, [
         ]))
    transitions.append(fac.Transition(st_15, [
         ]))
    transitions.append(fac.Transition(st_16, [
         ]))
    transitions.append(fac.Transition(st_17, [
         ]))
    transitions.append(fac.Transition(st_18, [
         ]))
    transitions.append(fac.Transition(st_19, [
         ]))
    transitions.append(fac.Transition(st_20, [
         ]))
    transitions.append(fac.Transition(st_21, [
         ]))
    st_7._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_8._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_9._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_10._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_11._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_12._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_5, True) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_5, False) ]))
    st_13._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_6, True) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_6, False) ]))
    st_14._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_7, True) ]))
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_7, False) ]))
    st_15._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_8, True) ]))
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_8, False) ]))
    st_16._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_9, True) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_9, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_9, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_9, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_9, False) ]))
    st_17._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_10, True) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_10, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_10, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_10, False) ]))
    st_18._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_11, True) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_11, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_11, False) ]))
    st_19._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_12, True) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_12, False) ]))
    st_20._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_13, True) ]))
    st_21._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
batchStatisticType._Automaton = _BuildAutomaton_75()




transactionResponse._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'responseCode'), pyxb.binding.datatypes.string, scope=transactionResponse, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2023, 3)))

transactionResponse._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'rawResponseCode'), pyxb.binding.datatypes.string, scope=transactionResponse, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2024, 3)))

transactionResponse._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'authCode'), pyxb.binding.datatypes.string, scope=transactionResponse, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2025, 3)))

transactionResponse._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'avsResultCode'), pyxb.binding.datatypes.string, scope=transactionResponse, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2026, 3)))

transactionResponse._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'cvvResultCode'), pyxb.binding.datatypes.string, scope=transactionResponse, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2027, 3)))

transactionResponse._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'cavvResultCode'), pyxb.binding.datatypes.string, scope=transactionResponse, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2028, 3)))

transactionResponse._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'transId'), pyxb.binding.datatypes.string, scope=transactionResponse, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2029, 3)))

transactionResponse._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'refTransID'), pyxb.binding.datatypes.string, scope=transactionResponse, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2030, 3)))

transactionResponse._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'transHash'), pyxb.binding.datatypes.string, scope=transactionResponse, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2031, 3)))

transactionResponse._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'testRequest'), pyxb.binding.datatypes.string, scope=transactionResponse, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2032, 3)))

transactionResponse._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'accountNumber'), pyxb.binding.datatypes.string, scope=transactionResponse, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2033, 3)))

transactionResponse._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'accountType'), pyxb.binding.datatypes.string, scope=transactionResponse, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2034, 3)))

transactionResponse._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'entryMode'), pyxb.binding.datatypes.string, scope=transactionResponse, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2035, 12)))

transactionResponse._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'splitTenderId'), pyxb.binding.datatypes.string, scope=transactionResponse, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2036, 3)))

transactionResponse._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'prePaidCard'), CTD_ANON_6, scope=transactionResponse, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2037, 3)))

transactionResponse._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'messages'), CTD_ANON_7, scope=transactionResponse, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2047, 3)))

transactionResponse._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'errors'), CTD_ANON_9, scope=transactionResponse, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2063, 3)))

transactionResponse._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'splitTenderPayments'), CTD_ANON_11, scope=transactionResponse, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2079, 3)))

transactionResponse._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'userFields'), CTD_ANON_13, scope=transactionResponse, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2102, 3)))

transactionResponse._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'shipTo'), nameAndAddressType, scope=transactionResponse, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2110, 6)))

transactionResponse._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'secureAcceptance'), CTD_ANON_14, scope=transactionResponse, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2111, 6)))

transactionResponse._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'emvResponse'), CTD_ANON_15, scope=transactionResponse, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2120, 12)))

def _BuildAutomaton_76 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_76
    del _BuildAutomaton_76
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2023, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2024, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2025, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2026, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2027, 3))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2028, 3))
    counters.add(cc_5)
    cc_6 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2029, 3))
    counters.add(cc_6)
    cc_7 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2030, 3))
    counters.add(cc_7)
    cc_8 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2031, 3))
    counters.add(cc_8)
    cc_9 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2032, 3))
    counters.add(cc_9)
    cc_10 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2033, 3))
    counters.add(cc_10)
    cc_11 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2034, 3))
    counters.add(cc_11)
    cc_12 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2035, 12))
    counters.add(cc_12)
    cc_13 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2036, 3))
    counters.add(cc_13)
    cc_14 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2037, 3))
    counters.add(cc_14)
    cc_15 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2047, 3))
    counters.add(cc_15)
    cc_16 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2063, 3))
    counters.add(cc_16)
    cc_17 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2079, 3))
    counters.add(cc_17)
    cc_18 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2102, 3))
    counters.add(cc_18)
    cc_19 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2110, 6))
    counters.add(cc_19)
    cc_20 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2111, 6))
    counters.add(cc_20)
    cc_21 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2120, 12))
    counters.add(cc_21)
    cc_22 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2129, 5))
    counters.add(cc_22)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(transactionResponse._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'responseCode')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2023, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(transactionResponse._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'rawResponseCode')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2024, 3))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(transactionResponse._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'authCode')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2025, 3))
    st_2 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.ElementUse(transactionResponse._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'avsResultCode')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2026, 3))
    st_3 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.ElementUse(transactionResponse._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'cvvResultCode')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2027, 3))
    st_4 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.ElementUse(transactionResponse._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'cavvResultCode')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2028, 3))
    st_5 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_6, False))
    symbol = pyxb.binding.content.ElementUse(transactionResponse._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'transId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2029, 3))
    st_6 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_7, False))
    symbol = pyxb.binding.content.ElementUse(transactionResponse._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refTransID')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2030, 3))
    st_7 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_7)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_8, False))
    symbol = pyxb.binding.content.ElementUse(transactionResponse._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'transHash')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2031, 3))
    st_8 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_8)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_9, False))
    symbol = pyxb.binding.content.ElementUse(transactionResponse._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'testRequest')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2032, 3))
    st_9 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_9)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_10, False))
    symbol = pyxb.binding.content.ElementUse(transactionResponse._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'accountNumber')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2033, 3))
    st_10 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_10)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_11, False))
    symbol = pyxb.binding.content.ElementUse(transactionResponse._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'accountType')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2034, 3))
    st_11 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_11)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_12, False))
    symbol = pyxb.binding.content.ElementUse(transactionResponse._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'entryMode')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2035, 12))
    st_12 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_12)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_13, False))
    symbol = pyxb.binding.content.ElementUse(transactionResponse._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'splitTenderId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2036, 3))
    st_13 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_13)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_14, False))
    symbol = pyxb.binding.content.ElementUse(transactionResponse._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'prePaidCard')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2037, 3))
    st_14 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_14)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_15, False))
    symbol = pyxb.binding.content.ElementUse(transactionResponse._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'messages')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2047, 3))
    st_15 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_15)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_16, False))
    symbol = pyxb.binding.content.ElementUse(transactionResponse._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'errors')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2063, 3))
    st_16 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_16)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_17, False))
    symbol = pyxb.binding.content.ElementUse(transactionResponse._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'splitTenderPayments')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2079, 3))
    st_17 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_17)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_18, False))
    symbol = pyxb.binding.content.ElementUse(transactionResponse._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'userFields')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2102, 3))
    st_18 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_18)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_19, False))
    symbol = pyxb.binding.content.ElementUse(transactionResponse._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'shipTo')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2110, 6))
    st_19 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_19)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_20, False))
    symbol = pyxb.binding.content.ElementUse(transactionResponse._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'secureAcceptance')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2111, 6))
    st_20 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_20)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_21, False))
    symbol = pyxb.binding.content.ElementUse(transactionResponse._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'emvResponse')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2120, 12))
    st_21 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_21)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_22, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2129, 5))
    st_22 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_22)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_22, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_22, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_22, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_22, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_22, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_5, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_22, [
        fac.UpdateInstruction(cc_5, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_6, True) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_22, [
        fac.UpdateInstruction(cc_6, False) ]))
    st_6._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_7, True) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_22, [
        fac.UpdateInstruction(cc_7, False) ]))
    st_7._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_8, True) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_22, [
        fac.UpdateInstruction(cc_8, False) ]))
    st_8._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_9, True) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_9, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_9, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_9, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_9, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_9, False) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_9, False) ]))
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_9, False) ]))
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_9, False) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_9, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_9, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_9, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_9, False) ]))
    transitions.append(fac.Transition(st_22, [
        fac.UpdateInstruction(cc_9, False) ]))
    st_9._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_10, True) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_10, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_10, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_10, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_10, False) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_10, False) ]))
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_10, False) ]))
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_10, False) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_10, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_10, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_10, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_10, False) ]))
    transitions.append(fac.Transition(st_22, [
        fac.UpdateInstruction(cc_10, False) ]))
    st_10._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_11, True) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_11, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_11, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_11, False) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_11, False) ]))
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_11, False) ]))
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_11, False) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_11, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_11, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_11, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_11, False) ]))
    transitions.append(fac.Transition(st_22, [
        fac.UpdateInstruction(cc_11, False) ]))
    st_11._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_12, True) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_12, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_12, False) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_12, False) ]))
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_12, False) ]))
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_12, False) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_12, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_12, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_12, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_12, False) ]))
    transitions.append(fac.Transition(st_22, [
        fac.UpdateInstruction(cc_12, False) ]))
    st_12._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_13, True) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_13, False) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_13, False) ]))
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_13, False) ]))
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_13, False) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_13, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_13, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_13, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_13, False) ]))
    transitions.append(fac.Transition(st_22, [
        fac.UpdateInstruction(cc_13, False) ]))
    st_13._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_14, True) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_14, False) ]))
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_14, False) ]))
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_14, False) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_14, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_14, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_14, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_14, False) ]))
    transitions.append(fac.Transition(st_22, [
        fac.UpdateInstruction(cc_14, False) ]))
    st_14._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_15, True) ]))
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_15, False) ]))
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_15, False) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_15, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_15, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_15, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_15, False) ]))
    transitions.append(fac.Transition(st_22, [
        fac.UpdateInstruction(cc_15, False) ]))
    st_15._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_16, True) ]))
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_16, False) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_16, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_16, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_16, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_16, False) ]))
    transitions.append(fac.Transition(st_22, [
        fac.UpdateInstruction(cc_16, False) ]))
    st_16._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_17, [
        fac.UpdateInstruction(cc_17, True) ]))
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_17, False) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_17, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_17, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_17, False) ]))
    transitions.append(fac.Transition(st_22, [
        fac.UpdateInstruction(cc_17, False) ]))
    st_17._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_18, [
        fac.UpdateInstruction(cc_18, True) ]))
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_18, False) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_18, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_18, False) ]))
    transitions.append(fac.Transition(st_22, [
        fac.UpdateInstruction(cc_18, False) ]))
    st_18._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_19, [
        fac.UpdateInstruction(cc_19, True) ]))
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_19, False) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_19, False) ]))
    transitions.append(fac.Transition(st_22, [
        fac.UpdateInstruction(cc_19, False) ]))
    st_19._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_20, [
        fac.UpdateInstruction(cc_20, True) ]))
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_20, False) ]))
    transitions.append(fac.Transition(st_22, [
        fac.UpdateInstruction(cc_20, False) ]))
    st_20._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_21, [
        fac.UpdateInstruction(cc_21, True) ]))
    transitions.append(fac.Transition(st_22, [
        fac.UpdateInstruction(cc_21, False) ]))
    st_21._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_22, [
        fac.UpdateInstruction(cc_22, True) ]))
    st_22._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
transactionResponse._Automaton = _BuildAutomaton_76()




CTD_ANON_6._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'requestedAmount'), pyxb.binding.datatypes.string, scope=CTD_ANON_6, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2040, 6)))

CTD_ANON_6._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'approvedAmount'), pyxb.binding.datatypes.string, scope=CTD_ANON_6, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2041, 6)))

CTD_ANON_6._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'balanceOnCard'), pyxb.binding.datatypes.string, scope=CTD_ANON_6, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2042, 6)))

def _BuildAutomaton_77 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_77
    del _BuildAutomaton_77
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2040, 6))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2041, 6))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2042, 6))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2043, 6))
    counters.add(cc_3)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_6._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'requestedAmount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2040, 6))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_6._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'approvedAmount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2041, 6))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_6._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'balanceOnCard')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2042, 6))
    st_2 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2043, 6))
    st_3 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_3, True) ]))
    st_3._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
CTD_ANON_6._Automaton = _BuildAutomaton_77()




CTD_ANON_7._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'message'), CTD_ANON_8, scope=CTD_ANON_7, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2050, 6)))

def _BuildAutomaton_78 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_78
    del _BuildAutomaton_78
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2050, 6))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2059, 6))
    counters.add(cc_1)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_7._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'message')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2050, 6))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2059, 6))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    st_1._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
CTD_ANON_7._Automaton = _BuildAutomaton_78()




CTD_ANON_8._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'code'), pyxb.binding.datatypes.string, scope=CTD_ANON_8, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2053, 9)))

CTD_ANON_8._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'description'), pyxb.binding.datatypes.string, scope=CTD_ANON_8, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2054, 9)))

def _BuildAutomaton_79 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_79
    del _BuildAutomaton_79
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2053, 9))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2054, 9))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2055, 9))
    counters.add(cc_2)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_8._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'code')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2053, 9))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_8._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'description')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2054, 9))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2055, 9))
    st_2 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_2, True) ]))
    st_2._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
CTD_ANON_8._Automaton = _BuildAutomaton_79()




CTD_ANON_9._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'error'), CTD_ANON_10, scope=CTD_ANON_9, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2066, 6)))

def _BuildAutomaton_80 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_80
    del _BuildAutomaton_80
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2066, 6))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2075, 6))
    counters.add(cc_1)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_9._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'error')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2066, 6))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2075, 6))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    st_1._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
CTD_ANON_9._Automaton = _BuildAutomaton_80()




CTD_ANON_10._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'errorCode'), pyxb.binding.datatypes.string, scope=CTD_ANON_10, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2069, 9)))

CTD_ANON_10._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'errorText'), pyxb.binding.datatypes.string, scope=CTD_ANON_10, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2070, 9)))

def _BuildAutomaton_81 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_81
    del _BuildAutomaton_81
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2069, 9))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2070, 9))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2071, 9))
    counters.add(cc_2)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_10._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'errorCode')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2069, 9))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_10._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'errorText')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2070, 9))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2071, 9))
    st_2 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_2, True) ]))
    st_2._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
CTD_ANON_10._Automaton = _BuildAutomaton_81()




CTD_ANON_11._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'splitTenderPayment'), CTD_ANON_12, scope=CTD_ANON_11, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2082, 6)))

def _BuildAutomaton_82 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_82
    del _BuildAutomaton_82
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2082, 6))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2098, 6))
    counters.add(cc_1)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_11._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'splitTenderPayment')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2082, 6))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2098, 6))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    st_1._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
CTD_ANON_11._Automaton = _BuildAutomaton_82()




CTD_ANON_12._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'transId'), pyxb.binding.datatypes.string, scope=CTD_ANON_12, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2085, 9)))

CTD_ANON_12._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'responseCode'), pyxb.binding.datatypes.string, scope=CTD_ANON_12, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2086, 9)))

CTD_ANON_12._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'responseToCustomer'), pyxb.binding.datatypes.string, scope=CTD_ANON_12, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2087, 9)))

CTD_ANON_12._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'authCode'), pyxb.binding.datatypes.string, scope=CTD_ANON_12, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2088, 9)))

CTD_ANON_12._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'accountNumber'), pyxb.binding.datatypes.string, scope=CTD_ANON_12, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2089, 9)))

CTD_ANON_12._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'accountType'), pyxb.binding.datatypes.string, scope=CTD_ANON_12, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2090, 9)))

CTD_ANON_12._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'requestedAmount'), pyxb.binding.datatypes.string, scope=CTD_ANON_12, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2091, 9)))

CTD_ANON_12._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'approvedAmount'), pyxb.binding.datatypes.string, scope=CTD_ANON_12, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2092, 9)))

CTD_ANON_12._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'balanceOnCard'), pyxb.binding.datatypes.string, scope=CTD_ANON_12, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2093, 9)))

def _BuildAutomaton_83 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_83
    del _BuildAutomaton_83
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2085, 9))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2086, 9))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2087, 9))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2088, 9))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2089, 9))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2090, 9))
    counters.add(cc_5)
    cc_6 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2091, 9))
    counters.add(cc_6)
    cc_7 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2092, 9))
    counters.add(cc_7)
    cc_8 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2093, 9))
    counters.add(cc_8)
    cc_9 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2094, 9))
    counters.add(cc_9)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_12._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'transId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2085, 9))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_12._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'responseCode')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2086, 9))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_12._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'responseToCustomer')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2087, 9))
    st_2 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_12._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'authCode')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2088, 9))
    st_3 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_12._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'accountNumber')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2089, 9))
    st_4 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_12._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'accountType')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2090, 9))
    st_5 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_6, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_12._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'requestedAmount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2091, 9))
    st_6 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_7, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_12._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'approvedAmount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2092, 9))
    st_7 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_7)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_8, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_12._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'balanceOnCard')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2093, 9))
    st_8 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_8)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_9, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2094, 9))
    st_9 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_9)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_5, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_5, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_6, True) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_6, False) ]))
    st_6._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_7, True) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_7, False) ]))
    st_7._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_8, True) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_8, False) ]))
    st_8._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_9, True) ]))
    st_9._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
CTD_ANON_12._Automaton = _BuildAutomaton_83()




CTD_ANON_13._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'userField'), userField, scope=CTD_ANON_13, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2105, 6)))

def _BuildAutomaton_84 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_84
    del _BuildAutomaton_84
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=20, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2105, 6))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2106, 6))
    counters.add(cc_1)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_13._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'userField')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2105, 6))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2106, 6))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    st_1._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
CTD_ANON_13._Automaton = _BuildAutomaton_84()




CTD_ANON_14._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'SecureAcceptanceUrl'), pyxb.binding.datatypes.string, scope=CTD_ANON_14, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2114, 12)))

CTD_ANON_14._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'PayerID'), pyxb.binding.datatypes.string, scope=CTD_ANON_14, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2115, 12)))

def _BuildAutomaton_85 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_85
    del _BuildAutomaton_85
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2114, 12))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2115, 12))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2116, 11))
    counters.add(cc_2)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_14._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'SecureAcceptanceUrl')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2114, 12))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_14._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'PayerID')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2115, 12))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2116, 11))
    st_2 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_2, True) ]))
    st_2._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
CTD_ANON_14._Automaton = _BuildAutomaton_85()




CTD_ANON_15._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'tlvData'), pyxb.binding.datatypes.string, scope=CTD_ANON_15, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2123, 24)))

CTD_ANON_15._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'tag'), emvTag, scope=CTD_ANON_15, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2124, 24)))

def _BuildAutomaton_86 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_86
    del _BuildAutomaton_86
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2123, 24))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2124, 24))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2125, 21))
    counters.add(cc_2)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_15._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'tlvData')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2123, 24))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_15._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'tag')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2124, 24))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2125, 21))
    st_2 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_2, True) ]))
    st_2._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
CTD_ANON_15._Automaton = _BuildAutomaton_86()




ANetApiRequest._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'merchantAuthentication'), merchantAuthenticationType, scope=ANetApiRequest, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2140, 3)))

ANetApiRequest._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'refId'), STD_ANON_94, scope=ANetApiRequest, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3)))

def _BuildAutomaton_87 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_87
    del _BuildAutomaton_87
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    counters.add(cc_1)
    states = []
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(ANetApiRequest._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantAuthentication')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2140, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(ANetApiRequest._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    st_2._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
ANetApiRequest._Automaton = _BuildAutomaton_87()




messagesType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'resultCode'), messageTypeEnum, scope=messagesType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2191, 3)))

messagesType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'message'), CTD_ANON_16, scope=messagesType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2192, 3)))

def _BuildAutomaton_88 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_88
    del _BuildAutomaton_88
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2201, 3))
    counters.add(cc_0)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(messagesType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'resultCode')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2191, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(messagesType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'message')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2192, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2201, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, True) ]))
    st_2._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
messagesType._Automaton = _BuildAutomaton_88()




CTD_ANON_16._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'code'), pyxb.binding.datatypes.string, scope=CTD_ANON_16, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2195, 6)))

CTD_ANON_16._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'text'), pyxb.binding.datatypes.string, scope=CTD_ANON_16, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2196, 6)))

def _BuildAutomaton_89 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_89
    del _BuildAutomaton_89
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2197, 6))
    counters.add(cc_0)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_16._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'code')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2195, 6))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_16._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'text')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2196, 6))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2197, 6))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, True) ]))
    st_2._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_16._Automaton = _BuildAutomaton_89()




ANetApiResponse._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'refId'), pyxb.binding.datatypes.string, scope=ANetApiResponse, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3)))

ANetApiResponse._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'messages'), messagesType, scope=ANetApiResponse, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2214, 4)))

ANetApiResponse._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'sessionToken'), pyxb.binding.datatypes.string, scope=ANetApiResponse, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3)))

def _BuildAutomaton_90 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_90
    del _BuildAutomaton_90
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    counters.add(cc_3)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(ANetApiResponse._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(ANetApiResponse._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'messages')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2214, 4))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(ANetApiResponse._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'sessionToken')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    st_4._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
ANetApiResponse._Automaton = _BuildAutomaton_90()




CTD_ANON_17._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'refId'), STD_ANON_96, scope=CTD_ANON_17, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2243, 4)))

def _BuildAutomaton_91 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_91
    del _BuildAutomaton_91
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2243, 4))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2250, 4))
    counters.add(cc_1)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_17._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2243, 4))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2250, 4))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    st_1._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
CTD_ANON_17._Automaton = _BuildAutomaton_91()




createProfileResponse._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'messages'), messagesType, scope=createProfileResponse, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2496, 12)))

createProfileResponse._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), numericString, scope=createProfileResponse, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2498, 12)))

createProfileResponse._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileIdList'), ArrayOfNumericString, scope=createProfileResponse, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2499, 12)))

createProfileResponse._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerShippingAddressIdList'), ArrayOfNumericString, scope=createProfileResponse, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2500, 12)))

def _BuildAutomaton_92 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_92
    del _BuildAutomaton_92
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2498, 12))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2499, 12))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2500, 12))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2501, 9))
    counters.add(cc_3)
    states = []
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(createProfileResponse._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'messages')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2496, 12))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(createProfileResponse._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2498, 12))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(createProfileResponse._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileIdList')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2499, 12))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(createProfileResponse._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerShippingAddressIdList')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2500, 12))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2501, 9))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    st_4._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
createProfileResponse._Automaton = _BuildAutomaton_92()




payPalType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'successUrl'), STD_ANON_102, scope=payPalType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3507, 3)))

payPalType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'cancelUrl'), STD_ANON_103, scope=payPalType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3514, 3)))

payPalType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'paypalLc'), STD_ANON_104, scope=payPalType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3521, 3)))

payPalType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'paypalHdrImg'), STD_ANON_105, scope=payPalType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3528, 3)))

payPalType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'paypalPayflowcolor'), STD_ANON_106, scope=payPalType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3535, 3)))

payPalType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'payerID'), STD_ANON_107, scope=payPalType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3542, 3)))

def _BuildAutomaton_93 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_93
    del _BuildAutomaton_93
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3507, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3514, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3521, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3528, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3535, 3))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3542, 3))
    counters.add(cc_5)
    cc_6 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3549, 3))
    counters.add(cc_6)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(payPalType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'successUrl')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3507, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(payPalType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'cancelUrl')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3514, 3))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(payPalType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'paypalLc')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3521, 3))
    st_2 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.ElementUse(payPalType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'paypalHdrImg')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3528, 3))
    st_3 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.ElementUse(payPalType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'paypalPayflowcolor')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3535, 3))
    st_4 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.ElementUse(payPalType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'payerID')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3542, 3))
    st_5 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_6, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3549, 3))
    st_6 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_5, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_5, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_6, True) ]))
    st_6._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
payPalType._Automaton = _BuildAutomaton_93()




Paging._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'limit'), STD_ANON_108, scope=Paging, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3568, 12)))

Paging._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'offset'), STD_ANON_109, scope=Paging, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3576, 12)))

def _BuildAutomaton_94 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_94
    del _BuildAutomaton_94
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3584, 9))
    counters.add(cc_0)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(Paging._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'limit')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3568, 12))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(Paging._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'offset')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3576, 12))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3584, 9))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, True) ]))
    st_2._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
Paging._Automaton = _BuildAutomaton_94()




ARBGetSubscriptionListSorting._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'orderBy'), ARBGetSubscriptionListOrderFieldEnum, scope=ARBGetSubscriptionListSorting, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3589, 12)))

ARBGetSubscriptionListSorting._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'orderDescending'), pyxb.binding.datatypes.boolean, scope=ARBGetSubscriptionListSorting, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3590, 12)))

def _BuildAutomaton_95 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_95
    del _BuildAutomaton_95
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3591, 9))
    counters.add(cc_0)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(ARBGetSubscriptionListSorting._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'orderBy')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3589, 12))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(ARBGetSubscriptionListSorting._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'orderDescending')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3590, 12))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3591, 9))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, True) ]))
    st_2._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
ARBGetSubscriptionListSorting._Automaton = _BuildAutomaton_95()




ArrayOfSubscription._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'subscriptionDetail'), SubscriptionDetail, nillable=pyxb.binding.datatypes.boolean(1), scope=ArrayOfSubscription, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3630, 3)))

def _BuildAutomaton_96 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_96
    del _BuildAutomaton_96
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3630, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3631, 3))
    counters.add(cc_1)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(ArrayOfSubscription._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'subscriptionDetail')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3630, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3631, 3))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    st_1._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
ArrayOfSubscription._Automaton = _BuildAutomaton_96()




SubscriptionDetail._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'id'), pyxb.binding.datatypes.int, scope=SubscriptionDetail, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3636, 3)))

SubscriptionDetail._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'name'), pyxb.binding.datatypes.string, scope=SubscriptionDetail, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3637, 3)))

SubscriptionDetail._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'status'), ARBSubscriptionStatusEnum, scope=SubscriptionDetail, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3638, 12)))

SubscriptionDetail._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'createTimeStampUTC'), pyxb.binding.datatypes.dateTime, scope=SubscriptionDetail, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3639, 3)))

SubscriptionDetail._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'firstName'), pyxb.binding.datatypes.string, scope=SubscriptionDetail, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3640, 3)))

SubscriptionDetail._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'lastName'), pyxb.binding.datatypes.string, scope=SubscriptionDetail, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3641, 3)))

SubscriptionDetail._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'totalOccurrences'), pyxb.binding.datatypes.int, scope=SubscriptionDetail, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3642, 3)))

SubscriptionDetail._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'pastOccurrences'), pyxb.binding.datatypes.int, scope=SubscriptionDetail, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3643, 3)))

SubscriptionDetail._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'paymentMethod'), paymentMethodEnum, scope=SubscriptionDetail, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3644, 12)))

SubscriptionDetail._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'accountNumber'), pyxb.binding.datatypes.string, scope=SubscriptionDetail, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3645, 12)))

SubscriptionDetail._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'invoice'), pyxb.binding.datatypes.string, scope=SubscriptionDetail, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3646, 3)))

SubscriptionDetail._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'amount'), STD_ANON_110, scope=SubscriptionDetail, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3647, 3)))

SubscriptionDetail._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'currencyCode'), pyxb.binding.datatypes.string, scope=SubscriptionDetail, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3655, 3)))

SubscriptionDetail._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), pyxb.binding.datatypes.int, scope=SubscriptionDetail, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3656, 3)))

SubscriptionDetail._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileId'), pyxb.binding.datatypes.int, scope=SubscriptionDetail, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3657, 3)))

SubscriptionDetail._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerShippingProfileId'), pyxb.binding.datatypes.int, scope=SubscriptionDetail, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3658, 3)))

def _BuildAutomaton_97 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_97
    del _BuildAutomaton_97
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3637, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3640, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3641, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3645, 12))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3646, 3))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3655, 3))
    counters.add(cc_5)
    cc_6 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3658, 3))
    counters.add(cc_6)
    cc_7 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3664, 3))
    counters.add(cc_7)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(SubscriptionDetail._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'id')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3636, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(SubscriptionDetail._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'name')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3637, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(SubscriptionDetail._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'status')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3638, 12))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(SubscriptionDetail._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'createTimeStampUTC')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3639, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(SubscriptionDetail._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'firstName')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3640, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(SubscriptionDetail._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'lastName')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3641, 3))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(SubscriptionDetail._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'totalOccurrences')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3642, 3))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(SubscriptionDetail._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'pastOccurrences')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3643, 3))
    st_7 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_7)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(SubscriptionDetail._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'paymentMethod')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3644, 12))
    st_8 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_8)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(SubscriptionDetail._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'accountNumber')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3645, 12))
    st_9 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_9)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(SubscriptionDetail._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'invoice')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3646, 3))
    st_10 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_10)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(SubscriptionDetail._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'amount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3647, 3))
    st_11 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_11)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(SubscriptionDetail._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'currencyCode')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3655, 3))
    st_12 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_12)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(SubscriptionDetail._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3656, 3))
    st_13 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_13)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(SubscriptionDetail._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3657, 3))
    st_14 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_14)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_6, False))
    symbol = pyxb.binding.content.ElementUse(SubscriptionDetail._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerShippingProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3658, 3))
    st_15 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_15)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_7, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3664, 3))
    st_16 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_16)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
         ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
         ]))
    transitions.append(fac.Transition(st_5, [
         ]))
    transitions.append(fac.Transition(st_6, [
         ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_7, [
         ]))
    st_6._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_8, [
         ]))
    st_7._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_9, [
         ]))
    transitions.append(fac.Transition(st_10, [
         ]))
    transitions.append(fac.Transition(st_11, [
         ]))
    st_8._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_9._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_10._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_12, [
         ]))
    transitions.append(fac.Transition(st_13, [
         ]))
    st_11._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_5, True) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_5, False) ]))
    st_12._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_14, [
         ]))
    st_13._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_15, [
         ]))
    transitions.append(fac.Transition(st_16, [
         ]))
    st_14._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_6, True) ]))
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_6, False) ]))
    st_15._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_7, True) ]))
    st_16._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
SubscriptionDetail._Automaton = _BuildAutomaton_97()




customerProfileSummaryType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), pyxb.binding.datatypes.string, scope=customerProfileSummaryType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3670, 8)))

customerProfileSummaryType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'description'), pyxb.binding.datatypes.string, scope=customerProfileSummaryType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3671, 8)))

customerProfileSummaryType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'merchantCustomerId'), pyxb.binding.datatypes.string, scope=customerProfileSummaryType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3672, 8)))

customerProfileSummaryType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'email'), pyxb.binding.datatypes.string, scope=customerProfileSummaryType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3673, 8)))

customerProfileSummaryType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'createdDate'), pyxb.binding.datatypes.dateTime, scope=customerProfileSummaryType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3674, 8)))

def _BuildAutomaton_98 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_98
    del _BuildAutomaton_98
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3670, 8))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3671, 8))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3673, 8))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3675, 7))
    counters.add(cc_3)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(customerProfileSummaryType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3670, 8))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(customerProfileSummaryType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'description')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3671, 8))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(customerProfileSummaryType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantCustomerId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3672, 8))
    st_2 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(customerProfileSummaryType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'email')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3673, 8))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(customerProfileSummaryType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'createdDate')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3674, 8))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3675, 7))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
         ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, True) ]))
    st_5._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
customerProfileSummaryType._Automaton = _BuildAutomaton_98()




CTD_ANON_18._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerProfileSummaryType'), customerProfileSummaryType, scope=CTD_ANON_18, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3684, 16)))

CTD_ANON_18._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'paymentSimpleType'), paymentSimpleType, scope=CTD_ANON_18, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3685, 16)))

CTD_ANON_18._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'accountTypeEnum'), accountTypeEnum, scope=CTD_ANON_18, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3687, 16)))

CTD_ANON_18._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'cardTypeEnum'), cardTypeEnum, scope=CTD_ANON_18, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3688, 16)))

CTD_ANON_18._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'FDSFilterActionEnum'), FDSFilterActionEnum, scope=CTD_ANON_18, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3689, 16)))

CTD_ANON_18._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'permissionsEnum'), permissionsEnum, scope=CTD_ANON_18, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3690, 16)))

CTD_ANON_18._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'settingNameEnum'), settingNameEnum, scope=CTD_ANON_18, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3691, 16)))

CTD_ANON_18._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'settlementStateEnum'), settlementStateEnum, scope=CTD_ANON_18, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3692, 16)))

CTD_ANON_18._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'transactionStatusEnum'), transactionStatusEnum, scope=CTD_ANON_18, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3693, 16)))

CTD_ANON_18._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'transactionTypeEnum'), transactionTypeEnum, scope=CTD_ANON_18, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3694, 16)))

def _BuildAutomaton_99 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_99
    del _BuildAutomaton_99
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3695, 13))
    counters.add(cc_0)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_18._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerProfileSummaryType')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3684, 16))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_18._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'paymentSimpleType')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3685, 16))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_18._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'accountTypeEnum')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3687, 16))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_18._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'cardTypeEnum')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3688, 16))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_18._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'FDSFilterActionEnum')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3689, 16))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_18._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'permissionsEnum')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3690, 16))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_18._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'settingNameEnum')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3691, 16))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_18._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'settlementStateEnum')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3692, 16))
    st_7 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_7)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_18._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'transactionStatusEnum')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3693, 16))
    st_8 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_8)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_18._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'transactionTypeEnum')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3694, 16))
    st_9 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_9)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3695, 13))
    st_10 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_10)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
         ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
         ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
         ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
         ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_7, [
         ]))
    st_6._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_8, [
         ]))
    st_7._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_9, [
         ]))
    st_8._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_10, [
         ]))
    st_9._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_0, True) ]))
    st_10._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_18._Automaton = _BuildAutomaton_99()




customerProfilePaymentType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'createProfile'), pyxb.binding.datatypes.boolean, scope=customerProfilePaymentType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3706, 8)))

customerProfilePaymentType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), numericString, scope=customerProfilePaymentType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3707, 8)))

customerProfilePaymentType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'paymentProfile'), paymentProfile, scope=customerProfilePaymentType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3708, 8)))

customerProfilePaymentType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'shippingProfileId'), numericString, scope=customerProfilePaymentType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3709, 8)))

def _BuildAutomaton_100 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_100
    del _BuildAutomaton_100
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3706, 8))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3707, 8))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3708, 8))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3709, 8))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3710, 5))
    counters.add(cc_4)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(customerProfilePaymentType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'createProfile')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3706, 8))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(customerProfilePaymentType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3707, 8))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(customerProfilePaymentType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'paymentProfile')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3708, 8))
    st_2 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.ElementUse(customerProfilePaymentType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'shippingProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3709, 8))
    st_3 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3710, 5))
    st_4 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_4, True) ]))
    st_4._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
customerProfilePaymentType._Automaton = _BuildAutomaton_100()




paymentProfile._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'paymentProfileId'), numericString, scope=paymentProfile, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3721, 6)))

paymentProfile._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'cardCode'), cardCode, scope=paymentProfile, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3722, 6)))

def _BuildAutomaton_101 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_101
    del _BuildAutomaton_101
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3722, 6))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3723, 5))
    counters.add(cc_1)
    states = []
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(paymentProfile._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'paymentProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3721, 6))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(paymentProfile._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'cardCode')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3722, 6))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3723, 5))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    st_2._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
paymentProfile._Automaton = _BuildAutomaton_101()




CustomerPaymentProfileSorting._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'orderBy'), CustomerPaymentProfileOrderFieldEnum, scope=CustomerPaymentProfileSorting, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3770, 12)))

CustomerPaymentProfileSorting._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'orderDescending'), pyxb.binding.datatypes.boolean, scope=CustomerPaymentProfileSorting, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3771, 12)))

def _BuildAutomaton_102 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_102
    del _BuildAutomaton_102
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3772, 9))
    counters.add(cc_0)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CustomerPaymentProfileSorting._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'orderBy')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3770, 12))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CustomerPaymentProfileSorting._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'orderDescending')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3771, 12))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3772, 9))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, True) ]))
    st_2._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CustomerPaymentProfileSorting._Automaton = _BuildAutomaton_102()




customerPaymentProfileListItemType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileId'), pyxb.binding.datatypes.int, scope=customerPaymentProfileListItemType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3783, 12)))

customerPaymentProfileListItemType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), pyxb.binding.datatypes.int, scope=customerPaymentProfileListItemType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3784, 12)))

customerPaymentProfileListItemType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'billTo'), customerAddressType, scope=customerPaymentProfileListItemType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3785, 3)))

customerPaymentProfileListItemType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'payment'), paymentMaskedType, scope=customerPaymentProfileListItemType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3786, 12)))

def _BuildAutomaton_103 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_103
    del _BuildAutomaton_103
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3787, 3))
    counters.add(cc_0)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(customerPaymentProfileListItemType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3783, 12))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(customerPaymentProfileListItemType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3784, 12))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(customerPaymentProfileListItemType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'billTo')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3785, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(customerPaymentProfileListItemType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'payment')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3786, 12))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3787, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
         ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
         ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_0, True) ]))
    st_4._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
customerPaymentProfileListItemType._Automaton = _BuildAutomaton_103()




arrayOfCustomerPaymentProfileListItemType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'paymentProfile'), customerPaymentProfileListItemType, nillable=pyxb.binding.datatypes.boolean(1), scope=arrayOfCustomerPaymentProfileListItemType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3792, 3)))

def _BuildAutomaton_104 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_104
    del _BuildAutomaton_104
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3792, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3793, 3))
    counters.add(cc_1)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(arrayOfCustomerPaymentProfileListItemType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'paymentProfile')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3792, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3793, 3))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    st_1._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
arrayOfCustomerPaymentProfileListItemType._Automaton = _BuildAutomaton_104()




customerProfileIdType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), numericString, scope=customerProfileIdType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3841, 6)))

customerProfileIdType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileId'), numericString, scope=customerProfileIdType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3842, 6)))

customerProfileIdType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerAddressId'), numericString, scope=customerProfileIdType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3843, 6)))

def _BuildAutomaton_105 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_105
    del _BuildAutomaton_105
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3842, 6))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3843, 6))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3844, 5))
    counters.add(cc_2)
    states = []
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(customerProfileIdType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3841, 6))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(customerProfileIdType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3842, 6))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(customerProfileIdType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerAddressId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3843, 6))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3844, 5))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    st_3._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
customerProfileIdType._Automaton = _BuildAutomaton_105()




creditCardType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'cardCode'), cardCode, scope=creditCardType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 448, 5)))

creditCardType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'isPaymentToken'), pyxb.binding.datatypes.boolean, scope=creditCardType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 450, 10)))

creditCardType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'cryptogram'), pyxb.binding.datatypes.string, scope=creditCardType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 452, 10)))

def _BuildAutomaton_106 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_106
    del _BuildAutomaton_106
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 424, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 448, 5))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 450, 10))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 452, 10))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 453, 5))
    counters.add(cc_4)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(creditCardType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'cardNumber')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 407, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(creditCardType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'expirationDate')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 416, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 424, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(creditCardType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'cardCode')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 448, 5))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(creditCardType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'isPaymentToken')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 450, 10))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.ElementUse(creditCardType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'cryptogram')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 452, 10))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 453, 5))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    transitions.append(fac.Transition(st_5, [
         ]))
    transitions.append(fac.Transition(st_6, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, True) ]))
    st_6._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
creditCardType._Automaton = _BuildAutomaton_106()




orderExType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'purchaseOrderNumber'), STD_ANON_31, scope=orderExType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 656, 5)))

def _BuildAutomaton_107 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_107
    del _BuildAutomaton_107
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 634, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 641, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 648, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 656, 5))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 663, 5))
    counters.add(cc_4)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(orderExType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'invoiceNumber')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 634, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(orderExType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'description')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 641, 3))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 648, 3))
    st_2 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.ElementUse(orderExType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'purchaseOrderNumber')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 656, 5))
    st_3 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 663, 5))
    st_4 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_4, True) ]))
    st_4._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
orderExType._Automaton = _BuildAutomaton_107()




CTD_ANON_19._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'opaqueData'), opaqueDataType, scope=CTD_ANON_19, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 827, 12)))

CTD_ANON_19._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'callId'), pyxb.binding.datatypes.string, scope=CTD_ANON_19, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 828, 12)))

def _BuildAutomaton_108 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_108
    del _BuildAutomaton_108
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 828, 12))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 829, 11))
    counters.add(cc_3)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_19._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantAuthentication')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2140, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_19._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_19._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'opaqueData')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 827, 12))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_19._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'callId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 828, 12))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 829, 11))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
         ]))
    transitions.append(fac.Transition(st_5, [
         ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, True) ]))
    st_5._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_19._Automaton = _BuildAutomaton_108()




CTD_ANON_20._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'shippingInfo'), customerAddressType, scope=CTD_ANON_20, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 841, 12)))

CTD_ANON_20._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'billingInfo'), customerAddressType, scope=CTD_ANON_20, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 842, 12)))

CTD_ANON_20._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'cardInfo'), creditCardMaskedType, scope=CTD_ANON_20, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 843, 12)))

CTD_ANON_20._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'paymentDetails'), paymentDetails, scope=CTD_ANON_20, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 844, 12)))

def _BuildAutomaton_109 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_109
    del _BuildAutomaton_109
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 841, 12))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 842, 12))
    counters.add(cc_5)
    cc_6 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 843, 12))
    counters.add(cc_6)
    cc_7 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 844, 12))
    counters.add(cc_7)
    cc_8 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 845, 11))
    counters.add(cc_8)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_20._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_20._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'messages')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2214, 4))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_20._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'sessionToken')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_20._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'shippingInfo')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 841, 12))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_20._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'billingInfo')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 842, 12))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_6, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_20._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'cardInfo')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 843, 12))
    st_7 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_7)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_7, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_20._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'paymentDetails')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 844, 12))
    st_8 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_8)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_8, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 845, 11))
    st_9 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_9)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    transitions.append(fac.Transition(st_5, [
         ]))
    transitions.append(fac.Transition(st_6, [
         ]))
    transitions.append(fac.Transition(st_7, [
         ]))
    transitions.append(fac.Transition(st_8, [
         ]))
    transitions.append(fac.Transition(st_9, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_5, True) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_5, False) ]))
    st_6._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_6, True) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_6, False) ]))
    st_7._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_7, True) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_7, False) ]))
    st_8._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_8, True) ]))
    st_9._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_20._Automaton = _BuildAutomaton_109()




CTD_ANON_21._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'data'), webCheckOutDataType, scope=CTD_ANON_21, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 859, 12)))

def _BuildAutomaton_110 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_110
    del _BuildAutomaton_110
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 860, 11))
    counters.add(cc_2)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_21._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantAuthentication')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2140, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_21._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_21._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'data')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 859, 12))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 860, 11))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
         ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, True) ]))
    st_4._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_21._Automaton = _BuildAutomaton_110()




CTD_ANON_22._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'opaqueData'), opaqueDataType, scope=CTD_ANON_22, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 872, 12)))

def _BuildAutomaton_111 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_111
    del _BuildAutomaton_111
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 873, 11))
    counters.add(cc_4)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_22._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_22._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'messages')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2214, 4))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_22._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'sessionToken')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_22._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'opaqueData')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 872, 12))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 873, 11))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    transitions.append(fac.Transition(st_5, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
         ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, True) ]))
    st_6._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_22._Automaton = _BuildAutomaton_111()




customerPaymentProfileType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'payment'), paymentType, scope=customerPaymentProfileType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1426, 5)))

customerPaymentProfileType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'driversLicense'), driversLicenseType, scope=customerPaymentProfileType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1427, 5)))

customerPaymentProfileType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'taxId'), STD_ANON_66, scope=customerPaymentProfileType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1429, 5)))

def _BuildAutomaton_112 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_112
    del _BuildAutomaton_112
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1416, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1417, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1418, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1426, 5))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1427, 5))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1429, 5))
    counters.add(cc_5)
    cc_6 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1437, 5))
    counters.add(cc_6)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(customerPaymentProfileType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerType')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1416, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(customerPaymentProfileType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'billTo')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1417, 3))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1418, 3))
    st_2 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.ElementUse(customerPaymentProfileType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'payment')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1426, 5))
    st_3 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.ElementUse(customerPaymentProfileType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'driversLicense')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1427, 5))
    st_4 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.ElementUse(customerPaymentProfileType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'taxId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1429, 5))
    st_5 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_6, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1437, 5))
    st_6 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_5, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_5, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_6, True) ]))
    st_6._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
customerPaymentProfileType._Automaton = _BuildAutomaton_112()




customerPaymentProfileMaskedType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), numericString, scope=customerPaymentProfileMaskedType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1458, 5)))

customerPaymentProfileMaskedType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileId'), numericString, scope=customerPaymentProfileMaskedType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1459, 5)))

customerPaymentProfileMaskedType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'payment'), paymentMaskedType, scope=customerPaymentProfileMaskedType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1460, 5)))

customerPaymentProfileMaskedType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'driversLicense'), driversLicenseMaskedType, scope=customerPaymentProfileMaskedType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1461, 5)))

customerPaymentProfileMaskedType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'taxId'), STD_ANON_67, scope=customerPaymentProfileMaskedType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1462, 5)))

customerPaymentProfileMaskedType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'subscriptionIds'), SubscriptionIdList, scope=customerPaymentProfileMaskedType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1469, 5)))

def _BuildAutomaton_113 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_113
    del _BuildAutomaton_113
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1416, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1417, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1418, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1458, 5))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1460, 5))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1461, 5))
    counters.add(cc_5)
    cc_6 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1462, 5))
    counters.add(cc_6)
    cc_7 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1469, 5))
    counters.add(cc_7)
    cc_8 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1470, 5))
    counters.add(cc_8)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(customerPaymentProfileMaskedType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerType')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1416, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(customerPaymentProfileMaskedType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'billTo')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1417, 3))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1418, 3))
    st_2 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(customerPaymentProfileMaskedType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1458, 5))
    st_3 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(customerPaymentProfileMaskedType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1459, 5))
    st_4 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.ElementUse(customerPaymentProfileMaskedType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'payment')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1460, 5))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.ElementUse(customerPaymentProfileMaskedType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'driversLicense')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1461, 5))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_6, False))
    symbol = pyxb.binding.content.ElementUse(customerPaymentProfileMaskedType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'taxId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1462, 5))
    st_7 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_7)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_7, False))
    symbol = pyxb.binding.content.ElementUse(customerPaymentProfileMaskedType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'subscriptionIds')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1469, 5))
    st_8 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_8)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_8, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1470, 5))
    st_9 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_9)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
         ]))
    transitions.append(fac.Transition(st_6, [
         ]))
    transitions.append(fac.Transition(st_7, [
         ]))
    transitions.append(fac.Transition(st_8, [
         ]))
    transitions.append(fac.Transition(st_9, [
         ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_5, True) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_5, False) ]))
    st_6._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_6, True) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_6, False) ]))
    st_7._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_7, True) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_7, False) ]))
    st_8._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_8, True) ]))
    st_9._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
customerPaymentProfileMaskedType._Automaton = _BuildAutomaton_113()




customerProfileType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'paymentProfiles'), customerPaymentProfileType, scope=customerProfileType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1516, 5)))

customerProfileType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'shipToList'), customerAddressType, scope=customerProfileType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1517, 5)))

def _BuildAutomaton_114 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_114
    del _BuildAutomaton_114
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1487, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1494, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1501, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1508, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1516, 5))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1517, 5))
    counters.add(cc_5)
    cc_6 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1518, 5))
    counters.add(cc_6)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(customerProfileType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantCustomerId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1487, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(customerProfileType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'description')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1494, 3))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(customerProfileType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'email')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1501, 3))
    st_2 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1508, 3))
    st_3 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.ElementUse(customerProfileType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'paymentProfiles')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1516, 5))
    st_4 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.ElementUse(customerProfileType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'shipToList')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1517, 5))
    st_5 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_6, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1518, 5))
    st_6 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_5, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_5, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_6, True) ]))
    st_6._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
customerProfileType._Automaton = _BuildAutomaton_114()




customerProfileExType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), numericString, scope=customerProfileExType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1537, 5)))

def _BuildAutomaton_115 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_115
    del _BuildAutomaton_115
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1487, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1494, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1501, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1508, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1537, 5))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1538, 5))
    counters.add(cc_5)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(customerProfileExType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantCustomerId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1487, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(customerProfileExType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'description')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1494, 3))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(customerProfileExType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'email')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1501, 3))
    st_2 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1508, 3))
    st_3 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.ElementUse(customerProfileExType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1537, 5))
    st_4 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1538, 5))
    st_5 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_5, True) ]))
    st_5._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
customerProfileExType._Automaton = _BuildAutomaton_115()




customerAddressType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'phoneNumber'), STD_ANON_71, scope=customerAddressType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1560, 5)))

customerAddressType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'faxNumber'), STD_ANON_72, scope=customerAddressType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1567, 5)))

customerAddressType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'email'), pyxb.binding.datatypes.string, scope=customerAddressType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1574, 14)))

def _BuildAutomaton_116 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_116
    del _BuildAutomaton_116
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 317, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 324, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 331, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 338, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 345, 3))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 352, 3))
    counters.add(cc_5)
    cc_6 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 359, 3))
    counters.add(cc_6)
    cc_7 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 366, 3))
    counters.add(cc_7)
    cc_8 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 373, 3))
    counters.add(cc_8)
    cc_9 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1560, 5))
    counters.add(cc_9)
    cc_10 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1567, 5))
    counters.add(cc_10)
    cc_11 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1574, 14))
    counters.add(cc_11)
    cc_12 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1575, 5))
    counters.add(cc_12)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(customerAddressType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'firstName')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 317, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(customerAddressType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'lastName')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 324, 3))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(customerAddressType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'company')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 331, 3))
    st_2 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.ElementUse(customerAddressType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'address')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 338, 3))
    st_3 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.ElementUse(customerAddressType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'city')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 345, 3))
    st_4 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.ElementUse(customerAddressType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'state')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 352, 3))
    st_5 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_6, False))
    symbol = pyxb.binding.content.ElementUse(customerAddressType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'zip')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 359, 3))
    st_6 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_7, False))
    symbol = pyxb.binding.content.ElementUse(customerAddressType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'country')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 366, 3))
    st_7 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_7)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_8, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 373, 3))
    st_8 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_8)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_9, False))
    symbol = pyxb.binding.content.ElementUse(customerAddressType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'phoneNumber')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1560, 5))
    st_9 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_9)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_10, False))
    symbol = pyxb.binding.content.ElementUse(customerAddressType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'faxNumber')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1567, 5))
    st_10 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_10)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_11, False))
    symbol = pyxb.binding.content.ElementUse(customerAddressType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'email')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1574, 14))
    st_11 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_11)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_12, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1575, 5))
    st_12 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_12)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_5, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_5, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_6, True) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_6, False) ]))
    st_6._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_7, True) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_7, False) ]))
    st_7._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_8, True) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_8, False) ]))
    st_8._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_9, True) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_9, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_9, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_9, False) ]))
    st_9._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_10, True) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_10, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_10, False) ]))
    st_10._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_11, True) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_11, False) ]))
    st_11._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_12, True) ]))
    st_12._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
customerAddressType._Automaton = _BuildAutomaton_116()




profileTransOrderType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), numericString, scope=profileTransOrderType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1688, 5)))

profileTransOrderType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileId'), numericString, scope=profileTransOrderType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1689, 5)))

profileTransOrderType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerShippingAddressId'), numericString, scope=profileTransOrderType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1690, 5)))

profileTransOrderType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'order'), orderExType, scope=profileTransOrderType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1691, 5)))

profileTransOrderType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'taxExempt'), pyxb.binding.datatypes.boolean, scope=profileTransOrderType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1692, 5)))

profileTransOrderType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'recurringBilling'), pyxb.binding.datatypes.boolean, scope=profileTransOrderType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1693, 5)))

profileTransOrderType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'cardCode'), cardCode, scope=profileTransOrderType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1694, 5)))

profileTransOrderType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'splitTenderId'), numericString, scope=profileTransOrderType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1695, 5)))

def _BuildAutomaton_117 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_117
    del _BuildAutomaton_117
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1676, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1677, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1678, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=30, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1679, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1680, 3))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1690, 5))
    counters.add(cc_5)
    cc_6 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1691, 5))
    counters.add(cc_6)
    cc_7 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1692, 5))
    counters.add(cc_7)
    cc_8 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1693, 5))
    counters.add(cc_8)
    cc_9 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1694, 5))
    counters.add(cc_9)
    cc_10 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1695, 5))
    counters.add(cc_10)
    cc_11 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1696, 5))
    counters.add(cc_11)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(profileTransOrderType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'amount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1668, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(profileTransOrderType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'tax')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1676, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(profileTransOrderType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'shipping')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1677, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(profileTransOrderType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'duty')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1678, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(profileTransOrderType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'lineItems')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1679, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1680, 3))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(profileTransOrderType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1688, 5))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(profileTransOrderType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1689, 5))
    st_7 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_7)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.ElementUse(profileTransOrderType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerShippingAddressId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1690, 5))
    st_8 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_8)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_6, False))
    symbol = pyxb.binding.content.ElementUse(profileTransOrderType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'order')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1691, 5))
    st_9 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_9)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_7, False))
    symbol = pyxb.binding.content.ElementUse(profileTransOrderType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'taxExempt')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1692, 5))
    st_10 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_10)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_8, False))
    symbol = pyxb.binding.content.ElementUse(profileTransOrderType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'recurringBilling')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1693, 5))
    st_11 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_11)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_9, False))
    symbol = pyxb.binding.content.ElementUse(profileTransOrderType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'cardCode')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1694, 5))
    st_12 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_12)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_10, False))
    symbol = pyxb.binding.content.ElementUse(profileTransOrderType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'splitTenderId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1695, 5))
    st_13 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_13)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_11, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1696, 5))
    st_14 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_14)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    transitions.append(fac.Transition(st_5, [
         ]))
    transitions.append(fac.Transition(st_6, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_7, [
         ]))
    st_6._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_8, [
         ]))
    transitions.append(fac.Transition(st_9, [
         ]))
    transitions.append(fac.Transition(st_10, [
         ]))
    transitions.append(fac.Transition(st_11, [
         ]))
    transitions.append(fac.Transition(st_12, [
         ]))
    transitions.append(fac.Transition(st_13, [
         ]))
    transitions.append(fac.Transition(st_14, [
         ]))
    st_7._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_5, True) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_5, False) ]))
    st_8._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_6, True) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_6, False) ]))
    st_9._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_7, True) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_7, False) ]))
    st_10._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_8, True) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_8, False) ]))
    st_11._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_9, True) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_9, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_9, False) ]))
    st_12._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_10, True) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_10, False) ]))
    st_13._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_11, True) ]))
    st_14._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
profileTransOrderType._Automaton = _BuildAutomaton_117()




profileTransPriorAuthCaptureType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), numericString, scope=profileTransPriorAuthCaptureType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1720, 5)))

profileTransPriorAuthCaptureType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileId'), numericString, scope=profileTransPriorAuthCaptureType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1721, 5)))

profileTransPriorAuthCaptureType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerShippingAddressId'), numericString, scope=profileTransPriorAuthCaptureType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1722, 5)))

profileTransPriorAuthCaptureType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'transId'), numericString, scope=profileTransPriorAuthCaptureType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1723, 5)))

def _BuildAutomaton_118 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_118
    del _BuildAutomaton_118
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1676, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1677, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1678, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=30, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1679, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1680, 3))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1720, 5))
    counters.add(cc_5)
    cc_6 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1721, 5))
    counters.add(cc_6)
    cc_7 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1722, 5))
    counters.add(cc_7)
    cc_8 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1724, 5))
    counters.add(cc_8)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(profileTransPriorAuthCaptureType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'amount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1668, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(profileTransPriorAuthCaptureType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'tax')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1676, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(profileTransPriorAuthCaptureType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'shipping')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1677, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(profileTransPriorAuthCaptureType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'duty')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1678, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(profileTransPriorAuthCaptureType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'lineItems')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1679, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1680, 3))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(profileTransPriorAuthCaptureType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1720, 5))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(profileTransPriorAuthCaptureType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1721, 5))
    st_7 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_7)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(profileTransPriorAuthCaptureType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerShippingAddressId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1722, 5))
    st_8 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_8)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(profileTransPriorAuthCaptureType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'transId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1723, 5))
    st_9 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_9)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_8, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1724, 5))
    st_10 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_10)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    transitions.append(fac.Transition(st_5, [
         ]))
    transitions.append(fac.Transition(st_6, [
         ]))
    transitions.append(fac.Transition(st_7, [
         ]))
    transitions.append(fac.Transition(st_8, [
         ]))
    transitions.append(fac.Transition(st_9, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_5, True) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_5, False) ]))
    st_6._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_6, True) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_6, False) ]))
    st_7._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_7, True) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_7, False) ]))
    st_8._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_10, [
         ]))
    st_9._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_8, True) ]))
    st_10._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
profileTransPriorAuthCaptureType._Automaton = _BuildAutomaton_118()




profileTransRefundType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), numericString, scope=profileTransRefundType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1751, 5)))

profileTransRefundType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileId'), numericString, scope=profileTransRefundType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1752, 5)))

profileTransRefundType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerShippingAddressId'), numericString, scope=profileTransRefundType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1753, 5)))

profileTransRefundType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'creditCardNumberMasked'), STD_ANON_83, scope=profileTransRefundType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1755, 5)))

profileTransRefundType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'bankRoutingNumberMasked'), STD_ANON_84, scope=profileTransRefundType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1764, 5)))

profileTransRefundType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'bankAccountNumberMasked'), STD_ANON_85, scope=profileTransRefundType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1773, 5)))

profileTransRefundType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'order'), orderExType, scope=profileTransRefundType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1781, 5)))

profileTransRefundType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'transId'), numericString, scope=profileTransRefundType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1782, 5)))

def _BuildAutomaton_119 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_119
    del _BuildAutomaton_119
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1676, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1677, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1678, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=30, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1679, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1680, 3))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1751, 5))
    counters.add(cc_5)
    cc_6 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1752, 5))
    counters.add(cc_6)
    cc_7 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1753, 5))
    counters.add(cc_7)
    cc_8 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1755, 5))
    counters.add(cc_8)
    cc_9 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1764, 5))
    counters.add(cc_9)
    cc_10 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1773, 5))
    counters.add(cc_10)
    cc_11 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1781, 5))
    counters.add(cc_11)
    cc_12 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1782, 5))
    counters.add(cc_12)
    cc_13 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1783, 5))
    counters.add(cc_13)
    states = []
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(profileTransRefundType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'amount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1668, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(profileTransRefundType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'tax')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1676, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(profileTransRefundType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'shipping')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1677, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(profileTransRefundType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'duty')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1678, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.ElementUse(profileTransRefundType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'lineItems')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1679, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1680, 3))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.ElementUse(profileTransRefundType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1751, 5))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_6, False))
    symbol = pyxb.binding.content.ElementUse(profileTransRefundType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1752, 5))
    st_7 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_7)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_7, False))
    symbol = pyxb.binding.content.ElementUse(profileTransRefundType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerShippingAddressId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1753, 5))
    st_8 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_8)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_8, False))
    symbol = pyxb.binding.content.ElementUse(profileTransRefundType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'creditCardNumberMasked')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1755, 5))
    st_9 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_9)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_9, False))
    symbol = pyxb.binding.content.ElementUse(profileTransRefundType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'bankRoutingNumberMasked')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1764, 5))
    st_10 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_10)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_10, False))
    symbol = pyxb.binding.content.ElementUse(profileTransRefundType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'bankAccountNumberMasked')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1773, 5))
    st_11 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_11)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_11, False))
    symbol = pyxb.binding.content.ElementUse(profileTransRefundType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'order')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1781, 5))
    st_12 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_12)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_12, False))
    symbol = pyxb.binding.content.ElementUse(profileTransRefundType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'transId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1782, 5))
    st_13 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_13)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_13, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1783, 5))
    st_14 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_14)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    transitions.append(fac.Transition(st_5, [
         ]))
    transitions.append(fac.Transition(st_6, [
         ]))
    transitions.append(fac.Transition(st_7, [
         ]))
    transitions.append(fac.Transition(st_8, [
         ]))
    transitions.append(fac.Transition(st_9, [
         ]))
    transitions.append(fac.Transition(st_10, [
         ]))
    transitions.append(fac.Transition(st_11, [
         ]))
    transitions.append(fac.Transition(st_12, [
         ]))
    transitions.append(fac.Transition(st_13, [
         ]))
    transitions.append(fac.Transition(st_14, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_5, True) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_5, False) ]))
    st_6._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_6, True) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_6, False) ]))
    st_7._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_7, True) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_7, False) ]))
    st_8._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_8, True) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_8, False) ]))
    st_9._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_9, True) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_9, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_9, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_9, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_9, False) ]))
    st_10._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_10, True) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_10, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_10, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_10, False) ]))
    st_11._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_11, True) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_11, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_11, False) ]))
    st_12._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_12, True) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_12, False) ]))
    st_13._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_13, True) ]))
    st_14._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
profileTransRefundType._Automaton = _BuildAutomaton_119()




def _BuildAutomaton_120 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_120
    del _BuildAutomaton_120
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 66, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 67, 3))
    counters.add(cc_1)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(emailSettingsType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'setting')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 66, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 67, 3))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    st_1._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
emailSettingsType._Automaton = _BuildAutomaton_120()




def _BuildAutomaton_121 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_121
    del _BuildAutomaton_121
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    counters.add(cc_3)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_23._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_23._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'messages')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2214, 4))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_23._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'sessionToken')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    st_4._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_23._Automaton = _BuildAutomaton_121()




def _BuildAutomaton_122 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_122
    del _BuildAutomaton_122
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    counters.add(cc_1)
    states = []
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_24._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantAuthentication')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2140, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_24._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    st_2._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_24._Automaton = _BuildAutomaton_122()




def _BuildAutomaton_123 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_123
    del _BuildAutomaton_123
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    counters.add(cc_3)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_25._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_25._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'messages')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2214, 4))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_25._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'sessionToken')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    st_4._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_25._Automaton = _BuildAutomaton_123()




CTD_ANON_26._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'subscription'), ARBSubscriptionType, scope=CTD_ANON_26, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2308, 6)))

def _BuildAutomaton_124 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_124
    del _BuildAutomaton_124
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2309, 6))
    counters.add(cc_2)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_26._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantAuthentication')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2140, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_26._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_26._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'subscription')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2308, 6))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2309, 6))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
         ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, True) ]))
    st_4._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_26._Automaton = _BuildAutomaton_124()




CTD_ANON_27._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'subscriptionId'), numericString, scope=CTD_ANON_27, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2328, 6)))

CTD_ANON_27._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'profile'), customerProfileIdType, scope=CTD_ANON_27, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2329, 6)))

def _BuildAutomaton_125 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_125
    del _BuildAutomaton_125
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2328, 6))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2329, 6))
    counters.add(cc_5)
    cc_6 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2330, 6))
    counters.add(cc_6)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_27._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_27._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'messages')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2214, 4))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_27._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'sessionToken')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_27._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'subscriptionId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2328, 6))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_27._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'profile')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2329, 6))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_6, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2330, 6))
    st_7 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_7)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    transitions.append(fac.Transition(st_5, [
         ]))
    transitions.append(fac.Transition(st_6, [
         ]))
    transitions.append(fac.Transition(st_7, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_5, True) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_5, False) ]))
    st_6._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_6, True) ]))
    st_7._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_27._Automaton = _BuildAutomaton_125()




CTD_ANON_28._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'subscriptionId'), numericString, scope=CTD_ANON_28, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2348, 6)))

CTD_ANON_28._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'subscription'), ARBSubscriptionType, scope=CTD_ANON_28, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2349, 6)))

def _BuildAutomaton_126 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_126
    del _BuildAutomaton_126
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2350, 6))
    counters.add(cc_2)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_28._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantAuthentication')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2140, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_28._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_28._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'subscriptionId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2348, 6))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_28._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'subscription')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2349, 6))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2350, 6))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
         ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
         ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, True) ]))
    st_5._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_28._Automaton = _BuildAutomaton_126()




CTD_ANON_29._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'profile'), customerProfileIdType, scope=CTD_ANON_29, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2367, 12)))

def _BuildAutomaton_127 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_127
    del _BuildAutomaton_127
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2367, 12))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2368, 11))
    counters.add(cc_5)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_29._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_29._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'messages')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2214, 4))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_29._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'sessionToken')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_29._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'profile')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2367, 12))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2368, 11))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    transitions.append(fac.Transition(st_5, [
         ]))
    transitions.append(fac.Transition(st_6, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_5, True) ]))
    st_6._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_29._Automaton = _BuildAutomaton_127()




CTD_ANON_30._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'subscriptionId'), numericString, scope=CTD_ANON_30, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2386, 6)))

def _BuildAutomaton_128 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_128
    del _BuildAutomaton_128
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2387, 6))
    counters.add(cc_2)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_30._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantAuthentication')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2140, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_30._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_30._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'subscriptionId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2386, 6))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2387, 6))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
         ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, True) ]))
    st_4._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_30._Automaton = _BuildAutomaton_128()




def _BuildAutomaton_129 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_129
    del _BuildAutomaton_129
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    counters.add(cc_3)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_31._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_31._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'messages')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2214, 4))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_31._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'sessionToken')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    st_4._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_31._Automaton = _BuildAutomaton_129()




CTD_ANON_32._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'subscriptionId'), numericString, scope=CTD_ANON_32, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2419, 6)))

def _BuildAutomaton_130 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_130
    del _BuildAutomaton_130
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2420, 6))
    counters.add(cc_2)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_32._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantAuthentication')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2140, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_32._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_32._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'subscriptionId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2419, 6))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2420, 6))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
         ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, True) ]))
    st_4._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_32._Automaton = _BuildAutomaton_130()




CTD_ANON_33._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'status'), ARBSubscriptionStatusEnum, scope=CTD_ANON_33, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2437, 6)))

def _BuildAutomaton_131 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_131
    del _BuildAutomaton_131
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2437, 6))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2438, 6))
    counters.add(cc_5)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_33._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_33._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'messages')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2214, 4))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_33._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'sessionToken')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_33._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'status')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2437, 6))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2438, 6))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    transitions.append(fac.Transition(st_5, [
         ]))
    transitions.append(fac.Transition(st_6, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_5, True) ]))
    st_6._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_33._Automaton = _BuildAutomaton_131()




CTD_ANON_34._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'profile'), customerProfileType, scope=CTD_ANON_34, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2457, 6)))

CTD_ANON_34._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'validationMode'), validationModeEnum, scope=CTD_ANON_34, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2458, 6)))

def _BuildAutomaton_132 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_132
    del _BuildAutomaton_132
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2458, 6))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2459, 6))
    counters.add(cc_3)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_34._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantAuthentication')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2140, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_34._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_34._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'profile')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2457, 6))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_34._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'validationMode')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2458, 6))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2459, 6))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
         ]))
    transitions.append(fac.Transition(st_5, [
         ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, True) ]))
    st_5._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_34._Automaton = _BuildAutomaton_132()




CTD_ANON_35._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), numericString, scope=CTD_ANON_35, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2477, 6)))

CTD_ANON_35._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileIdList'), ArrayOfNumericString, scope=CTD_ANON_35, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2478, 6)))

CTD_ANON_35._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerShippingAddressIdList'), ArrayOfNumericString, scope=CTD_ANON_35, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2479, 6)))

CTD_ANON_35._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'validationDirectResponseList'), ArrayOfString, scope=CTD_ANON_35, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2480, 6)))

def _BuildAutomaton_133 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_133
    del _BuildAutomaton_133
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2477, 6))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2481, 6))
    counters.add(cc_5)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_35._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_35._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'messages')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2214, 4))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_35._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'sessionToken')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_35._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2477, 6))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_35._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileIdList')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2478, 6))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_35._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerShippingAddressIdList')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2479, 6))
    st_7 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_7)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_35._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'validationDirectResponseList')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2480, 6))
    st_8 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_8)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2481, 6))
    st_9 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_9)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    transitions.append(fac.Transition(st_5, [
         ]))
    transitions.append(fac.Transition(st_6, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_7, [
         ]))
    st_6._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_8, [
         ]))
    st_7._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_9, [
         ]))
    st_8._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_5, True) ]))
    st_9._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_35._Automaton = _BuildAutomaton_133()




CTD_ANON_36._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), numericString, scope=CTD_ANON_36, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2517, 6)))

CTD_ANON_36._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'paymentProfile'), customerPaymentProfileType, scope=CTD_ANON_36, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2518, 6)))

CTD_ANON_36._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'validationMode'), validationModeEnum, scope=CTD_ANON_36, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2519, 6)))

def _BuildAutomaton_134 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_134
    del _BuildAutomaton_134
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2519, 6))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2520, 6))
    counters.add(cc_3)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_36._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantAuthentication')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2140, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_36._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_36._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2517, 6))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_36._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'paymentProfile')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2518, 6))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_36._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'validationMode')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2519, 6))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2520, 6))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
         ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
         ]))
    transitions.append(fac.Transition(st_6, [
         ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, True) ]))
    st_6._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_36._Automaton = _BuildAutomaton_134()




CTD_ANON_37._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), numericString, scope=CTD_ANON_37, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2539, 12)))

CTD_ANON_37._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileId'), numericString, scope=CTD_ANON_37, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2540, 12)))

CTD_ANON_37._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'validationDirectResponse'), STD_ANON_97, scope=CTD_ANON_37, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2542, 6)))

def _BuildAutomaton_135 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_135
    del _BuildAutomaton_135
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2539, 12))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2540, 12))
    counters.add(cc_5)
    cc_6 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2542, 6))
    counters.add(cc_6)
    cc_7 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2549, 6))
    counters.add(cc_7)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_37._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_37._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'messages')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2214, 4))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_37._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'sessionToken')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_37._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2539, 12))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_37._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2540, 12))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_6, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_37._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'validationDirectResponse')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2542, 6))
    st_7 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_7)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_7, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2549, 6))
    st_8 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_8)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    transitions.append(fac.Transition(st_5, [
         ]))
    transitions.append(fac.Transition(st_6, [
         ]))
    transitions.append(fac.Transition(st_7, [
         ]))
    transitions.append(fac.Transition(st_8, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_5, True) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_5, False) ]))
    st_6._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_6, True) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_6, False) ]))
    st_7._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_7, True) ]))
    st_8._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_37._Automaton = _BuildAutomaton_135()




CTD_ANON_38._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), numericString, scope=CTD_ANON_38, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2567, 6)))

CTD_ANON_38._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'address'), customerAddressType, scope=CTD_ANON_38, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2568, 6)))

def _BuildAutomaton_136 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_136
    del _BuildAutomaton_136
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2569, 6))
    counters.add(cc_2)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_38._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantAuthentication')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2140, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_38._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_38._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2567, 6))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_38._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'address')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2568, 6))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2569, 6))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
         ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
         ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, True) ]))
    st_5._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_38._Automaton = _BuildAutomaton_136()




CTD_ANON_39._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), numericString, scope=CTD_ANON_39, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2588, 12)))

CTD_ANON_39._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerAddressId'), numericString, scope=CTD_ANON_39, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2589, 12)))

def _BuildAutomaton_137 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_137
    del _BuildAutomaton_137
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2588, 12))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2589, 12))
    counters.add(cc_5)
    cc_6 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2590, 6))
    counters.add(cc_6)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_39._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_39._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'messages')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2214, 4))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_39._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'sessionToken')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_39._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2588, 12))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_39._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerAddressId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2589, 12))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_6, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2590, 6))
    st_7 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_7)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    transitions.append(fac.Transition(st_5, [
         ]))
    transitions.append(fac.Transition(st_6, [
         ]))
    transitions.append(fac.Transition(st_7, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_5, True) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_5, False) ]))
    st_6._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_6, True) ]))
    st_7._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_39._Automaton = _BuildAutomaton_137()




CTD_ANON_40._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'transId'), numericString, scope=CTD_ANON_40, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2607, 12)))

CTD_ANON_40._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customer'), customerProfileBaseType, scope=CTD_ANON_40, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2608, 12)))

CTD_ANON_40._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), numericString, scope=CTD_ANON_40, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2609, 12)))

def _BuildAutomaton_138 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_138
    del _BuildAutomaton_138
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2608, 12))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2609, 12))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2610, 11))
    counters.add(cc_4)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_40._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantAuthentication')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2140, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_40._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_40._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'transId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2607, 12))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_40._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customer')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2608, 12))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_40._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2609, 12))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2610, 11))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
         ]))
    transitions.append(fac.Transition(st_5, [
         ]))
    transitions.append(fac.Transition(st_6, [
         ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, True) ]))
    st_6._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_40._Automaton = _BuildAutomaton_138()




CTD_ANON_41._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), numericString, scope=CTD_ANON_41, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2630, 12)))

def _BuildAutomaton_139 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_139
    del _BuildAutomaton_139
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2631, 11))
    counters.add(cc_2)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_41._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantAuthentication')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2140, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_41._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_41._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2630, 12))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2631, 11))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
         ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, True) ]))
    st_4._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_41._Automaton = _BuildAutomaton_139()




CTD_ANON_42._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'profile'), customerProfileMaskedType, scope=CTD_ANON_42, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2649, 12)))

CTD_ANON_42._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'subscriptionIds'), SubscriptionIdList, scope=CTD_ANON_42, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2650, 12)))

def _BuildAutomaton_140 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_140
    del _BuildAutomaton_140
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2649, 12))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2650, 12))
    counters.add(cc_5)
    cc_6 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2651, 11))
    counters.add(cc_6)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_42._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_42._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'messages')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2214, 4))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_42._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'sessionToken')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_42._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'profile')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2649, 12))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_42._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'subscriptionIds')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2650, 12))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_6, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2651, 11))
    st_7 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_7)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    transitions.append(fac.Transition(st_5, [
         ]))
    transitions.append(fac.Transition(st_6, [
         ]))
    transitions.append(fac.Transition(st_7, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_5, True) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_5, False) ]))
    st_6._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_6, True) ]))
    st_7._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_42._Automaton = _BuildAutomaton_140()




CTD_ANON_43._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), numericString, scope=CTD_ANON_43, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2669, 12)))

CTD_ANON_43._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileId'), numericString, scope=CTD_ANON_43, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2670, 12)))

CTD_ANON_43._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'unmaskExpirationDate'), pyxb.binding.datatypes.boolean, scope=CTD_ANON_43, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2671, 12)))

def _BuildAutomaton_141 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_141
    del _BuildAutomaton_141
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2671, 12))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2672, 11))
    counters.add(cc_3)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_43._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantAuthentication')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2140, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_43._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_43._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2669, 12))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_43._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2670, 12))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_43._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'unmaskExpirationDate')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2671, 12))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2672, 11))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
         ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
         ]))
    transitions.append(fac.Transition(st_6, [
         ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, True) ]))
    st_6._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_43._Automaton = _BuildAutomaton_141()




CTD_ANON_44._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'paymentProfile'), customerPaymentProfileMaskedType, scope=CTD_ANON_44, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2691, 12)))

def _BuildAutomaton_142 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_142
    del _BuildAutomaton_142
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2691, 12))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2692, 11))
    counters.add(cc_5)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_44._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_44._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'messages')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2214, 4))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_44._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'sessionToken')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_44._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'paymentProfile')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2691, 12))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2692, 11))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    transitions.append(fac.Transition(st_5, [
         ]))
    transitions.append(fac.Transition(st_6, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_5, True) ]))
    st_6._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_44._Automaton = _BuildAutomaton_142()




CTD_ANON_45._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), numericString, scope=CTD_ANON_45, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2710, 12)))

CTD_ANON_45._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerAddressId'), numericString, scope=CTD_ANON_45, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2711, 12)))

def _BuildAutomaton_143 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_143
    del _BuildAutomaton_143
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2712, 11))
    counters.add(cc_2)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_45._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantAuthentication')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2140, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_45._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_45._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2710, 12))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_45._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerAddressId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2711, 12))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2712, 11))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
         ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
         ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, True) ]))
    st_5._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_45._Automaton = _BuildAutomaton_143()




CTD_ANON_46._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'address'), customerAddressExType, scope=CTD_ANON_46, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2730, 12)))

CTD_ANON_46._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'subscriptionIds'), SubscriptionIdList, scope=CTD_ANON_46, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2731, 12)))

def _BuildAutomaton_144 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_144
    del _BuildAutomaton_144
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2730, 12))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2731, 12))
    counters.add(cc_5)
    cc_6 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2732, 11))
    counters.add(cc_6)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_46._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_46._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'messages')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2214, 4))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_46._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'sessionToken')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_46._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'address')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2730, 12))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_46._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'subscriptionIds')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2731, 12))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_6, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2732, 11))
    st_7 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_7)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    transitions.append(fac.Transition(st_5, [
         ]))
    transitions.append(fac.Transition(st_6, [
         ]))
    transitions.append(fac.Transition(st_7, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_5, True) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_5, False) ]))
    st_6._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_6, True) ]))
    st_7._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_46._Automaton = _BuildAutomaton_144()




CTD_ANON_47._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'profile'), customerProfileExType, scope=CTD_ANON_47, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2750, 12)))

def _BuildAutomaton_145 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_145
    del _BuildAutomaton_145
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2751, 11))
    counters.add(cc_2)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_47._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantAuthentication')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2140, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_47._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_47._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'profile')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2750, 12))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2751, 11))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
         ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, True) ]))
    st_4._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_47._Automaton = _BuildAutomaton_145()




def _BuildAutomaton_146 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_146
    del _BuildAutomaton_146
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    counters.add(cc_3)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_48._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_48._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'messages')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2214, 4))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_48._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'sessionToken')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    st_4._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_48._Automaton = _BuildAutomaton_146()




CTD_ANON_49._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), numericString, scope=CTD_ANON_49, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2783, 12)))

CTD_ANON_49._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'paymentProfile'), customerPaymentProfileExType, scope=CTD_ANON_49, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2784, 12)))

CTD_ANON_49._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'validationMode'), validationModeEnum, scope=CTD_ANON_49, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2785, 12)))

def _BuildAutomaton_147 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_147
    del _BuildAutomaton_147
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2785, 12))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2786, 11))
    counters.add(cc_3)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_49._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantAuthentication')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2140, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_49._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_49._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2783, 12))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_49._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'paymentProfile')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2784, 12))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_49._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'validationMode')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2785, 12))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2786, 11))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
         ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
         ]))
    transitions.append(fac.Transition(st_6, [
         ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, True) ]))
    st_6._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_49._Automaton = _BuildAutomaton_147()




CTD_ANON_50._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'validationDirectResponse'), STD_ANON_98, scope=CTD_ANON_50, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2804, 12)))

def _BuildAutomaton_148 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_148
    del _BuildAutomaton_148
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2804, 12))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2811, 11))
    counters.add(cc_5)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_50._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_50._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'messages')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2214, 4))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_50._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'sessionToken')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_50._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'validationDirectResponse')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2804, 12))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2811, 11))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    transitions.append(fac.Transition(st_5, [
         ]))
    transitions.append(fac.Transition(st_6, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_5, True) ]))
    st_6._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_50._Automaton = _BuildAutomaton_148()




CTD_ANON_51._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), numericString, scope=CTD_ANON_51, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2829, 12)))

CTD_ANON_51._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'address'), customerAddressExType, scope=CTD_ANON_51, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2830, 12)))

def _BuildAutomaton_149 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_149
    del _BuildAutomaton_149
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2831, 11))
    counters.add(cc_2)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_51._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantAuthentication')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2140, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_51._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_51._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2829, 12))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_51._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'address')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2830, 12))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2831, 11))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
         ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
         ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, True) ]))
    st_5._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_51._Automaton = _BuildAutomaton_149()




def _BuildAutomaton_150 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_150
    del _BuildAutomaton_150
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    counters.add(cc_3)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_52._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_52._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'messages')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2214, 4))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_52._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'sessionToken')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    st_4._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_52._Automaton = _BuildAutomaton_150()




CTD_ANON_53._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), numericString, scope=CTD_ANON_53, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2864, 12)))

def _BuildAutomaton_151 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_151
    del _BuildAutomaton_151
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2865, 11))
    counters.add(cc_2)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_53._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantAuthentication')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2140, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_53._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_53._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2864, 12))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2865, 11))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
         ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, True) ]))
    st_4._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_53._Automaton = _BuildAutomaton_151()




def _BuildAutomaton_152 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_152
    del _BuildAutomaton_152
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    counters.add(cc_3)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_54._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_54._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'messages')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2214, 4))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_54._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'sessionToken')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    st_4._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_54._Automaton = _BuildAutomaton_152()




CTD_ANON_55._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), numericString, scope=CTD_ANON_55, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2897, 12)))

CTD_ANON_55._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileId'), numericString, scope=CTD_ANON_55, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2898, 12)))

def _BuildAutomaton_153 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_153
    del _BuildAutomaton_153
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2899, 11))
    counters.add(cc_2)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_55._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantAuthentication')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2140, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_55._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_55._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2897, 12))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_55._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2898, 12))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2899, 11))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
         ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
         ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, True) ]))
    st_5._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_55._Automaton = _BuildAutomaton_153()




def _BuildAutomaton_154 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_154
    del _BuildAutomaton_154
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    counters.add(cc_3)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_56._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_56._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'messages')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2214, 4))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_56._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'sessionToken')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    st_4._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_56._Automaton = _BuildAutomaton_154()




CTD_ANON_57._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), numericString, scope=CTD_ANON_57, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2931, 12)))

CTD_ANON_57._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerAddressId'), numericString, scope=CTD_ANON_57, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2932, 12)))

def _BuildAutomaton_155 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_155
    del _BuildAutomaton_155
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2933, 11))
    counters.add(cc_2)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_57._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantAuthentication')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2140, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_57._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_57._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2931, 12))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_57._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerAddressId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2932, 12))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2933, 11))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
         ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
         ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, True) ]))
    st_5._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_57._Automaton = _BuildAutomaton_155()




def _BuildAutomaton_156 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_156
    del _BuildAutomaton_156
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    counters.add(cc_3)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_58._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_58._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'messages')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2214, 4))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_58._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'sessionToken')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    st_4._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_58._Automaton = _BuildAutomaton_156()




CTD_ANON_59._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'transaction'), profileTransactionType, scope=CTD_ANON_59, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2965, 12)))

CTD_ANON_59._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'extraOptions'), STD_ANON_99, scope=CTD_ANON_59, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2966, 12)))

def _BuildAutomaton_157 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_157
    del _BuildAutomaton_157
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2966, 12))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2973, 11))
    counters.add(cc_3)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_59._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantAuthentication')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2140, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_59._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_59._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'transaction')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2965, 12))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_59._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'extraOptions')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2966, 12))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2973, 11))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
         ]))
    transitions.append(fac.Transition(st_5, [
         ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, True) ]))
    st_5._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_59._Automaton = _BuildAutomaton_157()




CTD_ANON_60._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'transactionResponse'), transactionResponse, scope=CTD_ANON_60, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2990, 48)))

CTD_ANON_60._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'directResponse'), STD_ANON_100, scope=CTD_ANON_60, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2991, 12)))

def _BuildAutomaton_158 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_158
    del _BuildAutomaton_158
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2990, 48))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2991, 12))
    counters.add(cc_5)
    cc_6 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2998, 11))
    counters.add(cc_6)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_60._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_60._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'messages')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2214, 4))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_60._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'sessionToken')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_60._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'transactionResponse')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2990, 48))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_60._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'directResponse')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2991, 12))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_6, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2998, 11))
    st_7 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_7)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    transitions.append(fac.Transition(st_5, [
         ]))
    transitions.append(fac.Transition(st_6, [
         ]))
    transitions.append(fac.Transition(st_7, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_5, True) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_5, False) ]))
    st_6._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_6, True) ]))
    st_7._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_60._Automaton = _BuildAutomaton_158()




CTD_ANON_61._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), numericString, scope=CTD_ANON_61, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3016, 12)))

CTD_ANON_61._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileId'), numericString, scope=CTD_ANON_61, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3017, 12)))

CTD_ANON_61._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerShippingAddressId'), numericString, scope=CTD_ANON_61, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3018, 12)))

CTD_ANON_61._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'cardCode'), cardCode, scope=CTD_ANON_61, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3019, 12)))

CTD_ANON_61._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'validationMode'), validationModeEnum, scope=CTD_ANON_61, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3020, 12)))

def _BuildAutomaton_159 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_159
    del _BuildAutomaton_159
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3018, 12))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3019, 12))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3021, 11))
    counters.add(cc_4)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_61._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantAuthentication')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2140, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_61._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_61._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3016, 12))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_61._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3017, 12))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_61._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerShippingAddressId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3018, 12))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_61._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'cardCode')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3019, 12))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_61._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'validationMode')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3020, 12))
    st_7 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_7)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3021, 11))
    st_8 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_8)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
         ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
         ]))
    transitions.append(fac.Transition(st_6, [
         ]))
    transitions.append(fac.Transition(st_7, [
         ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_6._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_8, [
         ]))
    st_7._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_4, True) ]))
    st_8._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_61._Automaton = _BuildAutomaton_159()




CTD_ANON_62._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'directResponse'), STD_ANON_101, scope=CTD_ANON_62, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3038, 12)))

def _BuildAutomaton_160 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_160
    del _BuildAutomaton_160
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3038, 12))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3045, 11))
    counters.add(cc_5)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_62._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_62._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'messages')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2214, 4))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_62._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'sessionToken')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_62._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'directResponse')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3038, 12))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3045, 11))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    transitions.append(fac.Transition(st_5, [
         ]))
    transitions.append(fac.Transition(st_6, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_5, True) ]))
    st_6._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_62._Automaton = _BuildAutomaton_160()




def _BuildAutomaton_161 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_161
    del _BuildAutomaton_161
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    counters.add(cc_1)
    states = []
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_63._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantAuthentication')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2140, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_63._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    st_2._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_63._Automaton = _BuildAutomaton_161()




CTD_ANON_64._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'ids'), ArrayOfNumericString, scope=CTD_ANON_64, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3077, 12)))

def _BuildAutomaton_162 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_162
    del _BuildAutomaton_162
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3078, 11))
    counters.add(cc_4)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_64._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_64._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'messages')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2214, 4))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_64._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'sessionToken')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_64._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'ids')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3077, 12))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3078, 11))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    transitions.append(fac.Transition(st_5, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
         ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, True) ]))
    st_6._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_64._Automaton = _BuildAutomaton_162()




CTD_ANON_65._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'splitTenderId'), pyxb.binding.datatypes.string, scope=CTD_ANON_65, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3095, 12)))

CTD_ANON_65._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'splitTenderStatus'), splitTenderStatusEnum, scope=CTD_ANON_65, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3096, 12)))

def _BuildAutomaton_163 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_163
    del _BuildAutomaton_163
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3097, 11))
    counters.add(cc_2)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_65._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantAuthentication')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2140, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_65._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_65._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'splitTenderId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3095, 12))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_65._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'splitTenderStatus')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3096, 12))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3097, 11))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
         ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
         ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, True) ]))
    st_5._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_65._Automaton = _BuildAutomaton_163()




def _BuildAutomaton_164 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_164
    del _BuildAutomaton_164
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    counters.add(cc_3)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_66._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_66._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'messages')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2214, 4))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_66._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'sessionToken')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    st_4._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_66._Automaton = _BuildAutomaton_164()




CTD_ANON_67._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'transId'), numericString, scope=CTD_ANON_67, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3128, 12)))

def _BuildAutomaton_165 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_165
    del _BuildAutomaton_165
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3129, 11))
    counters.add(cc_2)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_67._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantAuthentication')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2140, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_67._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_67._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'transId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3128, 12))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3129, 11))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
         ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, True) ]))
    st_4._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_67._Automaton = _BuildAutomaton_165()




CTD_ANON_68._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'transaction'), transactionDetailsType, scope=CTD_ANON_68, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3146, 6)))

def _BuildAutomaton_166 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_166
    del _BuildAutomaton_166
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3147, 6))
    counters.add(cc_4)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_68._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_68._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'messages')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2214, 4))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_68._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'sessionToken')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_68._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'transaction')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3146, 6))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3147, 6))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    transitions.append(fac.Transition(st_5, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
         ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, True) ]))
    st_6._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_68._Automaton = _BuildAutomaton_166()




CTD_ANON_69._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'transactionRequest'), transactionRequestType, scope=CTD_ANON_69, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3165, 6)))

def _BuildAutomaton_167 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_167
    del _BuildAutomaton_167
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3166, 6))
    counters.add(cc_2)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_69._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantAuthentication')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2140, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_69._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_69._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'transactionRequest')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3165, 6))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3166, 6))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
         ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, True) ]))
    st_4._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_69._Automaton = _BuildAutomaton_167()




CTD_ANON_70._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'transactionResponse'), transactionResponse, scope=CTD_ANON_70, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3184, 6)))

CTD_ANON_70._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'profileResponse'), createProfileResponse, scope=CTD_ANON_70, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3185, 12)))

def _BuildAutomaton_168 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_168
    del _BuildAutomaton_168
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3185, 12))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3186, 6))
    counters.add(cc_5)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_70._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_70._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'messages')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2214, 4))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_70._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'sessionToken')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_70._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'transactionResponse')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3184, 6))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_70._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'profileResponse')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3185, 12))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3186, 6))
    st_7 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_7)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    transitions.append(fac.Transition(st_5, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
         ]))
    transitions.append(fac.Transition(st_7, [
         ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_6._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_5, True) ]))
    st_7._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_70._Automaton = _BuildAutomaton_168()




CTD_ANON_71._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'batchId'), numericString, scope=CTD_ANON_71, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3203, 6)))

def _BuildAutomaton_169 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_169
    del _BuildAutomaton_169
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3204, 6))
    counters.add(cc_2)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_71._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantAuthentication')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2140, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_71._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_71._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'batchId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3203, 6))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3204, 6))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
         ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, True) ]))
    st_4._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_71._Automaton = _BuildAutomaton_169()




CTD_ANON_72._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'batch'), batchDetailsType, scope=CTD_ANON_72, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3221, 6)))

def _BuildAutomaton_170 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_170
    del _BuildAutomaton_170
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3221, 6))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3222, 6))
    counters.add(cc_5)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_72._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_72._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'messages')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2214, 4))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_72._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'sessionToken')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_72._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'batch')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3221, 6))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3222, 6))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    transitions.append(fac.Transition(st_5, [
         ]))
    transitions.append(fac.Transition(st_6, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_5, True) ]))
    st_6._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_72._Automaton = _BuildAutomaton_170()




CTD_ANON_73._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'includeStatistics'), pyxb.binding.datatypes.boolean, scope=CTD_ANON_73, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3239, 6)))

CTD_ANON_73._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'firstSettlementDate'), pyxb.binding.datatypes.dateTime, scope=CTD_ANON_73, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3240, 6)))

CTD_ANON_73._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'lastSettlementDate'), pyxb.binding.datatypes.dateTime, scope=CTD_ANON_73, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3241, 6)))

def _BuildAutomaton_171 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_171
    del _BuildAutomaton_171
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3239, 6))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3240, 6))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3241, 6))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3242, 6))
    counters.add(cc_5)
    states = []
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_73._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantAuthentication')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2140, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_73._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_73._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'includeStatistics')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3239, 6))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_73._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'firstSettlementDate')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3240, 6))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_73._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'lastSettlementDate')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3241, 6))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3242, 6))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    transitions.append(fac.Transition(st_5, [
         ]))
    transitions.append(fac.Transition(st_6, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_5, True) ]))
    st_6._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_73._Automaton = _BuildAutomaton_171()




CTD_ANON_74._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'batchList'), ArrayOfBatchDetailsType, scope=CTD_ANON_74, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3259, 6)))

def _BuildAutomaton_172 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_172
    del _BuildAutomaton_172
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3259, 6))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3260, 6))
    counters.add(cc_5)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_74._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_74._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'messages')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2214, 4))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_74._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'sessionToken')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_74._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'batchList')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3259, 6))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3260, 6))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    transitions.append(fac.Transition(st_5, [
         ]))
    transitions.append(fac.Transition(st_6, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_5, True) ]))
    st_6._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_74._Automaton = _BuildAutomaton_172()




CTD_ANON_75._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'batchId'), numericString, scope=CTD_ANON_75, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3277, 6)))

def _BuildAutomaton_173 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_173
    del _BuildAutomaton_173
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3277, 6))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3278, 6))
    counters.add(cc_3)
    states = []
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_75._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantAuthentication')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2140, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_75._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_75._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'batchId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3277, 6))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3278, 6))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    st_4._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_75._Automaton = _BuildAutomaton_173()




CTD_ANON_76._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'transactions'), ArrayOfTransactionSummaryType, scope=CTD_ANON_76, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3295, 6)))

def _BuildAutomaton_174 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_174
    del _BuildAutomaton_174
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3295, 6))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3296, 6))
    counters.add(cc_5)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_76._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_76._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'messages')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2214, 4))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_76._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'sessionToken')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_76._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'transactions')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3295, 6))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3296, 6))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    transitions.append(fac.Transition(st_5, [
         ]))
    transitions.append(fac.Transition(st_6, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_5, True) ]))
    st_6._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_76._Automaton = _BuildAutomaton_174()




CTD_ANON_77._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId'), numericString, scope=CTD_ANON_77, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3314, 6)))

CTD_ANON_77._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'hostedProfileSettings'), ArrayOfSetting, scope=CTD_ANON_77, documentation='Allowed values for settingName are: hostedProfileReturnUrl, hostedProfileReturnUrlText, hostedProfilePageBorderVisible, hostedProfileIFrameCommunicatorUrl, hostedProfileHeadingBgColor, hostedProfileBillingAddressRequired, hostedProfileCardCodeRequired.', location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3315, 6)))

def _BuildAutomaton_175 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_175
    del _BuildAutomaton_175
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3315, 6))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3320, 6))
    counters.add(cc_3)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_77._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantAuthentication')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2140, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_77._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_77._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3314, 6))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_77._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'hostedProfileSettings')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3315, 6))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3320, 6))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
         ]))
    transitions.append(fac.Transition(st_5, [
         ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, True) ]))
    st_5._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_77._Automaton = _BuildAutomaton_175()




CTD_ANON_78._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'token'), pyxb.binding.datatypes.string, scope=CTD_ANON_78, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3337, 6)))

def _BuildAutomaton_176 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_176
    del _BuildAutomaton_176
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3338, 6))
    counters.add(cc_4)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_78._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_78._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'messages')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2214, 4))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_78._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'sessionToken')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_78._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'token')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3337, 6))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3338, 6))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    transitions.append(fac.Transition(st_5, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
         ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, True) ]))
    st_6._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_78._Automaton = _BuildAutomaton_176()




def _BuildAutomaton_177 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_177
    del _BuildAutomaton_177
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    counters.add(cc_1)
    states = []
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_79._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantAuthentication')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2140, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_79._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    st_2._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_79._Automaton = _BuildAutomaton_177()




CTD_ANON_80._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'transactions'), ArrayOfTransactionSummaryType, scope=CTD_ANON_80, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3369, 6)))

def _BuildAutomaton_178 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_178
    del _BuildAutomaton_178
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3369, 6))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3370, 6))
    counters.add(cc_5)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_80._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_80._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'messages')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2214, 4))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_80._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'sessionToken')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_80._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'transactions')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3369, 6))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3370, 6))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    transitions.append(fac.Transition(st_5, [
         ]))
    transitions.append(fac.Transition(st_6, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_5, True) ]))
    st_6._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_80._Automaton = _BuildAutomaton_178()




CTD_ANON_81._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'mobileDevice'), mobileDeviceType, scope=CTD_ANON_81, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3388, 6)))

def _BuildAutomaton_179 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_179
    del _BuildAutomaton_179
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3389, 6))
    counters.add(cc_2)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_81._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantAuthentication')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2140, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_81._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_81._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'mobileDevice')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3388, 6))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3389, 6))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
         ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, True) ]))
    st_4._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_81._Automaton = _BuildAutomaton_179()




def _BuildAutomaton_180 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_180
    del _BuildAutomaton_180
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    counters.add(cc_3)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_82._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_82._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'messages')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2214, 4))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_82._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'sessionToken')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    st_4._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_82._Automaton = _BuildAutomaton_180()




def _BuildAutomaton_181 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_181
    del _BuildAutomaton_181
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    counters.add(cc_1)
    states = []
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_83._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantAuthentication')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2140, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_83._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    st_2._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_83._Automaton = _BuildAutomaton_181()




CTD_ANON_84._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'merchantContact'), merchantContactType, scope=CTD_ANON_84, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3432, 6)))

CTD_ANON_84._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'userPermissions'), ArrayOfPermissionType, scope=CTD_ANON_84, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3433, 6)))

CTD_ANON_84._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'merchantAccount'), transRetailInfoType, scope=CTD_ANON_84, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3434, 24)))

def _BuildAutomaton_182 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_182
    del _BuildAutomaton_182
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3434, 24))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3435, 6))
    counters.add(cc_5)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_84._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_84._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'messages')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2214, 4))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_84._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'sessionToken')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_84._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantContact')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3432, 6))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_84._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'userPermissions')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3433, 6))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_84._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantAccount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3434, 24))
    st_7 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_7)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3435, 6))
    st_8 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_8)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    transitions.append(fac.Transition(st_5, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
         ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_7, [
         ]))
    transitions.append(fac.Transition(st_8, [
         ]))
    st_6._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_7._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_5, True) ]))
    st_8._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_84._Automaton = _BuildAutomaton_182()




def _BuildAutomaton_183 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_183
    del _BuildAutomaton_183
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    counters.add(cc_1)
    states = []
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_85._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantAuthentication')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2140, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_85._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    st_2._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_85._Automaton = _BuildAutomaton_183()




def _BuildAutomaton_184 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_184
    del _BuildAutomaton_184
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    counters.add(cc_3)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_86._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_86._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'messages')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2214, 4))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_86._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'sessionToken')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    st_4._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_86._Automaton = _BuildAutomaton_184()




CTD_ANON_87._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'transId'), numericString, scope=CTD_ANON_87, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3478, 6)))

CTD_ANON_87._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerEmail'), pyxb.binding.datatypes.string, scope=CTD_ANON_87, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3479, 6)))

CTD_ANON_87._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'emailSettings'), emailSettingsType, scope=CTD_ANON_87, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3480, 6)))

def _BuildAutomaton_185 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_185
    del _BuildAutomaton_185
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3480, 6))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3481, 6))
    counters.add(cc_3)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_87._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantAuthentication')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2140, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_87._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_87._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'transId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3478, 6))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_87._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerEmail')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3479, 6))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_87._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'emailSettings')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3480, 6))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3481, 6))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
         ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
         ]))
    transitions.append(fac.Transition(st_6, [
         ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, True) ]))
    st_6._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_87._Automaton = _BuildAutomaton_185()




def _BuildAutomaton_186 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_186
    del _BuildAutomaton_186
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    counters.add(cc_3)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_88._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_88._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'messages')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2214, 4))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_88._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'sessionToken')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    st_4._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_88._Automaton = _BuildAutomaton_186()




CTD_ANON_89._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'searchType'), ARBGetSubscriptionListSearchTypeEnum, scope=CTD_ANON_89, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3557, 6)))

CTD_ANON_89._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'sorting'), ARBGetSubscriptionListSorting, scope=CTD_ANON_89, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3558, 6)))

CTD_ANON_89._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'paging'), Paging, scope=CTD_ANON_89, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3559, 6)))

def _BuildAutomaton_187 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_187
    del _BuildAutomaton_187
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3558, 6))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3559, 6))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3560, 6))
    counters.add(cc_4)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_89._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantAuthentication')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2140, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_89._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_89._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'searchType')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3557, 6))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_89._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'sorting')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3558, 6))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_89._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'paging')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3559, 6))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3560, 6))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
         ]))
    transitions.append(fac.Transition(st_5, [
         ]))
    transitions.append(fac.Transition(st_6, [
         ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, True) ]))
    st_6._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_89._Automaton = _BuildAutomaton_187()




CTD_ANON_90._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'totalNumInResultSet'), pyxb.binding.datatypes.int, scope=CTD_ANON_90, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3620, 6)))

CTD_ANON_90._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'subscriptionDetails'), ArrayOfSubscription, scope=CTD_ANON_90, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3621, 6)))

def _BuildAutomaton_188 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_188
    del _BuildAutomaton_188
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3620, 6))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3621, 6))
    counters.add(cc_5)
    cc_6 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3622, 6))
    counters.add(cc_6)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_90._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_90._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'messages')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2214, 4))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_90._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'sessionToken')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_90._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'totalNumInResultSet')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3620, 6))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_90._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'subscriptionDetails')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3621, 6))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_6, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3622, 6))
    st_7 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_7)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    transitions.append(fac.Transition(st_5, [
         ]))
    transitions.append(fac.Transition(st_6, [
         ]))
    transitions.append(fac.Transition(st_7, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_5, True) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_5, False) ]))
    st_6._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_6, True) ]))
    st_7._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_90._Automaton = _BuildAutomaton_188()




CTD_ANON_91._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'searchType'), CustomerPaymentProfileSearchTypeEnum, scope=CTD_ANON_91, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3733, 6)))

CTD_ANON_91._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'month'), STD_ANON_111, scope=CTD_ANON_91, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3734, 24)))

CTD_ANON_91._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'sorting'), CustomerPaymentProfileSorting, scope=CTD_ANON_91, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3742, 6)))

CTD_ANON_91._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'paging'), Paging, scope=CTD_ANON_91, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3743, 6)))

def _BuildAutomaton_189 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_189
    del _BuildAutomaton_189
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3742, 6))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3743, 6))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3744, 6))
    counters.add(cc_4)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_91._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantAuthentication')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2140, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_91._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_91._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'searchType')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3733, 6))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_91._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'month')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3734, 24))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_91._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'sorting')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3742, 6))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_91._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'paging')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3743, 6))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3744, 6))
    st_7 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_7)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
         ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
         ]))
    transitions.append(fac.Transition(st_6, [
         ]))
    transitions.append(fac.Transition(st_7, [
         ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_6._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_4, True) ]))
    st_7._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_91._Automaton = _BuildAutomaton_189()




CTD_ANON_92._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'totalNumInResultSet'), pyxb.binding.datatypes.int, scope=CTD_ANON_92, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3755, 6)))

CTD_ANON_92._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'paymentProfiles'), arrayOfCustomerPaymentProfileListItemType, scope=CTD_ANON_92, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3756, 6)))

def _BuildAutomaton_190 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_190
    del _BuildAutomaton_190
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3756, 6))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3757, 6))
    counters.add(cc_5)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_92._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_92._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'messages')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2214, 4))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_92._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'sessionToken')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_92._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'totalNumInResultSet')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3755, 6))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_92._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'paymentProfiles')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3756, 6))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3757, 6))
    st_7 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_7)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    transitions.append(fac.Transition(st_5, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
         ]))
    transitions.append(fac.Transition(st_7, [
         ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_6._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_5, True) ]))
    st_7._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_92._Automaton = _BuildAutomaton_190()




CTD_ANON_93._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'subscriptionId'), numericString, scope=CTD_ANON_93, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3809, 6)))

def _BuildAutomaton_191 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_191
    del _BuildAutomaton_191
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3810, 6))
    counters.add(cc_2)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_93._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantAuthentication')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2140, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_93._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2141, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2148, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_93._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'subscriptionId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3809, 6))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3810, 6))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
         ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, True) ]))
    st_4._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_93._Automaton = _BuildAutomaton_191()




CTD_ANON_94._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'subscription'), ARBSubscriptionMaskedType, scope=CTD_ANON_94, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3827, 4)))

def _BuildAutomaton_192 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_192
    del _BuildAutomaton_192
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3828, 4))
    counters.add(cc_4)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_94._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'refId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2212, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_94._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'messages')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2214, 4))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2215, 4))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_94._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'sessionToken')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2217, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 2218, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(CTD_ANON_94._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'subscription')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3827, 4))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 3828, 4))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    transitions.append(fac.Transition(st_5, [
         ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
         ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, True) ]))
    st_6._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
CTD_ANON_94._Automaton = _BuildAutomaton_192()




subscriptionCustomerProfileType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'paymentProfile'), customerPaymentProfileMaskedType, scope=subscriptionCustomerProfileType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1096, 16)))

subscriptionCustomerProfileType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'shippingProfile'), customerAddressExType, scope=subscriptionCustomerProfileType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1097, 16)))

def _BuildAutomaton_193 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_193
    del _BuildAutomaton_193
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1487, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1494, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1501, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1508, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1537, 5))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1538, 5))
    counters.add(cc_5)
    cc_6 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1096, 16))
    counters.add(cc_6)
    cc_7 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1097, 16))
    counters.add(cc_7)
    cc_8 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1098, 13))
    counters.add(cc_8)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(subscriptionCustomerProfileType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantCustomerId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1487, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(subscriptionCustomerProfileType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'description')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1494, 3))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(subscriptionCustomerProfileType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'email')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1501, 3))
    st_2 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1508, 3))
    st_3 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.ElementUse(subscriptionCustomerProfileType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1537, 5))
    st_4 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1538, 5))
    st_5 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_6, False))
    symbol = pyxb.binding.content.ElementUse(subscriptionCustomerProfileType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'paymentProfile')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1096, 16))
    st_6 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_7, False))
    symbol = pyxb.binding.content.ElementUse(subscriptionCustomerProfileType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'shippingProfile')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1097, 16))
    st_7 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_7)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_8, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1098, 13))
    st_8 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_8)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_5, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_5, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_6, True) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_6, False) ]))
    st_6._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_7, True) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_7, False) ]))
    st_7._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_8, True) ]))
    st_8._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
subscriptionCustomerProfileType._Automaton = _BuildAutomaton_193()




customerPaymentProfileExType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileId'), numericString, scope=customerPaymentProfileExType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1447, 5)))

def _BuildAutomaton_194 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_194
    del _BuildAutomaton_194
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1416, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1417, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1418, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1426, 5))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1427, 5))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1429, 5))
    counters.add(cc_5)
    cc_6 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1437, 5))
    counters.add(cc_6)
    cc_7 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1447, 5))
    counters.add(cc_7)
    cc_8 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1448, 5))
    counters.add(cc_8)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(customerPaymentProfileExType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerType')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1416, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(customerPaymentProfileExType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'billTo')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1417, 3))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1418, 3))
    st_2 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.ElementUse(customerPaymentProfileExType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'payment')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1426, 5))
    st_3 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.ElementUse(customerPaymentProfileExType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'driversLicense')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1427, 5))
    st_4 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.ElementUse(customerPaymentProfileExType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'taxId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1429, 5))
    st_5 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_6, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1437, 5))
    st_6 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_7, False))
    symbol = pyxb.binding.content.ElementUse(customerPaymentProfileExType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1447, 5))
    st_7 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_7)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_8, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1448, 5))
    st_8 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_8)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_5, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_5, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_6, True) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_6, False) ]))
    st_6._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_7, True) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_7, False) ]))
    st_7._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_8, True) ]))
    st_8._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
customerPaymentProfileExType._Automaton = _BuildAutomaton_194()




customerProfileMaskedType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'paymentProfiles'), customerPaymentProfileMaskedType, scope=customerProfileMaskedType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1548, 5)))

customerProfileMaskedType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'shipToList'), customerAddressExType, scope=customerProfileMaskedType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1549, 5)))

def _BuildAutomaton_195 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_195
    del _BuildAutomaton_195
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1487, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1494, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1501, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1508, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1537, 5))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1538, 5))
    counters.add(cc_5)
    cc_6 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1548, 5))
    counters.add(cc_6)
    cc_7 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1549, 5))
    counters.add(cc_7)
    cc_8 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1550, 5))
    counters.add(cc_8)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(customerProfileMaskedType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'merchantCustomerId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1487, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(customerProfileMaskedType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'description')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1494, 3))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(customerProfileMaskedType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'email')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1501, 3))
    st_2 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1508, 3))
    st_3 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.ElementUse(customerProfileMaskedType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1537, 5))
    st_4 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1538, 5))
    st_5 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_6, False))
    symbol = pyxb.binding.content.ElementUse(customerProfileMaskedType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'paymentProfiles')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1548, 5))
    st_6 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_7, False))
    symbol = pyxb.binding.content.ElementUse(customerProfileMaskedType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'shipToList')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1549, 5))
    st_7 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_7)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_8, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1550, 5))
    st_8 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_8)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_5, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_5, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_6, True) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_6, False) ]))
    st_6._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_7, True) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_7, False) ]))
    st_7._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_8, True) ]))
    st_8._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
customerProfileMaskedType._Automaton = _BuildAutomaton_195()




customerAddressExType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'customerAddressId'), numericString, scope=customerAddressExType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1585, 5)))

def _BuildAutomaton_196 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_196
    del _BuildAutomaton_196
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 317, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 324, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 331, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 338, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 345, 3))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 352, 3))
    counters.add(cc_5)
    cc_6 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 359, 3))
    counters.add(cc_6)
    cc_7 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 366, 3))
    counters.add(cc_7)
    cc_8 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 373, 3))
    counters.add(cc_8)
    cc_9 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1560, 5))
    counters.add(cc_9)
    cc_10 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1567, 5))
    counters.add(cc_10)
    cc_11 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1574, 14))
    counters.add(cc_11)
    cc_12 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1575, 5))
    counters.add(cc_12)
    cc_13 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1585, 5))
    counters.add(cc_13)
    cc_14 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1586, 5))
    counters.add(cc_14)
    states = []
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_0, False))
    symbol = pyxb.binding.content.ElementUse(customerAddressExType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'firstName')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 317, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_1, False))
    symbol = pyxb.binding.content.ElementUse(customerAddressExType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'lastName')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 324, 3))
    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_2, False))
    symbol = pyxb.binding.content.ElementUse(customerAddressExType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'company')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 331, 3))
    st_2 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_3, False))
    symbol = pyxb.binding.content.ElementUse(customerAddressExType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'address')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 338, 3))
    st_3 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_4, False))
    symbol = pyxb.binding.content.ElementUse(customerAddressExType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'city')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 345, 3))
    st_4 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.ElementUse(customerAddressExType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'state')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 352, 3))
    st_5 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_6, False))
    symbol = pyxb.binding.content.ElementUse(customerAddressExType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'zip')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 359, 3))
    st_6 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_7, False))
    symbol = pyxb.binding.content.ElementUse(customerAddressExType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'country')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 366, 3))
    st_7 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_7)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_8, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 373, 3))
    st_8 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_8)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_9, False))
    symbol = pyxb.binding.content.ElementUse(customerAddressExType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'phoneNumber')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1560, 5))
    st_9 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_9)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_10, False))
    symbol = pyxb.binding.content.ElementUse(customerAddressExType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'faxNumber')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1567, 5))
    st_10 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_10)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_11, False))
    symbol = pyxb.binding.content.ElementUse(customerAddressExType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'email')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1574, 14))
    st_11 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_11)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_12, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1575, 5))
    st_12 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_12)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_13, False))
    symbol = pyxb.binding.content.ElementUse(customerAddressExType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerAddressId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1585, 5))
    st_13 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_13)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_14, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1586, 5))
    st_14 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_14)
    transitions = []
    transitions.append(fac.Transition(st_0, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_4, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_5, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_5, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_6, True) ]))
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_6, False) ]))
    st_6._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_7, [
        fac.UpdateInstruction(cc_7, True) ]))
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_7, False) ]))
    st_7._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_8, True) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_8, False) ]))
    st_8._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_9, True) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_9, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_9, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_9, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_9, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_9, False) ]))
    st_9._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_10, True) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_10, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_10, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_10, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_10, False) ]))
    st_10._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_11, True) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_11, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_11, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_11, False) ]))
    st_11._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_12, True) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_12, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_12, False) ]))
    st_12._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_13, True) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_13, False) ]))
    st_13._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_14, True) ]))
    st_14._set_transitionSet(transitions)
    return fac.Automaton(states, counters, True, containing_state=None)
customerAddressExType._Automaton = _BuildAutomaton_196()




def _BuildAutomaton_197 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_197
    del _BuildAutomaton_197
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1676, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1677, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1678, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=30, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1679, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1680, 3))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1690, 5))
    counters.add(cc_5)
    cc_6 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1691, 5))
    counters.add(cc_6)
    cc_7 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1692, 5))
    counters.add(cc_7)
    cc_8 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1693, 5))
    counters.add(cc_8)
    cc_9 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1694, 5))
    counters.add(cc_9)
    cc_10 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1695, 5))
    counters.add(cc_10)
    cc_11 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1696, 5))
    counters.add(cc_11)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(profileTransAuthCaptureType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'amount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1668, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(profileTransAuthCaptureType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'tax')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1676, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(profileTransAuthCaptureType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'shipping')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1677, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(profileTransAuthCaptureType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'duty')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1678, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(profileTransAuthCaptureType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'lineItems')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1679, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1680, 3))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(profileTransAuthCaptureType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1688, 5))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(profileTransAuthCaptureType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1689, 5))
    st_7 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_7)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.ElementUse(profileTransAuthCaptureType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerShippingAddressId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1690, 5))
    st_8 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_8)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_6, False))
    symbol = pyxb.binding.content.ElementUse(profileTransAuthCaptureType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'order')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1691, 5))
    st_9 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_9)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_7, False))
    symbol = pyxb.binding.content.ElementUse(profileTransAuthCaptureType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'taxExempt')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1692, 5))
    st_10 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_10)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_8, False))
    symbol = pyxb.binding.content.ElementUse(profileTransAuthCaptureType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'recurringBilling')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1693, 5))
    st_11 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_11)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_9, False))
    symbol = pyxb.binding.content.ElementUse(profileTransAuthCaptureType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'cardCode')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1694, 5))
    st_12 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_12)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_10, False))
    symbol = pyxb.binding.content.ElementUse(profileTransAuthCaptureType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'splitTenderId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1695, 5))
    st_13 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_13)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_11, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1696, 5))
    st_14 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_14)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    transitions.append(fac.Transition(st_5, [
         ]))
    transitions.append(fac.Transition(st_6, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_7, [
         ]))
    st_6._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_8, [
         ]))
    transitions.append(fac.Transition(st_9, [
         ]))
    transitions.append(fac.Transition(st_10, [
         ]))
    transitions.append(fac.Transition(st_11, [
         ]))
    transitions.append(fac.Transition(st_12, [
         ]))
    transitions.append(fac.Transition(st_13, [
         ]))
    transitions.append(fac.Transition(st_14, [
         ]))
    st_7._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_5, True) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_5, False) ]))
    st_8._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_6, True) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_6, False) ]))
    st_9._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_7, True) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_7, False) ]))
    st_10._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_8, True) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_8, False) ]))
    st_11._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_9, True) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_9, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_9, False) ]))
    st_12._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_10, True) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_10, False) ]))
    st_13._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_11, True) ]))
    st_14._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
profileTransAuthCaptureType._Automaton = _BuildAutomaton_197()




def _BuildAutomaton_198 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_198
    del _BuildAutomaton_198
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1676, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1677, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1678, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=30, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1679, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1680, 3))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1690, 5))
    counters.add(cc_5)
    cc_6 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1691, 5))
    counters.add(cc_6)
    cc_7 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1692, 5))
    counters.add(cc_7)
    cc_8 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1693, 5))
    counters.add(cc_8)
    cc_9 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1694, 5))
    counters.add(cc_9)
    cc_10 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1695, 5))
    counters.add(cc_10)
    cc_11 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1696, 5))
    counters.add(cc_11)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(profileTransAuthOnlyType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'amount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1668, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(profileTransAuthOnlyType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'tax')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1676, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(profileTransAuthOnlyType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'shipping')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1677, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(profileTransAuthOnlyType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'duty')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1678, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(profileTransAuthOnlyType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'lineItems')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1679, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1680, 3))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(profileTransAuthOnlyType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1688, 5))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(profileTransAuthOnlyType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1689, 5))
    st_7 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_7)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_5, False))
    symbol = pyxb.binding.content.ElementUse(profileTransAuthOnlyType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerShippingAddressId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1690, 5))
    st_8 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_8)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_6, False))
    symbol = pyxb.binding.content.ElementUse(profileTransAuthOnlyType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'order')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1691, 5))
    st_9 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_9)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_7, False))
    symbol = pyxb.binding.content.ElementUse(profileTransAuthOnlyType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'taxExempt')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1692, 5))
    st_10 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_10)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_8, False))
    symbol = pyxb.binding.content.ElementUse(profileTransAuthOnlyType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'recurringBilling')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1693, 5))
    st_11 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_11)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_9, False))
    symbol = pyxb.binding.content.ElementUse(profileTransAuthOnlyType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'cardCode')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1694, 5))
    st_12 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_12)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_10, False))
    symbol = pyxb.binding.content.ElementUse(profileTransAuthOnlyType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'splitTenderId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1695, 5))
    st_13 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_13)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_11, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1696, 5))
    st_14 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_14)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    transitions.append(fac.Transition(st_5, [
         ]))
    transitions.append(fac.Transition(st_6, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_7, [
         ]))
    st_6._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_8, [
         ]))
    transitions.append(fac.Transition(st_9, [
         ]))
    transitions.append(fac.Transition(st_10, [
         ]))
    transitions.append(fac.Transition(st_11, [
         ]))
    transitions.append(fac.Transition(st_12, [
         ]))
    transitions.append(fac.Transition(st_13, [
         ]))
    transitions.append(fac.Transition(st_14, [
         ]))
    st_7._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_5, True) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_5, False) ]))
    st_8._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_6, True) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_6, False) ]))
    st_9._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_7, True) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_7, False) ]))
    st_10._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_8, True) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_8, False) ]))
    st_11._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_9, True) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_9, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_9, False) ]))
    st_12._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_10, True) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_10, False) ]))
    st_13._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_11, True) ]))
    st_14._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
profileTransAuthOnlyType._Automaton = _BuildAutomaton_198()




profileTransCaptureOnlyType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'approvalCode'), STD_ANON_82, scope=profileTransCaptureOnlyType, location=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1734, 5)))

def _BuildAutomaton_199 ():
    # Remove this helper function from the namespace after it is invoked
    global _BuildAutomaton_199
    del _BuildAutomaton_199
    import pyxb.utils.fac as fac

    counters = set()
    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1676, 3))
    counters.add(cc_0)
    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1677, 3))
    counters.add(cc_1)
    cc_2 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1678, 3))
    counters.add(cc_2)
    cc_3 = fac.CounterCondition(min=0, max=30, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1679, 3))
    counters.add(cc_3)
    cc_4 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1680, 3))
    counters.add(cc_4)
    cc_5 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1690, 5))
    counters.add(cc_5)
    cc_6 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1691, 5))
    counters.add(cc_6)
    cc_7 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1692, 5))
    counters.add(cc_7)
    cc_8 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1693, 5))
    counters.add(cc_8)
    cc_9 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1694, 5))
    counters.add(cc_9)
    cc_10 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1695, 5))
    counters.add(cc_10)
    cc_11 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1696, 5))
    counters.add(cc_11)
    cc_12 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1741, 5))
    counters.add(cc_12)
    states = []
    final_update = None
    symbol = pyxb.binding.content.ElementUse(profileTransCaptureOnlyType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'amount')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1668, 3))
    st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
    states.append(st_0)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(profileTransCaptureOnlyType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'tax')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1676, 3))
    st_1 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_1)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(profileTransCaptureOnlyType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'shipping')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1677, 3))
    st_2 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_2)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(profileTransCaptureOnlyType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'duty')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1678, 3))
    st_3 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_3)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(profileTransCaptureOnlyType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'lineItems')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1679, 3))
    st_4 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_4)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1680, 3))
    st_5 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_5)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(profileTransCaptureOnlyType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1688, 5))
    st_6 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_6)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(profileTransCaptureOnlyType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerPaymentProfileId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1689, 5))
    st_7 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_7)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(profileTransCaptureOnlyType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'customerShippingAddressId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1690, 5))
    st_8 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_8)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(profileTransCaptureOnlyType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'order')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1691, 5))
    st_9 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_9)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(profileTransCaptureOnlyType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'taxExempt')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1692, 5))
    st_10 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_10)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(profileTransCaptureOnlyType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'recurringBilling')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1693, 5))
    st_11 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_11)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(profileTransCaptureOnlyType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'cardCode')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1694, 5))
    st_12 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_12)
    final_update = None
    symbol = pyxb.binding.content.ElementUse(profileTransCaptureOnlyType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'splitTenderId')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1695, 5))
    st_13 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_13)
    final_update = None
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1696, 5))
    st_14 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_14)
    final_update = set()
    symbol = pyxb.binding.content.ElementUse(profileTransCaptureOnlyType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'approvalCode')), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1734, 5))
    st_15 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_15)
    final_update = set()
    final_update.add(fac.UpdateInstruction(cc_12, False))
    symbol = pyxb.binding.content.WildcardUse(pyxb.binding.content.Wildcard(process_contents=pyxb.binding.content.Wildcard.PC_lax, namespace_constraint=pyxb.binding.content.Wildcard.NC_any), pyxb.utils.utility.Location('C:\\Users\\krgupta\\Desktop\\xsd-bindings\\AnetOut_NewWithany.xsd', 1741, 5))
    st_16 = fac.State(symbol, is_initial=False, final_update=final_update, is_unordered_catenation=False)
    states.append(st_16)
    transitions = []
    transitions.append(fac.Transition(st_1, [
         ]))
    transitions.append(fac.Transition(st_2, [
         ]))
    transitions.append(fac.Transition(st_3, [
         ]))
    transitions.append(fac.Transition(st_4, [
         ]))
    transitions.append(fac.Transition(st_5, [
         ]))
    transitions.append(fac.Transition(st_6, [
         ]))
    st_0._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_1, [
        fac.UpdateInstruction(cc_0, True) ]))
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_0, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_0, False) ]))
    st_1._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_2, [
        fac.UpdateInstruction(cc_1, True) ]))
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_1, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_1, False) ]))
    st_2._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_3, [
        fac.UpdateInstruction(cc_2, True) ]))
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_2, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_2, False) ]))
    st_3._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_4, [
        fac.UpdateInstruction(cc_3, True) ]))
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_3, False) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_3, False) ]))
    st_4._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_5, [
        fac.UpdateInstruction(cc_4, True) ]))
    transitions.append(fac.Transition(st_6, [
        fac.UpdateInstruction(cc_4, False) ]))
    st_5._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_7, [
         ]))
    st_6._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_8, [
         ]))
    transitions.append(fac.Transition(st_9, [
         ]))
    transitions.append(fac.Transition(st_10, [
         ]))
    transitions.append(fac.Transition(st_11, [
         ]))
    transitions.append(fac.Transition(st_12, [
         ]))
    transitions.append(fac.Transition(st_13, [
         ]))
    transitions.append(fac.Transition(st_14, [
         ]))
    transitions.append(fac.Transition(st_15, [
         ]))
    st_7._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_8, [
        fac.UpdateInstruction(cc_5, True) ]))
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_5, False) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_5, False) ]))
    st_8._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_9, [
        fac.UpdateInstruction(cc_6, True) ]))
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_6, False) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_6, False) ]))
    st_9._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_10, [
        fac.UpdateInstruction(cc_7, True) ]))
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_7, False) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_7, False) ]))
    st_10._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_11, [
        fac.UpdateInstruction(cc_8, True) ]))
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_8, False) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_8, False) ]))
    st_11._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_12, [
        fac.UpdateInstruction(cc_9, True) ]))
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_9, False) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_9, False) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_9, False) ]))
    st_12._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_13, [
        fac.UpdateInstruction(cc_10, True) ]))
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_10, False) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_10, False) ]))
    st_13._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_14, [
        fac.UpdateInstruction(cc_11, True) ]))
    transitions.append(fac.Transition(st_15, [
        fac.UpdateInstruction(cc_11, False) ]))
    st_14._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_16, [
         ]))
    st_15._set_transitionSet(transitions)
    transitions = []
    transitions.append(fac.Transition(st_16, [
        fac.UpdateInstruction(cc_12, True) ]))
    st_16._set_transitionSet(transitions)
    return fac.Automaton(states, counters, False, containing_state=None)
profileTransCaptureOnlyType._Automaton = _BuildAutomaton_199()

